package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMAPPLY;
import cn.ibizlab.eam.core.eam_core.service.IEMAPPLYService;
import cn.ibizlab.eam.core.eam_core.filter.EMAPPLYSearchContext;




@Slf4j
@Api(tags = {"EMAPPLY" })
@RestController("WebApi-emapply")
@RequestMapping("")
public class EMAPPLYResource {

    @Autowired
    private IEMAPPLYService emapplyService;

    @Autowired
    @Lazy
    private EMAPPLYMapping emapplyMapping;




    @PreAuthorize("hasPermission('Remove',{#emapply_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMAPPLY" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emapplies/{emapply_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emapply_id") String emapply_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emapplyService.remove(emapply_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMAPPLY" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emapplies/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emapplyService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emapply_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMAPPLY" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emapplies/{emapply_id}")
    @Transactional
    public ResponseEntity<EMAPPLYDTO> update(@PathVariable("emapply_id") String emapply_id, @RequestBody EMAPPLYDTO emapplydto) {
		EMAPPLY domain = emapplyMapping.toDomain(emapplydto);
        domain.setEmapplyid(emapply_id);
		emapplyService.update(domain);
		EMAPPLYDTO dto = emapplyMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emapply_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMAPPLY" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emapplies/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMAPPLYDTO> emapplydtos) {
        emapplyService.updateBatch(emapplyMapping.toDomain(emapplydtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMAPPLY" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emapplies/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMAPPLYDTO emapplydto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emapplyService.checkKey(emapplyMapping.toDomain(emapplydto)));
    }




    @ApiOperation(value = "Save", tags = {"EMAPPLY" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emapplies/save")
    public ResponseEntity<Boolean> save(@RequestBody EMAPPLYDTO emapplydto) {
        return ResponseEntity.status(HttpStatus.OK).body(emapplyService.save(emapplyMapping.toDomain(emapplydto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMAPPLY" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emapplies/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMAPPLYDTO> emapplydtos) {
        emapplyService.saveBatch(emapplyMapping.toDomain(emapplydtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMAPPLY" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emapplies/getdraft")
    public ResponseEntity<EMAPPLYDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emapplyMapping.toDto(emapplyService.getDraft(new EMAPPLY())));
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMAPPLY" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emapplies")
    @Transactional
    public ResponseEntity<EMAPPLYDTO> create(@RequestBody EMAPPLYDTO emapplydto) {
        EMAPPLY domain = emapplyMapping.toDomain(emapplydto);
		emapplyService.create(domain);
        EMAPPLYDTO dto = emapplyMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMAPPLY" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emapplies/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMAPPLYDTO> emapplydtos) {
        emapplyService.createBatch(emapplyMapping.toDomain(emapplydtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emapply_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMAPPLY" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emapplies/{emapply_id}")
    public ResponseEntity<EMAPPLYDTO> get(@PathVariable("emapply_id") String emapply_id) {
        EMAPPLY domain = emapplyService.get(emapply_id);
        EMAPPLYDTO dto = emapplyMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMAPPLY" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emapplies/fetchdefault")
	public ResponseEntity<List<EMAPPLYDTO>> fetchDefault(EMAPPLYSearchContext context) {
        Page<EMAPPLY> domains = emapplyService.searchDefault(context) ;
        List<EMAPPLYDTO> list = emapplyMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMAPPLY" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emapplies/searchdefault")
	public ResponseEntity<Page<EMAPPLYDTO>> searchDefault(EMAPPLYSearchContext context) {
        Page<EMAPPLY> domains = emapplyService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emapplyMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "RemoveByEMEQUIP", tags = {"EMAPPLY" },  notes = "RemoveByEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emequips/{emequip_id}/emapplies/{emapply_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @PathVariable("emapply_id") String emapply_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emapplyService.remove(emapply_id));
    }

    @ApiOperation(value = "RemoveBatchByEMEQUIP", tags = {"EMAPPLY" },  notes = "RemoveBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emequips/{emequip_id}/emapplies/batch")
    public ResponseEntity<Boolean> removeBatchByEMEQUIP(@RequestBody List<String> ids) {
        emapplyService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMEQUIP", tags = {"EMAPPLY" },  notes = "UpdateByEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emequips/{emequip_id}/emapplies/{emapply_id}")
    @Transactional
    public ResponseEntity<EMAPPLYDTO> updateByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @PathVariable("emapply_id") String emapply_id, @RequestBody EMAPPLYDTO emapplydto) {
        EMAPPLY domain = emapplyMapping.toDomain(emapplydto);
        domain.setEquipid(emequip_id);
        domain.setEmapplyid(emapply_id);
		emapplyService.update(domain);
        EMAPPLYDTO dto = emapplyMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMEQUIP", tags = {"EMAPPLY" },  notes = "UpdateBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emequips/{emequip_id}/emapplies/batch")
    public ResponseEntity<Boolean> updateBatchByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody List<EMAPPLYDTO> emapplydtos) {
        List<EMAPPLY> domainlist=emapplyMapping.toDomain(emapplydtos);
        for(EMAPPLY domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emapplyService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMEQUIP", tags = {"EMAPPLY" },  notes = "CheckKeyByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emapplies/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody EMAPPLYDTO emapplydto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emapplyService.checkKey(emapplyMapping.toDomain(emapplydto)));
    }

    @ApiOperation(value = "SaveByEMEQUIP", tags = {"EMAPPLY" },  notes = "SaveByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emapplies/save")
    public ResponseEntity<Boolean> saveByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody EMAPPLYDTO emapplydto) {
        EMAPPLY domain = emapplyMapping.toDomain(emapplydto);
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emapplyService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMEQUIP", tags = {"EMAPPLY" },  notes = "SaveBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emapplies/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody List<EMAPPLYDTO> emapplydtos) {
        List<EMAPPLY> domainlist=emapplyMapping.toDomain(emapplydtos);
        for(EMAPPLY domain:domainlist){
             domain.setEquipid(emequip_id);
        }
        emapplyService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMEQUIP", tags = {"EMAPPLY" },  notes = "GetDraftByEMEQUIP")
    @RequestMapping(method = RequestMethod.GET, value = "/emequips/{emequip_id}/emapplies/getdraft")
    public ResponseEntity<EMAPPLYDTO> getDraftByEMEQUIP(@PathVariable("emequip_id") String emequip_id) {
        EMAPPLY domain = new EMAPPLY();
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emapplyMapping.toDto(emapplyService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByEMEQUIP", tags = {"EMAPPLY" },  notes = "CreateByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emapplies")
    @Transactional
    public ResponseEntity<EMAPPLYDTO> createByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody EMAPPLYDTO emapplydto) {
        EMAPPLY domain = emapplyMapping.toDomain(emapplydto);
        domain.setEquipid(emequip_id);
		emapplyService.create(domain);
        EMAPPLYDTO dto = emapplyMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMEQUIP", tags = {"EMAPPLY" },  notes = "createBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emapplies/batch")
    public ResponseEntity<Boolean> createBatchByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody List<EMAPPLYDTO> emapplydtos) {
        List<EMAPPLY> domainlist=emapplyMapping.toDomain(emapplydtos);
        for(EMAPPLY domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emapplyService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMEQUIP", tags = {"EMAPPLY" },  notes = "GetByEMEQUIP")
	@RequestMapping(method = RequestMethod.GET, value = "/emequips/{emequip_id}/emapplies/{emapply_id}")
    public ResponseEntity<EMAPPLYDTO> getByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @PathVariable("emapply_id") String emapply_id) {
        EMAPPLY domain = emapplyService.get(emapply_id);
        EMAPPLYDTO dto = emapplyMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "fetchDEFAULTByEMEQUIP", tags = {"EMAPPLY" } ,notes = "fetchDEFAULTByEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emequips/{emequip_id}/emapplies/fetchdefault")
	public ResponseEntity<List<EMAPPLYDTO>> fetchEMAPPLYDefaultByEMEQUIP(@PathVariable("emequip_id") String emequip_id,EMAPPLYSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMAPPLY> domains = emapplyService.searchDefault(context) ;
        List<EMAPPLYDTO> list = emapplyMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMEQUIP", tags = {"EMAPPLY" } ,notes = "searchDEFAULTByEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emequips/{emequip_id}/emapplies/searchdefault")
	public ResponseEntity<Page<EMAPPLYDTO>> searchEMAPPLYDefaultByEMEQUIP(@PathVariable("emequip_id") String emequip_id,EMAPPLYSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMAPPLY> domains = emapplyService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emapplyMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "RemoveByEMEQTYPEEMEQUIP", tags = {"EMAPPLY" },  notes = "RemoveByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emapplies/{emapply_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emapply_id") String emapply_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emapplyService.remove(emapply_id));
    }

    @ApiOperation(value = "RemoveBatchByEMEQTYPEEMEQUIP", tags = {"EMAPPLY" },  notes = "RemoveBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emapplies/batch")
    public ResponseEntity<Boolean> removeBatchByEMEQTYPEEMEQUIP(@RequestBody List<String> ids) {
        emapplyService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMEQTYPEEMEQUIP", tags = {"EMAPPLY" },  notes = "UpdateByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emapplies/{emapply_id}")
    @Transactional
    public ResponseEntity<EMAPPLYDTO> updateByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emapply_id") String emapply_id, @RequestBody EMAPPLYDTO emapplydto) {
        EMAPPLY domain = emapplyMapping.toDomain(emapplydto);
        domain.setEquipid(emequip_id);
        domain.setEmapplyid(emapply_id);
		emapplyService.update(domain);
        EMAPPLYDTO dto = emapplyMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMEQTYPEEMEQUIP", tags = {"EMAPPLY" },  notes = "UpdateBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emapplies/batch")
    public ResponseEntity<Boolean> updateBatchByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMAPPLYDTO> emapplydtos) {
        List<EMAPPLY> domainlist=emapplyMapping.toDomain(emapplydtos);
        for(EMAPPLY domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emapplyService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMEQTYPEEMEQUIP", tags = {"EMAPPLY" },  notes = "CheckKeyByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emapplies/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMAPPLYDTO emapplydto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emapplyService.checkKey(emapplyMapping.toDomain(emapplydto)));
    }

    @ApiOperation(value = "SaveByEMEQTYPEEMEQUIP", tags = {"EMAPPLY" },  notes = "SaveByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emapplies/save")
    public ResponseEntity<Boolean> saveByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMAPPLYDTO emapplydto) {
        EMAPPLY domain = emapplyMapping.toDomain(emapplydto);
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emapplyService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMEQTYPEEMEQUIP", tags = {"EMAPPLY" },  notes = "SaveBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emapplies/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMAPPLYDTO> emapplydtos) {
        List<EMAPPLY> domainlist=emapplyMapping.toDomain(emapplydtos);
        for(EMAPPLY domain:domainlist){
             domain.setEquipid(emequip_id);
        }
        emapplyService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMEQTYPEEMEQUIP", tags = {"EMAPPLY" },  notes = "GetDraftByEMEQTYPEEMEQUIP")
    @RequestMapping(method = RequestMethod.GET, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emapplies/getdraft")
    public ResponseEntity<EMAPPLYDTO> getDraftByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id) {
        EMAPPLY domain = new EMAPPLY();
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emapplyMapping.toDto(emapplyService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByEMEQTYPEEMEQUIP", tags = {"EMAPPLY" },  notes = "CreateByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emapplies")
    @Transactional
    public ResponseEntity<EMAPPLYDTO> createByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMAPPLYDTO emapplydto) {
        EMAPPLY domain = emapplyMapping.toDomain(emapplydto);
        domain.setEquipid(emequip_id);
		emapplyService.create(domain);
        EMAPPLYDTO dto = emapplyMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMEQTYPEEMEQUIP", tags = {"EMAPPLY" },  notes = "createBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emapplies/batch")
    public ResponseEntity<Boolean> createBatchByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMAPPLYDTO> emapplydtos) {
        List<EMAPPLY> domainlist=emapplyMapping.toDomain(emapplydtos);
        for(EMAPPLY domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emapplyService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMEQTYPEEMEQUIP", tags = {"EMAPPLY" },  notes = "GetByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.GET, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emapplies/{emapply_id}")
    public ResponseEntity<EMAPPLYDTO> getByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emapply_id") String emapply_id) {
        EMAPPLY domain = emapplyService.get(emapply_id);
        EMAPPLYDTO dto = emapplyMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "fetchDEFAULTByEMEQTYPEEMEQUIP", tags = {"EMAPPLY" } ,notes = "fetchDEFAULTByEMEQTYPEEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emapplies/fetchdefault")
	public ResponseEntity<List<EMAPPLYDTO>> fetchEMAPPLYDefaultByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id,EMAPPLYSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMAPPLY> domains = emapplyService.searchDefault(context) ;
        List<EMAPPLYDTO> list = emapplyMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMEQTYPEEMEQUIP", tags = {"EMAPPLY" } ,notes = "searchDEFAULTByEMEQTYPEEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emapplies/searchdefault")
	public ResponseEntity<Page<EMAPPLYDTO>> searchEMAPPLYDefaultByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id,EMAPPLYSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMAPPLY> domains = emapplyService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emapplyMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "RemoveByPFTEAMEMEQUIP", tags = {"EMAPPLY" },  notes = "RemoveByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emapplies/{emapply_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emapply_id") String emapply_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emapplyService.remove(emapply_id));
    }

    @ApiOperation(value = "RemoveBatchByPFTEAMEMEQUIP", tags = {"EMAPPLY" },  notes = "RemoveBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emapplies/batch")
    public ResponseEntity<Boolean> removeBatchByPFTEAMEMEQUIP(@RequestBody List<String> ids) {
        emapplyService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByPFTEAMEMEQUIP", tags = {"EMAPPLY" },  notes = "UpdateByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emapplies/{emapply_id}")
    @Transactional
    public ResponseEntity<EMAPPLYDTO> updateByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emapply_id") String emapply_id, @RequestBody EMAPPLYDTO emapplydto) {
        EMAPPLY domain = emapplyMapping.toDomain(emapplydto);
        domain.setEquipid(emequip_id);
        domain.setEmapplyid(emapply_id);
		emapplyService.update(domain);
        EMAPPLYDTO dto = emapplyMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFTEAMEMEQUIP", tags = {"EMAPPLY" },  notes = "UpdateBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emapplies/batch")
    public ResponseEntity<Boolean> updateBatchByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMAPPLYDTO> emapplydtos) {
        List<EMAPPLY> domainlist=emapplyMapping.toDomain(emapplydtos);
        for(EMAPPLY domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emapplyService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFTEAMEMEQUIP", tags = {"EMAPPLY" },  notes = "CheckKeyByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emapplies/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMAPPLYDTO emapplydto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emapplyService.checkKey(emapplyMapping.toDomain(emapplydto)));
    }

    @ApiOperation(value = "SaveByPFTEAMEMEQUIP", tags = {"EMAPPLY" },  notes = "SaveByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emapplies/save")
    public ResponseEntity<Boolean> saveByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMAPPLYDTO emapplydto) {
        EMAPPLY domain = emapplyMapping.toDomain(emapplydto);
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emapplyService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFTEAMEMEQUIP", tags = {"EMAPPLY" },  notes = "SaveBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emapplies/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMAPPLYDTO> emapplydtos) {
        List<EMAPPLY> domainlist=emapplyMapping.toDomain(emapplydtos);
        for(EMAPPLY domain:domainlist){
             domain.setEquipid(emequip_id);
        }
        emapplyService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFTEAMEMEQUIP", tags = {"EMAPPLY" },  notes = "GetDraftByPFTEAMEMEQUIP")
    @RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emapplies/getdraft")
    public ResponseEntity<EMAPPLYDTO> getDraftByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id) {
        EMAPPLY domain = new EMAPPLY();
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emapplyMapping.toDto(emapplyService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByPFTEAMEMEQUIP", tags = {"EMAPPLY" },  notes = "CreateByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emapplies")
    @Transactional
    public ResponseEntity<EMAPPLYDTO> createByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMAPPLYDTO emapplydto) {
        EMAPPLY domain = emapplyMapping.toDomain(emapplydto);
        domain.setEquipid(emequip_id);
		emapplyService.create(domain);
        EMAPPLYDTO dto = emapplyMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFTEAMEMEQUIP", tags = {"EMAPPLY" },  notes = "createBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emapplies/batch")
    public ResponseEntity<Boolean> createBatchByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMAPPLYDTO> emapplydtos) {
        List<EMAPPLY> domainlist=emapplyMapping.toDomain(emapplydtos);
        for(EMAPPLY domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emapplyService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFTEAMEMEQUIP", tags = {"EMAPPLY" },  notes = "GetByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emapplies/{emapply_id}")
    public ResponseEntity<EMAPPLYDTO> getByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emapply_id") String emapply_id) {
        EMAPPLY domain = emapplyService.get(emapply_id);
        EMAPPLYDTO dto = emapplyMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "fetchDEFAULTByPFTEAMEMEQUIP", tags = {"EMAPPLY" } ,notes = "fetchDEFAULTByPFTEAMEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emequips/{emequip_id}/emapplies/fetchdefault")
	public ResponseEntity<List<EMAPPLYDTO>> fetchEMAPPLYDefaultByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id,EMAPPLYSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMAPPLY> domains = emapplyService.searchDefault(context) ;
        List<EMAPPLYDTO> list = emapplyMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFTEAMEMEQUIP", tags = {"EMAPPLY" } ,notes = "searchDEFAULTByPFTEAMEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emequips/{emequip_id}/emapplies/searchdefault")
	public ResponseEntity<Page<EMAPPLYDTO>> searchEMAPPLYDefaultByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id,EMAPPLYSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMAPPLY> domains = emapplyService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emapplyMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMAPPLY getEntity(){
        return new EMAPPLY();
    }

}
