package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMASSESSMENTMX;
import cn.ibizlab.eam.core.eam_core.service.IEMASSESSMENTMXService;
import cn.ibizlab.eam.core.eam_core.filter.EMASSESSMENTMXSearchContext;




@Slf4j
@Api(tags = {"EMASSESSMENTMX" })
@RestController("WebApi-emassessmentmx")
@RequestMapping("")
public class EMASSESSMENTMXResource {

    @Autowired
    private IEMASSESSMENTMXService emassessmentmxService;

    @Autowired
    @Lazy
    private EMASSESSMENTMXMapping emassessmentmxMapping;




    @ApiOperation(value = "Save", tags = {"EMASSESSMENTMX" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emassessmentmxes/save")
    public ResponseEntity<Boolean> save(@RequestBody EMASSESSMENTMXDTO emassessmentmxdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emassessmentmxService.save(emassessmentmxMapping.toDomain(emassessmentmxdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMASSESSMENTMX" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emassessmentmxes/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMASSESSMENTMXDTO> emassessmentmxdtos) {
        emassessmentmxService.saveBatch(emassessmentmxMapping.toDomain(emassessmentmxdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emassessmentmx_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMASSESSMENTMX" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emassessmentmxes/{emassessmentmx_id}")
    @Transactional
    public ResponseEntity<EMASSESSMENTMXDTO> update(@PathVariable("emassessmentmx_id") String emassessmentmx_id, @RequestBody EMASSESSMENTMXDTO emassessmentmxdto) {
		EMASSESSMENTMX domain = emassessmentmxMapping.toDomain(emassessmentmxdto);
        domain.setEmassessmentmxid(emassessmentmx_id);
		emassessmentmxService.update(domain);
		EMASSESSMENTMXDTO dto = emassessmentmxMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emassessmentmx_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMASSESSMENTMX" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emassessmentmxes/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMASSESSMENTMXDTO> emassessmentmxdtos) {
        emassessmentmxService.updateBatch(emassessmentmxMapping.toDomain(emassessmentmxdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emassessmentmx_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMASSESSMENTMX" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emassessmentmxes/{emassessmentmx_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emassessmentmx_id") String emassessmentmx_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emassessmentmxService.remove(emassessmentmx_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMASSESSMENTMX" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emassessmentmxes/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emassessmentmxService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMASSESSMENTMX" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emassessmentmxes/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMASSESSMENTMXDTO emassessmentmxdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emassessmentmxService.checkKey(emassessmentmxMapping.toDomain(emassessmentmxdto)));
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMASSESSMENTMX" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emassessmentmxes")
    @Transactional
    public ResponseEntity<EMASSESSMENTMXDTO> create(@RequestBody EMASSESSMENTMXDTO emassessmentmxdto) {
        EMASSESSMENTMX domain = emassessmentmxMapping.toDomain(emassessmentmxdto);
		emassessmentmxService.create(domain);
        EMASSESSMENTMXDTO dto = emassessmentmxMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMASSESSMENTMX" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emassessmentmxes/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMASSESSMENTMXDTO> emassessmentmxdtos) {
        emassessmentmxService.createBatch(emassessmentmxMapping.toDomain(emassessmentmxdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMASSESSMENTMX" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emassessmentmxes/getdraft")
    public ResponseEntity<EMASSESSMENTMXDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emassessmentmxMapping.toDto(emassessmentmxService.getDraft(new EMASSESSMENTMX())));
    }




    @PreAuthorize("hasPermission(#emassessmentmx_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMASSESSMENTMX" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emassessmentmxes/{emassessmentmx_id}")
    public ResponseEntity<EMASSESSMENTMXDTO> get(@PathVariable("emassessmentmx_id") String emassessmentmx_id) {
        EMASSESSMENTMX domain = emassessmentmxService.get(emassessmentmx_id);
        EMASSESSMENTMXDTO dto = emassessmentmxMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMASSESSMENTMX" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emassessmentmxes/fetchdefault")
	public ResponseEntity<List<EMASSESSMENTMXDTO>> fetchDefault(EMASSESSMENTMXSearchContext context) {
        Page<EMASSESSMENTMX> domains = emassessmentmxService.searchDefault(context) ;
        List<EMASSESSMENTMXDTO> list = emassessmentmxMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMASSESSMENTMX" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emassessmentmxes/searchdefault")
	public ResponseEntity<Page<EMASSESSMENTMXDTO>> searchDefault(EMASSESSMENTMXSearchContext context) {
        Page<EMASSESSMENTMX> domains = emassessmentmxService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emassessmentmxMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMASSESSMENTMX getEntity(){
        return new EMASSESSMENTMX();
    }

}
