package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMASSESSMENT;
import cn.ibizlab.eam.core.eam_core.service.IEMASSESSMENTService;
import cn.ibizlab.eam.core.eam_core.filter.EMASSESSMENTSearchContext;




@Slf4j
@Api(tags = {"EMASSESSMENT" })
@RestController("WebApi-emassessment")
@RequestMapping("")
public class EMASSESSMENTResource {

    @Autowired
    private IEMASSESSMENTService emassessmentService;

    @Autowired
    @Lazy
    private EMASSESSMENTMapping emassessmentMapping;




    @ApiOperation(value = "Save", tags = {"EMASSESSMENT" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emassessments/save")
    public ResponseEntity<Boolean> save(@RequestBody EMASSESSMENTDTO emassessmentdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emassessmentService.save(emassessmentMapping.toDomain(emassessmentdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMASSESSMENT" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emassessments/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMASSESSMENTDTO> emassessmentdtos) {
        emassessmentService.saveBatch(emassessmentMapping.toDomain(emassessmentdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emassessment_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMASSESSMENT" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emassessments/{emassessment_id}")
    public ResponseEntity<EMASSESSMENTDTO> get(@PathVariable("emassessment_id") String emassessment_id) {
        EMASSESSMENT domain = emassessmentService.get(emassessment_id);
        EMASSESSMENTDTO dto = emassessmentMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @PreAuthorize("hasPermission('Remove',{#emassessment_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMASSESSMENT" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emassessments/{emassessment_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emassessment_id") String emassessment_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emassessmentService.remove(emassessment_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMASSESSMENT" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emassessments/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emassessmentService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMASSESSMENT" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emassessments")
    @Transactional
    public ResponseEntity<EMASSESSMENTDTO> create(@RequestBody EMASSESSMENTDTO emassessmentdto) {
        EMASSESSMENT domain = emassessmentMapping.toDomain(emassessmentdto);
		emassessmentService.create(domain);
        EMASSESSMENTDTO dto = emassessmentMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMASSESSMENT" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emassessments/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMASSESSMENTDTO> emassessmentdtos) {
        emassessmentService.createBatch(emassessmentMapping.toDomain(emassessmentdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emassessment_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMASSESSMENT" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emassessments/{emassessment_id}")
    @Transactional
    public ResponseEntity<EMASSESSMENTDTO> update(@PathVariable("emassessment_id") String emassessment_id, @RequestBody EMASSESSMENTDTO emassessmentdto) {
		EMASSESSMENT domain = emassessmentMapping.toDomain(emassessmentdto);
        domain.setEmassessmentid(emassessment_id);
		emassessmentService.update(domain);
		EMASSESSMENTDTO dto = emassessmentMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emassessment_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMASSESSMENT" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emassessments/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMASSESSMENTDTO> emassessmentdtos) {
        emassessmentService.updateBatch(emassessmentMapping.toDomain(emassessmentdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMASSESSMENT" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emassessments/getdraft")
    public ResponseEntity<EMASSESSMENTDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emassessmentMapping.toDto(emassessmentService.getDraft(new EMASSESSMENT())));
    }




    @ApiOperation(value = "CheckKey", tags = {"EMASSESSMENT" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emassessments/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMASSESSMENTDTO emassessmentdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emassessmentService.checkKey(emassessmentMapping.toDomain(emassessmentdto)));
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMASSESSMENT" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emassessments/fetchdefault")
	public ResponseEntity<List<EMASSESSMENTDTO>> fetchDefault(EMASSESSMENTSearchContext context) {
        Page<EMASSESSMENT> domains = emassessmentService.searchDefault(context) ;
        List<EMASSESSMENTDTO> list = emassessmentMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMASSESSMENT" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emassessments/searchdefault")
	public ResponseEntity<Page<EMASSESSMENTDTO>> searchDefault(EMASSESSMENTSearchContext context) {
        Page<EMASSESSMENT> domains = emassessmentService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emassessmentMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMASSESSMENT getEntity(){
        return new EMASSESSMENT();
    }

}
