package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMASSESS;
import cn.ibizlab.eam.core.eam_core.service.IEMASSESSService;
import cn.ibizlab.eam.core.eam_core.filter.EMASSESSSearchContext;




@Slf4j
@Api(tags = {"EMASSESS" })
@RestController("WebApi-emassess")
@RequestMapping("")
public class EMASSESSResource {

    @Autowired
    private IEMASSESSService emassessService;

    @Autowired
    @Lazy
    private EMASSESSMapping emassessMapping;




    @PreAuthorize("hasPermission(#emassess_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMASSESS" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emassesses/{emassess_id}")
    public ResponseEntity<EMASSESSDTO> get(@PathVariable("emassess_id") String emassess_id) {
        EMASSESS domain = emassessService.get(emassess_id);
        EMASSESSDTO dto = emassessMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMASSESS" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emassesses")
    @Transactional
    public ResponseEntity<EMASSESSDTO> create(@RequestBody EMASSESSDTO emassessdto) {
        EMASSESS domain = emassessMapping.toDomain(emassessdto);
		emassessService.create(domain);
        EMASSESSDTO dto = emassessMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMASSESS" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emassesses/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMASSESSDTO> emassessdtos) {
        emassessService.createBatch(emassessMapping.toDomain(emassessdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emassess_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMASSESS" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emassesses/{emassess_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emassess_id") String emassess_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emassessService.remove(emassess_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMASSESS" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emassesses/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emassessService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"EMASSESS" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emassesses/save")
    public ResponseEntity<Boolean> save(@RequestBody EMASSESSDTO emassessdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emassessService.save(emassessMapping.toDomain(emassessdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMASSESS" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emassesses/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMASSESSDTO> emassessdtos) {
        emassessService.saveBatch(emassessMapping.toDomain(emassessdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMASSESS" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emassesses/getdraft")
    public ResponseEntity<EMASSESSDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emassessMapping.toDto(emassessService.getDraft(new EMASSESS())));
    }




    @PreAuthorize("hasPermission(#emassess_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMASSESS" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emassesses/{emassess_id}")
    @Transactional
    public ResponseEntity<EMASSESSDTO> update(@PathVariable("emassess_id") String emassess_id, @RequestBody EMASSESSDTO emassessdto) {
		EMASSESS domain = emassessMapping.toDomain(emassessdto);
        domain.setEmassessid(emassess_id);
		emassessService.update(domain);
		EMASSESSDTO dto = emassessMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emassess_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMASSESS" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emassesses/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMASSESSDTO> emassessdtos) {
        emassessService.updateBatch(emassessMapping.toDomain(emassessdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMASSESS" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emassesses/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMASSESSDTO emassessdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emassessService.checkKey(emassessMapping.toDomain(emassessdto)));
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMASSESS" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emassesses/fetchdefault")
	public ResponseEntity<List<EMASSESSDTO>> fetchDefault(EMASSESSSearchContext context) {
        Page<EMASSESS> domains = emassessService.searchDefault(context) ;
        List<EMASSESSDTO> list = emassessMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMASSESS" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emassesses/searchdefault")
	public ResponseEntity<Page<EMASSESSDTO>> searchDefault(EMASSESSSearchContext context) {
        Page<EMASSESS> domains = emassessService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emassessMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMASSESS getEntity(){
        return new EMASSESS();
    }

}
