package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMASSETCLASS;
import cn.ibizlab.eam.core.eam_core.service.IEMASSETCLASSService;
import cn.ibizlab.eam.core.eam_core.filter.EMASSETCLASSSearchContext;




@Slf4j
@Api(tags = {"EMASSETCLASS" })
@RestController("WebApi-emassetclass")
@RequestMapping("")
public class EMASSETCLASSResource {

    @Autowired
    private IEMASSETCLASSService emassetclassService;

    @Autowired
    @Lazy
    private EMASSETCLASSMapping emassetclassMapping;




    @ApiOperation(value = "CheckKey", tags = {"EMASSETCLASS" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emassetclasses/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMASSETCLASSDTO emassetclassdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emassetclassService.checkKey(emassetclassMapping.toDomain(emassetclassdto)));
    }




    @ApiOperation(value = "GetDraft", tags = {"EMASSETCLASS" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emassetclasses/getdraft")
    public ResponseEntity<EMASSETCLASSDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emassetclassMapping.toDto(emassetclassService.getDraft(new EMASSETCLASS())));
    }




    @ApiOperation(value = "Save", tags = {"EMASSETCLASS" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emassetclasses/save")
    public ResponseEntity<Boolean> save(@RequestBody EMASSETCLASSDTO emassetclassdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emassetclassService.save(emassetclassMapping.toDomain(emassetclassdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMASSETCLASS" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emassetclasses/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMASSETCLASSDTO> emassetclassdtos) {
        emassetclassService.saveBatch(emassetclassMapping.toDomain(emassetclassdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emassetclass_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMASSETCLASS" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emassetclasses/{emassetclass_id}")
    @Transactional
    public ResponseEntity<EMASSETCLASSDTO> update(@PathVariable("emassetclass_id") String emassetclass_id, @RequestBody EMASSETCLASSDTO emassetclassdto) {
		EMASSETCLASS domain = emassetclassMapping.toDomain(emassetclassdto);
        domain.setEmassetclassid(emassetclass_id);
		emassetclassService.update(domain);
		EMASSETCLASSDTO dto = emassetclassMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emassetclass_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMASSETCLASS" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emassetclasses/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMASSETCLASSDTO> emassetclassdtos) {
        emassetclassService.updateBatch(emassetclassMapping.toDomain(emassetclassdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emassetclass_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMASSETCLASS" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emassetclasses/{emassetclass_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emassetclass_id") String emassetclass_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emassetclassService.remove(emassetclass_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMASSETCLASS" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emassetclasses/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emassetclassService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMASSETCLASS" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emassetclasses")
    @Transactional
    public ResponseEntity<EMASSETCLASSDTO> create(@RequestBody EMASSETCLASSDTO emassetclassdto) {
        EMASSETCLASS domain = emassetclassMapping.toDomain(emassetclassdto);
		emassetclassService.create(domain);
        EMASSETCLASSDTO dto = emassetclassMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMASSETCLASS" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emassetclasses/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMASSETCLASSDTO> emassetclassdtos) {
        emassetclassService.createBatch(emassetclassMapping.toDomain(emassetclassdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emassetclass_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMASSETCLASS" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emassetclasses/{emassetclass_id}")
    public ResponseEntity<EMASSETCLASSDTO> get(@PathVariable("emassetclass_id") String emassetclass_id) {
        EMASSETCLASS domain = emassetclassService.get(emassetclass_id);
        EMASSETCLASSDTO dto = emassetclassMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMASSETCLASS" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emassetclasses/fetchdefault")
	public ResponseEntity<List<EMASSETCLASSDTO>> fetchDefault(EMASSETCLASSSearchContext context) {
        Page<EMASSETCLASS> domains = emassetclassService.searchDefault(context) ;
        List<EMASSETCLASSDTO> list = emassetclassMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMASSETCLASS" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emassetclasses/searchdefault")
	public ResponseEntity<Page<EMASSETCLASSDTO>> searchDefault(EMASSETCLASSSearchContext context) {
        Page<EMASSETCLASS> domains = emassetclassService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emassetclassMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMASSETCLASS getEntity(){
        return new EMASSETCLASS();
    }

}
