package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMASSETCLEAR;
import cn.ibizlab.eam.core.eam_core.service.IEMASSETCLEARService;
import cn.ibizlab.eam.core.eam_core.filter.EMASSETCLEARSearchContext;




@Slf4j
@Api(tags = {"EMASSETCLEAR" })
@RestController("WebApi-emassetclear")
@RequestMapping("")
public class EMASSETCLEARResource {

    @Autowired
    private IEMASSETCLEARService emassetclearService;

    @Autowired
    @Lazy
    private EMASSETCLEARMapping emassetclearMapping;




    @ApiOperation(value = "GetDraft", tags = {"EMASSETCLEAR" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emassetclears/getdraft")
    public ResponseEntity<EMASSETCLEARDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emassetclearMapping.toDto(emassetclearService.getDraft(new EMASSETCLEAR())));
    }




    @ApiOperation(value = "Save", tags = {"EMASSETCLEAR" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emassetclears/save")
    public ResponseEntity<Boolean> save(@RequestBody EMASSETCLEARDTO emassetcleardto) {
        return ResponseEntity.status(HttpStatus.OK).body(emassetclearService.save(emassetclearMapping.toDomain(emassetcleardto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMASSETCLEAR" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emassetclears/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMASSETCLEARDTO> emassetcleardtos) {
        emassetclearService.saveBatch(emassetclearMapping.toDomain(emassetcleardtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emassetclear_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMASSETCLEAR" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emassetclears/{emassetclear_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emassetclear_id") String emassetclear_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emassetclearService.remove(emassetclear_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMASSETCLEAR" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emassetclears/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emassetclearService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMASSETCLEAR" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emassetclears/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMASSETCLEARDTO emassetcleardto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emassetclearService.checkKey(emassetclearMapping.toDomain(emassetcleardto)));
    }




    @PreAuthorize("hasPermission(#emassetclear_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMASSETCLEAR" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emassetclears/{emassetclear_id}")
    public ResponseEntity<EMASSETCLEARDTO> get(@PathVariable("emassetclear_id") String emassetclear_id) {
        EMASSETCLEAR domain = emassetclearService.get(emassetclear_id);
        EMASSETCLEARDTO dto = emassetclearMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @PreAuthorize("hasPermission(#emassetclear_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMASSETCLEAR" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emassetclears/{emassetclear_id}")
    @Transactional
    public ResponseEntity<EMASSETCLEARDTO> update(@PathVariable("emassetclear_id") String emassetclear_id, @RequestBody EMASSETCLEARDTO emassetcleardto) {
		EMASSETCLEAR domain = emassetclearMapping.toDomain(emassetcleardto);
        domain.setEmassetclearid(emassetclear_id);
		emassetclearService.update(domain);
		EMASSETCLEARDTO dto = emassetclearMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emassetclear_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMASSETCLEAR" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emassetclears/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMASSETCLEARDTO> emassetcleardtos) {
        emassetclearService.updateBatch(emassetclearMapping.toDomain(emassetcleardtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMASSETCLEAR" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emassetclears")
    @Transactional
    public ResponseEntity<EMASSETCLEARDTO> create(@RequestBody EMASSETCLEARDTO emassetcleardto) {
        EMASSETCLEAR domain = emassetclearMapping.toDomain(emassetcleardto);
		emassetclearService.create(domain);
        EMASSETCLEARDTO dto = emassetclearMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMASSETCLEAR" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emassetclears/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMASSETCLEARDTO> emassetcleardtos) {
        emassetclearService.createBatch(emassetclearMapping.toDomain(emassetcleardtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMASSETCLEAR" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emassetclears/fetchdefault")
	public ResponseEntity<List<EMASSETCLEARDTO>> fetchDefault(EMASSETCLEARSearchContext context) {
        Page<EMASSETCLEAR> domains = emassetclearService.searchDefault(context) ;
        List<EMASSETCLEARDTO> list = emassetclearMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMASSETCLEAR" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emassetclears/searchdefault")
	public ResponseEntity<Page<EMASSETCLEARDTO>> searchDefault(EMASSETCLEARSearchContext context) {
        Page<EMASSETCLEAR> domains = emassetclearService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emassetclearMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "GetDraftByEMASSET", tags = {"EMASSETCLEAR" },  notes = "GetDraftByEMASSET")
    @RequestMapping(method = RequestMethod.GET, value = "/emassets/{emasset_id}/emassetclears/getdraft")
    public ResponseEntity<EMASSETCLEARDTO> getDraftByEMASSET(@PathVariable("emasset_id") String emasset_id) {
        EMASSETCLEAR domain = new EMASSETCLEAR();
        domain.setEmassetid(emasset_id);
        return ResponseEntity.status(HttpStatus.OK).body(emassetclearMapping.toDto(emassetclearService.getDraft(domain)));
    }

    @ApiOperation(value = "SaveByEMASSET", tags = {"EMASSETCLEAR" },  notes = "SaveByEMASSET")
	@RequestMapping(method = RequestMethod.POST, value = "/emassets/{emasset_id}/emassetclears/save")
    public ResponseEntity<Boolean> saveByEMASSET(@PathVariable("emasset_id") String emasset_id, @RequestBody EMASSETCLEARDTO emassetcleardto) {
        EMASSETCLEAR domain = emassetclearMapping.toDomain(emassetcleardto);
        domain.setEmassetid(emasset_id);
        return ResponseEntity.status(HttpStatus.OK).body(emassetclearService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMASSET", tags = {"EMASSETCLEAR" },  notes = "SaveBatchByEMASSET")
	@RequestMapping(method = RequestMethod.POST, value = "/emassets/{emasset_id}/emassetclears/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMASSET(@PathVariable("emasset_id") String emasset_id, @RequestBody List<EMASSETCLEARDTO> emassetcleardtos) {
        List<EMASSETCLEAR> domainlist=emassetclearMapping.toDomain(emassetcleardtos);
        for(EMASSETCLEAR domain:domainlist){
             domain.setEmassetid(emasset_id);
        }
        emassetclearService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByEMASSET", tags = {"EMASSETCLEAR" },  notes = "RemoveByEMASSET")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emassets/{emasset_id}/emassetclears/{emassetclear_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMASSET(@PathVariable("emasset_id") String emasset_id, @PathVariable("emassetclear_id") String emassetclear_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emassetclearService.remove(emassetclear_id));
    }

    @ApiOperation(value = "RemoveBatchByEMASSET", tags = {"EMASSETCLEAR" },  notes = "RemoveBatchByEMASSET")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emassets/{emasset_id}/emassetclears/batch")
    public ResponseEntity<Boolean> removeBatchByEMASSET(@RequestBody List<String> ids) {
        emassetclearService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMASSET", tags = {"EMASSETCLEAR" },  notes = "CheckKeyByEMASSET")
	@RequestMapping(method = RequestMethod.POST, value = "/emassets/{emasset_id}/emassetclears/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMASSET(@PathVariable("emasset_id") String emasset_id, @RequestBody EMASSETCLEARDTO emassetcleardto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emassetclearService.checkKey(emassetclearMapping.toDomain(emassetcleardto)));
    }

    @ApiOperation(value = "GetByEMASSET", tags = {"EMASSETCLEAR" },  notes = "GetByEMASSET")
	@RequestMapping(method = RequestMethod.GET, value = "/emassets/{emasset_id}/emassetclears/{emassetclear_id}")
    public ResponseEntity<EMASSETCLEARDTO> getByEMASSET(@PathVariable("emasset_id") String emasset_id, @PathVariable("emassetclear_id") String emassetclear_id) {
        EMASSETCLEAR domain = emassetclearService.get(emassetclear_id);
        EMASSETCLEARDTO dto = emassetclearMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateByEMASSET", tags = {"EMASSETCLEAR" },  notes = "UpdateByEMASSET")
	@RequestMapping(method = RequestMethod.PUT, value = "/emassets/{emasset_id}/emassetclears/{emassetclear_id}")
    @Transactional
    public ResponseEntity<EMASSETCLEARDTO> updateByEMASSET(@PathVariable("emasset_id") String emasset_id, @PathVariable("emassetclear_id") String emassetclear_id, @RequestBody EMASSETCLEARDTO emassetcleardto) {
        EMASSETCLEAR domain = emassetclearMapping.toDomain(emassetcleardto);
        domain.setEmassetid(emasset_id);
        domain.setEmassetclearid(emassetclear_id);
		emassetclearService.update(domain);
        EMASSETCLEARDTO dto = emassetclearMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMASSET", tags = {"EMASSETCLEAR" },  notes = "UpdateBatchByEMASSET")
	@RequestMapping(method = RequestMethod.PUT, value = "/emassets/{emasset_id}/emassetclears/batch")
    public ResponseEntity<Boolean> updateBatchByEMASSET(@PathVariable("emasset_id") String emasset_id, @RequestBody List<EMASSETCLEARDTO> emassetcleardtos) {
        List<EMASSETCLEAR> domainlist=emassetclearMapping.toDomain(emassetcleardtos);
        for(EMASSETCLEAR domain:domainlist){
            domain.setEmassetid(emasset_id);
        }
        emassetclearService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMASSET", tags = {"EMASSETCLEAR" },  notes = "CreateByEMASSET")
	@RequestMapping(method = RequestMethod.POST, value = "/emassets/{emasset_id}/emassetclears")
    @Transactional
    public ResponseEntity<EMASSETCLEARDTO> createByEMASSET(@PathVariable("emasset_id") String emasset_id, @RequestBody EMASSETCLEARDTO emassetcleardto) {
        EMASSETCLEAR domain = emassetclearMapping.toDomain(emassetcleardto);
        domain.setEmassetid(emasset_id);
		emassetclearService.create(domain);
        EMASSETCLEARDTO dto = emassetclearMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMASSET", tags = {"EMASSETCLEAR" },  notes = "createBatchByEMASSET")
	@RequestMapping(method = RequestMethod.POST, value = "/emassets/{emasset_id}/emassetclears/batch")
    public ResponseEntity<Boolean> createBatchByEMASSET(@PathVariable("emasset_id") String emasset_id, @RequestBody List<EMASSETCLEARDTO> emassetcleardtos) {
        List<EMASSETCLEAR> domainlist=emassetclearMapping.toDomain(emassetcleardtos);
        for(EMASSETCLEAR domain:domainlist){
            domain.setEmassetid(emasset_id);
        }
        emassetclearService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMASSET", tags = {"EMASSETCLEAR" } ,notes = "fetchDEFAULTByEMASSET")
    @RequestMapping(method= RequestMethod.GET , value="/emassets/{emasset_id}/emassetclears/fetchdefault")
	public ResponseEntity<List<EMASSETCLEARDTO>> fetchEMASSETCLEARDefaultByEMASSET(@PathVariable("emasset_id") String emasset_id,EMASSETCLEARSearchContext context) {
        context.setN_emassetid_eq(emasset_id);
        Page<EMASSETCLEAR> domains = emassetclearService.searchDefault(context) ;
        List<EMASSETCLEARDTO> list = emassetclearMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMASSET", tags = {"EMASSETCLEAR" } ,notes = "searchDEFAULTByEMASSET")
    @RequestMapping(method= RequestMethod.GET , value="/emassets/{emasset_id}/emassetclears/searchdefault")
	public ResponseEntity<Page<EMASSETCLEARDTO>> searchEMASSETCLEARDefaultByEMASSET(@PathVariable("emasset_id") String emasset_id,EMASSETCLEARSearchContext context) {
        context.setN_emassetid_eq(emasset_id);
        Page<EMASSETCLEAR> domains = emassetclearService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emassetclearMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMASSETCLEAR getEntity(){
        return new EMASSETCLEAR();
    }

}
