package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMBERTH;
import cn.ibizlab.eam.core.eam_core.service.IEMBERTHService;
import cn.ibizlab.eam.core.eam_core.filter.EMBERTHSearchContext;




@Slf4j
@Api(tags = {"EMBERTH" })
@RestController("WebApi-emberth")
@RequestMapping("")
public class EMBERTHResource {

    @Autowired
    private IEMBERTHService emberthService;

    @Autowired
    @Lazy
    private EMBERTHMapping emberthMapping;




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMBERTH" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emberths")
    @Transactional
    public ResponseEntity<EMBERTHDTO> create(@RequestBody EMBERTHDTO emberthdto) {
        EMBERTH domain = emberthMapping.toDomain(emberthdto);
		emberthService.create(domain);
        EMBERTHDTO dto = emberthMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMBERTH" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emberths/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMBERTHDTO> emberthdtos) {
        emberthService.createBatch(emberthMapping.toDomain(emberthdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMBERTH" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emberths/getdraft")
    public ResponseEntity<EMBERTHDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emberthMapping.toDto(emberthService.getDraft(new EMBERTH())));
    }




    @PreAuthorize("hasPermission(#emberth_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMBERTH" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emberths/{emberth_id}")
    public ResponseEntity<EMBERTHDTO> get(@PathVariable("emberth_id") String emberth_id) {
        EMBERTH domain = emberthService.get(emberth_id);
        EMBERTHDTO dto = emberthMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @PreAuthorize("hasPermission(#emberth_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMBERTH" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emberths/{emberth_id}")
    @Transactional
    public ResponseEntity<EMBERTHDTO> update(@PathVariable("emberth_id") String emberth_id, @RequestBody EMBERTHDTO emberthdto) {
		EMBERTH domain = emberthMapping.toDomain(emberthdto);
        domain.setEmberthid(emberth_id);
		emberthService.update(domain);
		EMBERTHDTO dto = emberthMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emberth_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMBERTH" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emberths/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMBERTHDTO> emberthdtos) {
        emberthService.updateBatch(emberthMapping.toDomain(emberthdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"EMBERTH" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emberths/save")
    public ResponseEntity<Boolean> save(@RequestBody EMBERTHDTO emberthdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emberthService.save(emberthMapping.toDomain(emberthdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMBERTH" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emberths/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMBERTHDTO> emberthdtos) {
        emberthService.saveBatch(emberthMapping.toDomain(emberthdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMBERTH" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emberths/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMBERTHDTO emberthdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emberthService.checkKey(emberthMapping.toDomain(emberthdto)));
    }




    @PreAuthorize("hasPermission('Remove',{#emberth_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMBERTH" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emberths/{emberth_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emberth_id") String emberth_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emberthService.remove(emberth_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMBERTH" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emberths/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emberthService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMBERTH" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emberths/fetchdefault")
	public ResponseEntity<List<EMBERTHDTO>> fetchDefault(EMBERTHSearchContext context) {
        Page<EMBERTH> domains = emberthService.searchDefault(context) ;
        List<EMBERTHDTO> list = emberthMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMBERTH" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emberths/searchdefault")
	public ResponseEntity<Page<EMBERTHDTO>> searchDefault(EMBERTHSearchContext context) {
        Page<EMBERTH> domains = emberthService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emberthMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMBERTH getEntity(){
        return new EMBERTH();
    }

}
