package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMBRAND;
import cn.ibizlab.eam.core.eam_core.service.IEMBRANDService;
import cn.ibizlab.eam.core.eam_core.filter.EMBRANDSearchContext;




@Slf4j
@Api(tags = {"EMBRAND" })
@RestController("WebApi-embrand")
@RequestMapping("")
public class EMBRANDResource {

    @Autowired
    private IEMBRANDService embrandService;

    @Autowired
    @Lazy
    private EMBRANDMapping embrandMapping;




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMBRAND" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/embrands")
    @Transactional
    public ResponseEntity<EMBRANDDTO> create(@RequestBody EMBRANDDTO embranddto) {
        EMBRAND domain = embrandMapping.toDomain(embranddto);
		embrandService.create(domain);
        EMBRANDDTO dto = embrandMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMBRAND" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/embrands/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMBRANDDTO> embranddtos) {
        embrandService.createBatch(embrandMapping.toDomain(embranddtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#embrand_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMBRAND" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/embrands/{embrand_id}")
    public ResponseEntity<EMBRANDDTO> get(@PathVariable("embrand_id") String embrand_id) {
        EMBRAND domain = embrandService.get(embrand_id);
        EMBRANDDTO dto = embrandMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "Save", tags = {"EMBRAND" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/embrands/save")
    public ResponseEntity<Boolean> save(@RequestBody EMBRANDDTO embranddto) {
        return ResponseEntity.status(HttpStatus.OK).body(embrandService.save(embrandMapping.toDomain(embranddto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMBRAND" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/embrands/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMBRANDDTO> embranddtos) {
        embrandService.saveBatch(embrandMapping.toDomain(embranddtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMBRAND" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/embrands/getdraft")
    public ResponseEntity<EMBRANDDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(embrandMapping.toDto(embrandService.getDraft(new EMBRAND())));
    }




    @PreAuthorize("hasPermission(#embrand_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMBRAND" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/embrands/{embrand_id}")
    @Transactional
    public ResponseEntity<EMBRANDDTO> update(@PathVariable("embrand_id") String embrand_id, @RequestBody EMBRANDDTO embranddto) {
		EMBRAND domain = embrandMapping.toDomain(embranddto);
        domain.setEmbrandid(embrand_id);
		embrandService.update(domain);
		EMBRANDDTO dto = embrandMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#embrand_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMBRAND" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/embrands/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMBRANDDTO> embranddtos) {
        embrandService.updateBatch(embrandMapping.toDomain(embranddtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#embrand_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMBRAND" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/embrands/{embrand_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("embrand_id") String embrand_id) {
         return ResponseEntity.status(HttpStatus.OK).body(embrandService.remove(embrand_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMBRAND" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/embrands/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        embrandService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMBRAND" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/embrands/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMBRANDDTO embranddto) {
        return  ResponseEntity.status(HttpStatus.OK).body(embrandService.checkKey(embrandMapping.toDomain(embranddto)));
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMBRAND" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/embrands/fetchdefault")
	public ResponseEntity<List<EMBRANDDTO>> fetchDefault(EMBRANDSearchContext context) {
        Page<EMBRAND> domains = embrandService.searchDefault(context) ;
        List<EMBRANDDTO> list = embrandMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMBRAND" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/embrands/searchdefault")
	public ResponseEntity<Page<EMBRANDDTO>> searchDefault(EMBRANDSearchContext context) {
        Page<EMBRAND> domains = embrandService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(embrandMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMBRAND getEntity(){
        return new EMBRAND();
    }

}
