package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMDISABLEASSESS;
import cn.ibizlab.eam.core.eam_core.service.IEMDISABLEASSESSService;
import cn.ibizlab.eam.core.eam_core.filter.EMDISABLEASSESSSearchContext;




@Slf4j
@Api(tags = {"EMDISABLEASSESS" })
@RestController("WebApi-emdisableassess")
@RequestMapping("")
public class EMDISABLEASSESSResource {

    @Autowired
    private IEMDISABLEASSESSService emdisableassessService;

    @Autowired
    @Lazy
    private EMDISABLEASSESSMapping emdisableassessMapping;




    @ApiOperation(value = "CheckKey", tags = {"EMDISABLEASSESS" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emdisableassesses/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMDISABLEASSESSDTO emdisableassessdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emdisableassessService.checkKey(emdisableassessMapping.toDomain(emdisableassessdto)));
    }




    @ApiOperation(value = "GetDraft", tags = {"EMDISABLEASSESS" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emdisableassesses/getdraft")
    public ResponseEntity<EMDISABLEASSESSDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emdisableassessMapping.toDto(emdisableassessService.getDraft(new EMDISABLEASSESS())));
    }




    @PreAuthorize("hasPermission(#emdisableassess_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMDISABLEASSESS" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emdisableassesses/{emdisableassess_id}")
    @Transactional
    public ResponseEntity<EMDISABLEASSESSDTO> update(@PathVariable("emdisableassess_id") String emdisableassess_id, @RequestBody EMDISABLEASSESSDTO emdisableassessdto) {
		EMDISABLEASSESS domain = emdisableassessMapping.toDomain(emdisableassessdto);
        domain.setEmdisableassessid(emdisableassess_id);
		emdisableassessService.update(domain);
		EMDISABLEASSESSDTO dto = emdisableassessMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emdisableassess_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMDISABLEASSESS" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emdisableassesses/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMDISABLEASSESSDTO> emdisableassessdtos) {
        emdisableassessService.updateBatch(emdisableassessMapping.toDomain(emdisableassessdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMDISABLEASSESS" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emdisableassesses")
    @Transactional
    public ResponseEntity<EMDISABLEASSESSDTO> create(@RequestBody EMDISABLEASSESSDTO emdisableassessdto) {
        EMDISABLEASSESS domain = emdisableassessMapping.toDomain(emdisableassessdto);
		emdisableassessService.create(domain);
        EMDISABLEASSESSDTO dto = emdisableassessMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMDISABLEASSESS" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emdisableassesses/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMDISABLEASSESSDTO> emdisableassessdtos) {
        emdisableassessService.createBatch(emdisableassessMapping.toDomain(emdisableassessdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emdisableassess_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMDISABLEASSESS" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emdisableassesses/{emdisableassess_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emdisableassess_id") String emdisableassess_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emdisableassessService.remove(emdisableassess_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMDISABLEASSESS" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emdisableassesses/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emdisableassessService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"EMDISABLEASSESS" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emdisableassesses/save")
    public ResponseEntity<Boolean> save(@RequestBody EMDISABLEASSESSDTO emdisableassessdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emdisableassessService.save(emdisableassessMapping.toDomain(emdisableassessdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMDISABLEASSESS" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emdisableassesses/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMDISABLEASSESSDTO> emdisableassessdtos) {
        emdisableassessService.saveBatch(emdisableassessMapping.toDomain(emdisableassessdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emdisableassess_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMDISABLEASSESS" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emdisableassesses/{emdisableassess_id}")
    public ResponseEntity<EMDISABLEASSESSDTO> get(@PathVariable("emdisableassess_id") String emdisableassess_id) {
        EMDISABLEASSESS domain = emdisableassessService.get(emdisableassess_id);
        EMDISABLEASSESSDTO dto = emdisableassessMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMDISABLEASSESS" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emdisableassesses/fetchdefault")
	public ResponseEntity<List<EMDISABLEASSESSDTO>> fetchDefault(EMDISABLEASSESSSearchContext context) {
        Page<EMDISABLEASSESS> domains = emdisableassessService.searchDefault(context) ;
        List<EMDISABLEASSESSDTO> list = emdisableassessMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMDISABLEASSESS" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emdisableassesses/searchdefault")
	public ResponseEntity<Page<EMDISABLEASSESSDTO>> searchDefault(EMDISABLEASSESSSearchContext context) {
        Page<EMDISABLEASSESS> domains = emdisableassessService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emdisableassessMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMDISABLEASSESS getEntity(){
        return new EMDISABLEASSESS();
    }

}
