package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMDRWGMAP;
import cn.ibizlab.eam.core.eam_core.service.IEMDRWGMAPService;
import cn.ibizlab.eam.core.eam_core.filter.EMDRWGMAPSearchContext;




@Slf4j
@Api(tags = {"EMDRWGMAP" })
@RestController("WebApi-emdrwgmap")
@RequestMapping("")
public class EMDRWGMAPResource {

    @Autowired
    private IEMDRWGMAPService emdrwgmapService;

    @Autowired
    @Lazy
    private EMDRWGMAPMapping emdrwgmapMapping;




    @ApiOperation(value = "GetDraft", tags = {"EMDRWGMAP" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emdrwgmaps/getdraft")
    public ResponseEntity<EMDRWGMAPDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emdrwgmapMapping.toDto(emdrwgmapService.getDraft(new EMDRWGMAP())));
    }




    @PreAuthorize("hasPermission(#emdrwgmap_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMDRWGMAP" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emdrwgmaps/{emdrwgmap_id}")
    public ResponseEntity<EMDRWGMAPDTO> get(@PathVariable("emdrwgmap_id") String emdrwgmap_id) {
        EMDRWGMAP domain = emdrwgmapService.get(emdrwgmap_id);
        EMDRWGMAPDTO dto = emdrwgmapMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMDRWGMAP" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emdrwgmaps/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMDRWGMAPDTO emdrwgmapdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emdrwgmapService.checkKey(emdrwgmapMapping.toDomain(emdrwgmapdto)));
    }




    @PreAuthorize("hasPermission('Remove',{#emdrwgmap_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMDRWGMAP" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emdrwgmaps/{emdrwgmap_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emdrwgmap_id") String emdrwgmap_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emdrwgmapService.remove(emdrwgmap_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMDRWGMAP" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emdrwgmaps/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emdrwgmapService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMDRWGMAP" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emdrwgmaps")
    @Transactional
    public ResponseEntity<EMDRWGMAPDTO> create(@RequestBody EMDRWGMAPDTO emdrwgmapdto) {
        EMDRWGMAP domain = emdrwgmapMapping.toDomain(emdrwgmapdto);
		emdrwgmapService.create(domain);
        EMDRWGMAPDTO dto = emdrwgmapMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMDRWGMAP" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emdrwgmaps/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMDRWGMAPDTO> emdrwgmapdtos) {
        emdrwgmapService.createBatch(emdrwgmapMapping.toDomain(emdrwgmapdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emdrwgmap_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMDRWGMAP" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emdrwgmaps/{emdrwgmap_id}")
    @Transactional
    public ResponseEntity<EMDRWGMAPDTO> update(@PathVariable("emdrwgmap_id") String emdrwgmap_id, @RequestBody EMDRWGMAPDTO emdrwgmapdto) {
		EMDRWGMAP domain = emdrwgmapMapping.toDomain(emdrwgmapdto);
        domain.setEmdrwgmapid(emdrwgmap_id);
		emdrwgmapService.update(domain);
		EMDRWGMAPDTO dto = emdrwgmapMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emdrwgmap_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMDRWGMAP" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emdrwgmaps/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMDRWGMAPDTO> emdrwgmapdtos) {
        emdrwgmapService.updateBatch(emdrwgmapMapping.toDomain(emdrwgmapdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"EMDRWGMAP" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emdrwgmaps/save")
    public ResponseEntity<Boolean> save(@RequestBody EMDRWGMAPDTO emdrwgmapdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emdrwgmapService.save(emdrwgmapMapping.toDomain(emdrwgmapdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMDRWGMAP" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emdrwgmaps/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMDRWGMAPDTO> emdrwgmapdtos) {
        emdrwgmapService.saveBatch(emdrwgmapMapping.toDomain(emdrwgmapdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMDRWGMAP" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emdrwgmaps/fetchdefault")
	public ResponseEntity<List<EMDRWGMAPDTO>> fetchDefault(EMDRWGMAPSearchContext context) {
        Page<EMDRWGMAP> domains = emdrwgmapService.searchDefault(context) ;
        List<EMDRWGMAPDTO> list = emdrwgmapMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMDRWGMAP" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emdrwgmaps/searchdefault")
	public ResponseEntity<Page<EMDRWGMAPDTO>> searchDefault(EMDRWGMAPSearchContext context) {
        Page<EMDRWGMAP> domains = emdrwgmapService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emdrwgmapMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMDRWGMAP getEntity(){
        return new EMDRWGMAP();
    }

}
