package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMEIBATTERYSETUP;
import cn.ibizlab.eam.core.eam_core.service.IEMEIBATTERYSETUPService;
import cn.ibizlab.eam.core.eam_core.filter.EMEIBATTERYSETUPSearchContext;




@Slf4j
@Api(tags = {"EMEIBATTERYSETUP" })
@RestController("WebApi-emeibatterysetup")
@RequestMapping("")
public class EMEIBATTERYSETUPResource {

    @Autowired
    private IEMEIBATTERYSETUPService emeibatterysetupService;

    @Autowired
    @Lazy
    private EMEIBATTERYSETUPMapping emeibatterysetupMapping;




    @ApiOperation(value = "Save", tags = {"EMEIBATTERYSETUP" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emeibatterysetups/save")
    public ResponseEntity<Boolean> save(@RequestBody EMEIBATTERYSETUPDTO emeibatterysetupdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emeibatterysetupService.save(emeibatterysetupMapping.toDomain(emeibatterysetupdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMEIBATTERYSETUP" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emeibatterysetups/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMEIBATTERYSETUPDTO> emeibatterysetupdtos) {
        emeibatterysetupService.saveBatch(emeibatterysetupMapping.toDomain(emeibatterysetupdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMEIBATTERYSETUP" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emeibatterysetups/getdraft")
    public ResponseEntity<EMEIBATTERYSETUPDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emeibatterysetupMapping.toDto(emeibatterysetupService.getDraft(new EMEIBATTERYSETUP())));
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMEIBATTERYSETUP" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emeibatterysetups")
    @Transactional
    public ResponseEntity<EMEIBATTERYSETUPDTO> create(@RequestBody EMEIBATTERYSETUPDTO emeibatterysetupdto) {
        EMEIBATTERYSETUP domain = emeibatterysetupMapping.toDomain(emeibatterysetupdto);
		emeibatterysetupService.create(domain);
        EMEIBATTERYSETUPDTO dto = emeibatterysetupMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMEIBATTERYSETUP" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emeibatterysetups/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMEIBATTERYSETUPDTO> emeibatterysetupdtos) {
        emeibatterysetupService.createBatch(emeibatterysetupMapping.toDomain(emeibatterysetupdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMEIBATTERYSETUP" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emeibatterysetups/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMEIBATTERYSETUPDTO emeibatterysetupdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emeibatterysetupService.checkKey(emeibatterysetupMapping.toDomain(emeibatterysetupdto)));
    }




    @PreAuthorize("hasPermission(#emeibatterysetup_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMEIBATTERYSETUP" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emeibatterysetups/{emeibatterysetup_id}")
    public ResponseEntity<EMEIBATTERYSETUPDTO> get(@PathVariable("emeibatterysetup_id") String emeibatterysetup_id) {
        EMEIBATTERYSETUP domain = emeibatterysetupService.get(emeibatterysetup_id);
        EMEIBATTERYSETUPDTO dto = emeibatterysetupMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @PreAuthorize("hasPermission('Remove',{#emeibatterysetup_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMEIBATTERYSETUP" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeibatterysetups/{emeibatterysetup_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emeibatterysetup_id") String emeibatterysetup_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emeibatterysetupService.remove(emeibatterysetup_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMEIBATTERYSETUP" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeibatterysetups/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emeibatterysetupService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emeibatterysetup_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMEIBATTERYSETUP" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeibatterysetups/{emeibatterysetup_id}")
    @Transactional
    public ResponseEntity<EMEIBATTERYSETUPDTO> update(@PathVariable("emeibatterysetup_id") String emeibatterysetup_id, @RequestBody EMEIBATTERYSETUPDTO emeibatterysetupdto) {
		EMEIBATTERYSETUP domain = emeibatterysetupMapping.toDomain(emeibatterysetupdto);
        domain.setEmeibatterysetupid(emeibatterysetup_id);
		emeibatterysetupService.update(domain);
		EMEIBATTERYSETUPDTO dto = emeibatterysetupMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emeibatterysetup_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMEIBATTERYSETUP" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeibatterysetups/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMEIBATTERYSETUPDTO> emeibatterysetupdtos) {
        emeibatterysetupService.updateBatch(emeibatterysetupMapping.toDomain(emeibatterysetupdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMEIBATTERYSETUP" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emeibatterysetups/fetchdefault")
	public ResponseEntity<List<EMEIBATTERYSETUPDTO>> fetchDefault(EMEIBATTERYSETUPSearchContext context) {
        Page<EMEIBATTERYSETUP> domains = emeibatterysetupService.searchDefault(context) ;
        List<EMEIBATTERYSETUPDTO> list = emeibatterysetupMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMEIBATTERYSETUP" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emeibatterysetups/searchdefault")
	public ResponseEntity<Page<EMEIBATTERYSETUPDTO>> searchDefault(EMEIBATTERYSETUPSearchContext context) {
        Page<EMEIBATTERYSETUP> domains = emeibatterysetupService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emeibatterysetupMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMEIBATTERYSETUP getEntity(){
        return new EMEIBATTERYSETUP();
    }

}
