package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMEICAMHIST;
import cn.ibizlab.eam.core.eam_core.service.IEMEICAMHISTService;
import cn.ibizlab.eam.core.eam_core.filter.EMEICAMHISTSearchContext;




@Slf4j
@Api(tags = {"EMEICAMHIST" })
@RestController("WebApi-emeicamhist")
@RequestMapping("")
public class EMEICAMHISTResource {

    @Autowired
    private IEMEICAMHISTService emeicamhistService;

    @Autowired
    @Lazy
    private EMEICAMHISTMapping emeicamhistMapping;




    @ApiOperation(value = "Save", tags = {"EMEICAMHIST" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emeicamhists/save")
    public ResponseEntity<Boolean> save(@RequestBody EMEICAMHISTDTO emeicamhistdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emeicamhistService.save(emeicamhistMapping.toDomain(emeicamhistdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMEICAMHIST" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emeicamhists/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMEICAMHISTDTO> emeicamhistdtos) {
        emeicamhistService.saveBatch(emeicamhistMapping.toDomain(emeicamhistdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMEICAMHIST" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emeicamhists/getdraft")
    public ResponseEntity<EMEICAMHISTDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emeicamhistMapping.toDto(emeicamhistService.getDraft(new EMEICAMHIST())));
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMEICAMHIST" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emeicamhists")
    @Transactional
    public ResponseEntity<EMEICAMHISTDTO> create(@RequestBody EMEICAMHISTDTO emeicamhistdto) {
        EMEICAMHIST domain = emeicamhistMapping.toDomain(emeicamhistdto);
		emeicamhistService.create(domain);
        EMEICAMHISTDTO dto = emeicamhistMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMEICAMHIST" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emeicamhists/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMEICAMHISTDTO> emeicamhistdtos) {
        emeicamhistService.createBatch(emeicamhistMapping.toDomain(emeicamhistdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emeicamhist_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMEICAMHIST" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeicamhists/{emeicamhist_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emeicamhist_id") String emeicamhist_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emeicamhistService.remove(emeicamhist_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMEICAMHIST" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeicamhists/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emeicamhistService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emeicamhist_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMEICAMHIST" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emeicamhists/{emeicamhist_id}")
    public ResponseEntity<EMEICAMHISTDTO> get(@PathVariable("emeicamhist_id") String emeicamhist_id) {
        EMEICAMHIST domain = emeicamhistService.get(emeicamhist_id);
        EMEICAMHISTDTO dto = emeicamhistMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMEICAMHIST" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emeicamhists/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMEICAMHISTDTO emeicamhistdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emeicamhistService.checkKey(emeicamhistMapping.toDomain(emeicamhistdto)));
    }




    @PreAuthorize("hasPermission(#emeicamhist_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMEICAMHIST" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeicamhists/{emeicamhist_id}")
    @Transactional
    public ResponseEntity<EMEICAMHISTDTO> update(@PathVariable("emeicamhist_id") String emeicamhist_id, @RequestBody EMEICAMHISTDTO emeicamhistdto) {
		EMEICAMHIST domain = emeicamhistMapping.toDomain(emeicamhistdto);
        domain.setEmeicamhistid(emeicamhist_id);
		emeicamhistService.update(domain);
		EMEICAMHISTDTO dto = emeicamhistMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emeicamhist_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMEICAMHIST" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeicamhists/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMEICAMHISTDTO> emeicamhistdtos) {
        emeicamhistService.updateBatch(emeicamhistMapping.toDomain(emeicamhistdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMEICAMHIST" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emeicamhists/fetchdefault")
	public ResponseEntity<List<EMEICAMHISTDTO>> fetchDefault(EMEICAMHISTSearchContext context) {
        Page<EMEICAMHIST> domains = emeicamhistService.searchDefault(context) ;
        List<EMEICAMHISTDTO> list = emeicamhistMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMEICAMHIST" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emeicamhists/searchdefault")
	public ResponseEntity<Page<EMEICAMHISTDTO>> searchDefault(EMEICAMHISTSearchContext context) {
        Page<EMEICAMHIST> domains = emeicamhistService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emeicamhistMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMEICAMHIST getEntity(){
        return new EMEICAMHIST();
    }

}
