package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMEIREPORTM;
import cn.ibizlab.eam.core.eam_core.service.IEMEIREPORTMService;
import cn.ibizlab.eam.core.eam_core.filter.EMEIREPORTMSearchContext;




@Slf4j
@Api(tags = {"EMEIREPORTM" })
@RestController("WebApi-emeireportm")
@RequestMapping("")
public class EMEIREPORTMResource {

    @Autowired
    private IEMEIREPORTMService emeireportmService;

    @Autowired
    @Lazy
    private EMEIREPORTMMapping emeireportmMapping;




    @ApiOperation(value = "GetDraft", tags = {"EMEIREPORTM" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emeireportms/getdraft")
    public ResponseEntity<EMEIREPORTMDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emeireportmMapping.toDto(emeireportmService.getDraft(new EMEIREPORTM())));
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMEIREPORTM" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emeireportms")
    @Transactional
    public ResponseEntity<EMEIREPORTMDTO> create(@RequestBody EMEIREPORTMDTO emeireportmdto) {
        EMEIREPORTM domain = emeireportmMapping.toDomain(emeireportmdto);
		emeireportmService.create(domain);
        EMEIREPORTMDTO dto = emeireportmMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMEIREPORTM" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emeireportms/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMEIREPORTMDTO> emeireportmdtos) {
        emeireportmService.createBatch(emeireportmMapping.toDomain(emeireportmdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"EMEIREPORTM" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emeireportms/save")
    public ResponseEntity<Boolean> save(@RequestBody EMEIREPORTMDTO emeireportmdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emeireportmService.save(emeireportmMapping.toDomain(emeireportmdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMEIREPORTM" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emeireportms/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMEIREPORTMDTO> emeireportmdtos) {
        emeireportmService.saveBatch(emeireportmMapping.toDomain(emeireportmdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMEIREPORTM" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emeireportms/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMEIREPORTMDTO emeireportmdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emeireportmService.checkKey(emeireportmMapping.toDomain(emeireportmdto)));
    }




    @PreAuthorize("hasPermission('Remove',{#emeireportm_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMEIREPORTM" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeireportms/{emeireportm_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emeireportm_id") String emeireportm_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emeireportmService.remove(emeireportm_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMEIREPORTM" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeireportms/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emeireportmService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emeireportm_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMEIREPORTM" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeireportms/{emeireportm_id}")
    @Transactional
    public ResponseEntity<EMEIREPORTMDTO> update(@PathVariable("emeireportm_id") String emeireportm_id, @RequestBody EMEIREPORTMDTO emeireportmdto) {
		EMEIREPORTM domain = emeireportmMapping.toDomain(emeireportmdto);
        domain.setEmeireportmid(emeireportm_id);
		emeireportmService.update(domain);
		EMEIREPORTMDTO dto = emeireportmMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emeireportm_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMEIREPORTM" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeireportms/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMEIREPORTMDTO> emeireportmdtos) {
        emeireportmService.updateBatch(emeireportmMapping.toDomain(emeireportmdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emeireportm_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMEIREPORTM" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emeireportms/{emeireportm_id}")
    public ResponseEntity<EMEIREPORTMDTO> get(@PathVariable("emeireportm_id") String emeireportm_id) {
        EMEIREPORTM domain = emeireportmService.get(emeireportm_id);
        EMEIREPORTMDTO dto = emeireportmMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMEIREPORTM" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emeireportms/fetchdefault")
	public ResponseEntity<List<EMEIREPORTMDTO>> fetchDefault(EMEIREPORTMSearchContext context) {
        Page<EMEIREPORTM> domains = emeireportmService.searchDefault(context) ;
        List<EMEIREPORTMDTO> list = emeireportmMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMEIREPORTM" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emeireportms/searchdefault")
	public ResponseEntity<Page<EMEIREPORTMDTO>> searchDefault(EMEIREPORTMSearchContext context) {
        Page<EMEIREPORTM> domains = emeireportmService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emeireportmMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMEIREPORTM getEntity(){
        return new EMEIREPORTM();
    }

}
