package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMEITIRES;
import cn.ibizlab.eam.core.eam_core.service.IEMEITIRESService;
import cn.ibizlab.eam.core.eam_core.filter.EMEITIRESSearchContext;




@Slf4j
@Api(tags = {"EMEITIRES" })
@RestController("WebApi-emeitires")
@RequestMapping("")
public class EMEITIRESResource {

    @Autowired
    private IEMEITIRESService emeitiresService;

    @Autowired
    @Lazy
    private EMEITIRESMapping emeitiresMapping;




    @ApiOperation(value = "GetDraft", tags = {"EMEITIRES" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emeitires/getdraft")
    public ResponseEntity<EMEITIRESDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emeitiresMapping.toDto(emeitiresService.getDraft(new EMEITIRES())));
    }




    @ApiOperation(value = "Save", tags = {"EMEITIRES" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emeitires/save")
    public ResponseEntity<Boolean> save(@RequestBody EMEITIRESDTO emeitiresdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emeitiresService.save(emeitiresMapping.toDomain(emeitiresdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMEITIRES" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emeitires/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMEITIRESDTO> emeitiresdtos) {
        emeitiresService.saveBatch(emeitiresMapping.toDomain(emeitiresdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emeitires_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMEITIRES" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeitires/{emeitires_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emeitires_id") String emeitires_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emeitiresService.remove(emeitires_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMEITIRES" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeitires/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emeitiresService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMEITIRES" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emeitires")
    @Transactional
    public ResponseEntity<EMEITIRESDTO> create(@RequestBody EMEITIRESDTO emeitiresdto) {
        EMEITIRES domain = emeitiresMapping.toDomain(emeitiresdto);
		emeitiresService.create(domain);
        EMEITIRESDTO dto = emeitiresMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMEITIRES" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emeitires/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMEITIRESDTO> emeitiresdtos) {
        emeitiresService.createBatch(emeitiresMapping.toDomain(emeitiresdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emeitires_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMEITIRES" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emeitires/{emeitires_id}")
    public ResponseEntity<EMEITIRESDTO> get(@PathVariable("emeitires_id") String emeitires_id) {
        EMEITIRES domain = emeitiresService.get(emeitires_id);
        EMEITIRESDTO dto = emeitiresMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMEITIRES" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emeitires/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMEITIRESDTO emeitiresdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emeitiresService.checkKey(emeitiresMapping.toDomain(emeitiresdto)));
    }




    @PreAuthorize("hasPermission(#emeitires_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMEITIRES" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeitires/{emeitires_id}")
    @Transactional
    public ResponseEntity<EMEITIRESDTO> update(@PathVariable("emeitires_id") String emeitires_id, @RequestBody EMEITIRESDTO emeitiresdto) {
		EMEITIRES domain = emeitiresMapping.toDomain(emeitiresdto);
        domain.setEmeitiresid(emeitires_id);
		emeitiresService.update(domain);
		EMEITIRESDTO dto = emeitiresMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emeitires_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMEITIRES" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeitires/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMEITIRESDTO> emeitiresdtos) {
        emeitiresService.updateBatch(emeitiresMapping.toDomain(emeitiresdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMEITIRES" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emeitires/fetchdefault")
	public ResponseEntity<List<EMEITIRESDTO>> fetchDefault(EMEITIRESSearchContext context) {
        Page<EMEITIRES> domains = emeitiresService.searchDefault(context) ;
        List<EMEITIRESDTO> list = emeitiresMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMEITIRES" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emeitires/searchdefault")
	public ResponseEntity<Page<EMEITIRESDTO>> searchDefault(EMEITIRESSearchContext context) {
        Page<EMEITIRES> domains = emeitiresService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emeitiresMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMEITIRES getEntity(){
        return new EMEITIRES();
    }

}
