package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMEQCHECK;
import cn.ibizlab.eam.core.eam_core.service.IEMEQCHECKService;
import cn.ibizlab.eam.core.eam_core.filter.EMEQCHECKSearchContext;




@Slf4j
@Api(tags = {"EMEQCHECK" })
@RestController("WebApi-emeqcheck")
@RequestMapping("")
public class EMEQCHECKResource {

    @Autowired
    private IEMEQCHECKService emeqcheckService;

    @Autowired
    @Lazy
    private EMEQCHECKMapping emeqcheckMapping;




    @ApiOperation(value = "Save", tags = {"EMEQCHECK" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqchecks/save")
    public ResponseEntity<Boolean> save(@RequestBody EMEQCHECKDTO emeqcheckdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emeqcheckService.save(emeqcheckMapping.toDomain(emeqcheckdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMEQCHECK" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqchecks/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMEQCHECKDTO> emeqcheckdtos) {
        emeqcheckService.saveBatch(emeqcheckMapping.toDomain(emeqcheckdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emeqcheck_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMEQCHECK" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqchecks/{emeqcheck_id}")
    @Transactional
    public ResponseEntity<EMEQCHECKDTO> update(@PathVariable("emeqcheck_id") String emeqcheck_id, @RequestBody EMEQCHECKDTO emeqcheckdto) {
		EMEQCHECK domain = emeqcheckMapping.toDomain(emeqcheckdto);
        domain.setEmeqcheckid(emeqcheck_id);
		emeqcheckService.update(domain);
		EMEQCHECKDTO dto = emeqcheckMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emeqcheck_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMEQCHECK" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqchecks/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMEQCHECKDTO> emeqcheckdtos) {
        emeqcheckService.updateBatch(emeqcheckMapping.toDomain(emeqcheckdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMEQCHECK" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqchecks")
    @Transactional
    public ResponseEntity<EMEQCHECKDTO> create(@RequestBody EMEQCHECKDTO emeqcheckdto) {
        EMEQCHECK domain = emeqcheckMapping.toDomain(emeqcheckdto);
		emeqcheckService.create(domain);
        EMEQCHECKDTO dto = emeqcheckMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMEQCHECK" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqchecks/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMEQCHECKDTO> emeqcheckdtos) {
        emeqcheckService.createBatch(emeqcheckMapping.toDomain(emeqcheckdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMEQCHECK" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emeqchecks/getdraft")
    public ResponseEntity<EMEQCHECKDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emeqcheckMapping.toDto(emeqcheckService.getDraft(new EMEQCHECK())));
    }




    @PreAuthorize("hasPermission(#emeqcheck_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMEQCHECK" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emeqchecks/{emeqcheck_id}")
    public ResponseEntity<EMEQCHECKDTO> get(@PathVariable("emeqcheck_id") String emeqcheck_id) {
        EMEQCHECK domain = emeqcheckService.get(emeqcheck_id);
        EMEQCHECKDTO dto = emeqcheckMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMEQCHECK" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqchecks/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMEQCHECKDTO emeqcheckdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emeqcheckService.checkKey(emeqcheckMapping.toDomain(emeqcheckdto)));
    }




    @PreAuthorize("hasPermission('Remove',{#emeqcheck_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMEQCHECK" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqchecks/{emeqcheck_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emeqcheck_id") String emeqcheck_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emeqcheckService.remove(emeqcheck_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMEQCHECK" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqchecks/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emeqcheckService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMEQCHECK" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emeqchecks/fetchdefault")
	public ResponseEntity<List<EMEQCHECKDTO>> fetchDefault(EMEQCHECKSearchContext context) {
        Page<EMEQCHECK> domains = emeqcheckService.searchDefault(context) ;
        List<EMEQCHECKDTO> list = emeqcheckMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMEQCHECK" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emeqchecks/searchdefault")
	public ResponseEntity<Page<EMEQCHECKDTO>> searchDefault(EMEQCHECKSearchContext context) {
        Page<EMEQCHECK> domains = emeqcheckService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emeqcheckMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "SaveByEMEQUIP", tags = {"EMEQCHECK" },  notes = "SaveByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emeqchecks/save")
    public ResponseEntity<Boolean> saveByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody EMEQCHECKDTO emeqcheckdto) {
        EMEQCHECK domain = emeqcheckMapping.toDomain(emeqcheckdto);
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emeqcheckService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMEQUIP", tags = {"EMEQCHECK" },  notes = "SaveBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emeqchecks/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQCHECKDTO> emeqcheckdtos) {
        List<EMEQCHECK> domainlist=emeqcheckMapping.toDomain(emeqcheckdtos);
        for(EMEQCHECK domain:domainlist){
             domain.setEquipid(emequip_id);
        }
        emeqcheckService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMEQUIP", tags = {"EMEQCHECK" },  notes = "UpdateByEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emequips/{emequip_id}/emeqchecks/{emeqcheck_id}")
    @Transactional
    public ResponseEntity<EMEQCHECKDTO> updateByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @PathVariable("emeqcheck_id") String emeqcheck_id, @RequestBody EMEQCHECKDTO emeqcheckdto) {
        EMEQCHECK domain = emeqcheckMapping.toDomain(emeqcheckdto);
        domain.setEquipid(emequip_id);
        domain.setEmeqcheckid(emeqcheck_id);
		emeqcheckService.update(domain);
        EMEQCHECKDTO dto = emeqcheckMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMEQUIP", tags = {"EMEQCHECK" },  notes = "UpdateBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emequips/{emequip_id}/emeqchecks/batch")
    public ResponseEntity<Boolean> updateBatchByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQCHECKDTO> emeqcheckdtos) {
        List<EMEQCHECK> domainlist=emeqcheckMapping.toDomain(emeqcheckdtos);
        for(EMEQCHECK domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emeqcheckService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMEQUIP", tags = {"EMEQCHECK" },  notes = "CreateByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emeqchecks")
    @Transactional
    public ResponseEntity<EMEQCHECKDTO> createByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody EMEQCHECKDTO emeqcheckdto) {
        EMEQCHECK domain = emeqcheckMapping.toDomain(emeqcheckdto);
        domain.setEquipid(emequip_id);
		emeqcheckService.create(domain);
        EMEQCHECKDTO dto = emeqcheckMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMEQUIP", tags = {"EMEQCHECK" },  notes = "createBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emeqchecks/batch")
    public ResponseEntity<Boolean> createBatchByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQCHECKDTO> emeqcheckdtos) {
        List<EMEQCHECK> domainlist=emeqcheckMapping.toDomain(emeqcheckdtos);
        for(EMEQCHECK domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emeqcheckService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMEQUIP", tags = {"EMEQCHECK" },  notes = "GetDraftByEMEQUIP")
    @RequestMapping(method = RequestMethod.GET, value = "/emequips/{emequip_id}/emeqchecks/getdraft")
    public ResponseEntity<EMEQCHECKDTO> getDraftByEMEQUIP(@PathVariable("emequip_id") String emequip_id) {
        EMEQCHECK domain = new EMEQCHECK();
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emeqcheckMapping.toDto(emeqcheckService.getDraft(domain)));
    }

    @ApiOperation(value = "GetByEMEQUIP", tags = {"EMEQCHECK" },  notes = "GetByEMEQUIP")
	@RequestMapping(method = RequestMethod.GET, value = "/emequips/{emequip_id}/emeqchecks/{emeqcheck_id}")
    public ResponseEntity<EMEQCHECKDTO> getByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @PathVariable("emeqcheck_id") String emeqcheck_id) {
        EMEQCHECK domain = emeqcheckService.get(emeqcheck_id);
        EMEQCHECKDTO dto = emeqcheckMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKeyByEMEQUIP", tags = {"EMEQCHECK" },  notes = "CheckKeyByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emeqchecks/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody EMEQCHECKDTO emeqcheckdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emeqcheckService.checkKey(emeqcheckMapping.toDomain(emeqcheckdto)));
    }

    @ApiOperation(value = "RemoveByEMEQUIP", tags = {"EMEQCHECK" },  notes = "RemoveByEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emequips/{emequip_id}/emeqchecks/{emeqcheck_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @PathVariable("emeqcheck_id") String emeqcheck_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emeqcheckService.remove(emeqcheck_id));
    }

    @ApiOperation(value = "RemoveBatchByEMEQUIP", tags = {"EMEQCHECK" },  notes = "RemoveBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emequips/{emequip_id}/emeqchecks/batch")
    public ResponseEntity<Boolean> removeBatchByEMEQUIP(@RequestBody List<String> ids) {
        emeqcheckService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMEQUIP", tags = {"EMEQCHECK" } ,notes = "fetchDEFAULTByEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emequips/{emequip_id}/emeqchecks/fetchdefault")
	public ResponseEntity<List<EMEQCHECKDTO>> fetchEMEQCHECKDefaultByEMEQUIP(@PathVariable("emequip_id") String emequip_id,EMEQCHECKSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMEQCHECK> domains = emeqcheckService.searchDefault(context) ;
        List<EMEQCHECKDTO> list = emeqcheckMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMEQUIP", tags = {"EMEQCHECK" } ,notes = "searchDEFAULTByEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emequips/{emequip_id}/emeqchecks/searchdefault")
	public ResponseEntity<Page<EMEQCHECKDTO>> searchEMEQCHECKDefaultByEMEQUIP(@PathVariable("emequip_id") String emequip_id,EMEQCHECKSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMEQCHECK> domains = emeqcheckService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emeqcheckMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "SaveByEMEQTYPEEMEQUIP", tags = {"EMEQCHECK" },  notes = "SaveByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqchecks/save")
    public ResponseEntity<Boolean> saveByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMEQCHECKDTO emeqcheckdto) {
        EMEQCHECK domain = emeqcheckMapping.toDomain(emeqcheckdto);
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emeqcheckService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMEQTYPEEMEQUIP", tags = {"EMEQCHECK" },  notes = "SaveBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqchecks/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQCHECKDTO> emeqcheckdtos) {
        List<EMEQCHECK> domainlist=emeqcheckMapping.toDomain(emeqcheckdtos);
        for(EMEQCHECK domain:domainlist){
             domain.setEquipid(emequip_id);
        }
        emeqcheckService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMEQTYPEEMEQUIP", tags = {"EMEQCHECK" },  notes = "UpdateByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqchecks/{emeqcheck_id}")
    @Transactional
    public ResponseEntity<EMEQCHECKDTO> updateByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emeqcheck_id") String emeqcheck_id, @RequestBody EMEQCHECKDTO emeqcheckdto) {
        EMEQCHECK domain = emeqcheckMapping.toDomain(emeqcheckdto);
        domain.setEquipid(emequip_id);
        domain.setEmeqcheckid(emeqcheck_id);
		emeqcheckService.update(domain);
        EMEQCHECKDTO dto = emeqcheckMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMEQTYPEEMEQUIP", tags = {"EMEQCHECK" },  notes = "UpdateBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqchecks/batch")
    public ResponseEntity<Boolean> updateBatchByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQCHECKDTO> emeqcheckdtos) {
        List<EMEQCHECK> domainlist=emeqcheckMapping.toDomain(emeqcheckdtos);
        for(EMEQCHECK domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emeqcheckService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMEQTYPEEMEQUIP", tags = {"EMEQCHECK" },  notes = "CreateByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqchecks")
    @Transactional
    public ResponseEntity<EMEQCHECKDTO> createByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMEQCHECKDTO emeqcheckdto) {
        EMEQCHECK domain = emeqcheckMapping.toDomain(emeqcheckdto);
        domain.setEquipid(emequip_id);
		emeqcheckService.create(domain);
        EMEQCHECKDTO dto = emeqcheckMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMEQTYPEEMEQUIP", tags = {"EMEQCHECK" },  notes = "createBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqchecks/batch")
    public ResponseEntity<Boolean> createBatchByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQCHECKDTO> emeqcheckdtos) {
        List<EMEQCHECK> domainlist=emeqcheckMapping.toDomain(emeqcheckdtos);
        for(EMEQCHECK domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emeqcheckService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMEQTYPEEMEQUIP", tags = {"EMEQCHECK" },  notes = "GetDraftByEMEQTYPEEMEQUIP")
    @RequestMapping(method = RequestMethod.GET, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqchecks/getdraft")
    public ResponseEntity<EMEQCHECKDTO> getDraftByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id) {
        EMEQCHECK domain = new EMEQCHECK();
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emeqcheckMapping.toDto(emeqcheckService.getDraft(domain)));
    }

    @ApiOperation(value = "GetByEMEQTYPEEMEQUIP", tags = {"EMEQCHECK" },  notes = "GetByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.GET, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqchecks/{emeqcheck_id}")
    public ResponseEntity<EMEQCHECKDTO> getByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emeqcheck_id") String emeqcheck_id) {
        EMEQCHECK domain = emeqcheckService.get(emeqcheck_id);
        EMEQCHECKDTO dto = emeqcheckMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKeyByEMEQTYPEEMEQUIP", tags = {"EMEQCHECK" },  notes = "CheckKeyByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqchecks/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMEQCHECKDTO emeqcheckdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emeqcheckService.checkKey(emeqcheckMapping.toDomain(emeqcheckdto)));
    }

    @ApiOperation(value = "RemoveByEMEQTYPEEMEQUIP", tags = {"EMEQCHECK" },  notes = "RemoveByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqchecks/{emeqcheck_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emeqcheck_id") String emeqcheck_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emeqcheckService.remove(emeqcheck_id));
    }

    @ApiOperation(value = "RemoveBatchByEMEQTYPEEMEQUIP", tags = {"EMEQCHECK" },  notes = "RemoveBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqchecks/batch")
    public ResponseEntity<Boolean> removeBatchByEMEQTYPEEMEQUIP(@RequestBody List<String> ids) {
        emeqcheckService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMEQTYPEEMEQUIP", tags = {"EMEQCHECK" } ,notes = "fetchDEFAULTByEMEQTYPEEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqchecks/fetchdefault")
	public ResponseEntity<List<EMEQCHECKDTO>> fetchEMEQCHECKDefaultByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id,EMEQCHECKSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMEQCHECK> domains = emeqcheckService.searchDefault(context) ;
        List<EMEQCHECKDTO> list = emeqcheckMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMEQTYPEEMEQUIP", tags = {"EMEQCHECK" } ,notes = "searchDEFAULTByEMEQTYPEEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqchecks/searchdefault")
	public ResponseEntity<Page<EMEQCHECKDTO>> searchEMEQCHECKDefaultByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id,EMEQCHECKSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMEQCHECK> domains = emeqcheckService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emeqcheckMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "SaveByPFTEAMEMEQUIP", tags = {"EMEQCHECK" },  notes = "SaveByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqchecks/save")
    public ResponseEntity<Boolean> saveByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMEQCHECKDTO emeqcheckdto) {
        EMEQCHECK domain = emeqcheckMapping.toDomain(emeqcheckdto);
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emeqcheckService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFTEAMEMEQUIP", tags = {"EMEQCHECK" },  notes = "SaveBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqchecks/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQCHECKDTO> emeqcheckdtos) {
        List<EMEQCHECK> domainlist=emeqcheckMapping.toDomain(emeqcheckdtos);
        for(EMEQCHECK domain:domainlist){
             domain.setEquipid(emequip_id);
        }
        emeqcheckService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByPFTEAMEMEQUIP", tags = {"EMEQCHECK" },  notes = "UpdateByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqchecks/{emeqcheck_id}")
    @Transactional
    public ResponseEntity<EMEQCHECKDTO> updateByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emeqcheck_id") String emeqcheck_id, @RequestBody EMEQCHECKDTO emeqcheckdto) {
        EMEQCHECK domain = emeqcheckMapping.toDomain(emeqcheckdto);
        domain.setEquipid(emequip_id);
        domain.setEmeqcheckid(emeqcheck_id);
		emeqcheckService.update(domain);
        EMEQCHECKDTO dto = emeqcheckMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFTEAMEMEQUIP", tags = {"EMEQCHECK" },  notes = "UpdateBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqchecks/batch")
    public ResponseEntity<Boolean> updateBatchByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQCHECKDTO> emeqcheckdtos) {
        List<EMEQCHECK> domainlist=emeqcheckMapping.toDomain(emeqcheckdtos);
        for(EMEQCHECK domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emeqcheckService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByPFTEAMEMEQUIP", tags = {"EMEQCHECK" },  notes = "CreateByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqchecks")
    @Transactional
    public ResponseEntity<EMEQCHECKDTO> createByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMEQCHECKDTO emeqcheckdto) {
        EMEQCHECK domain = emeqcheckMapping.toDomain(emeqcheckdto);
        domain.setEquipid(emequip_id);
		emeqcheckService.create(domain);
        EMEQCHECKDTO dto = emeqcheckMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFTEAMEMEQUIP", tags = {"EMEQCHECK" },  notes = "createBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqchecks/batch")
    public ResponseEntity<Boolean> createBatchByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQCHECKDTO> emeqcheckdtos) {
        List<EMEQCHECK> domainlist=emeqcheckMapping.toDomain(emeqcheckdtos);
        for(EMEQCHECK domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emeqcheckService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFTEAMEMEQUIP", tags = {"EMEQCHECK" },  notes = "GetDraftByPFTEAMEMEQUIP")
    @RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqchecks/getdraft")
    public ResponseEntity<EMEQCHECKDTO> getDraftByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id) {
        EMEQCHECK domain = new EMEQCHECK();
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emeqcheckMapping.toDto(emeqcheckService.getDraft(domain)));
    }

    @ApiOperation(value = "GetByPFTEAMEMEQUIP", tags = {"EMEQCHECK" },  notes = "GetByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqchecks/{emeqcheck_id}")
    public ResponseEntity<EMEQCHECKDTO> getByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emeqcheck_id") String emeqcheck_id) {
        EMEQCHECK domain = emeqcheckService.get(emeqcheck_id);
        EMEQCHECKDTO dto = emeqcheckMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKeyByPFTEAMEMEQUIP", tags = {"EMEQCHECK" },  notes = "CheckKeyByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqchecks/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMEQCHECKDTO emeqcheckdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emeqcheckService.checkKey(emeqcheckMapping.toDomain(emeqcheckdto)));
    }

    @ApiOperation(value = "RemoveByPFTEAMEMEQUIP", tags = {"EMEQCHECK" },  notes = "RemoveByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqchecks/{emeqcheck_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emeqcheck_id") String emeqcheck_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emeqcheckService.remove(emeqcheck_id));
    }

    @ApiOperation(value = "RemoveBatchByPFTEAMEMEQUIP", tags = {"EMEQCHECK" },  notes = "RemoveBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqchecks/batch")
    public ResponseEntity<Boolean> removeBatchByPFTEAMEMEQUIP(@RequestBody List<String> ids) {
        emeqcheckService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFTEAMEMEQUIP", tags = {"EMEQCHECK" } ,notes = "fetchDEFAULTByPFTEAMEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqchecks/fetchdefault")
	public ResponseEntity<List<EMEQCHECKDTO>> fetchEMEQCHECKDefaultByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id,EMEQCHECKSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMEQCHECK> domains = emeqcheckService.searchDefault(context) ;
        List<EMEQCHECKDTO> list = emeqcheckMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFTEAMEMEQUIP", tags = {"EMEQCHECK" } ,notes = "searchDEFAULTByPFTEAMEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqchecks/searchdefault")
	public ResponseEntity<Page<EMEQCHECKDTO>> searchEMEQCHECKDefaultByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id,EMEQCHECKSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMEQCHECK> domains = emeqcheckService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emeqcheckMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMEQCHECK getEntity(){
        return new EMEQCHECK();
    }

}
