package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMEQMAINTANCE;
import cn.ibizlab.eam.core.eam_core.service.IEMEQMAINTANCEService;
import cn.ibizlab.eam.core.eam_core.filter.EMEQMAINTANCESearchContext;




@Slf4j
@Api(tags = {"EMEQMAINTANCE" })
@RestController("WebApi-emeqmaintance")
@RequestMapping("")
public class EMEQMAINTANCEResource {

    @Autowired
    private IEMEQMAINTANCEService emeqmaintanceService;

    @Autowired
    @Lazy
    private EMEQMAINTANCEMapping emeqmaintanceMapping;




    @PreAuthorize("hasPermission(#emeqmaintance_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMEQMAINTANCE" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqmaintances/{emeqmaintance_id}")
    @Transactional
    public ResponseEntity<EMEQMAINTANCEDTO> update(@PathVariable("emeqmaintance_id") String emeqmaintance_id, @RequestBody EMEQMAINTANCEDTO emeqmaintancedto) {
		EMEQMAINTANCE domain = emeqmaintanceMapping.toDomain(emeqmaintancedto);
        domain.setEmeqmaintanceid(emeqmaintance_id);
		emeqmaintanceService.update(domain);
		EMEQMAINTANCEDTO dto = emeqmaintanceMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emeqmaintance_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMEQMAINTANCE" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqmaintances/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMEQMAINTANCEDTO> emeqmaintancedtos) {
        emeqmaintanceService.updateBatch(emeqmaintanceMapping.toDomain(emeqmaintancedtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMEQMAINTANCE" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqmaintances/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMEQMAINTANCEDTO emeqmaintancedto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emeqmaintanceService.checkKey(emeqmaintanceMapping.toDomain(emeqmaintancedto)));
    }




    @PreAuthorize("hasPermission(#emeqmaintance_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMEQMAINTANCE" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emeqmaintances/{emeqmaintance_id}")
    public ResponseEntity<EMEQMAINTANCEDTO> get(@PathVariable("emeqmaintance_id") String emeqmaintance_id) {
        EMEQMAINTANCE domain = emeqmaintanceService.get(emeqmaintance_id);
        EMEQMAINTANCEDTO dto = emeqmaintanceMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @PreAuthorize("hasPermission('Remove',{#emeqmaintance_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMEQMAINTANCE" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqmaintances/{emeqmaintance_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emeqmaintance_id") String emeqmaintance_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emeqmaintanceService.remove(emeqmaintance_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMEQMAINTANCE" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqmaintances/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emeqmaintanceService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"EMEQMAINTANCE" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqmaintances/save")
    public ResponseEntity<Boolean> save(@RequestBody EMEQMAINTANCEDTO emeqmaintancedto) {
        return ResponseEntity.status(HttpStatus.OK).body(emeqmaintanceService.save(emeqmaintanceMapping.toDomain(emeqmaintancedto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMEQMAINTANCE" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqmaintances/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMEQMAINTANCEDTO> emeqmaintancedtos) {
        emeqmaintanceService.saveBatch(emeqmaintanceMapping.toDomain(emeqmaintancedtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMEQMAINTANCE" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqmaintances")
    @Transactional
    public ResponseEntity<EMEQMAINTANCEDTO> create(@RequestBody EMEQMAINTANCEDTO emeqmaintancedto) {
        EMEQMAINTANCE domain = emeqmaintanceMapping.toDomain(emeqmaintancedto);
		emeqmaintanceService.create(domain);
        EMEQMAINTANCEDTO dto = emeqmaintanceMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMEQMAINTANCE" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqmaintances/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMEQMAINTANCEDTO> emeqmaintancedtos) {
        emeqmaintanceService.createBatch(emeqmaintanceMapping.toDomain(emeqmaintancedtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMEQMAINTANCE" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emeqmaintances/getdraft")
    public ResponseEntity<EMEQMAINTANCEDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emeqmaintanceMapping.toDto(emeqmaintanceService.getDraft(new EMEQMAINTANCE())));
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMEQMAINTANCE" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emeqmaintances/fetchdefault")
	public ResponseEntity<List<EMEQMAINTANCEDTO>> fetchDefault(EMEQMAINTANCESearchContext context) {
        Page<EMEQMAINTANCE> domains = emeqmaintanceService.searchDefault(context) ;
        List<EMEQMAINTANCEDTO> list = emeqmaintanceMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMEQMAINTANCE" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emeqmaintances/searchdefault")
	public ResponseEntity<Page<EMEQMAINTANCEDTO>> searchDefault(EMEQMAINTANCESearchContext context) {
        Page<EMEQMAINTANCE> domains = emeqmaintanceService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emeqmaintanceMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "UpdateByEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "UpdateByEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emequips/{emequip_id}/emeqmaintances/{emeqmaintance_id}")
    @Transactional
    public ResponseEntity<EMEQMAINTANCEDTO> updateByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @PathVariable("emeqmaintance_id") String emeqmaintance_id, @RequestBody EMEQMAINTANCEDTO emeqmaintancedto) {
        EMEQMAINTANCE domain = emeqmaintanceMapping.toDomain(emeqmaintancedto);
        domain.setEquipid(emequip_id);
        domain.setEmeqmaintanceid(emeqmaintance_id);
		emeqmaintanceService.update(domain);
        EMEQMAINTANCEDTO dto = emeqmaintanceMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "UpdateBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emequips/{emequip_id}/emeqmaintances/batch")
    public ResponseEntity<Boolean> updateBatchByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQMAINTANCEDTO> emeqmaintancedtos) {
        List<EMEQMAINTANCE> domainlist=emeqmaintanceMapping.toDomain(emeqmaintancedtos);
        for(EMEQMAINTANCE domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emeqmaintanceService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "CheckKeyByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emeqmaintances/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody EMEQMAINTANCEDTO emeqmaintancedto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emeqmaintanceService.checkKey(emeqmaintanceMapping.toDomain(emeqmaintancedto)));
    }

    @ApiOperation(value = "GetByEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "GetByEMEQUIP")
	@RequestMapping(method = RequestMethod.GET, value = "/emequips/{emequip_id}/emeqmaintances/{emeqmaintance_id}")
    public ResponseEntity<EMEQMAINTANCEDTO> getByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @PathVariable("emeqmaintance_id") String emeqmaintance_id) {
        EMEQMAINTANCE domain = emeqmaintanceService.get(emeqmaintance_id);
        EMEQMAINTANCEDTO dto = emeqmaintanceMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "RemoveByEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emequips/{emequip_id}/emeqmaintances/{emeqmaintance_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @PathVariable("emeqmaintance_id") String emeqmaintance_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emeqmaintanceService.remove(emeqmaintance_id));
    }

    @ApiOperation(value = "RemoveBatchByEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "RemoveBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emequips/{emequip_id}/emeqmaintances/batch")
    public ResponseEntity<Boolean> removeBatchByEMEQUIP(@RequestBody List<String> ids) {
        emeqmaintanceService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "SaveByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emeqmaintances/save")
    public ResponseEntity<Boolean> saveByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody EMEQMAINTANCEDTO emeqmaintancedto) {
        EMEQMAINTANCE domain = emeqmaintanceMapping.toDomain(emeqmaintancedto);
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emeqmaintanceService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "SaveBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emeqmaintances/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQMAINTANCEDTO> emeqmaintancedtos) {
        List<EMEQMAINTANCE> domainlist=emeqmaintanceMapping.toDomain(emeqmaintancedtos);
        for(EMEQMAINTANCE domain:domainlist){
             domain.setEquipid(emequip_id);
        }
        emeqmaintanceService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "CreateByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emeqmaintances")
    @Transactional
    public ResponseEntity<EMEQMAINTANCEDTO> createByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody EMEQMAINTANCEDTO emeqmaintancedto) {
        EMEQMAINTANCE domain = emeqmaintanceMapping.toDomain(emeqmaintancedto);
        domain.setEquipid(emequip_id);
		emeqmaintanceService.create(domain);
        EMEQMAINTANCEDTO dto = emeqmaintanceMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "createBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emeqmaintances/batch")
    public ResponseEntity<Boolean> createBatchByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQMAINTANCEDTO> emeqmaintancedtos) {
        List<EMEQMAINTANCE> domainlist=emeqmaintanceMapping.toDomain(emeqmaintancedtos);
        for(EMEQMAINTANCE domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emeqmaintanceService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "GetDraftByEMEQUIP")
    @RequestMapping(method = RequestMethod.GET, value = "/emequips/{emequip_id}/emeqmaintances/getdraft")
    public ResponseEntity<EMEQMAINTANCEDTO> getDraftByEMEQUIP(@PathVariable("emequip_id") String emequip_id) {
        EMEQMAINTANCE domain = new EMEQMAINTANCE();
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emeqmaintanceMapping.toDto(emeqmaintanceService.getDraft(domain)));
    }

	@ApiOperation(value = "fetchDEFAULTByEMEQUIP", tags = {"EMEQMAINTANCE" } ,notes = "fetchDEFAULTByEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emequips/{emequip_id}/emeqmaintances/fetchdefault")
	public ResponseEntity<List<EMEQMAINTANCEDTO>> fetchEMEQMAINTANCEDefaultByEMEQUIP(@PathVariable("emequip_id") String emequip_id,EMEQMAINTANCESearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMEQMAINTANCE> domains = emeqmaintanceService.searchDefault(context) ;
        List<EMEQMAINTANCEDTO> list = emeqmaintanceMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMEQUIP", tags = {"EMEQMAINTANCE" } ,notes = "searchDEFAULTByEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emequips/{emequip_id}/emeqmaintances/searchdefault")
	public ResponseEntity<Page<EMEQMAINTANCEDTO>> searchEMEQMAINTANCEDefaultByEMEQUIP(@PathVariable("emequip_id") String emequip_id,EMEQMAINTANCESearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMEQMAINTANCE> domains = emeqmaintanceService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emeqmaintanceMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "UpdateByEMEQTYPEEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "UpdateByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqmaintances/{emeqmaintance_id}")
    @Transactional
    public ResponseEntity<EMEQMAINTANCEDTO> updateByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emeqmaintance_id") String emeqmaintance_id, @RequestBody EMEQMAINTANCEDTO emeqmaintancedto) {
        EMEQMAINTANCE domain = emeqmaintanceMapping.toDomain(emeqmaintancedto);
        domain.setEquipid(emequip_id);
        domain.setEmeqmaintanceid(emeqmaintance_id);
		emeqmaintanceService.update(domain);
        EMEQMAINTANCEDTO dto = emeqmaintanceMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMEQTYPEEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "UpdateBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqmaintances/batch")
    public ResponseEntity<Boolean> updateBatchByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQMAINTANCEDTO> emeqmaintancedtos) {
        List<EMEQMAINTANCE> domainlist=emeqmaintanceMapping.toDomain(emeqmaintancedtos);
        for(EMEQMAINTANCE domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emeqmaintanceService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMEQTYPEEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "CheckKeyByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqmaintances/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMEQMAINTANCEDTO emeqmaintancedto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emeqmaintanceService.checkKey(emeqmaintanceMapping.toDomain(emeqmaintancedto)));
    }

    @ApiOperation(value = "GetByEMEQTYPEEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "GetByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.GET, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqmaintances/{emeqmaintance_id}")
    public ResponseEntity<EMEQMAINTANCEDTO> getByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emeqmaintance_id") String emeqmaintance_id) {
        EMEQMAINTANCE domain = emeqmaintanceService.get(emeqmaintance_id);
        EMEQMAINTANCEDTO dto = emeqmaintanceMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByEMEQTYPEEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "RemoveByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqmaintances/{emeqmaintance_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emeqmaintance_id") String emeqmaintance_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emeqmaintanceService.remove(emeqmaintance_id));
    }

    @ApiOperation(value = "RemoveBatchByEMEQTYPEEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "RemoveBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqmaintances/batch")
    public ResponseEntity<Boolean> removeBatchByEMEQTYPEEMEQUIP(@RequestBody List<String> ids) {
        emeqmaintanceService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByEMEQTYPEEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "SaveByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqmaintances/save")
    public ResponseEntity<Boolean> saveByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMEQMAINTANCEDTO emeqmaintancedto) {
        EMEQMAINTANCE domain = emeqmaintanceMapping.toDomain(emeqmaintancedto);
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emeqmaintanceService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMEQTYPEEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "SaveBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqmaintances/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQMAINTANCEDTO> emeqmaintancedtos) {
        List<EMEQMAINTANCE> domainlist=emeqmaintanceMapping.toDomain(emeqmaintancedtos);
        for(EMEQMAINTANCE domain:domainlist){
             domain.setEquipid(emequip_id);
        }
        emeqmaintanceService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMEQTYPEEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "CreateByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqmaintances")
    @Transactional
    public ResponseEntity<EMEQMAINTANCEDTO> createByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMEQMAINTANCEDTO emeqmaintancedto) {
        EMEQMAINTANCE domain = emeqmaintanceMapping.toDomain(emeqmaintancedto);
        domain.setEquipid(emequip_id);
		emeqmaintanceService.create(domain);
        EMEQMAINTANCEDTO dto = emeqmaintanceMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMEQTYPEEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "createBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqmaintances/batch")
    public ResponseEntity<Boolean> createBatchByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQMAINTANCEDTO> emeqmaintancedtos) {
        List<EMEQMAINTANCE> domainlist=emeqmaintanceMapping.toDomain(emeqmaintancedtos);
        for(EMEQMAINTANCE domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emeqmaintanceService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMEQTYPEEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "GetDraftByEMEQTYPEEMEQUIP")
    @RequestMapping(method = RequestMethod.GET, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqmaintances/getdraft")
    public ResponseEntity<EMEQMAINTANCEDTO> getDraftByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id) {
        EMEQMAINTANCE domain = new EMEQMAINTANCE();
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emeqmaintanceMapping.toDto(emeqmaintanceService.getDraft(domain)));
    }

	@ApiOperation(value = "fetchDEFAULTByEMEQTYPEEMEQUIP", tags = {"EMEQMAINTANCE" } ,notes = "fetchDEFAULTByEMEQTYPEEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqmaintances/fetchdefault")
	public ResponseEntity<List<EMEQMAINTANCEDTO>> fetchEMEQMAINTANCEDefaultByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id,EMEQMAINTANCESearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMEQMAINTANCE> domains = emeqmaintanceService.searchDefault(context) ;
        List<EMEQMAINTANCEDTO> list = emeqmaintanceMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMEQTYPEEMEQUIP", tags = {"EMEQMAINTANCE" } ,notes = "searchDEFAULTByEMEQTYPEEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emeqmaintances/searchdefault")
	public ResponseEntity<Page<EMEQMAINTANCEDTO>> searchEMEQMAINTANCEDefaultByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id,EMEQMAINTANCESearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMEQMAINTANCE> domains = emeqmaintanceService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emeqmaintanceMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "UpdateByPFTEAMEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "UpdateByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqmaintances/{emeqmaintance_id}")
    @Transactional
    public ResponseEntity<EMEQMAINTANCEDTO> updateByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emeqmaintance_id") String emeqmaintance_id, @RequestBody EMEQMAINTANCEDTO emeqmaintancedto) {
        EMEQMAINTANCE domain = emeqmaintanceMapping.toDomain(emeqmaintancedto);
        domain.setEquipid(emequip_id);
        domain.setEmeqmaintanceid(emeqmaintance_id);
		emeqmaintanceService.update(domain);
        EMEQMAINTANCEDTO dto = emeqmaintanceMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFTEAMEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "UpdateBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqmaintances/batch")
    public ResponseEntity<Boolean> updateBatchByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQMAINTANCEDTO> emeqmaintancedtos) {
        List<EMEQMAINTANCE> domainlist=emeqmaintanceMapping.toDomain(emeqmaintancedtos);
        for(EMEQMAINTANCE domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emeqmaintanceService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFTEAMEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "CheckKeyByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqmaintances/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMEQMAINTANCEDTO emeqmaintancedto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emeqmaintanceService.checkKey(emeqmaintanceMapping.toDomain(emeqmaintancedto)));
    }

    @ApiOperation(value = "GetByPFTEAMEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "GetByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqmaintances/{emeqmaintance_id}")
    public ResponseEntity<EMEQMAINTANCEDTO> getByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emeqmaintance_id") String emeqmaintance_id) {
        EMEQMAINTANCE domain = emeqmaintanceService.get(emeqmaintance_id);
        EMEQMAINTANCEDTO dto = emeqmaintanceMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByPFTEAMEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "RemoveByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqmaintances/{emeqmaintance_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emeqmaintance_id") String emeqmaintance_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emeqmaintanceService.remove(emeqmaintance_id));
    }

    @ApiOperation(value = "RemoveBatchByPFTEAMEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "RemoveBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqmaintances/batch")
    public ResponseEntity<Boolean> removeBatchByPFTEAMEMEQUIP(@RequestBody List<String> ids) {
        emeqmaintanceService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByPFTEAMEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "SaveByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqmaintances/save")
    public ResponseEntity<Boolean> saveByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMEQMAINTANCEDTO emeqmaintancedto) {
        EMEQMAINTANCE domain = emeqmaintanceMapping.toDomain(emeqmaintancedto);
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emeqmaintanceService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFTEAMEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "SaveBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqmaintances/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQMAINTANCEDTO> emeqmaintancedtos) {
        List<EMEQMAINTANCE> domainlist=emeqmaintanceMapping.toDomain(emeqmaintancedtos);
        for(EMEQMAINTANCE domain:domainlist){
             domain.setEquipid(emequip_id);
        }
        emeqmaintanceService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByPFTEAMEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "CreateByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqmaintances")
    @Transactional
    public ResponseEntity<EMEQMAINTANCEDTO> createByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMEQMAINTANCEDTO emeqmaintancedto) {
        EMEQMAINTANCE domain = emeqmaintanceMapping.toDomain(emeqmaintancedto);
        domain.setEquipid(emequip_id);
		emeqmaintanceService.create(domain);
        EMEQMAINTANCEDTO dto = emeqmaintanceMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFTEAMEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "createBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqmaintances/batch")
    public ResponseEntity<Boolean> createBatchByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMEQMAINTANCEDTO> emeqmaintancedtos) {
        List<EMEQMAINTANCE> domainlist=emeqmaintanceMapping.toDomain(emeqmaintancedtos);
        for(EMEQMAINTANCE domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emeqmaintanceService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFTEAMEMEQUIP", tags = {"EMEQMAINTANCE" },  notes = "GetDraftByPFTEAMEMEQUIP")
    @RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqmaintances/getdraft")
    public ResponseEntity<EMEQMAINTANCEDTO> getDraftByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id) {
        EMEQMAINTANCE domain = new EMEQMAINTANCE();
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emeqmaintanceMapping.toDto(emeqmaintanceService.getDraft(domain)));
    }

	@ApiOperation(value = "fetchDEFAULTByPFTEAMEMEQUIP", tags = {"EMEQMAINTANCE" } ,notes = "fetchDEFAULTByPFTEAMEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqmaintances/fetchdefault")
	public ResponseEntity<List<EMEQMAINTANCEDTO>> fetchEMEQMAINTANCEDefaultByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id,EMEQMAINTANCESearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMEQMAINTANCE> domains = emeqmaintanceService.searchDefault(context) ;
        List<EMEQMAINTANCEDTO> list = emeqmaintanceMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFTEAMEMEQUIP", tags = {"EMEQMAINTANCE" } ,notes = "searchDEFAULTByPFTEAMEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emequips/{emequip_id}/emeqmaintances/searchdefault")
	public ResponseEntity<Page<EMEQMAINTANCEDTO>> searchEMEQMAINTANCEDefaultByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id,EMEQMAINTANCESearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMEQMAINTANCE> domains = emeqmaintanceService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emeqmaintanceMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMEQMAINTANCE getEntity(){
        return new EMEQMAINTANCE();
    }

}
