package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMEQSPAREMAP;
import cn.ibizlab.eam.core.eam_core.service.IEMEQSPAREMAPService;
import cn.ibizlab.eam.core.eam_core.filter.EMEQSPAREMAPSearchContext;




@Slf4j
@Api(tags = {"EMEQSPAREMAP" })
@RestController("WebApi-emeqsparemap")
@RequestMapping("")
public class EMEQSPAREMAPResource {

    @Autowired
    private IEMEQSPAREMAPService emeqsparemapService;

    @Autowired
    @Lazy
    private EMEQSPAREMAPMapping emeqsparemapMapping;




    @ApiOperation(value = "Save", tags = {"EMEQSPAREMAP" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqsparemaps/save")
    public ResponseEntity<Boolean> save(@RequestBody EMEQSPAREMAPDTO emeqsparemapdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emeqsparemapService.save(emeqsparemapMapping.toDomain(emeqsparemapdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMEQSPAREMAP" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqsparemaps/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMEQSPAREMAPDTO> emeqsparemapdtos) {
        emeqsparemapService.saveBatch(emeqsparemapMapping.toDomain(emeqsparemapdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMEQSPAREMAP" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emeqsparemaps/getdraft")
    public ResponseEntity<EMEQSPAREMAPDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emeqsparemapMapping.toDto(emeqsparemapService.getDraft(new EMEQSPAREMAP())));
    }




    @PreAuthorize("hasPermission(#emeqsparemap_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMEQSPAREMAP" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emeqsparemaps/{emeqsparemap_id}")
    public ResponseEntity<EMEQSPAREMAPDTO> get(@PathVariable("emeqsparemap_id") String emeqsparemap_id) {
        EMEQSPAREMAP domain = emeqsparemapService.get(emeqsparemap_id);
        EMEQSPAREMAPDTO dto = emeqsparemapMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMEQSPAREMAP" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqsparemaps/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMEQSPAREMAPDTO emeqsparemapdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emeqsparemapService.checkKey(emeqsparemapMapping.toDomain(emeqsparemapdto)));
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMEQSPAREMAP" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqsparemaps")
    @Transactional
    public ResponseEntity<EMEQSPAREMAPDTO> create(@RequestBody EMEQSPAREMAPDTO emeqsparemapdto) {
        EMEQSPAREMAP domain = emeqsparemapMapping.toDomain(emeqsparemapdto);
		emeqsparemapService.create(domain);
        EMEQSPAREMAPDTO dto = emeqsparemapMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMEQSPAREMAP" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqsparemaps/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMEQSPAREMAPDTO> emeqsparemapdtos) {
        emeqsparemapService.createBatch(emeqsparemapMapping.toDomain(emeqsparemapdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emeqsparemap_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMEQSPAREMAP" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqsparemaps/{emeqsparemap_id}")
    @Transactional
    public ResponseEntity<EMEQSPAREMAPDTO> update(@PathVariable("emeqsparemap_id") String emeqsparemap_id, @RequestBody EMEQSPAREMAPDTO emeqsparemapdto) {
		EMEQSPAREMAP domain = emeqsparemapMapping.toDomain(emeqsparemapdto);
        domain.setEmeqsparemapid(emeqsparemap_id);
		emeqsparemapService.update(domain);
		EMEQSPAREMAPDTO dto = emeqsparemapMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emeqsparemap_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMEQSPAREMAP" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqsparemaps/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMEQSPAREMAPDTO> emeqsparemapdtos) {
        emeqsparemapService.updateBatch(emeqsparemapMapping.toDomain(emeqsparemapdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emeqsparemap_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMEQSPAREMAP" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqsparemaps/{emeqsparemap_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emeqsparemap_id") String emeqsparemap_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emeqsparemapService.remove(emeqsparemap_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMEQSPAREMAP" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqsparemaps/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emeqsparemapService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMEQSPAREMAP" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emeqsparemaps/fetchdefault")
	public ResponseEntity<List<EMEQSPAREMAPDTO>> fetchDefault(EMEQSPAREMAPSearchContext context) {
        Page<EMEQSPAREMAP> domains = emeqsparemapService.searchDefault(context) ;
        List<EMEQSPAREMAPDTO> list = emeqsparemapMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMEQSPAREMAP" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emeqsparemaps/searchdefault")
	public ResponseEntity<Page<EMEQSPAREMAPDTO>> searchDefault(EMEQSPAREMAPSearchContext context) {
        Page<EMEQSPAREMAP> domains = emeqsparemapService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emeqsparemapMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "SaveByEMEQSPARE", tags = {"EMEQSPAREMAP" },  notes = "SaveByEMEQSPARE")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqspares/{emeqspare_id}/emeqsparemaps/save")
    public ResponseEntity<Boolean> saveByEMEQSPARE(@PathVariable("emeqspare_id") String emeqspare_id, @RequestBody EMEQSPAREMAPDTO emeqsparemapdto) {
        EMEQSPAREMAP domain = emeqsparemapMapping.toDomain(emeqsparemapdto);
        domain.setEqspareid(emeqspare_id);
        return ResponseEntity.status(HttpStatus.OK).body(emeqsparemapService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMEQSPARE", tags = {"EMEQSPAREMAP" },  notes = "SaveBatchByEMEQSPARE")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqspares/{emeqspare_id}/emeqsparemaps/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMEQSPARE(@PathVariable("emeqspare_id") String emeqspare_id, @RequestBody List<EMEQSPAREMAPDTO> emeqsparemapdtos) {
        List<EMEQSPAREMAP> domainlist=emeqsparemapMapping.toDomain(emeqsparemapdtos);
        for(EMEQSPAREMAP domain:domainlist){
             domain.setEqspareid(emeqspare_id);
        }
        emeqsparemapService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMEQSPARE", tags = {"EMEQSPAREMAP" },  notes = "GetDraftByEMEQSPARE")
    @RequestMapping(method = RequestMethod.GET, value = "/emeqspares/{emeqspare_id}/emeqsparemaps/getdraft")
    public ResponseEntity<EMEQSPAREMAPDTO> getDraftByEMEQSPARE(@PathVariable("emeqspare_id") String emeqspare_id) {
        EMEQSPAREMAP domain = new EMEQSPAREMAP();
        domain.setEqspareid(emeqspare_id);
        return ResponseEntity.status(HttpStatus.OK).body(emeqsparemapMapping.toDto(emeqsparemapService.getDraft(domain)));
    }

    @ApiOperation(value = "GetByEMEQSPARE", tags = {"EMEQSPAREMAP" },  notes = "GetByEMEQSPARE")
	@RequestMapping(method = RequestMethod.GET, value = "/emeqspares/{emeqspare_id}/emeqsparemaps/{emeqsparemap_id}")
    public ResponseEntity<EMEQSPAREMAPDTO> getByEMEQSPARE(@PathVariable("emeqspare_id") String emeqspare_id, @PathVariable("emeqsparemap_id") String emeqsparemap_id) {
        EMEQSPAREMAP domain = emeqsparemapService.get(emeqsparemap_id);
        EMEQSPAREMAPDTO dto = emeqsparemapMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKeyByEMEQSPARE", tags = {"EMEQSPAREMAP" },  notes = "CheckKeyByEMEQSPARE")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqspares/{emeqspare_id}/emeqsparemaps/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMEQSPARE(@PathVariable("emeqspare_id") String emeqspare_id, @RequestBody EMEQSPAREMAPDTO emeqsparemapdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emeqsparemapService.checkKey(emeqsparemapMapping.toDomain(emeqsparemapdto)));
    }

    @ApiOperation(value = "CreateByEMEQSPARE", tags = {"EMEQSPAREMAP" },  notes = "CreateByEMEQSPARE")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqspares/{emeqspare_id}/emeqsparemaps")
    @Transactional
    public ResponseEntity<EMEQSPAREMAPDTO> createByEMEQSPARE(@PathVariable("emeqspare_id") String emeqspare_id, @RequestBody EMEQSPAREMAPDTO emeqsparemapdto) {
        EMEQSPAREMAP domain = emeqsparemapMapping.toDomain(emeqsparemapdto);
        domain.setEqspareid(emeqspare_id);
		emeqsparemapService.create(domain);
        EMEQSPAREMAPDTO dto = emeqsparemapMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMEQSPARE", tags = {"EMEQSPAREMAP" },  notes = "createBatchByEMEQSPARE")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqspares/{emeqspare_id}/emeqsparemaps/batch")
    public ResponseEntity<Boolean> createBatchByEMEQSPARE(@PathVariable("emeqspare_id") String emeqspare_id, @RequestBody List<EMEQSPAREMAPDTO> emeqsparemapdtos) {
        List<EMEQSPAREMAP> domainlist=emeqsparemapMapping.toDomain(emeqsparemapdtos);
        for(EMEQSPAREMAP domain:domainlist){
            domain.setEqspareid(emeqspare_id);
        }
        emeqsparemapService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMEQSPARE", tags = {"EMEQSPAREMAP" },  notes = "UpdateByEMEQSPARE")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqspares/{emeqspare_id}/emeqsparemaps/{emeqsparemap_id}")
    @Transactional
    public ResponseEntity<EMEQSPAREMAPDTO> updateByEMEQSPARE(@PathVariable("emeqspare_id") String emeqspare_id, @PathVariable("emeqsparemap_id") String emeqsparemap_id, @RequestBody EMEQSPAREMAPDTO emeqsparemapdto) {
        EMEQSPAREMAP domain = emeqsparemapMapping.toDomain(emeqsparemapdto);
        domain.setEqspareid(emeqspare_id);
        domain.setEmeqsparemapid(emeqsparemap_id);
		emeqsparemapService.update(domain);
        EMEQSPAREMAPDTO dto = emeqsparemapMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMEQSPARE", tags = {"EMEQSPAREMAP" },  notes = "UpdateBatchByEMEQSPARE")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqspares/{emeqspare_id}/emeqsparemaps/batch")
    public ResponseEntity<Boolean> updateBatchByEMEQSPARE(@PathVariable("emeqspare_id") String emeqspare_id, @RequestBody List<EMEQSPAREMAPDTO> emeqsparemapdtos) {
        List<EMEQSPAREMAP> domainlist=emeqsparemapMapping.toDomain(emeqsparemapdtos);
        for(EMEQSPAREMAP domain:domainlist){
            domain.setEqspareid(emeqspare_id);
        }
        emeqsparemapService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByEMEQSPARE", tags = {"EMEQSPAREMAP" },  notes = "RemoveByEMEQSPARE")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqspares/{emeqspare_id}/emeqsparemaps/{emeqsparemap_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMEQSPARE(@PathVariable("emeqspare_id") String emeqspare_id, @PathVariable("emeqsparemap_id") String emeqsparemap_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emeqsparemapService.remove(emeqsparemap_id));
    }

    @ApiOperation(value = "RemoveBatchByEMEQSPARE", tags = {"EMEQSPAREMAP" },  notes = "RemoveBatchByEMEQSPARE")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqspares/{emeqspare_id}/emeqsparemaps/batch")
    public ResponseEntity<Boolean> removeBatchByEMEQSPARE(@RequestBody List<String> ids) {
        emeqsparemapService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMEQSPARE", tags = {"EMEQSPAREMAP" } ,notes = "fetchDEFAULTByEMEQSPARE")
    @RequestMapping(method= RequestMethod.GET , value="/emeqspares/{emeqspare_id}/emeqsparemaps/fetchdefault")
	public ResponseEntity<List<EMEQSPAREMAPDTO>> fetchEMEQSPAREMAPDefaultByEMEQSPARE(@PathVariable("emeqspare_id") String emeqspare_id,EMEQSPAREMAPSearchContext context) {
        context.setN_eqspareid_eq(emeqspare_id);
        Page<EMEQSPAREMAP> domains = emeqsparemapService.searchDefault(context) ;
        List<EMEQSPAREMAPDTO> list = emeqsparemapMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMEQSPARE", tags = {"EMEQSPAREMAP" } ,notes = "searchDEFAULTByEMEQSPARE")
    @RequestMapping(method= RequestMethod.GET , value="/emeqspares/{emeqspare_id}/emeqsparemaps/searchdefault")
	public ResponseEntity<Page<EMEQSPAREMAPDTO>> searchEMEQSPAREMAPDefaultByEMEQSPARE(@PathVariable("emeqspare_id") String emeqspare_id,EMEQSPAREMAPSearchContext context) {
        context.setN_eqspareid_eq(emeqspare_id);
        Page<EMEQSPAREMAP> domains = emeqsparemapService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emeqsparemapMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMEQSPAREMAP getEntity(){
        return new EMEQSPAREMAP();
    }

}
