package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMEQUIP;
import cn.ibizlab.eam.core.eam_core.service.IEMEQUIPService;
import cn.ibizlab.eam.core.eam_core.filter.EMEQUIPSearchContext;




@Slf4j
@Api(tags = {"EMEQUIP" })
@RestController("WebApi-emequip")
@RequestMapping("")
public class EMEQUIPResource {

    @Autowired
    private IEMEQUIPService emequipService;

    @Autowired
    @Lazy
    private EMEQUIPMapping emequipMapping;




    @PreAuthorize("hasPermission(#emequip_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMEQUIP" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emequips/{emequip_id}")
    @Transactional
    public ResponseEntity<EMEQUIPDTO> update(@PathVariable("emequip_id") String emequip_id, @RequestBody EMEQUIPDTO emequipdto) {
		EMEQUIP domain = emequipMapping.toDomain(emequipdto);
        domain.setEmequipid(emequip_id);
		emequipService.update(domain);
		EMEQUIPDTO dto = emequipMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emequip_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMEQUIP" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emequips/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMEQUIPDTO> emequipdtos) {
        emequipService.updateBatch(emequipMapping.toDomain(emequipdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMEQUIP" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips")
    @Transactional
    public ResponseEntity<EMEQUIPDTO> create(@RequestBody EMEQUIPDTO emequipdto) {
        EMEQUIP domain = emequipMapping.toDomain(emequipdto);
		emequipService.create(domain);
        EMEQUIPDTO dto = emequipMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMEQUIP" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMEQUIPDTO> emequipdtos) {
        emequipService.createBatch(emequipMapping.toDomain(emequipdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMEQUIP" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMEQUIPDTO emequipdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emequipService.checkKey(emequipMapping.toDomain(emequipdto)));
    }




    @PreAuthorize("hasPermission(#emequip_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMEQUIP" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emequips/{emequip_id}")
    public ResponseEntity<EMEQUIPDTO> get(@PathVariable("emequip_id") String emequip_id) {
        EMEQUIP domain = emequipService.get(emequip_id);
        EMEQUIPDTO dto = emequipMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "Save", tags = {"EMEQUIP" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/save")
    public ResponseEntity<Boolean> save(@RequestBody EMEQUIPDTO emequipdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emequipService.save(emequipMapping.toDomain(emequipdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMEQUIP" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMEQUIPDTO> emequipdtos) {
        emequipService.saveBatch(emequipMapping.toDomain(emequipdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emequip_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMEQUIP" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emequips/{emequip_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emequip_id") String emequip_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emequipService.remove(emequip_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMEQUIP" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emequips/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emequipService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMEQUIP" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emequips/getdraft")
    public ResponseEntity<EMEQUIPDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emequipMapping.toDto(emequipService.getDraft(new EMEQUIP())));
    }

    @PreAuthorize("hasPermission('Get',{#context,'TypeEQNum',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetch各类型设备数量", tags = {"EMEQUIP" } ,notes = "fetch各类型设备数量")
    @RequestMapping(method= RequestMethod.GET , value="/emequips/fetchtypeeqnum")
	public ResponseEntity<List<HashMap>> fetchTypeEQNum(EMEQUIPSearchContext context) {
        Page<HashMap> domains = emequipService.searchTypeEQNum(context) ;
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(domains.getContent());
	}

    @PreAuthorize("hasPermission('Get',{#context,'TypeEQNum',this.getEntity(),'Sql'})")
	@ApiOperation(value = "search各类型设备数量", tags = {"EMEQUIP" } ,notes = "search各类型设备数量")
    @RequestMapping(method= RequestMethod.GET , value="/emequips/searchtypeeqnum")
	public ResponseEntity<Page<HashMap>> searchTypeEQNum(EMEQUIPSearchContext context) {
        Page<HashMap> domains = emequipService.searchTypeEQNum(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(domains.getContent(), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMEQUIP" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emequips/fetchdefault")
	public ResponseEntity<List<EMEQUIPDTO>> fetchDefault(EMEQUIPSearchContext context) {
        Page<EMEQUIP> domains = emequipService.searchDefault(context) ;
        List<EMEQUIPDTO> list = emequipMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMEQUIP" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emequips/searchdefault")
	public ResponseEntity<Page<EMEQUIPDTO>> searchDefault(EMEQUIPSearchContext context) {
        Page<EMEQUIP> domains = emequipService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emequipMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "UpdateByEMEQTYPE", tags = {"EMEQUIP" },  notes = "UpdateByEMEQTYPE")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}")
    @Transactional
    public ResponseEntity<EMEQUIPDTO> updateByEMEQTYPE(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMEQUIPDTO emequipdto) {
        EMEQUIP domain = emequipMapping.toDomain(emequipdto);
        domain.setEqtypeid(emeqtype_id);
        domain.setEmequipid(emequip_id);
		emequipService.update(domain);
        EMEQUIPDTO dto = emequipMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMEQTYPE", tags = {"EMEQUIP" },  notes = "UpdateBatchByEMEQTYPE")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqtypes/{emeqtype_id}/emequips/batch")
    public ResponseEntity<Boolean> updateBatchByEMEQTYPE(@PathVariable("emeqtype_id") String emeqtype_id, @RequestBody List<EMEQUIPDTO> emequipdtos) {
        List<EMEQUIP> domainlist=emequipMapping.toDomain(emequipdtos);
        for(EMEQUIP domain:domainlist){
            domain.setEqtypeid(emeqtype_id);
        }
        emequipService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMEQTYPE", tags = {"EMEQUIP" },  notes = "CreateByEMEQTYPE")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips")
    @Transactional
    public ResponseEntity<EMEQUIPDTO> createByEMEQTYPE(@PathVariable("emeqtype_id") String emeqtype_id, @RequestBody EMEQUIPDTO emequipdto) {
        EMEQUIP domain = emequipMapping.toDomain(emequipdto);
        domain.setEqtypeid(emeqtype_id);
		emequipService.create(domain);
        EMEQUIPDTO dto = emequipMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMEQTYPE", tags = {"EMEQUIP" },  notes = "createBatchByEMEQTYPE")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/batch")
    public ResponseEntity<Boolean> createBatchByEMEQTYPE(@PathVariable("emeqtype_id") String emeqtype_id, @RequestBody List<EMEQUIPDTO> emequipdtos) {
        List<EMEQUIP> domainlist=emequipMapping.toDomain(emequipdtos);
        for(EMEQUIP domain:domainlist){
            domain.setEqtypeid(emeqtype_id);
        }
        emequipService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMEQTYPE", tags = {"EMEQUIP" },  notes = "CheckKeyByEMEQTYPE")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMEQTYPE(@PathVariable("emeqtype_id") String emeqtype_id, @RequestBody EMEQUIPDTO emequipdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emequipService.checkKey(emequipMapping.toDomain(emequipdto)));
    }

    @ApiOperation(value = "GetByEMEQTYPE", tags = {"EMEQUIP" },  notes = "GetByEMEQTYPE")
	@RequestMapping(method = RequestMethod.GET, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}")
    public ResponseEntity<EMEQUIPDTO> getByEMEQTYPE(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id) {
        EMEQUIP domain = emequipService.get(emequip_id);
        EMEQUIPDTO dto = emequipMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMEQTYPE", tags = {"EMEQUIP" },  notes = "SaveByEMEQTYPE")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/save")
    public ResponseEntity<Boolean> saveByEMEQTYPE(@PathVariable("emeqtype_id") String emeqtype_id, @RequestBody EMEQUIPDTO emequipdto) {
        EMEQUIP domain = emequipMapping.toDomain(emequipdto);
        domain.setEqtypeid(emeqtype_id);
        return ResponseEntity.status(HttpStatus.OK).body(emequipService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMEQTYPE", tags = {"EMEQUIP" },  notes = "SaveBatchByEMEQTYPE")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMEQTYPE(@PathVariable("emeqtype_id") String emeqtype_id, @RequestBody List<EMEQUIPDTO> emequipdtos) {
        List<EMEQUIP> domainlist=emequipMapping.toDomain(emequipdtos);
        for(EMEQUIP domain:domainlist){
             domain.setEqtypeid(emeqtype_id);
        }
        emequipService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByEMEQTYPE", tags = {"EMEQUIP" },  notes = "RemoveByEMEQTYPE")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMEQTYPE(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emequipService.remove(emequip_id));
    }

    @ApiOperation(value = "RemoveBatchByEMEQTYPE", tags = {"EMEQUIP" },  notes = "RemoveBatchByEMEQTYPE")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqtypes/{emeqtype_id}/emequips/batch")
    public ResponseEntity<Boolean> removeBatchByEMEQTYPE(@RequestBody List<String> ids) {
        emequipService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMEQTYPE", tags = {"EMEQUIP" },  notes = "GetDraftByEMEQTYPE")
    @RequestMapping(method = RequestMethod.GET, value = "/emeqtypes/{emeqtype_id}/emequips/getdraft")
    public ResponseEntity<EMEQUIPDTO> getDraftByEMEQTYPE(@PathVariable("emeqtype_id") String emeqtype_id) {
        EMEQUIP domain = new EMEQUIP();
        domain.setEqtypeid(emeqtype_id);
        return ResponseEntity.status(HttpStatus.OK).body(emequipMapping.toDto(emequipService.getDraft(domain)));
    }

	@ApiOperation(value = "fetch各类型设备数量ByEMEQTYPE", tags = {"EMEQUIP" } ,notes = "fetch各类型设备数量ByEMEQTYPE")
    @RequestMapping(method= RequestMethod.GET , value="/emeqtypes/{emeqtype_id}/emequips/fetchtypeeqnum")
	public ResponseEntity<List<HashMap>> fetchEMEQUIPTypeEQNumByEMEQTYPE(@PathVariable("emeqtype_id") String emeqtype_id,EMEQUIPSearchContext context) {
        context.setN_eqtypeid_eq(emeqtype_id);
        Page<HashMap> domains = emequipService.searchTypeEQNum(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(domains.getContent());
	}

	@ApiOperation(value = "search各类型设备数量ByEMEQTYPE", tags = {"EMEQUIP" } ,notes = "search各类型设备数量ByEMEQTYPE")
    @RequestMapping(method= RequestMethod.GET , value="/emeqtypes/{emeqtype_id}/emequips/searchtypeeqnum")
	public ResponseEntity<Page<HashMap>> searchEMEQUIPTypeEQNumByEMEQTYPE(@PathVariable("emeqtype_id") String emeqtype_id,EMEQUIPSearchContext context) {
        context.setN_eqtypeid_eq(emeqtype_id);
        Page<HashMap> domains = emequipService.searchTypeEQNum(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(domains.getContent(), context.getPageable(), domains.getTotalElements()));
	}

	@ApiOperation(value = "fetchDEFAULTByEMEQTYPE", tags = {"EMEQUIP" } ,notes = "fetchDEFAULTByEMEQTYPE")
    @RequestMapping(method= RequestMethod.GET , value="/emeqtypes/{emeqtype_id}/emequips/fetchdefault")
	public ResponseEntity<List<EMEQUIPDTO>> fetchEMEQUIPDefaultByEMEQTYPE(@PathVariable("emeqtype_id") String emeqtype_id,EMEQUIPSearchContext context) {
        context.setN_eqtypeid_eq(emeqtype_id);
        Page<EMEQUIP> domains = emequipService.searchDefault(context) ;
        List<EMEQUIPDTO> list = emequipMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMEQTYPE", tags = {"EMEQUIP" } ,notes = "searchDEFAULTByEMEQTYPE")
    @RequestMapping(method= RequestMethod.GET , value="/emeqtypes/{emeqtype_id}/emequips/searchdefault")
	public ResponseEntity<Page<EMEQUIPDTO>> searchEMEQUIPDefaultByEMEQTYPE(@PathVariable("emeqtype_id") String emeqtype_id,EMEQUIPSearchContext context) {
        context.setN_eqtypeid_eq(emeqtype_id);
        Page<EMEQUIP> domains = emequipService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emequipMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "UpdateByPFTEAM", tags = {"EMEQUIP" },  notes = "UpdateByPFTEAM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}")
    @Transactional
    public ResponseEntity<EMEQUIPDTO> updateByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMEQUIPDTO emequipdto) {
        EMEQUIP domain = emequipMapping.toDomain(emequipdto);
        domain.setRteamid(pfteam_id);
        domain.setEmequipid(emequip_id);
		emequipService.update(domain);
        EMEQUIPDTO dto = emequipMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFTEAM", tags = {"EMEQUIP" },  notes = "UpdateBatchByPFTEAM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emequips/batch")
    public ResponseEntity<Boolean> updateBatchByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody List<EMEQUIPDTO> emequipdtos) {
        List<EMEQUIP> domainlist=emequipMapping.toDomain(emequipdtos);
        for(EMEQUIP domain:domainlist){
            domain.setRteamid(pfteam_id);
        }
        emequipService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByPFTEAM", tags = {"EMEQUIP" },  notes = "CreateByPFTEAM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips")
    @Transactional
    public ResponseEntity<EMEQUIPDTO> createByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody EMEQUIPDTO emequipdto) {
        EMEQUIP domain = emequipMapping.toDomain(emequipdto);
        domain.setRteamid(pfteam_id);
		emequipService.create(domain);
        EMEQUIPDTO dto = emequipMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFTEAM", tags = {"EMEQUIP" },  notes = "createBatchByPFTEAM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/batch")
    public ResponseEntity<Boolean> createBatchByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody List<EMEQUIPDTO> emequipdtos) {
        List<EMEQUIP> domainlist=emequipMapping.toDomain(emequipdtos);
        for(EMEQUIP domain:domainlist){
            domain.setRteamid(pfteam_id);
        }
        emequipService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFTEAM", tags = {"EMEQUIP" },  notes = "CheckKeyByPFTEAM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody EMEQUIPDTO emequipdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emequipService.checkKey(emequipMapping.toDomain(emequipdto)));
    }

    @ApiOperation(value = "GetByPFTEAM", tags = {"EMEQUIP" },  notes = "GetByPFTEAM")
	@RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}")
    public ResponseEntity<EMEQUIPDTO> getByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id) {
        EMEQUIP domain = emequipService.get(emequip_id);
        EMEQUIPDTO dto = emequipMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByPFTEAM", tags = {"EMEQUIP" },  notes = "SaveByPFTEAM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/save")
    public ResponseEntity<Boolean> saveByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody EMEQUIPDTO emequipdto) {
        EMEQUIP domain = emequipMapping.toDomain(emequipdto);
        domain.setRteamid(pfteam_id);
        return ResponseEntity.status(HttpStatus.OK).body(emequipService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFTEAM", tags = {"EMEQUIP" },  notes = "SaveBatchByPFTEAM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody List<EMEQUIPDTO> emequipdtos) {
        List<EMEQUIP> domainlist=emequipMapping.toDomain(emequipdtos);
        for(EMEQUIP domain:domainlist){
             domain.setRteamid(pfteam_id);
        }
        emequipService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByPFTEAM", tags = {"EMEQUIP" },  notes = "RemoveByPFTEAM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emequipService.remove(emequip_id));
    }

    @ApiOperation(value = "RemoveBatchByPFTEAM", tags = {"EMEQUIP" },  notes = "RemoveBatchByPFTEAM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emequips/batch")
    public ResponseEntity<Boolean> removeBatchByPFTEAM(@RequestBody List<String> ids) {
        emequipService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFTEAM", tags = {"EMEQUIP" },  notes = "GetDraftByPFTEAM")
    @RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emequips/getdraft")
    public ResponseEntity<EMEQUIPDTO> getDraftByPFTEAM(@PathVariable("pfteam_id") String pfteam_id) {
        EMEQUIP domain = new EMEQUIP();
        domain.setRteamid(pfteam_id);
        return ResponseEntity.status(HttpStatus.OK).body(emequipMapping.toDto(emequipService.getDraft(domain)));
    }

	@ApiOperation(value = "fetch各类型设备数量ByPFTEAM", tags = {"EMEQUIP" } ,notes = "fetch各类型设备数量ByPFTEAM")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emequips/fetchtypeeqnum")
	public ResponseEntity<List<HashMap>> fetchEMEQUIPTypeEQNumByPFTEAM(@PathVariable("pfteam_id") String pfteam_id,EMEQUIPSearchContext context) {
        context.setN_rteamid_eq(pfteam_id);
        Page<HashMap> domains = emequipService.searchTypeEQNum(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(domains.getContent());
	}

	@ApiOperation(value = "search各类型设备数量ByPFTEAM", tags = {"EMEQUIP" } ,notes = "search各类型设备数量ByPFTEAM")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emequips/searchtypeeqnum")
	public ResponseEntity<Page<HashMap>> searchEMEQUIPTypeEQNumByPFTEAM(@PathVariable("pfteam_id") String pfteam_id,EMEQUIPSearchContext context) {
        context.setN_rteamid_eq(pfteam_id);
        Page<HashMap> domains = emequipService.searchTypeEQNum(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(domains.getContent(), context.getPageable(), domains.getTotalElements()));
	}

	@ApiOperation(value = "fetchDEFAULTByPFTEAM", tags = {"EMEQUIP" } ,notes = "fetchDEFAULTByPFTEAM")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emequips/fetchdefault")
	public ResponseEntity<List<EMEQUIPDTO>> fetchEMEQUIPDefaultByPFTEAM(@PathVariable("pfteam_id") String pfteam_id,EMEQUIPSearchContext context) {
        context.setN_rteamid_eq(pfteam_id);
        Page<EMEQUIP> domains = emequipService.searchDefault(context) ;
        List<EMEQUIPDTO> list = emequipMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFTEAM", tags = {"EMEQUIP" } ,notes = "searchDEFAULTByPFTEAM")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emequips/searchdefault")
	public ResponseEntity<Page<EMEQUIPDTO>> searchEMEQUIPDefaultByPFTEAM(@PathVariable("pfteam_id") String pfteam_id,EMEQUIPSearchContext context) {
        context.setN_rteamid_eq(pfteam_id);
        Page<EMEQUIP> domains = emequipService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emequipMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMEQUIP getEntity(){
        return new EMEQUIP();
    }

}
