package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMITEMPRTN;
import cn.ibizlab.eam.core.eam_core.service.IEMITEMPRTNService;
import cn.ibizlab.eam.core.eam_core.filter.EMITEMPRTNSearchContext;




@Slf4j
@Api(tags = {"EMITEMPRTN" })
@RestController("WebApi-emitemprtn")
@RequestMapping("")
public class EMITEMPRTNResource {

    @Autowired
    private IEMITEMPRTNService emitemprtnService;

    @Autowired
    @Lazy
    private EMITEMPRTNMapping emitemprtnMapping;




    @ApiOperation(value = "CheckKey", tags = {"EMITEMPRTN" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emitemprtns/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMITEMPRTNDTO emitemprtndto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.checkKey(emitemprtnMapping.toDomain(emitemprtndto)));
    }




    @ApiOperation(value = "GetDraft", tags = {"EMITEMPRTN" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emitemprtns/getdraft")
    public ResponseEntity<EMITEMPRTNDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emitemprtnMapping.toDto(emitemprtnService.getDraft(new EMITEMPRTN())));
    }




    @PreAuthorize("hasPermission(#emitemprtn_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMITEMPRTN" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emitemprtns/{emitemprtn_id}")
    @Transactional
    public ResponseEntity<EMITEMPRTNDTO> update(@PathVariable("emitemprtn_id") String emitemprtn_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
		EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setEmitemprtnid(emitemprtn_id);
		emitemprtnService.update(domain);
		EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emitemprtn_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMITEMPRTN" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emitemprtns/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        emitemprtnService.updateBatch(emitemprtnMapping.toDomain(emitemprtndtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emitemprtn_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMITEMPRTN" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emitemprtns/{emitemprtn_id}")
    public ResponseEntity<EMITEMPRTNDTO> get(@PathVariable("emitemprtn_id") String emitemprtn_id) {
        EMITEMPRTN domain = emitemprtnService.get(emitemprtn_id);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "Save", tags = {"EMITEMPRTN" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emitemprtns/save")
    public ResponseEntity<Boolean> save(@RequestBody EMITEMPRTNDTO emitemprtndto) {
        return ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.save(emitemprtnMapping.toDomain(emitemprtndto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMITEMPRTN" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emitemprtns/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        emitemprtnService.saveBatch(emitemprtnMapping.toDomain(emitemprtndtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emitemprtn_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMITEMPRTN" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emitemprtns/{emitemprtn_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emitemprtn_id") String emitemprtn_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.remove(emitemprtn_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMITEMPRTN" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emitemprtns/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emitemprtnService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMITEMPRTN" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emitemprtns")
    @Transactional
    public ResponseEntity<EMITEMPRTNDTO> create(@RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
		emitemprtnService.create(domain);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMITEMPRTN" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emitemprtns/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        emitemprtnService.createBatch(emitemprtnMapping.toDomain(emitemprtndtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMITEMPRTN" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emitemprtns/fetchdefault")
	public ResponseEntity<List<EMITEMPRTNDTO>> fetchDefault(EMITEMPRTNSearchContext context) {
        Page<EMITEMPRTN> domains = emitemprtnService.searchDefault(context) ;
        List<EMITEMPRTNDTO> list = emitemprtnMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMITEMPRTN" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emitemprtns/searchdefault")
	public ResponseEntity<Page<EMITEMPRTNDTO>> searchDefault(EMITEMPRTNSearchContext context) {
        Page<EMITEMPRTN> domains = emitemprtnService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemprtnMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "CheckKeyByEMITEM", tags = {"EMITEMPRTN" },  notes = "CheckKeyByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/emitemprtns/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.checkKey(emitemprtnMapping.toDomain(emitemprtndto)));
    }

    @ApiOperation(value = "GetDraftByEMITEM", tags = {"EMITEMPRTN" },  notes = "GetDraftByEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emitems/{emitem_id}/emitemprtns/getdraft")
    public ResponseEntity<EMITEMPRTNDTO> getDraftByEMITEM(@PathVariable("emitem_id") String emitem_id) {
        EMITEMPRTN domain = new EMITEMPRTN();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemprtnMapping.toDto(emitemprtnService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMITEM", tags = {"EMITEMPRTN" },  notes = "UpdateByEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    @Transactional
    public ResponseEntity<EMITEMPRTNDTO> updateByEMITEM(@PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
        domain.setEmitemprtnid(emitemprtn_id);
		emitemprtnService.update(domain);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMITEM", tags = {"EMITEMPRTN" },  notes = "UpdateBatchByEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> updateBatchByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemprtnService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMITEM", tags = {"EMITEMPRTN" },  notes = "GetByEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    public ResponseEntity<EMITEMPRTNDTO> getByEMITEM(@PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id) {
        EMITEMPRTN domain = emitemprtnService.get(emitemprtn_id);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMITEM", tags = {"EMITEMPRTN" },  notes = "SaveByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/emitemprtns/save")
    public ResponseEntity<Boolean> saveByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMITEM", tags = {"EMITEMPRTN" },  notes = "SaveBatchByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/emitemprtns/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemprtnService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByEMITEM", tags = {"EMITEMPRTN" },  notes = "RemoveByEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMITEM(@PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.remove(emitemprtn_id));
    }

    @ApiOperation(value = "RemoveBatchByEMITEM", tags = {"EMITEMPRTN" },  notes = "RemoveBatchByEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> removeBatchByEMITEM(@RequestBody List<String> ids) {
        emitemprtnService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMITEM", tags = {"EMITEMPRTN" },  notes = "CreateByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/emitemprtns")
    @Transactional
    public ResponseEntity<EMITEMPRTNDTO> createByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
		emitemprtnService.create(domain);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMITEM", tags = {"EMITEMPRTN" },  notes = "createBatchByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> createBatchByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemprtnService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMITEM", tags = {"EMITEMPRTN" } ,notes = "fetchDEFAULTByEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emitems/{emitem_id}/emitemprtns/fetchdefault")
	public ResponseEntity<List<EMITEMPRTNDTO>> fetchEMITEMPRTNDefaultByEMITEM(@PathVariable("emitem_id") String emitem_id,EMITEMPRTNSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMPRTN> domains = emitemprtnService.searchDefault(context) ;
        List<EMITEMPRTNDTO> list = emitemprtnMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMITEM", tags = {"EMITEMPRTN" } ,notes = "searchDEFAULTByEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emitems/{emitem_id}/emitemprtns/searchdefault")
	public ResponseEntity<Page<EMITEMPRTNDTO>> searchEMITEMPRTNDefaultByEMITEM(@PathVariable("emitem_id") String emitem_id,EMITEMPRTNSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMPRTN> domains = emitemprtnService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemprtnMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CheckKeyByEMSERVICEEMITEM", tags = {"EMITEMPRTN" },  notes = "CheckKeyByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemprtns/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.checkKey(emitemprtnMapping.toDomain(emitemprtndto)));
    }

    @ApiOperation(value = "GetDraftByEMSERVICEEMITEM", tags = {"EMITEMPRTN" },  notes = "GetDraftByEMSERVICEEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemprtns/getdraft")
    public ResponseEntity<EMITEMPRTNDTO> getDraftByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMPRTN domain = new EMITEMPRTN();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemprtnMapping.toDto(emitemprtnService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMSERVICEEMITEM", tags = {"EMITEMPRTN" },  notes = "UpdateByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    @Transactional
    public ResponseEntity<EMITEMPRTNDTO> updateByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
        domain.setEmitemprtnid(emitemprtn_id);
		emitemprtnService.update(domain);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSERVICEEMITEM", tags = {"EMITEMPRTN" },  notes = "UpdateBatchByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> updateBatchByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemprtnService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSERVICEEMITEM", tags = {"EMITEMPRTN" },  notes = "GetByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    public ResponseEntity<EMITEMPRTNDTO> getByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id) {
        EMITEMPRTN domain = emitemprtnService.get(emitemprtn_id);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMSERVICEEMITEM", tags = {"EMITEMPRTN" },  notes = "SaveByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemprtns/save")
    public ResponseEntity<Boolean> saveByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSERVICEEMITEM", tags = {"EMITEMPRTN" },  notes = "SaveBatchByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemprtns/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemprtnService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByEMSERVICEEMITEM", tags = {"EMITEMPRTN" },  notes = "RemoveByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.remove(emitemprtn_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSERVICEEMITEM", tags = {"EMITEMPRTN" },  notes = "RemoveBatchByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> removeBatchByEMSERVICEEMITEM(@RequestBody List<String> ids) {
        emitemprtnService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMSERVICEEMITEM", tags = {"EMITEMPRTN" },  notes = "CreateByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemprtns")
    @Transactional
    public ResponseEntity<EMITEMPRTNDTO> createByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
		emitemprtnService.create(domain);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSERVICEEMITEM", tags = {"EMITEMPRTN" },  notes = "createBatchByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> createBatchByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemprtnService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMSERVICEEMITEM", tags = {"EMITEMPRTN" } ,notes = "fetchDEFAULTByEMSERVICEEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emitems/{emitem_id}/emitemprtns/fetchdefault")
	public ResponseEntity<List<EMITEMPRTNDTO>> fetchEMITEMPRTNDefaultByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id,EMITEMPRTNSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMPRTN> domains = emitemprtnService.searchDefault(context) ;
        List<EMITEMPRTNDTO> list = emitemprtnMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSERVICEEMITEM", tags = {"EMITEMPRTN" } ,notes = "searchDEFAULTByEMSERVICEEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emitems/{emitem_id}/emitemprtns/searchdefault")
	public ResponseEntity<Page<EMITEMPRTNDTO>> searchEMITEMPRTNDefaultByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id,EMITEMPRTNSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMPRTN> domains = emitemprtnService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemprtnMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CheckKeyByEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "CheckKeyByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.checkKey(emitemprtnMapping.toDomain(emitemprtndto)));
    }

    @ApiOperation(value = "GetDraftByEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "GetDraftByEMSTOREPARTEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/getdraft")
    public ResponseEntity<EMITEMPRTNDTO> getDraftByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMPRTN domain = new EMITEMPRTN();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemprtnMapping.toDto(emitemprtnService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "UpdateByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    @Transactional
    public ResponseEntity<EMITEMPRTNDTO> updateByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
        domain.setEmitemprtnid(emitemprtn_id);
		emitemprtnService.update(domain);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "UpdateBatchByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> updateBatchByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemprtnService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "GetByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    public ResponseEntity<EMITEMPRTNDTO> getByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id) {
        EMITEMPRTN domain = emitemprtnService.get(emitemprtn_id);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "SaveByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/save")
    public ResponseEntity<Boolean> saveByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "SaveBatchByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemprtnService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "RemoveByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.remove(emitemprtn_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "RemoveBatchByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> removeBatchByEMSTOREPARTEMITEM(@RequestBody List<String> ids) {
        emitemprtnService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "CreateByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns")
    @Transactional
    public ResponseEntity<EMITEMPRTNDTO> createByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
		emitemprtnService.create(domain);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "createBatchByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> createBatchByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemprtnService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" } ,notes = "fetchDEFAULTByEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/fetchdefault")
	public ResponseEntity<List<EMITEMPRTNDTO>> fetchEMITEMPRTNDefaultByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMITEMPRTNSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMPRTN> domains = emitemprtnService.searchDefault(context) ;
        List<EMITEMPRTNDTO> list = emitemprtnMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" } ,notes = "searchDEFAULTByEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/searchdefault")
	public ResponseEntity<Page<EMITEMPRTNDTO>> searchEMITEMPRTNDefaultByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMITEMPRTNSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMPRTN> domains = emitemprtnService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemprtnMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CheckKeyByEMSTOREEMITEM", tags = {"EMITEMPRTN" },  notes = "CheckKeyByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemprtns/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.checkKey(emitemprtnMapping.toDomain(emitemprtndto)));
    }

    @ApiOperation(value = "GetDraftByEMSTOREEMITEM", tags = {"EMITEMPRTN" },  notes = "GetDraftByEMSTOREEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemprtns/getdraft")
    public ResponseEntity<EMITEMPRTNDTO> getDraftByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMPRTN domain = new EMITEMPRTN();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemprtnMapping.toDto(emitemprtnService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMSTOREEMITEM", tags = {"EMITEMPRTN" },  notes = "UpdateByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    @Transactional
    public ResponseEntity<EMITEMPRTNDTO> updateByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
        domain.setEmitemprtnid(emitemprtn_id);
		emitemprtnService.update(domain);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSTOREEMITEM", tags = {"EMITEMPRTN" },  notes = "UpdateBatchByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> updateBatchByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemprtnService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSTOREEMITEM", tags = {"EMITEMPRTN" },  notes = "GetByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    public ResponseEntity<EMITEMPRTNDTO> getByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id) {
        EMITEMPRTN domain = emitemprtnService.get(emitemprtn_id);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMSTOREEMITEM", tags = {"EMITEMPRTN" },  notes = "SaveByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemprtns/save")
    public ResponseEntity<Boolean> saveByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSTOREEMITEM", tags = {"EMITEMPRTN" },  notes = "SaveBatchByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemprtns/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemprtnService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByEMSTOREEMITEM", tags = {"EMITEMPRTN" },  notes = "RemoveByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.remove(emitemprtn_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSTOREEMITEM", tags = {"EMITEMPRTN" },  notes = "RemoveBatchByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> removeBatchByEMSTOREEMITEM(@RequestBody List<String> ids) {
        emitemprtnService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMSTOREEMITEM", tags = {"EMITEMPRTN" },  notes = "CreateByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemprtns")
    @Transactional
    public ResponseEntity<EMITEMPRTNDTO> createByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
		emitemprtnService.create(domain);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSTOREEMITEM", tags = {"EMITEMPRTN" },  notes = "createBatchByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> createBatchByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemprtnService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMSTOREEMITEM", tags = {"EMITEMPRTN" } ,notes = "fetchDEFAULTByEMSTOREEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emitems/{emitem_id}/emitemprtns/fetchdefault")
	public ResponseEntity<List<EMITEMPRTNDTO>> fetchEMITEMPRTNDefaultByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id,EMITEMPRTNSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMPRTN> domains = emitemprtnService.searchDefault(context) ;
        List<EMITEMPRTNDTO> list = emitemprtnMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSTOREEMITEM", tags = {"EMITEMPRTN" } ,notes = "searchDEFAULTByEMSTOREEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emitems/{emitem_id}/emitemprtns/searchdefault")
	public ResponseEntity<Page<EMITEMPRTNDTO>> searchEMITEMPRTNDefaultByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id,EMITEMPRTNSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMPRTN> domains = emitemprtnService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemprtnMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CheckKeyByPFEMPEMITEM", tags = {"EMITEMPRTN" },  notes = "CheckKeyByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemprtns/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.checkKey(emitemprtnMapping.toDomain(emitemprtndto)));
    }

    @ApiOperation(value = "GetDraftByPFEMPEMITEM", tags = {"EMITEMPRTN" },  notes = "GetDraftByPFEMPEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemprtns/getdraft")
    public ResponseEntity<EMITEMPRTNDTO> getDraftByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMPRTN domain = new EMITEMPRTN();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemprtnMapping.toDto(emitemprtnService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByPFEMPEMITEM", tags = {"EMITEMPRTN" },  notes = "UpdateByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    @Transactional
    public ResponseEntity<EMITEMPRTNDTO> updateByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
        domain.setEmitemprtnid(emitemprtn_id);
		emitemprtnService.update(domain);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFEMPEMITEM", tags = {"EMITEMPRTN" },  notes = "UpdateBatchByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> updateBatchByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemprtnService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFEMPEMITEM", tags = {"EMITEMPRTN" },  notes = "GetByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    public ResponseEntity<EMITEMPRTNDTO> getByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id) {
        EMITEMPRTN domain = emitemprtnService.get(emitemprtn_id);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByPFEMPEMITEM", tags = {"EMITEMPRTN" },  notes = "SaveByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemprtns/save")
    public ResponseEntity<Boolean> saveByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFEMPEMITEM", tags = {"EMITEMPRTN" },  notes = "SaveBatchByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemprtns/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemprtnService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByPFEMPEMITEM", tags = {"EMITEMPRTN" },  notes = "RemoveByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.remove(emitemprtn_id));
    }

    @ApiOperation(value = "RemoveBatchByPFEMPEMITEM", tags = {"EMITEMPRTN" },  notes = "RemoveBatchByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> removeBatchByPFEMPEMITEM(@RequestBody List<String> ids) {
        emitemprtnService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByPFEMPEMITEM", tags = {"EMITEMPRTN" },  notes = "CreateByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemprtns")
    @Transactional
    public ResponseEntity<EMITEMPRTNDTO> createByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
		emitemprtnService.create(domain);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFEMPEMITEM", tags = {"EMITEMPRTN" },  notes = "createBatchByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> createBatchByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemprtnService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFEMPEMITEM", tags = {"EMITEMPRTN" } ,notes = "fetchDEFAULTByPFEMPEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemprtns/fetchdefault")
	public ResponseEntity<List<EMITEMPRTNDTO>> fetchEMITEMPRTNDefaultByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id,EMITEMPRTNSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMPRTN> domains = emitemprtnService.searchDefault(context) ;
        List<EMITEMPRTNDTO> list = emitemprtnMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFEMPEMITEM", tags = {"EMITEMPRTN" } ,notes = "searchDEFAULTByPFEMPEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemprtns/searchdefault")
	public ResponseEntity<Page<EMITEMPRTNDTO>> searchEMITEMPRTNDefaultByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id,EMITEMPRTNSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMPRTN> domains = emitemprtnService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemprtnMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CheckKeyByPFUNITEMITEM", tags = {"EMITEMPRTN" },  notes = "CheckKeyByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemprtns/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.checkKey(emitemprtnMapping.toDomain(emitemprtndto)));
    }

    @ApiOperation(value = "GetDraftByPFUNITEMITEM", tags = {"EMITEMPRTN" },  notes = "GetDraftByPFUNITEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemprtns/getdraft")
    public ResponseEntity<EMITEMPRTNDTO> getDraftByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMPRTN domain = new EMITEMPRTN();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemprtnMapping.toDto(emitemprtnService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByPFUNITEMITEM", tags = {"EMITEMPRTN" },  notes = "UpdateByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    @Transactional
    public ResponseEntity<EMITEMPRTNDTO> updateByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
        domain.setEmitemprtnid(emitemprtn_id);
		emitemprtnService.update(domain);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFUNITEMITEM", tags = {"EMITEMPRTN" },  notes = "UpdateBatchByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> updateBatchByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemprtnService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFUNITEMITEM", tags = {"EMITEMPRTN" },  notes = "GetByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    public ResponseEntity<EMITEMPRTNDTO> getByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id) {
        EMITEMPRTN domain = emitemprtnService.get(emitemprtn_id);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByPFUNITEMITEM", tags = {"EMITEMPRTN" },  notes = "SaveByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemprtns/save")
    public ResponseEntity<Boolean> saveByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFUNITEMITEM", tags = {"EMITEMPRTN" },  notes = "SaveBatchByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemprtns/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemprtnService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByPFUNITEMITEM", tags = {"EMITEMPRTN" },  notes = "RemoveByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.remove(emitemprtn_id));
    }

    @ApiOperation(value = "RemoveBatchByPFUNITEMITEM", tags = {"EMITEMPRTN" },  notes = "RemoveBatchByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> removeBatchByPFUNITEMITEM(@RequestBody List<String> ids) {
        emitemprtnService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByPFUNITEMITEM", tags = {"EMITEMPRTN" },  notes = "CreateByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemprtns")
    @Transactional
    public ResponseEntity<EMITEMPRTNDTO> createByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
		emitemprtnService.create(domain);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFUNITEMITEM", tags = {"EMITEMPRTN" },  notes = "createBatchByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> createBatchByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemprtnService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFUNITEMITEM", tags = {"EMITEMPRTN" } ,notes = "fetchDEFAULTByPFUNITEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemprtns/fetchdefault")
	public ResponseEntity<List<EMITEMPRTNDTO>> fetchEMITEMPRTNDefaultByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id,EMITEMPRTNSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMPRTN> domains = emitemprtnService.searchDefault(context) ;
        List<EMITEMPRTNDTO> list = emitemprtnMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFUNITEMITEM", tags = {"EMITEMPRTN" } ,notes = "searchDEFAULTByPFUNITEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemprtns/searchdefault")
	public ResponseEntity<Page<EMITEMPRTNDTO>> searchEMITEMPRTNDefaultByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id,EMITEMPRTNSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMPRTN> domains = emitemprtnService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemprtnMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}





    @ApiOperation(value = "CheckKeyByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "CheckKeyByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.checkKey(emitemprtnMapping.toDomain(emitemprtndto)));
    }

    @ApiOperation(value = "GetDraftByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "GetDraftByEMSTOREEMSTOREPARTEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/getdraft")
    public ResponseEntity<EMITEMPRTNDTO> getDraftByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMPRTN domain = new EMITEMPRTN();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemprtnMapping.toDto(emitemprtnService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "UpdateByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    @Transactional
    public ResponseEntity<EMITEMPRTNDTO> updateByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
        domain.setEmitemprtnid(emitemprtn_id);
		emitemprtnService.update(domain);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "UpdateBatchByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> updateBatchByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemprtnService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "GetByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    public ResponseEntity<EMITEMPRTNDTO> getByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id) {
        EMITEMPRTN domain = emitemprtnService.get(emitemprtn_id);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "SaveByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/save")
    public ResponseEntity<Boolean> saveByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "SaveBatchByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemprtnService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "RemoveByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/{emitemprtn_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemprtn_id") String emitemprtn_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemprtnService.remove(emitemprtn_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "RemoveBatchByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> removeBatchByEMSTOREEMSTOREPARTEMITEM(@RequestBody List<String> ids) {
        emitemprtnService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "CreateByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns")
    @Transactional
    public ResponseEntity<EMITEMPRTNDTO> createByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMPRTNDTO emitemprtndto) {
        EMITEMPRTN domain = emitemprtnMapping.toDomain(emitemprtndto);
        domain.setItemid(emitem_id);
		emitemprtnService.create(domain);
        EMITEMPRTNDTO dto = emitemprtnMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" },  notes = "createBatchByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/batch")
    public ResponseEntity<Boolean> createBatchByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMPRTNDTO> emitemprtndtos) {
        List<EMITEMPRTN> domainlist=emitemprtnMapping.toDomain(emitemprtndtos);
        for(EMITEMPRTN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemprtnService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" } ,notes = "fetchDEFAULTByEMSTOREEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/fetchdefault")
	public ResponseEntity<List<EMITEMPRTNDTO>> fetchEMITEMPRTNDefaultByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMITEMPRTNSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMPRTN> domains = emitemprtnService.searchDefault(context) ;
        List<EMITEMPRTNDTO> list = emitemprtnMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMPRTN" } ,notes = "searchDEFAULTByEMSTOREEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemprtns/searchdefault")
	public ResponseEntity<Page<EMITEMPRTNDTO>> searchEMITEMPRTNDefaultByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMITEMPRTNSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMPRTN> domains = emitemprtnService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemprtnMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMITEMPRTN getEntity(){
        return new EMITEMPRTN();
    }

}
