package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMITEMRIN;
import cn.ibizlab.eam.core.eam_core.service.IEMITEMRINService;
import cn.ibizlab.eam.core.eam_core.filter.EMITEMRINSearchContext;




@Slf4j
@Api(tags = {"EMITEMRIN" })
@RestController("WebApi-emitemrin")
@RequestMapping("")
public class EMITEMRINResource {

    @Autowired
    private IEMITEMRINService emitemrinService;

    @Autowired
    @Lazy
    private EMITEMRINMapping emitemrinMapping;




    @ApiOperation(value = "CheckKey", tags = {"EMITEMRIN" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emitemrins/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMITEMRINDTO emitemrindto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemrinService.checkKey(emitemrinMapping.toDomain(emitemrindto)));
    }




    @ApiOperation(value = "GetDraft", tags = {"EMITEMRIN" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emitemrins/getdraft")
    public ResponseEntity<EMITEMRINDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emitemrinMapping.toDto(emitemrinService.getDraft(new EMITEMRIN())));
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMITEMRIN" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emitemrins")
    @Transactional
    public ResponseEntity<EMITEMRINDTO> create(@RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
		emitemrinService.create(domain);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMITEMRIN" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emitemrins/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMITEMRINDTO> emitemrindtos) {
        emitemrinService.createBatch(emitemrinMapping.toDomain(emitemrindtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emitemrin_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMITEMRIN" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emitemrins/{emitemrin_id}")
    @Transactional
    public ResponseEntity<EMITEMRINDTO> update(@PathVariable("emitemrin_id") String emitemrin_id, @RequestBody EMITEMRINDTO emitemrindto) {
		EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setEmitemrinid(emitemrin_id);
		emitemrinService.update(domain);
		EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emitemrin_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMITEMRIN" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emitemrins/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMITEMRINDTO> emitemrindtos) {
        emitemrinService.updateBatch(emitemrinMapping.toDomain(emitemrindtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"EMITEMRIN" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emitemrins/save")
    public ResponseEntity<Boolean> save(@RequestBody EMITEMRINDTO emitemrindto) {
        return ResponseEntity.status(HttpStatus.OK).body(emitemrinService.save(emitemrinMapping.toDomain(emitemrindto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMITEMRIN" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emitemrins/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMITEMRINDTO> emitemrindtos) {
        emitemrinService.saveBatch(emitemrinMapping.toDomain(emitemrindtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emitemrin_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMITEMRIN" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emitemrins/{emitemrin_id}")
    public ResponseEntity<EMITEMRINDTO> get(@PathVariable("emitemrin_id") String emitemrin_id) {
        EMITEMRIN domain = emitemrinService.get(emitemrin_id);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @PreAuthorize("hasPermission('Remove',{#emitemrin_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMITEMRIN" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emitemrins/{emitemrin_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emitemrin_id") String emitemrin_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emitemrinService.remove(emitemrin_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMITEMRIN" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emitemrins/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emitemrinService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMITEMRIN" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emitemrins/fetchdefault")
	public ResponseEntity<List<EMITEMRINDTO>> fetchDefault(EMITEMRINSearchContext context) {
        Page<EMITEMRIN> domains = emitemrinService.searchDefault(context) ;
        List<EMITEMRINDTO> list = emitemrinMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMITEMRIN" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emitemrins/searchdefault")
	public ResponseEntity<Page<EMITEMRINDTO>> searchDefault(EMITEMRINSearchContext context) {
        Page<EMITEMRIN> domains = emitemrinService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemrinMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "CheckKeyByEMITEM", tags = {"EMITEMRIN" },  notes = "CheckKeyByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/emitemrins/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemrinService.checkKey(emitemrinMapping.toDomain(emitemrindto)));
    }

    @ApiOperation(value = "GetDraftByEMITEM", tags = {"EMITEMRIN" },  notes = "GetDraftByEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emitems/{emitem_id}/emitemrins/getdraft")
    public ResponseEntity<EMITEMRINDTO> getDraftByEMITEM(@PathVariable("emitem_id") String emitem_id) {
        EMITEMRIN domain = new EMITEMRIN();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemrinMapping.toDto(emitemrinService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByEMITEM", tags = {"EMITEMRIN" },  notes = "CreateByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/emitemrins")
    @Transactional
    public ResponseEntity<EMITEMRINDTO> createByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
		emitemrinService.create(domain);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMITEM", tags = {"EMITEMRIN" },  notes = "createBatchByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> createBatchByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemrinService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMITEM", tags = {"EMITEMRIN" },  notes = "UpdateByEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    @Transactional
    public ResponseEntity<EMITEMRINDTO> updateByEMITEM(@PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
        domain.setEmitemrinid(emitemrin_id);
		emitemrinService.update(domain);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMITEM", tags = {"EMITEMRIN" },  notes = "UpdateBatchByEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> updateBatchByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemrinService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByEMITEM", tags = {"EMITEMRIN" },  notes = "SaveByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/emitemrins/save")
    public ResponseEntity<Boolean> saveByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemrinService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMITEM", tags = {"EMITEMRIN" },  notes = "SaveBatchByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/emitemrins/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemrinService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMITEM", tags = {"EMITEMRIN" },  notes = "GetByEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    public ResponseEntity<EMITEMRINDTO> getByEMITEM(@PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id) {
        EMITEMRIN domain = emitemrinService.get(emitemrin_id);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByEMITEM", tags = {"EMITEMRIN" },  notes = "RemoveByEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMITEM(@PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemrinService.remove(emitemrin_id));
    }

    @ApiOperation(value = "RemoveBatchByEMITEM", tags = {"EMITEMRIN" },  notes = "RemoveBatchByEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> removeBatchByEMITEM(@RequestBody List<String> ids) {
        emitemrinService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMITEM", tags = {"EMITEMRIN" } ,notes = "fetchDEFAULTByEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emitems/{emitem_id}/emitemrins/fetchdefault")
	public ResponseEntity<List<EMITEMRINDTO>> fetchEMITEMRINDefaultByEMITEM(@PathVariable("emitem_id") String emitem_id,EMITEMRINSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMRIN> domains = emitemrinService.searchDefault(context) ;
        List<EMITEMRINDTO> list = emitemrinMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMITEM", tags = {"EMITEMRIN" } ,notes = "searchDEFAULTByEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emitems/{emitem_id}/emitemrins/searchdefault")
	public ResponseEntity<Page<EMITEMRINDTO>> searchEMITEMRINDefaultByEMITEM(@PathVariable("emitem_id") String emitem_id,EMITEMRINSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMRIN> domains = emitemrinService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemrinMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CheckKeyByEMSERVICEEMITEM", tags = {"EMITEMRIN" },  notes = "CheckKeyByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrins/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemrinService.checkKey(emitemrinMapping.toDomain(emitemrindto)));
    }

    @ApiOperation(value = "GetDraftByEMSERVICEEMITEM", tags = {"EMITEMRIN" },  notes = "GetDraftByEMSERVICEEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrins/getdraft")
    public ResponseEntity<EMITEMRINDTO> getDraftByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMRIN domain = new EMITEMRIN();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemrinMapping.toDto(emitemrinService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByEMSERVICEEMITEM", tags = {"EMITEMRIN" },  notes = "CreateByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrins")
    @Transactional
    public ResponseEntity<EMITEMRINDTO> createByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
		emitemrinService.create(domain);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSERVICEEMITEM", tags = {"EMITEMRIN" },  notes = "createBatchByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> createBatchByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemrinService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMSERVICEEMITEM", tags = {"EMITEMRIN" },  notes = "UpdateByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    @Transactional
    public ResponseEntity<EMITEMRINDTO> updateByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
        domain.setEmitemrinid(emitemrin_id);
		emitemrinService.update(domain);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSERVICEEMITEM", tags = {"EMITEMRIN" },  notes = "UpdateBatchByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> updateBatchByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemrinService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByEMSERVICEEMITEM", tags = {"EMITEMRIN" },  notes = "SaveByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrins/save")
    public ResponseEntity<Boolean> saveByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemrinService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSERVICEEMITEM", tags = {"EMITEMRIN" },  notes = "SaveBatchByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrins/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemrinService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSERVICEEMITEM", tags = {"EMITEMRIN" },  notes = "GetByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    public ResponseEntity<EMITEMRINDTO> getByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id) {
        EMITEMRIN domain = emitemrinService.get(emitemrin_id);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByEMSERVICEEMITEM", tags = {"EMITEMRIN" },  notes = "RemoveByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemrinService.remove(emitemrin_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSERVICEEMITEM", tags = {"EMITEMRIN" },  notes = "RemoveBatchByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> removeBatchByEMSERVICEEMITEM(@RequestBody List<String> ids) {
        emitemrinService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMSERVICEEMITEM", tags = {"EMITEMRIN" } ,notes = "fetchDEFAULTByEMSERVICEEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emitems/{emitem_id}/emitemrins/fetchdefault")
	public ResponseEntity<List<EMITEMRINDTO>> fetchEMITEMRINDefaultByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id,EMITEMRINSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMRIN> domains = emitemrinService.searchDefault(context) ;
        List<EMITEMRINDTO> list = emitemrinMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSERVICEEMITEM", tags = {"EMITEMRIN" } ,notes = "searchDEFAULTByEMSERVICEEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emitems/{emitem_id}/emitemrins/searchdefault")
	public ResponseEntity<Page<EMITEMRINDTO>> searchEMITEMRINDefaultByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id,EMITEMRINSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMRIN> domains = emitemrinService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemrinMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CheckKeyByEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "CheckKeyByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemrinService.checkKey(emitemrinMapping.toDomain(emitemrindto)));
    }

    @ApiOperation(value = "GetDraftByEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "GetDraftByEMSTOREPARTEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/getdraft")
    public ResponseEntity<EMITEMRINDTO> getDraftByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMRIN domain = new EMITEMRIN();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemrinMapping.toDto(emitemrinService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "CreateByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins")
    @Transactional
    public ResponseEntity<EMITEMRINDTO> createByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
		emitemrinService.create(domain);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "createBatchByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> createBatchByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemrinService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "UpdateByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    @Transactional
    public ResponseEntity<EMITEMRINDTO> updateByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
        domain.setEmitemrinid(emitemrin_id);
		emitemrinService.update(domain);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "UpdateBatchByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> updateBatchByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemrinService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "SaveByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/save")
    public ResponseEntity<Boolean> saveByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemrinService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "SaveBatchByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemrinService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "GetByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    public ResponseEntity<EMITEMRINDTO> getByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id) {
        EMITEMRIN domain = emitemrinService.get(emitemrin_id);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "RemoveByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemrinService.remove(emitemrin_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "RemoveBatchByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> removeBatchByEMSTOREPARTEMITEM(@RequestBody List<String> ids) {
        emitemrinService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMSTOREPARTEMITEM", tags = {"EMITEMRIN" } ,notes = "fetchDEFAULTByEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/fetchdefault")
	public ResponseEntity<List<EMITEMRINDTO>> fetchEMITEMRINDefaultByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMITEMRINSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMRIN> domains = emitemrinService.searchDefault(context) ;
        List<EMITEMRINDTO> list = emitemrinMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSTOREPARTEMITEM", tags = {"EMITEMRIN" } ,notes = "searchDEFAULTByEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/searchdefault")
	public ResponseEntity<Page<EMITEMRINDTO>> searchEMITEMRINDefaultByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMITEMRINSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMRIN> domains = emitemrinService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemrinMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CheckKeyByEMSTOREEMITEM", tags = {"EMITEMRIN" },  notes = "CheckKeyByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrins/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemrinService.checkKey(emitemrinMapping.toDomain(emitemrindto)));
    }

    @ApiOperation(value = "GetDraftByEMSTOREEMITEM", tags = {"EMITEMRIN" },  notes = "GetDraftByEMSTOREEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrins/getdraft")
    public ResponseEntity<EMITEMRINDTO> getDraftByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMRIN domain = new EMITEMRIN();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemrinMapping.toDto(emitemrinService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByEMSTOREEMITEM", tags = {"EMITEMRIN" },  notes = "CreateByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrins")
    @Transactional
    public ResponseEntity<EMITEMRINDTO> createByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
		emitemrinService.create(domain);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSTOREEMITEM", tags = {"EMITEMRIN" },  notes = "createBatchByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> createBatchByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemrinService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMSTOREEMITEM", tags = {"EMITEMRIN" },  notes = "UpdateByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    @Transactional
    public ResponseEntity<EMITEMRINDTO> updateByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
        domain.setEmitemrinid(emitemrin_id);
		emitemrinService.update(domain);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSTOREEMITEM", tags = {"EMITEMRIN" },  notes = "UpdateBatchByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> updateBatchByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemrinService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByEMSTOREEMITEM", tags = {"EMITEMRIN" },  notes = "SaveByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrins/save")
    public ResponseEntity<Boolean> saveByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemrinService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSTOREEMITEM", tags = {"EMITEMRIN" },  notes = "SaveBatchByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrins/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemrinService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSTOREEMITEM", tags = {"EMITEMRIN" },  notes = "GetByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    public ResponseEntity<EMITEMRINDTO> getByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id) {
        EMITEMRIN domain = emitemrinService.get(emitemrin_id);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByEMSTOREEMITEM", tags = {"EMITEMRIN" },  notes = "RemoveByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemrinService.remove(emitemrin_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSTOREEMITEM", tags = {"EMITEMRIN" },  notes = "RemoveBatchByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> removeBatchByEMSTOREEMITEM(@RequestBody List<String> ids) {
        emitemrinService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMSTOREEMITEM", tags = {"EMITEMRIN" } ,notes = "fetchDEFAULTByEMSTOREEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emitems/{emitem_id}/emitemrins/fetchdefault")
	public ResponseEntity<List<EMITEMRINDTO>> fetchEMITEMRINDefaultByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id,EMITEMRINSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMRIN> domains = emitemrinService.searchDefault(context) ;
        List<EMITEMRINDTO> list = emitemrinMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSTOREEMITEM", tags = {"EMITEMRIN" } ,notes = "searchDEFAULTByEMSTOREEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emitems/{emitem_id}/emitemrins/searchdefault")
	public ResponseEntity<Page<EMITEMRINDTO>> searchEMITEMRINDefaultByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id,EMITEMRINSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMRIN> domains = emitemrinService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemrinMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CheckKeyByPFEMPEMITEM", tags = {"EMITEMRIN" },  notes = "CheckKeyByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrins/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemrinService.checkKey(emitemrinMapping.toDomain(emitemrindto)));
    }

    @ApiOperation(value = "GetDraftByPFEMPEMITEM", tags = {"EMITEMRIN" },  notes = "GetDraftByPFEMPEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrins/getdraft")
    public ResponseEntity<EMITEMRINDTO> getDraftByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMRIN domain = new EMITEMRIN();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemrinMapping.toDto(emitemrinService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByPFEMPEMITEM", tags = {"EMITEMRIN" },  notes = "CreateByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrins")
    @Transactional
    public ResponseEntity<EMITEMRINDTO> createByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
		emitemrinService.create(domain);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFEMPEMITEM", tags = {"EMITEMRIN" },  notes = "createBatchByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> createBatchByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemrinService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByPFEMPEMITEM", tags = {"EMITEMRIN" },  notes = "UpdateByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    @Transactional
    public ResponseEntity<EMITEMRINDTO> updateByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
        domain.setEmitemrinid(emitemrin_id);
		emitemrinService.update(domain);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFEMPEMITEM", tags = {"EMITEMRIN" },  notes = "UpdateBatchByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> updateBatchByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemrinService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByPFEMPEMITEM", tags = {"EMITEMRIN" },  notes = "SaveByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrins/save")
    public ResponseEntity<Boolean> saveByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemrinService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFEMPEMITEM", tags = {"EMITEMRIN" },  notes = "SaveBatchByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrins/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemrinService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFEMPEMITEM", tags = {"EMITEMRIN" },  notes = "GetByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    public ResponseEntity<EMITEMRINDTO> getByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id) {
        EMITEMRIN domain = emitemrinService.get(emitemrin_id);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByPFEMPEMITEM", tags = {"EMITEMRIN" },  notes = "RemoveByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemrinService.remove(emitemrin_id));
    }

    @ApiOperation(value = "RemoveBatchByPFEMPEMITEM", tags = {"EMITEMRIN" },  notes = "RemoveBatchByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> removeBatchByPFEMPEMITEM(@RequestBody List<String> ids) {
        emitemrinService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFEMPEMITEM", tags = {"EMITEMRIN" } ,notes = "fetchDEFAULTByPFEMPEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrins/fetchdefault")
	public ResponseEntity<List<EMITEMRINDTO>> fetchEMITEMRINDefaultByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id,EMITEMRINSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMRIN> domains = emitemrinService.searchDefault(context) ;
        List<EMITEMRINDTO> list = emitemrinMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFEMPEMITEM", tags = {"EMITEMRIN" } ,notes = "searchDEFAULTByPFEMPEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrins/searchdefault")
	public ResponseEntity<Page<EMITEMRINDTO>> searchEMITEMRINDefaultByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id,EMITEMRINSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMRIN> domains = emitemrinService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemrinMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CheckKeyByPFUNITEMITEM", tags = {"EMITEMRIN" },  notes = "CheckKeyByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrins/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemrinService.checkKey(emitemrinMapping.toDomain(emitemrindto)));
    }

    @ApiOperation(value = "GetDraftByPFUNITEMITEM", tags = {"EMITEMRIN" },  notes = "GetDraftByPFUNITEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrins/getdraft")
    public ResponseEntity<EMITEMRINDTO> getDraftByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMRIN domain = new EMITEMRIN();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemrinMapping.toDto(emitemrinService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByPFUNITEMITEM", tags = {"EMITEMRIN" },  notes = "CreateByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrins")
    @Transactional
    public ResponseEntity<EMITEMRINDTO> createByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
		emitemrinService.create(domain);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFUNITEMITEM", tags = {"EMITEMRIN" },  notes = "createBatchByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> createBatchByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemrinService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByPFUNITEMITEM", tags = {"EMITEMRIN" },  notes = "UpdateByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    @Transactional
    public ResponseEntity<EMITEMRINDTO> updateByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
        domain.setEmitemrinid(emitemrin_id);
		emitemrinService.update(domain);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFUNITEMITEM", tags = {"EMITEMRIN" },  notes = "UpdateBatchByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> updateBatchByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemrinService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByPFUNITEMITEM", tags = {"EMITEMRIN" },  notes = "SaveByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrins/save")
    public ResponseEntity<Boolean> saveByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemrinService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFUNITEMITEM", tags = {"EMITEMRIN" },  notes = "SaveBatchByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrins/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemrinService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFUNITEMITEM", tags = {"EMITEMRIN" },  notes = "GetByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    public ResponseEntity<EMITEMRINDTO> getByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id) {
        EMITEMRIN domain = emitemrinService.get(emitemrin_id);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByPFUNITEMITEM", tags = {"EMITEMRIN" },  notes = "RemoveByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemrinService.remove(emitemrin_id));
    }

    @ApiOperation(value = "RemoveBatchByPFUNITEMITEM", tags = {"EMITEMRIN" },  notes = "RemoveBatchByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> removeBatchByPFUNITEMITEM(@RequestBody List<String> ids) {
        emitemrinService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFUNITEMITEM", tags = {"EMITEMRIN" } ,notes = "fetchDEFAULTByPFUNITEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrins/fetchdefault")
	public ResponseEntity<List<EMITEMRINDTO>> fetchEMITEMRINDefaultByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id,EMITEMRINSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMRIN> domains = emitemrinService.searchDefault(context) ;
        List<EMITEMRINDTO> list = emitemrinMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFUNITEMITEM", tags = {"EMITEMRIN" } ,notes = "searchDEFAULTByPFUNITEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrins/searchdefault")
	public ResponseEntity<Page<EMITEMRINDTO>> searchEMITEMRINDefaultByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id,EMITEMRINSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMRIN> domains = emitemrinService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemrinMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}





    @ApiOperation(value = "CheckKeyByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "CheckKeyByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemrinService.checkKey(emitemrinMapping.toDomain(emitemrindto)));
    }

    @ApiOperation(value = "GetDraftByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "GetDraftByEMSTOREEMSTOREPARTEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/getdraft")
    public ResponseEntity<EMITEMRINDTO> getDraftByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMRIN domain = new EMITEMRIN();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemrinMapping.toDto(emitemrinService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "CreateByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins")
    @Transactional
    public ResponseEntity<EMITEMRINDTO> createByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
		emitemrinService.create(domain);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "createBatchByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> createBatchByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemrinService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "UpdateByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    @Transactional
    public ResponseEntity<EMITEMRINDTO> updateByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
        domain.setEmitemrinid(emitemrin_id);
		emitemrinService.update(domain);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "UpdateBatchByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> updateBatchByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemrinService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "SaveByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/save")
    public ResponseEntity<Boolean> saveByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMRINDTO emitemrindto) {
        EMITEMRIN domain = emitemrinMapping.toDomain(emitemrindto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemrinService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "SaveBatchByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMRINDTO> emitemrindtos) {
        List<EMITEMRIN> domainlist=emitemrinMapping.toDomain(emitemrindtos);
        for(EMITEMRIN domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemrinService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "GetByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    public ResponseEntity<EMITEMRINDTO> getByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id) {
        EMITEMRIN domain = emitemrinService.get(emitemrin_id);
        EMITEMRINDTO dto = emitemrinMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "RemoveByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/{emitemrin_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrin_id") String emitemrin_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemrinService.remove(emitemrin_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMRIN" },  notes = "RemoveBatchByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/batch")
    public ResponseEntity<Boolean> removeBatchByEMSTOREEMSTOREPARTEMITEM(@RequestBody List<String> ids) {
        emitemrinService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMRIN" } ,notes = "fetchDEFAULTByEMSTOREEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/fetchdefault")
	public ResponseEntity<List<EMITEMRINDTO>> fetchEMITEMRINDefaultByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMITEMRINSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMRIN> domains = emitemrinService.searchDefault(context) ;
        List<EMITEMRINDTO> list = emitemrinMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMRIN" } ,notes = "searchDEFAULTByEMSTOREEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrins/searchdefault")
	public ResponseEntity<Page<EMITEMRINDTO>> searchEMITEMRINDefaultByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMITEMRINSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMRIN> domains = emitemrinService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemrinMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMITEMRIN getEntity(){
        return new EMITEMRIN();
    }

}
