package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMITEMROUT;
import cn.ibizlab.eam.core.eam_core.service.IEMITEMROUTService;
import cn.ibizlab.eam.core.eam_core.filter.EMITEMROUTSearchContext;




@Slf4j
@Api(tags = {"EMITEMROUT" })
@RestController("WebApi-emitemrout")
@RequestMapping("")
public class EMITEMROUTResource {

    @Autowired
    private IEMITEMROUTService emitemroutService;

    @Autowired
    @Lazy
    private EMITEMROUTMapping emitemroutMapping;




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMITEMROUT" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emitemrouts")
    @Transactional
    public ResponseEntity<EMITEMROUTDTO> create(@RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
		emitemroutService.create(domain);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMITEMROUT" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emitemrouts/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        emitemroutService.createBatch(emitemroutMapping.toDomain(emitemroutdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emitemrout_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMITEMROUT" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emitemrouts/{emitemrout_id}")
    public ResponseEntity<EMITEMROUTDTO> get(@PathVariable("emitemrout_id") String emitemrout_id) {
        EMITEMROUT domain = emitemroutService.get(emitemrout_id);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMITEMROUT" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emitemrouts/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMITEMROUTDTO emitemroutdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemroutService.checkKey(emitemroutMapping.toDomain(emitemroutdto)));
    }




    @PreAuthorize("hasPermission('Remove',{#emitemrout_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMITEMROUT" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emitemrouts/{emitemrout_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emitemrout_id") String emitemrout_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emitemroutService.remove(emitemrout_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMITEMROUT" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emitemrouts/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emitemroutService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emitemrout_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMITEMROUT" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emitemrouts/{emitemrout_id}")
    @Transactional
    public ResponseEntity<EMITEMROUTDTO> update(@PathVariable("emitemrout_id") String emitemrout_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
		EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setEmitemroutid(emitemrout_id);
		emitemroutService.update(domain);
		EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emitemrout_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMITEMROUT" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emitemrouts/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        emitemroutService.updateBatch(emitemroutMapping.toDomain(emitemroutdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"EMITEMROUT" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emitemrouts/save")
    public ResponseEntity<Boolean> save(@RequestBody EMITEMROUTDTO emitemroutdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emitemroutService.save(emitemroutMapping.toDomain(emitemroutdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMITEMROUT" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emitemrouts/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        emitemroutService.saveBatch(emitemroutMapping.toDomain(emitemroutdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMITEMROUT" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emitemrouts/getdraft")
    public ResponseEntity<EMITEMROUTDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emitemroutMapping.toDto(emitemroutService.getDraft(new EMITEMROUT())));
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMITEMROUT" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emitemrouts/fetchdefault")
	public ResponseEntity<List<EMITEMROUTDTO>> fetchDefault(EMITEMROUTSearchContext context) {
        Page<EMITEMROUT> domains = emitemroutService.searchDefault(context) ;
        List<EMITEMROUTDTO> list = emitemroutMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMITEMROUT" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emitemrouts/searchdefault")
	public ResponseEntity<Page<EMITEMROUTDTO>> searchDefault(EMITEMROUTSearchContext context) {
        Page<EMITEMROUT> domains = emitemroutService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemroutMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "CreateByEMITEM", tags = {"EMITEMROUT" },  notes = "CreateByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/emitemrouts")
    @Transactional
    public ResponseEntity<EMITEMROUTDTO> createByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
		emitemroutService.create(domain);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMITEM", tags = {"EMITEMROUT" },  notes = "createBatchByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> createBatchByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemroutService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMITEM", tags = {"EMITEMROUT" },  notes = "GetByEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    public ResponseEntity<EMITEMROUTDTO> getByEMITEM(@PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id) {
        EMITEMROUT domain = emitemroutService.get(emitemrout_id);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKeyByEMITEM", tags = {"EMITEMROUT" },  notes = "CheckKeyByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/emitemrouts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemroutService.checkKey(emitemroutMapping.toDomain(emitemroutdto)));
    }

    @ApiOperation(value = "RemoveByEMITEM", tags = {"EMITEMROUT" },  notes = "RemoveByEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMITEM(@PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemroutService.remove(emitemrout_id));
    }

    @ApiOperation(value = "RemoveBatchByEMITEM", tags = {"EMITEMROUT" },  notes = "RemoveBatchByEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> removeBatchByEMITEM(@RequestBody List<String> ids) {
        emitemroutService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMITEM", tags = {"EMITEMROUT" },  notes = "UpdateByEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    @Transactional
    public ResponseEntity<EMITEMROUTDTO> updateByEMITEM(@PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
        domain.setEmitemroutid(emitemrout_id);
		emitemroutService.update(domain);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMITEM", tags = {"EMITEMROUT" },  notes = "UpdateBatchByEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> updateBatchByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemroutService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByEMITEM", tags = {"EMITEMROUT" },  notes = "SaveByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/emitemrouts/save")
    public ResponseEntity<Boolean> saveByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemroutService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMITEM", tags = {"EMITEMROUT" },  notes = "SaveBatchByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/emitemrouts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemroutService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMITEM", tags = {"EMITEMROUT" },  notes = "GetDraftByEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emitems/{emitem_id}/emitemrouts/getdraft")
    public ResponseEntity<EMITEMROUTDTO> getDraftByEMITEM(@PathVariable("emitem_id") String emitem_id) {
        EMITEMROUT domain = new EMITEMROUT();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemroutMapping.toDto(emitemroutService.getDraft(domain)));
    }

	@ApiOperation(value = "fetchDEFAULTByEMITEM", tags = {"EMITEMROUT" } ,notes = "fetchDEFAULTByEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emitems/{emitem_id}/emitemrouts/fetchdefault")
	public ResponseEntity<List<EMITEMROUTDTO>> fetchEMITEMROUTDefaultByEMITEM(@PathVariable("emitem_id") String emitem_id,EMITEMROUTSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMROUT> domains = emitemroutService.searchDefault(context) ;
        List<EMITEMROUTDTO> list = emitemroutMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMITEM", tags = {"EMITEMROUT" } ,notes = "searchDEFAULTByEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emitems/{emitem_id}/emitemrouts/searchdefault")
	public ResponseEntity<Page<EMITEMROUTDTO>> searchEMITEMROUTDefaultByEMITEM(@PathVariable("emitem_id") String emitem_id,EMITEMROUTSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMROUT> domains = emitemroutService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemroutMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CreateByEMSERVICEEMITEM", tags = {"EMITEMROUT" },  notes = "CreateByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrouts")
    @Transactional
    public ResponseEntity<EMITEMROUTDTO> createByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
		emitemroutService.create(domain);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSERVICEEMITEM", tags = {"EMITEMROUT" },  notes = "createBatchByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> createBatchByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemroutService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSERVICEEMITEM", tags = {"EMITEMROUT" },  notes = "GetByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    public ResponseEntity<EMITEMROUTDTO> getByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id) {
        EMITEMROUT domain = emitemroutService.get(emitemrout_id);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKeyByEMSERVICEEMITEM", tags = {"EMITEMROUT" },  notes = "CheckKeyByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrouts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemroutService.checkKey(emitemroutMapping.toDomain(emitemroutdto)));
    }

    @ApiOperation(value = "RemoveByEMSERVICEEMITEM", tags = {"EMITEMROUT" },  notes = "RemoveByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemroutService.remove(emitemrout_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSERVICEEMITEM", tags = {"EMITEMROUT" },  notes = "RemoveBatchByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> removeBatchByEMSERVICEEMITEM(@RequestBody List<String> ids) {
        emitemroutService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMSERVICEEMITEM", tags = {"EMITEMROUT" },  notes = "UpdateByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    @Transactional
    public ResponseEntity<EMITEMROUTDTO> updateByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
        domain.setEmitemroutid(emitemrout_id);
		emitemroutService.update(domain);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSERVICEEMITEM", tags = {"EMITEMROUT" },  notes = "UpdateBatchByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> updateBatchByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemroutService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByEMSERVICEEMITEM", tags = {"EMITEMROUT" },  notes = "SaveByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrouts/save")
    public ResponseEntity<Boolean> saveByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemroutService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSERVICEEMITEM", tags = {"EMITEMROUT" },  notes = "SaveBatchByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrouts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemroutService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSERVICEEMITEM", tags = {"EMITEMROUT" },  notes = "GetDraftByEMSERVICEEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emitems/{emitem_id}/emitemrouts/getdraft")
    public ResponseEntity<EMITEMROUTDTO> getDraftByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMROUT domain = new EMITEMROUT();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemroutMapping.toDto(emitemroutService.getDraft(domain)));
    }

	@ApiOperation(value = "fetchDEFAULTByEMSERVICEEMITEM", tags = {"EMITEMROUT" } ,notes = "fetchDEFAULTByEMSERVICEEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emitems/{emitem_id}/emitemrouts/fetchdefault")
	public ResponseEntity<List<EMITEMROUTDTO>> fetchEMITEMROUTDefaultByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id,EMITEMROUTSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMROUT> domains = emitemroutService.searchDefault(context) ;
        List<EMITEMROUTDTO> list = emitemroutMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSERVICEEMITEM", tags = {"EMITEMROUT" } ,notes = "searchDEFAULTByEMSERVICEEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emitems/{emitem_id}/emitemrouts/searchdefault")
	public ResponseEntity<Page<EMITEMROUTDTO>> searchEMITEMROUTDefaultByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id,EMITEMROUTSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMROUT> domains = emitemroutService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemroutMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CreateByEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "CreateByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts")
    @Transactional
    public ResponseEntity<EMITEMROUTDTO> createByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
		emitemroutService.create(domain);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "createBatchByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> createBatchByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemroutService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "GetByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    public ResponseEntity<EMITEMROUTDTO> getByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id) {
        EMITEMROUT domain = emitemroutService.get(emitemrout_id);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKeyByEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "CheckKeyByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemroutService.checkKey(emitemroutMapping.toDomain(emitemroutdto)));
    }

    @ApiOperation(value = "RemoveByEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "RemoveByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemroutService.remove(emitemrout_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "RemoveBatchByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> removeBatchByEMSTOREPARTEMITEM(@RequestBody List<String> ids) {
        emitemroutService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "UpdateByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    @Transactional
    public ResponseEntity<EMITEMROUTDTO> updateByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
        domain.setEmitemroutid(emitemrout_id);
		emitemroutService.update(domain);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "UpdateBatchByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> updateBatchByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemroutService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "SaveByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/save")
    public ResponseEntity<Boolean> saveByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemroutService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "SaveBatchByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemroutService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "GetDraftByEMSTOREPARTEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/getdraft")
    public ResponseEntity<EMITEMROUTDTO> getDraftByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMROUT domain = new EMITEMROUT();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemroutMapping.toDto(emitemroutService.getDraft(domain)));
    }

	@ApiOperation(value = "fetchDEFAULTByEMSTOREPARTEMITEM", tags = {"EMITEMROUT" } ,notes = "fetchDEFAULTByEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/fetchdefault")
	public ResponseEntity<List<EMITEMROUTDTO>> fetchEMITEMROUTDefaultByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMITEMROUTSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMROUT> domains = emitemroutService.searchDefault(context) ;
        List<EMITEMROUTDTO> list = emitemroutMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSTOREPARTEMITEM", tags = {"EMITEMROUT" } ,notes = "searchDEFAULTByEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/searchdefault")
	public ResponseEntity<Page<EMITEMROUTDTO>> searchEMITEMROUTDefaultByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMITEMROUTSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMROUT> domains = emitemroutService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemroutMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CreateByEMSTOREEMITEM", tags = {"EMITEMROUT" },  notes = "CreateByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrouts")
    @Transactional
    public ResponseEntity<EMITEMROUTDTO> createByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
		emitemroutService.create(domain);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSTOREEMITEM", tags = {"EMITEMROUT" },  notes = "createBatchByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> createBatchByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemroutService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSTOREEMITEM", tags = {"EMITEMROUT" },  notes = "GetByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    public ResponseEntity<EMITEMROUTDTO> getByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id) {
        EMITEMROUT domain = emitemroutService.get(emitemrout_id);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKeyByEMSTOREEMITEM", tags = {"EMITEMROUT" },  notes = "CheckKeyByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrouts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemroutService.checkKey(emitemroutMapping.toDomain(emitemroutdto)));
    }

    @ApiOperation(value = "RemoveByEMSTOREEMITEM", tags = {"EMITEMROUT" },  notes = "RemoveByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemroutService.remove(emitemrout_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSTOREEMITEM", tags = {"EMITEMROUT" },  notes = "RemoveBatchByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> removeBatchByEMSTOREEMITEM(@RequestBody List<String> ids) {
        emitemroutService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMSTOREEMITEM", tags = {"EMITEMROUT" },  notes = "UpdateByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    @Transactional
    public ResponseEntity<EMITEMROUTDTO> updateByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
        domain.setEmitemroutid(emitemrout_id);
		emitemroutService.update(domain);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSTOREEMITEM", tags = {"EMITEMROUT" },  notes = "UpdateBatchByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> updateBatchByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemroutService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByEMSTOREEMITEM", tags = {"EMITEMROUT" },  notes = "SaveByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrouts/save")
    public ResponseEntity<Boolean> saveByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemroutService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSTOREEMITEM", tags = {"EMITEMROUT" },  notes = "SaveBatchByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrouts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemroutService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSTOREEMITEM", tags = {"EMITEMROUT" },  notes = "GetDraftByEMSTOREEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emitems/{emitem_id}/emitemrouts/getdraft")
    public ResponseEntity<EMITEMROUTDTO> getDraftByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMROUT domain = new EMITEMROUT();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemroutMapping.toDto(emitemroutService.getDraft(domain)));
    }

	@ApiOperation(value = "fetchDEFAULTByEMSTOREEMITEM", tags = {"EMITEMROUT" } ,notes = "fetchDEFAULTByEMSTOREEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emitems/{emitem_id}/emitemrouts/fetchdefault")
	public ResponseEntity<List<EMITEMROUTDTO>> fetchEMITEMROUTDefaultByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id,EMITEMROUTSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMROUT> domains = emitemroutService.searchDefault(context) ;
        List<EMITEMROUTDTO> list = emitemroutMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSTOREEMITEM", tags = {"EMITEMROUT" } ,notes = "searchDEFAULTByEMSTOREEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emitems/{emitem_id}/emitemrouts/searchdefault")
	public ResponseEntity<Page<EMITEMROUTDTO>> searchEMITEMROUTDefaultByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id,EMITEMROUTSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMROUT> domains = emitemroutService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemroutMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CreateByPFEMPEMITEM", tags = {"EMITEMROUT" },  notes = "CreateByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrouts")
    @Transactional
    public ResponseEntity<EMITEMROUTDTO> createByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
		emitemroutService.create(domain);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFEMPEMITEM", tags = {"EMITEMROUT" },  notes = "createBatchByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> createBatchByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemroutService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFEMPEMITEM", tags = {"EMITEMROUT" },  notes = "GetByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    public ResponseEntity<EMITEMROUTDTO> getByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id) {
        EMITEMROUT domain = emitemroutService.get(emitemrout_id);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKeyByPFEMPEMITEM", tags = {"EMITEMROUT" },  notes = "CheckKeyByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrouts/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemroutService.checkKey(emitemroutMapping.toDomain(emitemroutdto)));
    }

    @ApiOperation(value = "RemoveByPFEMPEMITEM", tags = {"EMITEMROUT" },  notes = "RemoveByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemroutService.remove(emitemrout_id));
    }

    @ApiOperation(value = "RemoveBatchByPFEMPEMITEM", tags = {"EMITEMROUT" },  notes = "RemoveBatchByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> removeBatchByPFEMPEMITEM(@RequestBody List<String> ids) {
        emitemroutService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByPFEMPEMITEM", tags = {"EMITEMROUT" },  notes = "UpdateByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    @Transactional
    public ResponseEntity<EMITEMROUTDTO> updateByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
        domain.setEmitemroutid(emitemrout_id);
		emitemroutService.update(domain);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFEMPEMITEM", tags = {"EMITEMROUT" },  notes = "UpdateBatchByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> updateBatchByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemroutService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByPFEMPEMITEM", tags = {"EMITEMROUT" },  notes = "SaveByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrouts/save")
    public ResponseEntity<Boolean> saveByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemroutService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFEMPEMITEM", tags = {"EMITEMROUT" },  notes = "SaveBatchByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrouts/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemroutService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFEMPEMITEM", tags = {"EMITEMROUT" },  notes = "GetDraftByPFEMPEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrouts/getdraft")
    public ResponseEntity<EMITEMROUTDTO> getDraftByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMROUT domain = new EMITEMROUT();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemroutMapping.toDto(emitemroutService.getDraft(domain)));
    }

	@ApiOperation(value = "fetchDEFAULTByPFEMPEMITEM", tags = {"EMITEMROUT" } ,notes = "fetchDEFAULTByPFEMPEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrouts/fetchdefault")
	public ResponseEntity<List<EMITEMROUTDTO>> fetchEMITEMROUTDefaultByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id,EMITEMROUTSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMROUT> domains = emitemroutService.searchDefault(context) ;
        List<EMITEMROUTDTO> list = emitemroutMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFEMPEMITEM", tags = {"EMITEMROUT" } ,notes = "searchDEFAULTByPFEMPEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emitems/{emitem_id}/emitemrouts/searchdefault")
	public ResponseEntity<Page<EMITEMROUTDTO>> searchEMITEMROUTDefaultByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id,EMITEMROUTSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMROUT> domains = emitemroutService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemroutMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CreateByPFUNITEMITEM", tags = {"EMITEMROUT" },  notes = "CreateByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrouts")
    @Transactional
    public ResponseEntity<EMITEMROUTDTO> createByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
		emitemroutService.create(domain);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFUNITEMITEM", tags = {"EMITEMROUT" },  notes = "createBatchByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> createBatchByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemroutService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFUNITEMITEM", tags = {"EMITEMROUT" },  notes = "GetByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    public ResponseEntity<EMITEMROUTDTO> getByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id) {
        EMITEMROUT domain = emitemroutService.get(emitemrout_id);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKeyByPFUNITEMITEM", tags = {"EMITEMROUT" },  notes = "CheckKeyByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrouts/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemroutService.checkKey(emitemroutMapping.toDomain(emitemroutdto)));
    }

    @ApiOperation(value = "RemoveByPFUNITEMITEM", tags = {"EMITEMROUT" },  notes = "RemoveByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemroutService.remove(emitemrout_id));
    }

    @ApiOperation(value = "RemoveBatchByPFUNITEMITEM", tags = {"EMITEMROUT" },  notes = "RemoveBatchByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> removeBatchByPFUNITEMITEM(@RequestBody List<String> ids) {
        emitemroutService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByPFUNITEMITEM", tags = {"EMITEMROUT" },  notes = "UpdateByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    @Transactional
    public ResponseEntity<EMITEMROUTDTO> updateByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
        domain.setEmitemroutid(emitemrout_id);
		emitemroutService.update(domain);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFUNITEMITEM", tags = {"EMITEMROUT" },  notes = "UpdateBatchByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> updateBatchByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemroutService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByPFUNITEMITEM", tags = {"EMITEMROUT" },  notes = "SaveByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrouts/save")
    public ResponseEntity<Boolean> saveByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemroutService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFUNITEMITEM", tags = {"EMITEMROUT" },  notes = "SaveBatchByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrouts/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemroutService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFUNITEMITEM", tags = {"EMITEMROUT" },  notes = "GetDraftByPFUNITEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrouts/getdraft")
    public ResponseEntity<EMITEMROUTDTO> getDraftByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMROUT domain = new EMITEMROUT();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemroutMapping.toDto(emitemroutService.getDraft(domain)));
    }

	@ApiOperation(value = "fetchDEFAULTByPFUNITEMITEM", tags = {"EMITEMROUT" } ,notes = "fetchDEFAULTByPFUNITEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrouts/fetchdefault")
	public ResponseEntity<List<EMITEMROUTDTO>> fetchEMITEMROUTDefaultByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id,EMITEMROUTSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMROUT> domains = emitemroutService.searchDefault(context) ;
        List<EMITEMROUTDTO> list = emitemroutMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFUNITEMITEM", tags = {"EMITEMROUT" } ,notes = "searchDEFAULTByPFUNITEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfunits/{pfunit_id}/emitems/{emitem_id}/emitemrouts/searchdefault")
	public ResponseEntity<Page<EMITEMROUTDTO>> searchEMITEMROUTDefaultByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id,EMITEMROUTSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMROUT> domains = emitemroutService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemroutMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}





    @ApiOperation(value = "CreateByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "CreateByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts")
    @Transactional
    public ResponseEntity<EMITEMROUTDTO> createByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
		emitemroutService.create(domain);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "createBatchByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> createBatchByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemroutService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "GetByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    public ResponseEntity<EMITEMROUTDTO> getByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id) {
        EMITEMROUT domain = emitemroutService.get(emitemrout_id);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKeyByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "CheckKeyByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemroutService.checkKey(emitemroutMapping.toDomain(emitemroutdto)));
    }

    @ApiOperation(value = "RemoveByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "RemoveByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemroutService.remove(emitemrout_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "RemoveBatchByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> removeBatchByEMSTOREEMSTOREPARTEMITEM(@RequestBody List<String> ids) {
        emitemroutService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "UpdateByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/{emitemrout_id}")
    @Transactional
    public ResponseEntity<EMITEMROUTDTO> updateByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("emitemrout_id") String emitemrout_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
        domain.setEmitemroutid(emitemrout_id);
		emitemroutService.update(domain);
        EMITEMROUTDTO dto = emitemroutMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "UpdateBatchByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/batch")
    public ResponseEntity<Boolean> updateBatchByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
            domain.setItemid(emitem_id);
        }
        emitemroutService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "SaveByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/save")
    public ResponseEntity<Boolean> saveByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMROUTDTO emitemroutdto) {
        EMITEMROUT domain = emitemroutMapping.toDomain(emitemroutdto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemroutService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "SaveBatchByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMITEMROUTDTO> emitemroutdtos) {
        List<EMITEMROUT> domainlist=emitemroutMapping.toDomain(emitemroutdtos);
        for(EMITEMROUT domain:domainlist){
             domain.setItemid(emitem_id);
        }
        emitemroutService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMROUT" },  notes = "GetDraftByEMSTOREEMSTOREPARTEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/getdraft")
    public ResponseEntity<EMITEMROUTDTO> getDraftByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEMROUT domain = new EMITEMROUT();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemroutMapping.toDto(emitemroutService.getDraft(domain)));
    }

	@ApiOperation(value = "fetchDEFAULTByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMROUT" } ,notes = "fetchDEFAULTByEMSTOREEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/fetchdefault")
	public ResponseEntity<List<EMITEMROUTDTO>> fetchEMITEMROUTDefaultByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMITEMROUTSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMROUT> domains = emitemroutService.searchDefault(context) ;
        List<EMITEMROUTDTO> list = emitemroutMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSTOREEMSTOREPARTEMITEM", tags = {"EMITEMROUT" } ,notes = "searchDEFAULTByEMSTOREEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/emitemrouts/searchdefault")
	public ResponseEntity<Page<EMITEMROUTDTO>> searchEMITEMROUTDefaultByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMITEMROUTSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMITEMROUT> domains = emitemroutService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemroutMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMITEMROUT getEntity(){
        return new EMITEMROUT();
    }

}
