package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMITEM;
import cn.ibizlab.eam.core.eam_core.service.IEMITEMService;
import cn.ibizlab.eam.core.eam_core.filter.EMITEMSearchContext;




@Slf4j
@Api(tags = {"EMITEM" })
@RestController("WebApi-emitem")
@RequestMapping("")
public class EMITEMResource {

    @Autowired
    private IEMITEMService emitemService;

    @Autowired
    @Lazy
    private EMITEMMapping emitemMapping;




    @PreAuthorize("hasPermission('Remove',{#emitem_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMITEM" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emitems/{emitem_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emitem_id") String emitem_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emitemService.remove(emitem_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMITEM" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emitems/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emitemService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emitem_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMITEM" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emitems/{emitem_id}")
    public ResponseEntity<EMITEMDTO> get(@PathVariable("emitem_id") String emitem_id) {
        EMITEM domain = emitemService.get(emitem_id);
        EMITEMDTO dto = emitemMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "Save", tags = {"EMITEM" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/save")
    public ResponseEntity<Boolean> save(@RequestBody EMITEMDTO emitemdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emitemService.save(emitemMapping.toDomain(emitemdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMITEM" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMITEMDTO> emitemdtos) {
        emitemService.saveBatch(emitemMapping.toDomain(emitemdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMITEM" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emitems/getdraft")
    public ResponseEntity<EMITEMDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emitemMapping.toDto(emitemService.getDraft(new EMITEM())));
    }




    @PreAuthorize("hasPermission(#emitem_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMITEM" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emitems/{emitem_id}")
    @Transactional
    public ResponseEntity<EMITEMDTO> update(@PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMDTO emitemdto) {
		EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setEmitemid(emitem_id);
		emitemService.update(domain);
		EMITEMDTO dto = emitemMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emitem_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMITEM" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emitems/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMITEMDTO> emitemdtos) {
        emitemService.updateBatch(emitemMapping.toDomain(emitemdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMITEM" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems")
    @Transactional
    public ResponseEntity<EMITEMDTO> create(@RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
		emitemService.create(domain);
        EMITEMDTO dto = emitemMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMITEM" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMITEMDTO> emitemdtos) {
        emitemService.createBatch(emitemMapping.toDomain(emitemdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMITEM" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMITEMDTO emitemdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemService.checkKey(emitemMapping.toDomain(emitemdto)));
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMITEM" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emitems/fetchdefault")
	public ResponseEntity<List<EMITEMDTO>> fetchDefault(EMITEMSearchContext context) {
        Page<EMITEM> domains = emitemService.searchDefault(context) ;
        List<EMITEMDTO> list = emitemMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMITEM" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emitems/searchdefault")
	public ResponseEntity<Page<EMITEMDTO>> searchDefault(EMITEMSearchContext context) {
        Page<EMITEM> domains = emitemService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "RemoveByEMSERVICE", tags = {"EMITEM" },  notes = "RemoveByEMSERVICE")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emitems/{emitem_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemService.remove(emitem_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSERVICE", tags = {"EMITEM" },  notes = "RemoveBatchByEMSERVICE")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emitems/batch")
    public ResponseEntity<Boolean> removeBatchByEMSERVICE(@RequestBody List<String> ids) {
        emitemService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSERVICE", tags = {"EMITEM" },  notes = "GetByEMSERVICE")
	@RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emitems/{emitem_id}")
    public ResponseEntity<EMITEMDTO> getByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEM domain = emitemService.get(emitem_id);
        EMITEMDTO dto = emitemMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMSERVICE", tags = {"EMITEM" },  notes = "SaveByEMSERVICE")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/save")
    public ResponseEntity<Boolean> saveByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setMserviceid(emservice_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSERVICE", tags = {"EMITEM" },  notes = "SaveBatchByEMSERVICE")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
             domain.setMserviceid(emservice_id);
        }
        emitemService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSERVICE", tags = {"EMITEM" },  notes = "GetDraftByEMSERVICE")
    @RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emitems/getdraft")
    public ResponseEntity<EMITEMDTO> getDraftByEMSERVICE(@PathVariable("emservice_id") String emservice_id) {
        EMITEM domain = new EMITEM();
        domain.setMserviceid(emservice_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemMapping.toDto(emitemService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMSERVICE", tags = {"EMITEM" },  notes = "UpdateByEMSERVICE")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emitems/{emitem_id}")
    @Transactional
    public ResponseEntity<EMITEMDTO> updateByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setMserviceid(emservice_id);
        domain.setEmitemid(emitem_id);
		emitemService.update(domain);
        EMITEMDTO dto = emitemMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSERVICE", tags = {"EMITEM" },  notes = "UpdateBatchByEMSERVICE")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emitems/batch")
    public ResponseEntity<Boolean> updateBatchByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
            domain.setMserviceid(emservice_id);
        }
        emitemService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMSERVICE", tags = {"EMITEM" },  notes = "CreateByEMSERVICE")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems")
    @Transactional
    public ResponseEntity<EMITEMDTO> createByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setMserviceid(emservice_id);
		emitemService.create(domain);
        EMITEMDTO dto = emitemMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSERVICE", tags = {"EMITEM" },  notes = "createBatchByEMSERVICE")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/batch")
    public ResponseEntity<Boolean> createBatchByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
            domain.setMserviceid(emservice_id);
        }
        emitemService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMSERVICE", tags = {"EMITEM" },  notes = "CheckKeyByEMSERVICE")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody EMITEMDTO emitemdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemService.checkKey(emitemMapping.toDomain(emitemdto)));
    }

	@ApiOperation(value = "fetchDEFAULTByEMSERVICE", tags = {"EMITEM" } ,notes = "fetchDEFAULTByEMSERVICE")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emitems/fetchdefault")
	public ResponseEntity<List<EMITEMDTO>> fetchEMITEMDefaultByEMSERVICE(@PathVariable("emservice_id") String emservice_id,EMITEMSearchContext context) {
        context.setN_mserviceid_eq(emservice_id);
        Page<EMITEM> domains = emitemService.searchDefault(context) ;
        List<EMITEMDTO> list = emitemMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSERVICE", tags = {"EMITEM" } ,notes = "searchDEFAULTByEMSERVICE")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emitems/searchdefault")
	public ResponseEntity<Page<EMITEMDTO>> searchEMITEMDefaultByEMSERVICE(@PathVariable("emservice_id") String emservice_id,EMITEMSearchContext context) {
        context.setN_mserviceid_eq(emservice_id);
        Page<EMITEM> domains = emitemService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "RemoveByEMSTOREPART", tags = {"EMITEM" },  notes = "RemoveByEMSTOREPART")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSTOREPART(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemService.remove(emitem_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSTOREPART", tags = {"EMITEM" },  notes = "RemoveBatchByEMSTOREPART")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstoreparts/{emstorepart_id}/emitems/batch")
    public ResponseEntity<Boolean> removeBatchByEMSTOREPART(@RequestBody List<String> ids) {
        emitemService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSTOREPART", tags = {"EMITEM" },  notes = "GetByEMSTOREPART")
	@RequestMapping(method = RequestMethod.GET, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}")
    public ResponseEntity<EMITEMDTO> getByEMSTOREPART(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEM domain = emitemService.get(emitem_id);
        EMITEMDTO dto = emitemMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMSTOREPART", tags = {"EMITEM" },  notes = "SaveByEMSTOREPART")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/save")
    public ResponseEntity<Boolean> saveByEMSTOREPART(@PathVariable("emstorepart_id") String emstorepart_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setStorepartid(emstorepart_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSTOREPART", tags = {"EMITEM" },  notes = "SaveBatchByEMSTOREPART")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSTOREPART(@PathVariable("emstorepart_id") String emstorepart_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
             domain.setStorepartid(emstorepart_id);
        }
        emitemService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSTOREPART", tags = {"EMITEM" },  notes = "GetDraftByEMSTOREPART")
    @RequestMapping(method = RequestMethod.GET, value = "/emstoreparts/{emstorepart_id}/emitems/getdraft")
    public ResponseEntity<EMITEMDTO> getDraftByEMSTOREPART(@PathVariable("emstorepart_id") String emstorepart_id) {
        EMITEM domain = new EMITEM();
        domain.setStorepartid(emstorepart_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemMapping.toDto(emitemService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMSTOREPART", tags = {"EMITEM" },  notes = "UpdateByEMSTOREPART")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}")
    @Transactional
    public ResponseEntity<EMITEMDTO> updateByEMSTOREPART(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setStorepartid(emstorepart_id);
        domain.setEmitemid(emitem_id);
		emitemService.update(domain);
        EMITEMDTO dto = emitemMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSTOREPART", tags = {"EMITEM" },  notes = "UpdateBatchByEMSTOREPART")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstoreparts/{emstorepart_id}/emitems/batch")
    public ResponseEntity<Boolean> updateBatchByEMSTOREPART(@PathVariable("emstorepart_id") String emstorepart_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
            domain.setStorepartid(emstorepart_id);
        }
        emitemService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMSTOREPART", tags = {"EMITEM" },  notes = "CreateByEMSTOREPART")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems")
    @Transactional
    public ResponseEntity<EMITEMDTO> createByEMSTOREPART(@PathVariable("emstorepart_id") String emstorepart_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setStorepartid(emstorepart_id);
		emitemService.create(domain);
        EMITEMDTO dto = emitemMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSTOREPART", tags = {"EMITEM" },  notes = "createBatchByEMSTOREPART")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/batch")
    public ResponseEntity<Boolean> createBatchByEMSTOREPART(@PathVariable("emstorepart_id") String emstorepart_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
            domain.setStorepartid(emstorepart_id);
        }
        emitemService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMSTOREPART", tags = {"EMITEM" },  notes = "CheckKeyByEMSTOREPART")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSTOREPART(@PathVariable("emstorepart_id") String emstorepart_id, @RequestBody EMITEMDTO emitemdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemService.checkKey(emitemMapping.toDomain(emitemdto)));
    }

	@ApiOperation(value = "fetchDEFAULTByEMSTOREPART", tags = {"EMITEM" } ,notes = "fetchDEFAULTByEMSTOREPART")
    @RequestMapping(method= RequestMethod.GET , value="/emstoreparts/{emstorepart_id}/emitems/fetchdefault")
	public ResponseEntity<List<EMITEMDTO>> fetchEMITEMDefaultByEMSTOREPART(@PathVariable("emstorepart_id") String emstorepart_id,EMITEMSearchContext context) {
        context.setN_storepartid_eq(emstorepart_id);
        Page<EMITEM> domains = emitemService.searchDefault(context) ;
        List<EMITEMDTO> list = emitemMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSTOREPART", tags = {"EMITEM" } ,notes = "searchDEFAULTByEMSTOREPART")
    @RequestMapping(method= RequestMethod.GET , value="/emstoreparts/{emstorepart_id}/emitems/searchdefault")
	public ResponseEntity<Page<EMITEMDTO>> searchEMITEMDefaultByEMSTOREPART(@PathVariable("emstorepart_id") String emstorepart_id,EMITEMSearchContext context) {
        context.setN_storepartid_eq(emstorepart_id);
        Page<EMITEM> domains = emitemService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "RemoveByEMSTORE", tags = {"EMITEM" },  notes = "RemoveByEMSTORE")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emitems/{emitem_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSTORE(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemService.remove(emitem_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSTORE", tags = {"EMITEM" },  notes = "RemoveBatchByEMSTORE")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emitems/batch")
    public ResponseEntity<Boolean> removeBatchByEMSTORE(@RequestBody List<String> ids) {
        emitemService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSTORE", tags = {"EMITEM" },  notes = "GetByEMSTORE")
	@RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emitems/{emitem_id}")
    public ResponseEntity<EMITEMDTO> getByEMSTORE(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEM domain = emitemService.get(emitem_id);
        EMITEMDTO dto = emitemMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMSTORE", tags = {"EMITEM" },  notes = "SaveByEMSTORE")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/save")
    public ResponseEntity<Boolean> saveByEMSTORE(@PathVariable("emstore_id") String emstore_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setStoreid(emstore_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSTORE", tags = {"EMITEM" },  notes = "SaveBatchByEMSTORE")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSTORE(@PathVariable("emstore_id") String emstore_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
             domain.setStoreid(emstore_id);
        }
        emitemService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSTORE", tags = {"EMITEM" },  notes = "GetDraftByEMSTORE")
    @RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emitems/getdraft")
    public ResponseEntity<EMITEMDTO> getDraftByEMSTORE(@PathVariable("emstore_id") String emstore_id) {
        EMITEM domain = new EMITEM();
        domain.setStoreid(emstore_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemMapping.toDto(emitemService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMSTORE", tags = {"EMITEM" },  notes = "UpdateByEMSTORE")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emitems/{emitem_id}")
    @Transactional
    public ResponseEntity<EMITEMDTO> updateByEMSTORE(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setStoreid(emstore_id);
        domain.setEmitemid(emitem_id);
		emitemService.update(domain);
        EMITEMDTO dto = emitemMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSTORE", tags = {"EMITEM" },  notes = "UpdateBatchByEMSTORE")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emitems/batch")
    public ResponseEntity<Boolean> updateBatchByEMSTORE(@PathVariable("emstore_id") String emstore_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
            domain.setStoreid(emstore_id);
        }
        emitemService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMSTORE", tags = {"EMITEM" },  notes = "CreateByEMSTORE")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems")
    @Transactional
    public ResponseEntity<EMITEMDTO> createByEMSTORE(@PathVariable("emstore_id") String emstore_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setStoreid(emstore_id);
		emitemService.create(domain);
        EMITEMDTO dto = emitemMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSTORE", tags = {"EMITEM" },  notes = "createBatchByEMSTORE")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/batch")
    public ResponseEntity<Boolean> createBatchByEMSTORE(@PathVariable("emstore_id") String emstore_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
            domain.setStoreid(emstore_id);
        }
        emitemService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMSTORE", tags = {"EMITEM" },  notes = "CheckKeyByEMSTORE")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSTORE(@PathVariable("emstore_id") String emstore_id, @RequestBody EMITEMDTO emitemdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemService.checkKey(emitemMapping.toDomain(emitemdto)));
    }

	@ApiOperation(value = "fetchDEFAULTByEMSTORE", tags = {"EMITEM" } ,notes = "fetchDEFAULTByEMSTORE")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emitems/fetchdefault")
	public ResponseEntity<List<EMITEMDTO>> fetchEMITEMDefaultByEMSTORE(@PathVariable("emstore_id") String emstore_id,EMITEMSearchContext context) {
        context.setN_storeid_eq(emstore_id);
        Page<EMITEM> domains = emitemService.searchDefault(context) ;
        List<EMITEMDTO> list = emitemMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSTORE", tags = {"EMITEM" } ,notes = "searchDEFAULTByEMSTORE")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emitems/searchdefault")
	public ResponseEntity<Page<EMITEMDTO>> searchEMITEMDefaultByEMSTORE(@PathVariable("emstore_id") String emstore_id,EMITEMSearchContext context) {
        context.setN_storeid_eq(emstore_id);
        Page<EMITEM> domains = emitemService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "RemoveByPFEMP", tags = {"EMITEM" },  notes = "RemoveByPFEMP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemService.remove(emitem_id));
    }

    @ApiOperation(value = "RemoveBatchByPFEMP", tags = {"EMITEM" },  notes = "RemoveBatchByPFEMP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emitems/batch")
    public ResponseEntity<Boolean> removeBatchByPFEMP(@RequestBody List<String> ids) {
        emitemService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFEMP", tags = {"EMITEM" },  notes = "GetByPFEMP")
	@RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}")
    public ResponseEntity<EMITEMDTO> getByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEM domain = emitemService.get(emitem_id);
        EMITEMDTO dto = emitemMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByPFEMP", tags = {"EMITEM" },  notes = "SaveByPFEMP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/save")
    public ResponseEntity<Boolean> saveByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setSempid(pfemp_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFEMP", tags = {"EMITEM" },  notes = "SaveBatchByPFEMP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
             domain.setSempid(pfemp_id);
        }
        emitemService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFEMP", tags = {"EMITEM" },  notes = "GetDraftByPFEMP")
    @RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emitems/getdraft")
    public ResponseEntity<EMITEMDTO> getDraftByPFEMP(@PathVariable("pfemp_id") String pfemp_id) {
        EMITEM domain = new EMITEM();
        domain.setSempid(pfemp_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemMapping.toDto(emitemService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByPFEMP", tags = {"EMITEM" },  notes = "UpdateByPFEMP")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}")
    @Transactional
    public ResponseEntity<EMITEMDTO> updateByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setSempid(pfemp_id);
        domain.setEmitemid(emitem_id);
		emitemService.update(domain);
        EMITEMDTO dto = emitemMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFEMP", tags = {"EMITEM" },  notes = "UpdateBatchByPFEMP")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emitems/batch")
    public ResponseEntity<Boolean> updateBatchByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
            domain.setSempid(pfemp_id);
        }
        emitemService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByPFEMP", tags = {"EMITEM" },  notes = "CreateByPFEMP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems")
    @Transactional
    public ResponseEntity<EMITEMDTO> createByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setSempid(pfemp_id);
		emitemService.create(domain);
        EMITEMDTO dto = emitemMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFEMP", tags = {"EMITEM" },  notes = "createBatchByPFEMP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/batch")
    public ResponseEntity<Boolean> createBatchByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
            domain.setSempid(pfemp_id);
        }
        emitemService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFEMP", tags = {"EMITEM" },  notes = "CheckKeyByPFEMP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody EMITEMDTO emitemdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemService.checkKey(emitemMapping.toDomain(emitemdto)));
    }

	@ApiOperation(value = "fetchDEFAULTByPFEMP", tags = {"EMITEM" } ,notes = "fetchDEFAULTByPFEMP")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emitems/fetchdefault")
	public ResponseEntity<List<EMITEMDTO>> fetchEMITEMDefaultByPFEMP(@PathVariable("pfemp_id") String pfemp_id,EMITEMSearchContext context) {
        context.setN_sempid_eq(pfemp_id);
        Page<EMITEM> domains = emitemService.searchDefault(context) ;
        List<EMITEMDTO> list = emitemMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFEMP", tags = {"EMITEM" } ,notes = "searchDEFAULTByPFEMP")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emitems/searchdefault")
	public ResponseEntity<Page<EMITEMDTO>> searchEMITEMDefaultByPFEMP(@PathVariable("pfemp_id") String pfemp_id,EMITEMSearchContext context) {
        context.setN_sempid_eq(pfemp_id);
        Page<EMITEM> domains = emitemService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "RemoveByPFUNIT", tags = {"EMITEM" },  notes = "RemoveByPFUNIT")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFUNIT(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemService.remove(emitem_id));
    }

    @ApiOperation(value = "RemoveBatchByPFUNIT", tags = {"EMITEM" },  notes = "RemoveBatchByPFUNIT")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfunits/{pfunit_id}/emitems/batch")
    public ResponseEntity<Boolean> removeBatchByPFUNIT(@RequestBody List<String> ids) {
        emitemService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFUNIT", tags = {"EMITEM" },  notes = "GetByPFUNIT")
	@RequestMapping(method = RequestMethod.GET, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}")
    public ResponseEntity<EMITEMDTO> getByPFUNIT(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEM domain = emitemService.get(emitem_id);
        EMITEMDTO dto = emitemMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByPFUNIT", tags = {"EMITEM" },  notes = "SaveByPFUNIT")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/save")
    public ResponseEntity<Boolean> saveByPFUNIT(@PathVariable("pfunit_id") String pfunit_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setUnitid(pfunit_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFUNIT", tags = {"EMITEM" },  notes = "SaveBatchByPFUNIT")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFUNIT(@PathVariable("pfunit_id") String pfunit_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
             domain.setUnitid(pfunit_id);
        }
        emitemService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFUNIT", tags = {"EMITEM" },  notes = "GetDraftByPFUNIT")
    @RequestMapping(method = RequestMethod.GET, value = "/pfunits/{pfunit_id}/emitems/getdraft")
    public ResponseEntity<EMITEMDTO> getDraftByPFUNIT(@PathVariable("pfunit_id") String pfunit_id) {
        EMITEM domain = new EMITEM();
        domain.setUnitid(pfunit_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemMapping.toDto(emitemService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByPFUNIT", tags = {"EMITEM" },  notes = "UpdateByPFUNIT")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}")
    @Transactional
    public ResponseEntity<EMITEMDTO> updateByPFUNIT(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setUnitid(pfunit_id);
        domain.setEmitemid(emitem_id);
		emitemService.update(domain);
        EMITEMDTO dto = emitemMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFUNIT", tags = {"EMITEM" },  notes = "UpdateBatchByPFUNIT")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfunits/{pfunit_id}/emitems/batch")
    public ResponseEntity<Boolean> updateBatchByPFUNIT(@PathVariable("pfunit_id") String pfunit_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
            domain.setUnitid(pfunit_id);
        }
        emitemService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByPFUNIT", tags = {"EMITEM" },  notes = "CreateByPFUNIT")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems")
    @Transactional
    public ResponseEntity<EMITEMDTO> createByPFUNIT(@PathVariable("pfunit_id") String pfunit_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setUnitid(pfunit_id);
		emitemService.create(domain);
        EMITEMDTO dto = emitemMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFUNIT", tags = {"EMITEM" },  notes = "createBatchByPFUNIT")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/batch")
    public ResponseEntity<Boolean> createBatchByPFUNIT(@PathVariable("pfunit_id") String pfunit_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
            domain.setUnitid(pfunit_id);
        }
        emitemService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFUNIT", tags = {"EMITEM" },  notes = "CheckKeyByPFUNIT")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFUNIT(@PathVariable("pfunit_id") String pfunit_id, @RequestBody EMITEMDTO emitemdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemService.checkKey(emitemMapping.toDomain(emitemdto)));
    }

	@ApiOperation(value = "fetchDEFAULTByPFUNIT", tags = {"EMITEM" } ,notes = "fetchDEFAULTByPFUNIT")
    @RequestMapping(method= RequestMethod.GET , value="/pfunits/{pfunit_id}/emitems/fetchdefault")
	public ResponseEntity<List<EMITEMDTO>> fetchEMITEMDefaultByPFUNIT(@PathVariable("pfunit_id") String pfunit_id,EMITEMSearchContext context) {
        context.setN_unitid_eq(pfunit_id);
        Page<EMITEM> domains = emitemService.searchDefault(context) ;
        List<EMITEMDTO> list = emitemMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFUNIT", tags = {"EMITEM" } ,notes = "searchDEFAULTByPFUNIT")
    @RequestMapping(method= RequestMethod.GET , value="/pfunits/{pfunit_id}/emitems/searchdefault")
	public ResponseEntity<Page<EMITEMDTO>> searchEMITEMDefaultByPFUNIT(@PathVariable("pfunit_id") String pfunit_id,EMITEMSearchContext context) {
        context.setN_unitid_eq(pfunit_id);
        Page<EMITEM> domains = emitemService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "RemoveByEMSTOREEMSTOREPART", tags = {"EMITEM" },  notes = "RemoveByEMSTOREEMSTOREPART")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSTOREEMSTOREPART(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emitemService.remove(emitem_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSTOREEMSTOREPART", tags = {"EMITEM" },  notes = "RemoveBatchByEMSTOREEMSTOREPART")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/batch")
    public ResponseEntity<Boolean> removeBatchByEMSTOREEMSTOREPART(@RequestBody List<String> ids) {
        emitemService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSTOREEMSTOREPART", tags = {"EMITEM" },  notes = "GetByEMSTOREEMSTOREPART")
	@RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}")
    public ResponseEntity<EMITEMDTO> getByEMSTOREEMSTOREPART(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id) {
        EMITEM domain = emitemService.get(emitem_id);
        EMITEMDTO dto = emitemMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMSTOREEMSTOREPART", tags = {"EMITEM" },  notes = "SaveByEMSTOREEMSTOREPART")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/save")
    public ResponseEntity<Boolean> saveByEMSTOREEMSTOREPART(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setStorepartid(emstorepart_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSTOREEMSTOREPART", tags = {"EMITEM" },  notes = "SaveBatchByEMSTOREEMSTOREPART")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSTOREEMSTOREPART(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
             domain.setStorepartid(emstorepart_id);
        }
        emitemService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSTOREEMSTOREPART", tags = {"EMITEM" },  notes = "GetDraftByEMSTOREEMSTOREPART")
    @RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/getdraft")
    public ResponseEntity<EMITEMDTO> getDraftByEMSTOREEMSTOREPART(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id) {
        EMITEM domain = new EMITEM();
        domain.setStorepartid(emstorepart_id);
        return ResponseEntity.status(HttpStatus.OK).body(emitemMapping.toDto(emitemService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMSTOREEMSTOREPART", tags = {"EMITEM" },  notes = "UpdateByEMSTOREEMSTOREPART")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}")
    @Transactional
    public ResponseEntity<EMITEMDTO> updateByEMSTOREEMSTOREPART(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setStorepartid(emstorepart_id);
        domain.setEmitemid(emitem_id);
		emitemService.update(domain);
        EMITEMDTO dto = emitemMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSTOREEMSTOREPART", tags = {"EMITEM" },  notes = "UpdateBatchByEMSTOREEMSTOREPART")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/batch")
    public ResponseEntity<Boolean> updateBatchByEMSTOREEMSTOREPART(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
            domain.setStorepartid(emstorepart_id);
        }
        emitemService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMSTOREEMSTOREPART", tags = {"EMITEM" },  notes = "CreateByEMSTOREEMSTOREPART")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems")
    @Transactional
    public ResponseEntity<EMITEMDTO> createByEMSTOREEMSTOREPART(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @RequestBody EMITEMDTO emitemdto) {
        EMITEM domain = emitemMapping.toDomain(emitemdto);
        domain.setStorepartid(emstorepart_id);
		emitemService.create(domain);
        EMITEMDTO dto = emitemMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSTOREEMSTOREPART", tags = {"EMITEM" },  notes = "createBatchByEMSTOREEMSTOREPART")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/batch")
    public ResponseEntity<Boolean> createBatchByEMSTOREEMSTOREPART(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @RequestBody List<EMITEMDTO> emitemdtos) {
        List<EMITEM> domainlist=emitemMapping.toDomain(emitemdtos);
        for(EMITEM domain:domainlist){
            domain.setStorepartid(emstorepart_id);
        }
        emitemService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMSTOREEMSTOREPART", tags = {"EMITEM" },  notes = "CheckKeyByEMSTOREEMSTOREPART")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSTOREEMSTOREPART(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @RequestBody EMITEMDTO emitemdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emitemService.checkKey(emitemMapping.toDomain(emitemdto)));
    }

	@ApiOperation(value = "fetchDEFAULTByEMSTOREEMSTOREPART", tags = {"EMITEM" } ,notes = "fetchDEFAULTByEMSTOREEMSTOREPART")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/fetchdefault")
	public ResponseEntity<List<EMITEMDTO>> fetchEMITEMDefaultByEMSTOREEMSTOREPART(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id,EMITEMSearchContext context) {
        context.setN_storepartid_eq(emstorepart_id);
        Page<EMITEM> domains = emitemService.searchDefault(context) ;
        List<EMITEMDTO> list = emitemMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSTOREEMSTOREPART", tags = {"EMITEM" } ,notes = "searchDEFAULTByEMSTOREEMSTOREPART")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/searchdefault")
	public ResponseEntity<Page<EMITEMDTO>> searchEMITEMDefaultByEMSTOREEMSTOREPART(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id,EMITEMSearchContext context) {
        context.setN_storepartid_eq(emstorepart_id);
        Page<EMITEM> domains = emitemService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emitemMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMITEM getEntity(){
        return new EMITEM();
    }

}
