package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMMACHMODEL;
import cn.ibizlab.eam.core.eam_core.service.IEMMACHMODELService;
import cn.ibizlab.eam.core.eam_core.filter.EMMACHMODELSearchContext;




@Slf4j
@Api(tags = {"EMMACHMODEL" })
@RestController("WebApi-emmachmodel")
@RequestMapping("")
public class EMMACHMODELResource {

    @Autowired
    private IEMMACHMODELService emmachmodelService;

    @Autowired
    @Lazy
    private EMMACHMODELMapping emmachmodelMapping;




    @ApiOperation(value = "GetDraft", tags = {"EMMACHMODEL" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emmachmodels/getdraft")
    public ResponseEntity<EMMACHMODELDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emmachmodelMapping.toDto(emmachmodelService.getDraft(new EMMACHMODEL())));
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMMACHMODEL" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emmachmodels")
    @Transactional
    public ResponseEntity<EMMACHMODELDTO> create(@RequestBody EMMACHMODELDTO emmachmodeldto) {
        EMMACHMODEL domain = emmachmodelMapping.toDomain(emmachmodeldto);
		emmachmodelService.create(domain);
        EMMACHMODELDTO dto = emmachmodelMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMMACHMODEL" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emmachmodels/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMMACHMODELDTO> emmachmodeldtos) {
        emmachmodelService.createBatch(emmachmodelMapping.toDomain(emmachmodeldtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emmachmodel_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMMACHMODEL" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emmachmodels/{emmachmodel_id}")
    public ResponseEntity<EMMACHMODELDTO> get(@PathVariable("emmachmodel_id") String emmachmodel_id) {
        EMMACHMODEL domain = emmachmodelService.get(emmachmodel_id);
        EMMACHMODELDTO dto = emmachmodelMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @PreAuthorize("hasPermission(#emmachmodel_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMMACHMODEL" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emmachmodels/{emmachmodel_id}")
    @Transactional
    public ResponseEntity<EMMACHMODELDTO> update(@PathVariable("emmachmodel_id") String emmachmodel_id, @RequestBody EMMACHMODELDTO emmachmodeldto) {
		EMMACHMODEL domain = emmachmodelMapping.toDomain(emmachmodeldto);
        domain.setEmmachmodelid(emmachmodel_id);
		emmachmodelService.update(domain);
		EMMACHMODELDTO dto = emmachmodelMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emmachmodel_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMMACHMODEL" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emmachmodels/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMMACHMODELDTO> emmachmodeldtos) {
        emmachmodelService.updateBatch(emmachmodelMapping.toDomain(emmachmodeldtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"EMMACHMODEL" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emmachmodels/save")
    public ResponseEntity<Boolean> save(@RequestBody EMMACHMODELDTO emmachmodeldto) {
        return ResponseEntity.status(HttpStatus.OK).body(emmachmodelService.save(emmachmodelMapping.toDomain(emmachmodeldto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMMACHMODEL" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emmachmodels/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMMACHMODELDTO> emmachmodeldtos) {
        emmachmodelService.saveBatch(emmachmodelMapping.toDomain(emmachmodeldtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMMACHMODEL" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emmachmodels/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMMACHMODELDTO emmachmodeldto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emmachmodelService.checkKey(emmachmodelMapping.toDomain(emmachmodeldto)));
    }




    @PreAuthorize("hasPermission('Remove',{#emmachmodel_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMMACHMODEL" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emmachmodels/{emmachmodel_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emmachmodel_id") String emmachmodel_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emmachmodelService.remove(emmachmodel_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMMACHMODEL" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emmachmodels/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emmachmodelService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMMACHMODEL" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emmachmodels/fetchdefault")
	public ResponseEntity<List<EMMACHMODELDTO>> fetchDefault(EMMACHMODELSearchContext context) {
        Page<EMMACHMODEL> domains = emmachmodelService.searchDefault(context) ;
        List<EMMACHMODELDTO> list = emmachmodelMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMMACHMODEL" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emmachmodels/searchdefault")
	public ResponseEntity<Page<EMMACHMODELDTO>> searchDefault(EMMACHMODELSearchContext context) {
        Page<EMMACHMODEL> domains = emmachmodelService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emmachmodelMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMMACHMODEL getEntity(){
        return new EMMACHMODEL();
    }

}
