package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMMONTHLY;
import cn.ibizlab.eam.core.eam_core.service.IEMMONTHLYService;
import cn.ibizlab.eam.core.eam_core.filter.EMMONTHLYSearchContext;




@Slf4j
@Api(tags = {"EMMONTHLY" })
@RestController("WebApi-emmonthly")
@RequestMapping("")
public class EMMONTHLYResource {

    @Autowired
    private IEMMONTHLYService emmonthlyService;

    @Autowired
    @Lazy
    private EMMONTHLYMapping emmonthlyMapping;




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMMONTHLY" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emmonthlies")
    @Transactional
    public ResponseEntity<EMMONTHLYDTO> create(@RequestBody EMMONTHLYDTO emmonthlydto) {
        EMMONTHLY domain = emmonthlyMapping.toDomain(emmonthlydto);
		emmonthlyService.create(domain);
        EMMONTHLYDTO dto = emmonthlyMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMMONTHLY" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emmonthlies/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMMONTHLYDTO> emmonthlydtos) {
        emmonthlyService.createBatch(emmonthlyMapping.toDomain(emmonthlydtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"EMMONTHLY" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emmonthlies/save")
    public ResponseEntity<Boolean> save(@RequestBody EMMONTHLYDTO emmonthlydto) {
        return ResponseEntity.status(HttpStatus.OK).body(emmonthlyService.save(emmonthlyMapping.toDomain(emmonthlydto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMMONTHLY" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emmonthlies/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMMONTHLYDTO> emmonthlydtos) {
        emmonthlyService.saveBatch(emmonthlyMapping.toDomain(emmonthlydtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMMONTHLY" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emmonthlies/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMMONTHLYDTO emmonthlydto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emmonthlyService.checkKey(emmonthlyMapping.toDomain(emmonthlydto)));
    }




    @PreAuthorize("hasPermission(#emmonthly_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMMONTHLY" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emmonthlies/{emmonthly_id}")
    public ResponseEntity<EMMONTHLYDTO> get(@PathVariable("emmonthly_id") String emmonthly_id) {
        EMMONTHLY domain = emmonthlyService.get(emmonthly_id);
        EMMONTHLYDTO dto = emmonthlyMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @PreAuthorize("hasPermission('Remove',{#emmonthly_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMMONTHLY" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emmonthlies/{emmonthly_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emmonthly_id") String emmonthly_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emmonthlyService.remove(emmonthly_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMMONTHLY" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emmonthlies/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emmonthlyService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emmonthly_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMMONTHLY" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emmonthlies/{emmonthly_id}")
    @Transactional
    public ResponseEntity<EMMONTHLYDTO> update(@PathVariable("emmonthly_id") String emmonthly_id, @RequestBody EMMONTHLYDTO emmonthlydto) {
		EMMONTHLY domain = emmonthlyMapping.toDomain(emmonthlydto);
        domain.setEmmonthlyid(emmonthly_id);
		emmonthlyService.update(domain);
		EMMONTHLYDTO dto = emmonthlyMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emmonthly_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMMONTHLY" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emmonthlies/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMMONTHLYDTO> emmonthlydtos) {
        emmonthlyService.updateBatch(emmonthlyMapping.toDomain(emmonthlydtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMMONTHLY" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emmonthlies/getdraft")
    public ResponseEntity<EMMONTHLYDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emmonthlyMapping.toDto(emmonthlyService.getDraft(new EMMONTHLY())));
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMMONTHLY" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emmonthlies/fetchdefault")
	public ResponseEntity<List<EMMONTHLYDTO>> fetchDefault(EMMONTHLYSearchContext context) {
        Page<EMMONTHLY> domains = emmonthlyService.searchDefault(context) ;
        List<EMMONTHLYDTO> list = emmonthlyMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMMONTHLY" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emmonthlies/searchdefault")
	public ResponseEntity<Page<EMMONTHLYDTO>> searchDefault(EMMONTHLYSearchContext context) {
        Page<EMMONTHLY> domains = emmonthlyService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emmonthlyMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMMONTHLY getEntity(){
        return new EMMONTHLY();
    }

}
