package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMOBJECT;
import cn.ibizlab.eam.core.eam_core.service.IEMOBJECTService;
import cn.ibizlab.eam.core.eam_core.filter.EMOBJECTSearchContext;




@Slf4j
@Api(tags = {"EMOBJECT" })
@RestController("WebApi-emobject")
@RequestMapping("")
public class EMOBJECTResource {

    @Autowired
    private IEMOBJECTService emobjectService;

    @Autowired
    @Lazy
    private EMOBJECTMapping emobjectMapping;




    @ApiOperation(value = "Save", tags = {"EMOBJECT" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emobjects/save")
    public ResponseEntity<Boolean> save(@RequestBody EMOBJECTDTO emobjectdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emobjectService.save(emobjectMapping.toDomain(emobjectdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMOBJECT" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emobjects/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMOBJECTDTO> emobjectdtos) {
        emobjectService.saveBatch(emobjectMapping.toDomain(emobjectdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMOBJECT" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emobjects/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMOBJECTDTO emobjectdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emobjectService.checkKey(emobjectMapping.toDomain(emobjectdto)));
    }




    @PreAuthorize("hasPermission(#emobject_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMOBJECT" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emobjects/{emobject_id}")
    public ResponseEntity<EMOBJECTDTO> get(@PathVariable("emobject_id") String emobject_id) {
        EMOBJECT domain = emobjectService.get(emobject_id);
        EMOBJECTDTO dto = emobjectMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMOBJECT" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emobjects/getdraft")
    public ResponseEntity<EMOBJECTDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emobjectMapping.toDto(emobjectService.getDraft(new EMOBJECT())));
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMOBJECT" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emobjects")
    @Transactional
    public ResponseEntity<EMOBJECTDTO> create(@RequestBody EMOBJECTDTO emobjectdto) {
        EMOBJECT domain = emobjectMapping.toDomain(emobjectdto);
		emobjectService.create(domain);
        EMOBJECTDTO dto = emobjectMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMOBJECT" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emobjects/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMOBJECTDTO> emobjectdtos) {
        emobjectService.createBatch(emobjectMapping.toDomain(emobjectdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emobject_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMOBJECT" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emobjects/{emobject_id}")
    @Transactional
    public ResponseEntity<EMOBJECTDTO> update(@PathVariable("emobject_id") String emobject_id, @RequestBody EMOBJECTDTO emobjectdto) {
		EMOBJECT domain = emobjectMapping.toDomain(emobjectdto);
        domain.setEmobjectid(emobject_id);
		emobjectService.update(domain);
		EMOBJECTDTO dto = emobjectMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emobject_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMOBJECT" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emobjects/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMOBJECTDTO> emobjectdtos) {
        emobjectService.updateBatch(emobjectMapping.toDomain(emobjectdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emobject_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMOBJECT" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emobjects/{emobject_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emobject_id") String emobject_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emobjectService.remove(emobject_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMOBJECT" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emobjects/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emobjectService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMOBJECT" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emobjects/fetchdefault")
	public ResponseEntity<List<EMOBJECTDTO>> fetchDefault(EMOBJECTSearchContext context) {
        Page<EMOBJECT> domains = emobjectService.searchDefault(context) ;
        List<EMOBJECTDTO> list = emobjectMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMOBJECT" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emobjects/searchdefault")
	public ResponseEntity<Page<EMOBJECTDTO>> searchDefault(EMOBJECTSearchContext context) {
        Page<EMOBJECT> domains = emobjectService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emobjectMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasPermission('Get',{#context,'IndexDER',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchIndexDER", tags = {"EMOBJECT" } ,notes = "fetchIndexDER")
    @RequestMapping(method= RequestMethod.GET , value="/emobjects/fetchindexder")
	public ResponseEntity<List<EMOBJECTDTO>> fetchIndexDER(EMOBJECTSearchContext context) {
        Page<EMOBJECT> domains = emobjectService.searchIndexDER(context) ;
        List<EMOBJECTDTO> list = emobjectMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'IndexDER',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchIndexDER", tags = {"EMOBJECT" } ,notes = "searchIndexDER")
    @RequestMapping(method= RequestMethod.GET , value="/emobjects/searchindexder")
	public ResponseEntity<Page<EMOBJECTDTO>> searchIndexDER(EMOBJECTSearchContext context) {
        Page<EMOBJECT> domains = emobjectService.searchIndexDER(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emobjectMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMOBJECT getEntity(){
        return new EMOBJECT();
    }

}
