package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMOUTPUTRCT;
import cn.ibizlab.eam.core.eam_core.service.IEMOUTPUTRCTService;
import cn.ibizlab.eam.core.eam_core.filter.EMOUTPUTRCTSearchContext;




@Slf4j
@Api(tags = {"EMOUTPUTRCT" })
@RestController("WebApi-emoutputrct")
@RequestMapping("")
public class EMOUTPUTRCTResource {

    @Autowired
    private IEMOUTPUTRCTService emoutputrctService;

    @Autowired
    @Lazy
    private EMOUTPUTRCTMapping emoutputrctMapping;




    @PreAuthorize("hasPermission(#emoutputrct_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMOUTPUTRCT" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emoutputrcts/{emoutputrct_id}")
    public ResponseEntity<EMOUTPUTRCTDTO> get(@PathVariable("emoutputrct_id") String emoutputrct_id) {
        EMOUTPUTRCT domain = emoutputrctService.get(emoutputrct_id);
        EMOUTPUTRCTDTO dto = emoutputrctMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMOUTPUTRCT" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emoutputrcts")
    @Transactional
    public ResponseEntity<EMOUTPUTRCTDTO> create(@RequestBody EMOUTPUTRCTDTO emoutputrctdto) {
        EMOUTPUTRCT domain = emoutputrctMapping.toDomain(emoutputrctdto);
		emoutputrctService.create(domain);
        EMOUTPUTRCTDTO dto = emoutputrctMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMOUTPUTRCT" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emoutputrcts/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMOUTPUTRCTDTO> emoutputrctdtos) {
        emoutputrctService.createBatch(emoutputrctMapping.toDomain(emoutputrctdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"EMOUTPUTRCT" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emoutputrcts/save")
    public ResponseEntity<Boolean> save(@RequestBody EMOUTPUTRCTDTO emoutputrctdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emoutputrctService.save(emoutputrctMapping.toDomain(emoutputrctdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMOUTPUTRCT" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emoutputrcts/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMOUTPUTRCTDTO> emoutputrctdtos) {
        emoutputrctService.saveBatch(emoutputrctMapping.toDomain(emoutputrctdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMOUTPUTRCT" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emoutputrcts/getdraft")
    public ResponseEntity<EMOUTPUTRCTDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emoutputrctMapping.toDto(emoutputrctService.getDraft(new EMOUTPUTRCT())));
    }




    @PreAuthorize("hasPermission(#emoutputrct_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMOUTPUTRCT" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emoutputrcts/{emoutputrct_id}")
    @Transactional
    public ResponseEntity<EMOUTPUTRCTDTO> update(@PathVariable("emoutputrct_id") String emoutputrct_id, @RequestBody EMOUTPUTRCTDTO emoutputrctdto) {
		EMOUTPUTRCT domain = emoutputrctMapping.toDomain(emoutputrctdto);
        domain.setEmoutputrctid(emoutputrct_id);
		emoutputrctService.update(domain);
		EMOUTPUTRCTDTO dto = emoutputrctMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emoutputrct_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMOUTPUTRCT" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emoutputrcts/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMOUTPUTRCTDTO> emoutputrctdtos) {
        emoutputrctService.updateBatch(emoutputrctMapping.toDomain(emoutputrctdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emoutputrct_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMOUTPUTRCT" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emoutputrcts/{emoutputrct_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emoutputrct_id") String emoutputrct_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emoutputrctService.remove(emoutputrct_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMOUTPUTRCT" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emoutputrcts/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emoutputrctService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMOUTPUTRCT" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emoutputrcts/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMOUTPUTRCTDTO emoutputrctdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emoutputrctService.checkKey(emoutputrctMapping.toDomain(emoutputrctdto)));
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMOUTPUTRCT" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emoutputrcts/fetchdefault")
	public ResponseEntity<List<EMOUTPUTRCTDTO>> fetchDefault(EMOUTPUTRCTSearchContext context) {
        Page<EMOUTPUTRCT> domains = emoutputrctService.searchDefault(context) ;
        List<EMOUTPUTRCTDTO> list = emoutputrctMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMOUTPUTRCT" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emoutputrcts/searchdefault")
	public ResponseEntity<Page<EMOUTPUTRCTDTO>> searchDefault(EMOUTPUTRCTSearchContext context) {
        Page<EMOUTPUTRCT> domains = emoutputrctService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emoutputrctMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "GetByEMOUTPUT", tags = {"EMOUTPUTRCT" },  notes = "GetByEMOUTPUT")
	@RequestMapping(method = RequestMethod.GET, value = "/emoutputs/{emoutput_id}/emoutputrcts/{emoutputrct_id}")
    public ResponseEntity<EMOUTPUTRCTDTO> getByEMOUTPUT(@PathVariable("emoutput_id") String emoutput_id, @PathVariable("emoutputrct_id") String emoutputrct_id) {
        EMOUTPUTRCT domain = emoutputrctService.get(emoutputrct_id);
        EMOUTPUTRCTDTO dto = emoutputrctMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CreateByEMOUTPUT", tags = {"EMOUTPUTRCT" },  notes = "CreateByEMOUTPUT")
	@RequestMapping(method = RequestMethod.POST, value = "/emoutputs/{emoutput_id}/emoutputrcts")
    @Transactional
    public ResponseEntity<EMOUTPUTRCTDTO> createByEMOUTPUT(@PathVariable("emoutput_id") String emoutput_id, @RequestBody EMOUTPUTRCTDTO emoutputrctdto) {
        EMOUTPUTRCT domain = emoutputrctMapping.toDomain(emoutputrctdto);
        domain.setOutputid(emoutput_id);
		emoutputrctService.create(domain);
        EMOUTPUTRCTDTO dto = emoutputrctMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMOUTPUT", tags = {"EMOUTPUTRCT" },  notes = "createBatchByEMOUTPUT")
	@RequestMapping(method = RequestMethod.POST, value = "/emoutputs/{emoutput_id}/emoutputrcts/batch")
    public ResponseEntity<Boolean> createBatchByEMOUTPUT(@PathVariable("emoutput_id") String emoutput_id, @RequestBody List<EMOUTPUTRCTDTO> emoutputrctdtos) {
        List<EMOUTPUTRCT> domainlist=emoutputrctMapping.toDomain(emoutputrctdtos);
        for(EMOUTPUTRCT domain:domainlist){
            domain.setOutputid(emoutput_id);
        }
        emoutputrctService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByEMOUTPUT", tags = {"EMOUTPUTRCT" },  notes = "SaveByEMOUTPUT")
	@RequestMapping(method = RequestMethod.POST, value = "/emoutputs/{emoutput_id}/emoutputrcts/save")
    public ResponseEntity<Boolean> saveByEMOUTPUT(@PathVariable("emoutput_id") String emoutput_id, @RequestBody EMOUTPUTRCTDTO emoutputrctdto) {
        EMOUTPUTRCT domain = emoutputrctMapping.toDomain(emoutputrctdto);
        domain.setOutputid(emoutput_id);
        return ResponseEntity.status(HttpStatus.OK).body(emoutputrctService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMOUTPUT", tags = {"EMOUTPUTRCT" },  notes = "SaveBatchByEMOUTPUT")
	@RequestMapping(method = RequestMethod.POST, value = "/emoutputs/{emoutput_id}/emoutputrcts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMOUTPUT(@PathVariable("emoutput_id") String emoutput_id, @RequestBody List<EMOUTPUTRCTDTO> emoutputrctdtos) {
        List<EMOUTPUTRCT> domainlist=emoutputrctMapping.toDomain(emoutputrctdtos);
        for(EMOUTPUTRCT domain:domainlist){
             domain.setOutputid(emoutput_id);
        }
        emoutputrctService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMOUTPUT", tags = {"EMOUTPUTRCT" },  notes = "GetDraftByEMOUTPUT")
    @RequestMapping(method = RequestMethod.GET, value = "/emoutputs/{emoutput_id}/emoutputrcts/getdraft")
    public ResponseEntity<EMOUTPUTRCTDTO> getDraftByEMOUTPUT(@PathVariable("emoutput_id") String emoutput_id) {
        EMOUTPUTRCT domain = new EMOUTPUTRCT();
        domain.setOutputid(emoutput_id);
        return ResponseEntity.status(HttpStatus.OK).body(emoutputrctMapping.toDto(emoutputrctService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMOUTPUT", tags = {"EMOUTPUTRCT" },  notes = "UpdateByEMOUTPUT")
	@RequestMapping(method = RequestMethod.PUT, value = "/emoutputs/{emoutput_id}/emoutputrcts/{emoutputrct_id}")
    @Transactional
    public ResponseEntity<EMOUTPUTRCTDTO> updateByEMOUTPUT(@PathVariable("emoutput_id") String emoutput_id, @PathVariable("emoutputrct_id") String emoutputrct_id, @RequestBody EMOUTPUTRCTDTO emoutputrctdto) {
        EMOUTPUTRCT domain = emoutputrctMapping.toDomain(emoutputrctdto);
        domain.setOutputid(emoutput_id);
        domain.setEmoutputrctid(emoutputrct_id);
		emoutputrctService.update(domain);
        EMOUTPUTRCTDTO dto = emoutputrctMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMOUTPUT", tags = {"EMOUTPUTRCT" },  notes = "UpdateBatchByEMOUTPUT")
	@RequestMapping(method = RequestMethod.PUT, value = "/emoutputs/{emoutput_id}/emoutputrcts/batch")
    public ResponseEntity<Boolean> updateBatchByEMOUTPUT(@PathVariable("emoutput_id") String emoutput_id, @RequestBody List<EMOUTPUTRCTDTO> emoutputrctdtos) {
        List<EMOUTPUTRCT> domainlist=emoutputrctMapping.toDomain(emoutputrctdtos);
        for(EMOUTPUTRCT domain:domainlist){
            domain.setOutputid(emoutput_id);
        }
        emoutputrctService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByEMOUTPUT", tags = {"EMOUTPUTRCT" },  notes = "RemoveByEMOUTPUT")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emoutputs/{emoutput_id}/emoutputrcts/{emoutputrct_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMOUTPUT(@PathVariable("emoutput_id") String emoutput_id, @PathVariable("emoutputrct_id") String emoutputrct_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emoutputrctService.remove(emoutputrct_id));
    }

    @ApiOperation(value = "RemoveBatchByEMOUTPUT", tags = {"EMOUTPUTRCT" },  notes = "RemoveBatchByEMOUTPUT")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emoutputs/{emoutput_id}/emoutputrcts/batch")
    public ResponseEntity<Boolean> removeBatchByEMOUTPUT(@RequestBody List<String> ids) {
        emoutputrctService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMOUTPUT", tags = {"EMOUTPUTRCT" },  notes = "CheckKeyByEMOUTPUT")
	@RequestMapping(method = RequestMethod.POST, value = "/emoutputs/{emoutput_id}/emoutputrcts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMOUTPUT(@PathVariable("emoutput_id") String emoutput_id, @RequestBody EMOUTPUTRCTDTO emoutputrctdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emoutputrctService.checkKey(emoutputrctMapping.toDomain(emoutputrctdto)));
    }

	@ApiOperation(value = "fetchDEFAULTByEMOUTPUT", tags = {"EMOUTPUTRCT" } ,notes = "fetchDEFAULTByEMOUTPUT")
    @RequestMapping(method= RequestMethod.GET , value="/emoutputs/{emoutput_id}/emoutputrcts/fetchdefault")
	public ResponseEntity<List<EMOUTPUTRCTDTO>> fetchEMOUTPUTRCTDefaultByEMOUTPUT(@PathVariable("emoutput_id") String emoutput_id,EMOUTPUTRCTSearchContext context) {
        context.setN_outputid_eq(emoutput_id);
        Page<EMOUTPUTRCT> domains = emoutputrctService.searchDefault(context) ;
        List<EMOUTPUTRCTDTO> list = emoutputrctMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMOUTPUT", tags = {"EMOUTPUTRCT" } ,notes = "searchDEFAULTByEMOUTPUT")
    @RequestMapping(method= RequestMethod.GET , value="/emoutputs/{emoutput_id}/emoutputrcts/searchdefault")
	public ResponseEntity<Page<EMOUTPUTRCTDTO>> searchEMOUTPUTRCTDefaultByEMOUTPUT(@PathVariable("emoutput_id") String emoutput_id,EMOUTPUTRCTSearchContext context) {
        context.setN_outputid_eq(emoutput_id);
        Page<EMOUTPUTRCT> domains = emoutputrctService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emoutputrctMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMOUTPUTRCT getEntity(){
        return new EMOUTPUTRCT();
    }

}
