package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMOUTPUT;
import cn.ibizlab.eam.core.eam_core.service.IEMOUTPUTService;
import cn.ibizlab.eam.core.eam_core.filter.EMOUTPUTSearchContext;




@Slf4j
@Api(tags = {"EMOUTPUT" })
@RestController("WebApi-emoutput")
@RequestMapping("")
public class EMOUTPUTResource {

    @Autowired
    private IEMOUTPUTService emoutputService;

    @Autowired
    @Lazy
    private EMOUTPUTMapping emoutputMapping;




    @PreAuthorize("hasPermission('Remove',{#emoutput_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMOUTPUT" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emoutputs/{emoutput_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emoutput_id") String emoutput_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emoutputService.remove(emoutput_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMOUTPUT" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emoutputs/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emoutputService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMOUTPUT" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emoutputs/getdraft")
    public ResponseEntity<EMOUTPUTDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emoutputMapping.toDto(emoutputService.getDraft(new EMOUTPUT())));
    }




    @PreAuthorize("hasPermission(#emoutput_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMOUTPUT" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emoutputs/{emoutput_id}")
    public ResponseEntity<EMOUTPUTDTO> get(@PathVariable("emoutput_id") String emoutput_id) {
        EMOUTPUT domain = emoutputService.get(emoutput_id);
        EMOUTPUTDTO dto = emoutputMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "Save", tags = {"EMOUTPUT" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emoutputs/save")
    public ResponseEntity<Boolean> save(@RequestBody EMOUTPUTDTO emoutputdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emoutputService.save(emoutputMapping.toDomain(emoutputdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMOUTPUT" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emoutputs/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMOUTPUTDTO> emoutputdtos) {
        emoutputService.saveBatch(emoutputMapping.toDomain(emoutputdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMOUTPUT" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emoutputs")
    @Transactional
    public ResponseEntity<EMOUTPUTDTO> create(@RequestBody EMOUTPUTDTO emoutputdto) {
        EMOUTPUT domain = emoutputMapping.toDomain(emoutputdto);
		emoutputService.create(domain);
        EMOUTPUTDTO dto = emoutputMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMOUTPUT" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emoutputs/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMOUTPUTDTO> emoutputdtos) {
        emoutputService.createBatch(emoutputMapping.toDomain(emoutputdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMOUTPUT" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emoutputs/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMOUTPUTDTO emoutputdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emoutputService.checkKey(emoutputMapping.toDomain(emoutputdto)));
    }




    @PreAuthorize("hasPermission(#emoutput_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMOUTPUT" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emoutputs/{emoutput_id}")
    @Transactional
    public ResponseEntity<EMOUTPUTDTO> update(@PathVariable("emoutput_id") String emoutput_id, @RequestBody EMOUTPUTDTO emoutputdto) {
		EMOUTPUT domain = emoutputMapping.toDomain(emoutputdto);
        domain.setEmoutputid(emoutput_id);
		emoutputService.update(domain);
		EMOUTPUTDTO dto = emoutputMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emoutput_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMOUTPUT" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emoutputs/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMOUTPUTDTO> emoutputdtos) {
        emoutputService.updateBatch(emoutputMapping.toDomain(emoutputdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMOUTPUT" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emoutputs/fetchdefault")
	public ResponseEntity<List<EMOUTPUTDTO>> fetchDefault(EMOUTPUTSearchContext context) {
        Page<EMOUTPUT> domains = emoutputService.searchDefault(context) ;
        List<EMOUTPUTDTO> list = emoutputMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMOUTPUT" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emoutputs/searchdefault")
	public ResponseEntity<Page<EMOUTPUTDTO>> searchDefault(EMOUTPUTSearchContext context) {
        Page<EMOUTPUT> domains = emoutputService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emoutputMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMOUTPUT getEntity(){
        return new EMOUTPUT();
    }

}
