package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMPLANCDT;
import cn.ibizlab.eam.core.eam_core.service.IEMPLANCDTService;
import cn.ibizlab.eam.core.eam_core.filter.EMPLANCDTSearchContext;




@Slf4j
@Api(tags = {"EMPLANCDT" })
@RestController("WebApi-emplancdt")
@RequestMapping("")
public class EMPLANCDTResource {

    @Autowired
    private IEMPLANCDTService emplancdtService;

    @Autowired
    @Lazy
    private EMPLANCDTMapping emplancdtMapping;




    @PreAuthorize("hasPermission(#emplancdt_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMPLANCDT" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emplancdts/{emplancdt_id}")
    public ResponseEntity<EMPLANCDTDTO> get(@PathVariable("emplancdt_id") String emplancdt_id) {
        EMPLANCDT domain = emplancdtService.get(emplancdt_id);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "Save", tags = {"EMPLANCDT" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emplancdts/save")
    public ResponseEntity<Boolean> save(@RequestBody EMPLANCDTDTO emplancdtdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.save(emplancdtMapping.toDomain(emplancdtdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMPLANCDT" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emplancdts/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        emplancdtService.saveBatch(emplancdtMapping.toDomain(emplancdtdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMPLANCDT" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emplancdts")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> create(@RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
		emplancdtService.create(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMPLANCDT" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emplancdts/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        emplancdtService.createBatch(emplancdtMapping.toDomain(emplancdtdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMPLANCDT" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emplancdts/getdraft")
    public ResponseEntity<EMPLANCDTDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtMapping.toDto(emplancdtService.getDraft(new EMPLANCDT())));
    }




    @PreAuthorize("hasPermission(#emplancdt_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMPLANCDT" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> update(@PathVariable("emplancdt_id") String emplancdt_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
		EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setEmplancdtid(emplancdt_id);
		emplancdtService.update(domain);
		EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emplancdt_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMPLANCDT" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emplancdts/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        emplancdtService.updateBatch(emplancdtMapping.toDomain(emplancdtdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMPLANCDT" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emplancdts/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMPLANCDTDTO emplancdtdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplancdtService.checkKey(emplancdtMapping.toDomain(emplancdtdto)));
    }




    @PreAuthorize("hasPermission('Remove',{#emplancdt_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMPLANCDT" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emplancdt_id") String emplancdt_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.remove(emplancdt_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMPLANCDT" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emplancdts/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emplancdtService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMPLANCDT" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emplancdts/fetchdefault")
	public ResponseEntity<List<EMPLANCDTDTO>> fetchDefault(EMPLANCDTSearchContext context) {
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
        List<EMPLANCDTDTO> list = emplancdtMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMPLANCDT" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emplancdts/searchdefault")
	public ResponseEntity<Page<EMPLANCDTDTO>> searchDefault(EMPLANCDTSearchContext context) {
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplancdtMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "GetByEMPLAN", tags = {"EMPLANCDT" },  notes = "GetByEMPLAN")
	@RequestMapping(method = RequestMethod.GET, value = "/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    public ResponseEntity<EMPLANCDTDTO> getByEMPLAN(@PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
        EMPLANCDT domain = emplancdtService.get(emplancdt_id);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveByEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emplans/{emplan_id}/emplancdts/save")
    public ResponseEntity<Boolean> saveByEMPLAN(@PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveBatchByEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emplans/{emplan_id}/emplancdts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMPLAN(@PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
             domain.setPlanid(emplan_id);
        }
        emplancdtService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMPLAN", tags = {"EMPLANCDT" },  notes = "CreateByEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emplans/{emplan_id}/emplancdts")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> createByEMPLAN(@PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
		emplancdtService.create(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMPLAN", tags = {"EMPLANCDT" },  notes = "createBatchByEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> createBatchByEMPLAN(@PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMPLAN", tags = {"EMPLANCDT" },  notes = "GetDraftByEMPLAN")
    @RequestMapping(method = RequestMethod.GET, value = "/emplans/{emplan_id}/emplancdts/getdraft")
    public ResponseEntity<EMPLANCDTDTO> getDraftByEMPLAN(@PathVariable("emplan_id") String emplan_id) {
        EMPLANCDT domain = new EMPLANCDT();
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtMapping.toDto(emplancdtService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateByEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> updateByEMPLAN(@PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        domain.setEmplancdtid(emplancdt_id);
		emplancdtService.update(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateBatchByEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> updateBatchByEMPLAN(@PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMPLAN", tags = {"EMPLANCDT" },  notes = "CheckKeyByEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emplans/{emplan_id}/emplancdts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMPLAN(@PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplancdtService.checkKey(emplancdtMapping.toDomain(emplancdtdto)));
    }

    @ApiOperation(value = "RemoveByEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveByEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMPLAN(@PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.remove(emplancdt_id));
    }

    @ApiOperation(value = "RemoveBatchByEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveBatchByEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> removeBatchByEMPLAN(@RequestBody List<String> ids) {
        emplancdtService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMPLAN", tags = {"EMPLANCDT" } ,notes = "fetchDEFAULTByEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/emplans/{emplan_id}/emplancdts/fetchdefault")
	public ResponseEntity<List<EMPLANCDTDTO>> fetchEMPLANCDTDefaultByEMPLAN(@PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
        List<EMPLANCDTDTO> list = emplancdtMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMPLAN", tags = {"EMPLANCDT" } ,notes = "searchDEFAULTByEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/emplans/{emplan_id}/emplancdts/searchdefault")
	public ResponseEntity<Page<EMPLANCDTDTO>> searchEMPLANCDTDefaultByEMPLAN(@PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplancdtMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "GetByEMACCLASSEMPLAN", tags = {"EMPLANCDT" },  notes = "GetByEMACCLASSEMPLAN")
	@RequestMapping(method = RequestMethod.GET, value = "/emacclasses/{emacclass_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    public ResponseEntity<EMPLANCDTDTO> getByEMACCLASSEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
        EMPLANCDT domain = emplancdtService.get(emplancdt_id);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMACCLASSEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveByEMACCLASSEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplans/{emplan_id}/emplancdts/save")
    public ResponseEntity<Boolean> saveByEMACCLASSEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMACCLASSEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveBatchByEMACCLASSEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplans/{emplan_id}/emplancdts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMACCLASSEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
             domain.setPlanid(emplan_id);
        }
        emplancdtService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMACCLASSEMPLAN", tags = {"EMPLANCDT" },  notes = "CreateByEMACCLASSEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplans/{emplan_id}/emplancdts")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> createByEMACCLASSEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
		emplancdtService.create(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMACCLASSEMPLAN", tags = {"EMPLANCDT" },  notes = "createBatchByEMACCLASSEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> createBatchByEMACCLASSEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMACCLASSEMPLAN", tags = {"EMPLANCDT" },  notes = "GetDraftByEMACCLASSEMPLAN")
    @RequestMapping(method = RequestMethod.GET, value = "/emacclasses/{emacclass_id}/emplans/{emplan_id}/emplancdts/getdraft")
    public ResponseEntity<EMPLANCDTDTO> getDraftByEMACCLASSEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLANCDT domain = new EMPLANCDT();
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtMapping.toDto(emplancdtService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMACCLASSEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateByEMACCLASSEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/emacclasses/{emacclass_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> updateByEMACCLASSEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        domain.setEmplancdtid(emplancdt_id);
		emplancdtService.update(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMACCLASSEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateBatchByEMACCLASSEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/emacclasses/{emacclass_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> updateBatchByEMACCLASSEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMACCLASSEMPLAN", tags = {"EMPLANCDT" },  notes = "CheckKeyByEMACCLASSEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplans/{emplan_id}/emplancdts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMACCLASSEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplancdtService.checkKey(emplancdtMapping.toDomain(emplancdtdto)));
    }

    @ApiOperation(value = "RemoveByEMACCLASSEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveByEMACCLASSEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emacclasses/{emacclass_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMACCLASSEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.remove(emplancdt_id));
    }

    @ApiOperation(value = "RemoveBatchByEMACCLASSEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveBatchByEMACCLASSEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emacclasses/{emacclass_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> removeBatchByEMACCLASSEMPLAN(@RequestBody List<String> ids) {
        emplancdtService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMACCLASSEMPLAN", tags = {"EMPLANCDT" } ,notes = "fetchDEFAULTByEMACCLASSEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/emacclasses/{emacclass_id}/emplans/{emplan_id}/emplancdts/fetchdefault")
	public ResponseEntity<List<EMPLANCDTDTO>> fetchEMPLANCDTDefaultByEMACCLASSEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
        List<EMPLANCDTDTO> list = emplancdtMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMACCLASSEMPLAN", tags = {"EMPLANCDT" } ,notes = "searchDEFAULTByEMACCLASSEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/emacclasses/{emacclass_id}/emplans/{emplan_id}/emplancdts/searchdefault")
	public ResponseEntity<Page<EMPLANCDTDTO>> searchEMPLANCDTDefaultByEMACCLASSEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplancdtMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "GetByEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "GetByEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.GET, value = "/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    public ResponseEntity<EMPLANCDTDTO> getByEMEQUIPEMPLAN(@PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
        EMPLANCDT domain = emplancdtService.get(emplancdt_id);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveByEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/save")
    public ResponseEntity<Boolean> saveByEMEQUIPEMPLAN(@PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveBatchByEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMEQUIPEMPLAN(@PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
             domain.setPlanid(emplan_id);
        }
        emplancdtService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "CreateByEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> createByEMEQUIPEMPLAN(@PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
		emplancdtService.create(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "createBatchByEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> createBatchByEMEQUIPEMPLAN(@PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "GetDraftByEMEQUIPEMPLAN")
    @RequestMapping(method = RequestMethod.GET, value = "/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/getdraft")
    public ResponseEntity<EMPLANCDTDTO> getDraftByEMEQUIPEMPLAN(@PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLANCDT domain = new EMPLANCDT();
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtMapping.toDto(emplancdtService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateByEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> updateByEMEQUIPEMPLAN(@PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        domain.setEmplancdtid(emplancdt_id);
		emplancdtService.update(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateBatchByEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> updateBatchByEMEQUIPEMPLAN(@PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "CheckKeyByEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMEQUIPEMPLAN(@PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplancdtService.checkKey(emplancdtMapping.toDomain(emplancdtdto)));
    }

    @ApiOperation(value = "RemoveByEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveByEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMEQUIPEMPLAN(@PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.remove(emplancdt_id));
    }

    @ApiOperation(value = "RemoveBatchByEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveBatchByEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> removeBatchByEMEQUIPEMPLAN(@RequestBody List<String> ids) {
        emplancdtService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMEQUIPEMPLAN", tags = {"EMPLANCDT" } ,notes = "fetchDEFAULTByEMEQUIPEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/fetchdefault")
	public ResponseEntity<List<EMPLANCDTDTO>> fetchEMPLANCDTDefaultByEMEQUIPEMPLAN(@PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
        List<EMPLANCDTDTO> list = emplancdtMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMEQUIPEMPLAN", tags = {"EMPLANCDT" } ,notes = "searchDEFAULTByEMEQUIPEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/searchdefault")
	public ResponseEntity<Page<EMPLANCDTDTO>> searchEMPLANCDTDefaultByEMEQUIPEMPLAN(@PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplancdtMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "GetByEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "GetByEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.GET, value = "/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    public ResponseEntity<EMPLANCDTDTO> getByEMPLANTEMPLEMPLAN(@PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
        EMPLANCDT domain = emplancdtService.get(emplancdt_id);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveByEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/save")
    public ResponseEntity<Boolean> saveByEMPLANTEMPLEMPLAN(@PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveBatchByEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMPLANTEMPLEMPLAN(@PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
             domain.setPlanid(emplan_id);
        }
        emplancdtService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "CreateByEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> createByEMPLANTEMPLEMPLAN(@PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
		emplancdtService.create(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "createBatchByEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> createBatchByEMPLANTEMPLEMPLAN(@PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "GetDraftByEMPLANTEMPLEMPLAN")
    @RequestMapping(method = RequestMethod.GET, value = "/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/getdraft")
    public ResponseEntity<EMPLANCDTDTO> getDraftByEMPLANTEMPLEMPLAN(@PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLANCDT domain = new EMPLANCDT();
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtMapping.toDto(emplancdtService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateByEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> updateByEMPLANTEMPLEMPLAN(@PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        domain.setEmplancdtid(emplancdt_id);
		emplancdtService.update(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateBatchByEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> updateBatchByEMPLANTEMPLEMPLAN(@PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "CheckKeyByEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMPLANTEMPLEMPLAN(@PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplancdtService.checkKey(emplancdtMapping.toDomain(emplancdtdto)));
    }

    @ApiOperation(value = "RemoveByEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveByEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMPLANTEMPLEMPLAN(@PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.remove(emplancdt_id));
    }

    @ApiOperation(value = "RemoveBatchByEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveBatchByEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> removeBatchByEMPLANTEMPLEMPLAN(@RequestBody List<String> ids) {
        emplancdtService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" } ,notes = "fetchDEFAULTByEMPLANTEMPLEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/fetchdefault")
	public ResponseEntity<List<EMPLANCDTDTO>> fetchEMPLANCDTDefaultByEMPLANTEMPLEMPLAN(@PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
        List<EMPLANCDTDTO> list = emplancdtMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" } ,notes = "searchDEFAULTByEMPLANTEMPLEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/searchdefault")
	public ResponseEntity<Page<EMPLANCDTDTO>> searchEMPLANCDTDefaultByEMPLANTEMPLEMPLAN(@PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplancdtMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "GetByEMSERVICEEMPLAN", tags = {"EMPLANCDT" },  notes = "GetByEMSERVICEEMPLAN")
	@RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    public ResponseEntity<EMPLANCDTDTO> getByEMSERVICEEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
        EMPLANCDT domain = emplancdtService.get(emplancdt_id);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMSERVICEEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveByEMSERVICEEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplans/{emplan_id}/emplancdts/save")
    public ResponseEntity<Boolean> saveByEMSERVICEEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSERVICEEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveBatchByEMSERVICEEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplans/{emplan_id}/emplancdts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSERVICEEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
             domain.setPlanid(emplan_id);
        }
        emplancdtService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMSERVICEEMPLAN", tags = {"EMPLANCDT" },  notes = "CreateByEMSERVICEEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplans/{emplan_id}/emplancdts")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> createByEMSERVICEEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
		emplancdtService.create(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSERVICEEMPLAN", tags = {"EMPLANCDT" },  notes = "createBatchByEMSERVICEEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> createBatchByEMSERVICEEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSERVICEEMPLAN", tags = {"EMPLANCDT" },  notes = "GetDraftByEMSERVICEEMPLAN")
    @RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emplans/{emplan_id}/emplancdts/getdraft")
    public ResponseEntity<EMPLANCDTDTO> getDraftByEMSERVICEEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLANCDT domain = new EMPLANCDT();
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtMapping.toDto(emplancdtService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMSERVICEEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateByEMSERVICEEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> updateByEMSERVICEEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        domain.setEmplancdtid(emplancdt_id);
		emplancdtService.update(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSERVICEEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateBatchByEMSERVICEEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> updateBatchByEMSERVICEEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMSERVICEEMPLAN", tags = {"EMPLANCDT" },  notes = "CheckKeyByEMSERVICEEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplans/{emplan_id}/emplancdts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSERVICEEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplancdtService.checkKey(emplancdtMapping.toDomain(emplancdtdto)));
    }

    @ApiOperation(value = "RemoveByEMSERVICEEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveByEMSERVICEEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSERVICEEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.remove(emplancdt_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSERVICEEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveBatchByEMSERVICEEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> removeBatchByEMSERVICEEMPLAN(@RequestBody List<String> ids) {
        emplancdtService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMSERVICEEMPLAN", tags = {"EMPLANCDT" } ,notes = "fetchDEFAULTByEMSERVICEEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emplans/{emplan_id}/emplancdts/fetchdefault")
	public ResponseEntity<List<EMPLANCDTDTO>> fetchEMPLANCDTDefaultByEMSERVICEEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
        List<EMPLANCDTDTO> list = emplancdtMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSERVICEEMPLAN", tags = {"EMPLANCDT" } ,notes = "searchDEFAULTByEMSERVICEEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emplans/{emplan_id}/emplancdts/searchdefault")
	public ResponseEntity<Page<EMPLANCDTDTO>> searchEMPLANCDTDefaultByEMSERVICEEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplancdtMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "GetByPFDEPTEMPLAN", tags = {"EMPLANCDT" },  notes = "GetByPFDEPTEMPLAN")
	@RequestMapping(method = RequestMethod.GET, value = "/pfdepts/{pfdept_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    public ResponseEntity<EMPLANCDTDTO> getByPFDEPTEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
        EMPLANCDT domain = emplancdtService.get(emplancdt_id);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByPFDEPTEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveByPFDEPTEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplans/{emplan_id}/emplancdts/save")
    public ResponseEntity<Boolean> saveByPFDEPTEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFDEPTEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveBatchByPFDEPTEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplans/{emplan_id}/emplancdts/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFDEPTEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
             domain.setPlanid(emplan_id);
        }
        emplancdtService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByPFDEPTEMPLAN", tags = {"EMPLANCDT" },  notes = "CreateByPFDEPTEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplans/{emplan_id}/emplancdts")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> createByPFDEPTEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
		emplancdtService.create(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFDEPTEMPLAN", tags = {"EMPLANCDT" },  notes = "createBatchByPFDEPTEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> createBatchByPFDEPTEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFDEPTEMPLAN", tags = {"EMPLANCDT" },  notes = "GetDraftByPFDEPTEMPLAN")
    @RequestMapping(method = RequestMethod.GET, value = "/pfdepts/{pfdept_id}/emplans/{emplan_id}/emplancdts/getdraft")
    public ResponseEntity<EMPLANCDTDTO> getDraftByPFDEPTEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLANCDT domain = new EMPLANCDT();
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtMapping.toDto(emplancdtService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByPFDEPTEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateByPFDEPTEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfdepts/{pfdept_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> updateByPFDEPTEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        domain.setEmplancdtid(emplancdt_id);
		emplancdtService.update(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFDEPTEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateBatchByPFDEPTEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfdepts/{pfdept_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> updateBatchByPFDEPTEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFDEPTEMPLAN", tags = {"EMPLANCDT" },  notes = "CheckKeyByPFDEPTEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplans/{emplan_id}/emplancdts/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFDEPTEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplancdtService.checkKey(emplancdtMapping.toDomain(emplancdtdto)));
    }

    @ApiOperation(value = "RemoveByPFDEPTEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveByPFDEPTEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfdepts/{pfdept_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFDEPTEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.remove(emplancdt_id));
    }

    @ApiOperation(value = "RemoveBatchByPFDEPTEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveBatchByPFDEPTEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfdepts/{pfdept_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> removeBatchByPFDEPTEMPLAN(@RequestBody List<String> ids) {
        emplancdtService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFDEPTEMPLAN", tags = {"EMPLANCDT" } ,notes = "fetchDEFAULTByPFDEPTEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/pfdepts/{pfdept_id}/emplans/{emplan_id}/emplancdts/fetchdefault")
	public ResponseEntity<List<EMPLANCDTDTO>> fetchEMPLANCDTDefaultByPFDEPTEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
        List<EMPLANCDTDTO> list = emplancdtMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFDEPTEMPLAN", tags = {"EMPLANCDT" } ,notes = "searchDEFAULTByPFDEPTEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/pfdepts/{pfdept_id}/emplans/{emplan_id}/emplancdts/searchdefault")
	public ResponseEntity<Page<EMPLANCDTDTO>> searchEMPLANCDTDefaultByPFDEPTEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplancdtMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "GetByPFEMPEMPLAN", tags = {"EMPLANCDT" },  notes = "GetByPFEMPEMPLAN")
	@RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    public ResponseEntity<EMPLANCDTDTO> getByPFEMPEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
        EMPLANCDT domain = emplancdtService.get(emplancdt_id);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByPFEMPEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveByPFEMPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplans/{emplan_id}/emplancdts/save")
    public ResponseEntity<Boolean> saveByPFEMPEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFEMPEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveBatchByPFEMPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplans/{emplan_id}/emplancdts/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFEMPEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
             domain.setPlanid(emplan_id);
        }
        emplancdtService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByPFEMPEMPLAN", tags = {"EMPLANCDT" },  notes = "CreateByPFEMPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplans/{emplan_id}/emplancdts")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> createByPFEMPEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
		emplancdtService.create(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFEMPEMPLAN", tags = {"EMPLANCDT" },  notes = "createBatchByPFEMPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> createBatchByPFEMPEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFEMPEMPLAN", tags = {"EMPLANCDT" },  notes = "GetDraftByPFEMPEMPLAN")
    @RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emplans/{emplan_id}/emplancdts/getdraft")
    public ResponseEntity<EMPLANCDTDTO> getDraftByPFEMPEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLANCDT domain = new EMPLANCDT();
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtMapping.toDto(emplancdtService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByPFEMPEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateByPFEMPEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> updateByPFEMPEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        domain.setEmplancdtid(emplancdt_id);
		emplancdtService.update(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFEMPEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateBatchByPFEMPEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> updateBatchByPFEMPEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFEMPEMPLAN", tags = {"EMPLANCDT" },  notes = "CheckKeyByPFEMPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplans/{emplan_id}/emplancdts/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFEMPEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplancdtService.checkKey(emplancdtMapping.toDomain(emplancdtdto)));
    }

    @ApiOperation(value = "RemoveByPFEMPEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveByPFEMPEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFEMPEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.remove(emplancdt_id));
    }

    @ApiOperation(value = "RemoveBatchByPFEMPEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveBatchByPFEMPEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> removeBatchByPFEMPEMPLAN(@RequestBody List<String> ids) {
        emplancdtService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFEMPEMPLAN", tags = {"EMPLANCDT" } ,notes = "fetchDEFAULTByPFEMPEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emplans/{emplan_id}/emplancdts/fetchdefault")
	public ResponseEntity<List<EMPLANCDTDTO>> fetchEMPLANCDTDefaultByPFEMPEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
        List<EMPLANCDTDTO> list = emplancdtMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFEMPEMPLAN", tags = {"EMPLANCDT" } ,notes = "searchDEFAULTByPFEMPEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emplans/{emplan_id}/emplancdts/searchdefault")
	public ResponseEntity<Page<EMPLANCDTDTO>> searchEMPLANCDTDefaultByPFEMPEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplancdtMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "GetByPFTEAMEMPLAN", tags = {"EMPLANCDT" },  notes = "GetByPFTEAMEMPLAN")
	@RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    public ResponseEntity<EMPLANCDTDTO> getByPFTEAMEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
        EMPLANCDT domain = emplancdtService.get(emplancdt_id);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByPFTEAMEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveByPFTEAMEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplans/{emplan_id}/emplancdts/save")
    public ResponseEntity<Boolean> saveByPFTEAMEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFTEAMEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveBatchByPFTEAMEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplans/{emplan_id}/emplancdts/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFTEAMEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
             domain.setPlanid(emplan_id);
        }
        emplancdtService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByPFTEAMEMPLAN", tags = {"EMPLANCDT" },  notes = "CreateByPFTEAMEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplans/{emplan_id}/emplancdts")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> createByPFTEAMEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
		emplancdtService.create(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFTEAMEMPLAN", tags = {"EMPLANCDT" },  notes = "createBatchByPFTEAMEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> createBatchByPFTEAMEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFTEAMEMPLAN", tags = {"EMPLANCDT" },  notes = "GetDraftByPFTEAMEMPLAN")
    @RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emplans/{emplan_id}/emplancdts/getdraft")
    public ResponseEntity<EMPLANCDTDTO> getDraftByPFTEAMEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLANCDT domain = new EMPLANCDT();
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtMapping.toDto(emplancdtService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByPFTEAMEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateByPFTEAMEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> updateByPFTEAMEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        domain.setEmplancdtid(emplancdt_id);
		emplancdtService.update(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFTEAMEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateBatchByPFTEAMEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> updateBatchByPFTEAMEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFTEAMEMPLAN", tags = {"EMPLANCDT" },  notes = "CheckKeyByPFTEAMEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplans/{emplan_id}/emplancdts/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFTEAMEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplancdtService.checkKey(emplancdtMapping.toDomain(emplancdtdto)));
    }

    @ApiOperation(value = "RemoveByPFTEAMEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveByPFTEAMEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFTEAMEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.remove(emplancdt_id));
    }

    @ApiOperation(value = "RemoveBatchByPFTEAMEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveBatchByPFTEAMEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> removeBatchByPFTEAMEMPLAN(@RequestBody List<String> ids) {
        emplancdtService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFTEAMEMPLAN", tags = {"EMPLANCDT" } ,notes = "fetchDEFAULTByPFTEAMEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emplans/{emplan_id}/emplancdts/fetchdefault")
	public ResponseEntity<List<EMPLANCDTDTO>> fetchEMPLANCDTDefaultByPFTEAMEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
        List<EMPLANCDTDTO> list = emplancdtMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFTEAMEMPLAN", tags = {"EMPLANCDT" } ,notes = "searchDEFAULTByPFTEAMEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emplans/{emplan_id}/emplancdts/searchdefault")
	public ResponseEntity<Page<EMPLANCDTDTO>> searchEMPLANCDTDefaultByPFTEAMEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplancdtMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}





    @ApiOperation(value = "GetByEMEQTYPEEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "GetByEMEQTYPEEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.GET, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    public ResponseEntity<EMPLANCDTDTO> getByEMEQTYPEEMEQUIPEMPLAN(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
        EMPLANCDT domain = emplancdtService.get(emplancdt_id);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMEQTYPEEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveByEMEQTYPEEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/save")
    public ResponseEntity<Boolean> saveByEMEQTYPEEMEQUIPEMPLAN(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMEQTYPEEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveBatchByEMEQTYPEEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMEQTYPEEMEQUIPEMPLAN(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
             domain.setPlanid(emplan_id);
        }
        emplancdtService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMEQTYPEEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "CreateByEMEQTYPEEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> createByEMEQTYPEEMEQUIPEMPLAN(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
		emplancdtService.create(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMEQTYPEEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "createBatchByEMEQTYPEEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> createBatchByEMEQTYPEEMEQUIPEMPLAN(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMEQTYPEEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "GetDraftByEMEQTYPEEMEQUIPEMPLAN")
    @RequestMapping(method = RequestMethod.GET, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/getdraft")
    public ResponseEntity<EMPLANCDTDTO> getDraftByEMEQTYPEEMEQUIPEMPLAN(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLANCDT domain = new EMPLANCDT();
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtMapping.toDto(emplancdtService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMEQTYPEEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateByEMEQTYPEEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> updateByEMEQTYPEEMEQUIPEMPLAN(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        domain.setEmplancdtid(emplancdt_id);
		emplancdtService.update(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMEQTYPEEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateBatchByEMEQTYPEEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> updateBatchByEMEQTYPEEMEQUIPEMPLAN(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMEQTYPEEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "CheckKeyByEMEQTYPEEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMEQTYPEEMEQUIPEMPLAN(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplancdtService.checkKey(emplancdtMapping.toDomain(emplancdtdto)));
    }

    @ApiOperation(value = "RemoveByEMEQTYPEEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveByEMEQTYPEEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMEQTYPEEMEQUIPEMPLAN(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.remove(emplancdt_id));
    }

    @ApiOperation(value = "RemoveBatchByEMEQTYPEEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveBatchByEMEQTYPEEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> removeBatchByEMEQTYPEEMEQUIPEMPLAN(@RequestBody List<String> ids) {
        emplancdtService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMEQTYPEEMEQUIPEMPLAN", tags = {"EMPLANCDT" } ,notes = "fetchDEFAULTByEMEQTYPEEMEQUIPEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/fetchdefault")
	public ResponseEntity<List<EMPLANCDTDTO>> fetchEMPLANCDTDefaultByEMEQTYPEEMEQUIPEMPLAN(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
        List<EMPLANCDTDTO> list = emplancdtMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMEQTYPEEMEQUIPEMPLAN", tags = {"EMPLANCDT" } ,notes = "searchDEFAULTByEMEQTYPEEMEQUIPEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/searchdefault")
	public ResponseEntity<Page<EMPLANCDTDTO>> searchEMPLANCDTDefaultByEMEQTYPEEMEQUIPEMPLAN(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplancdtMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}





    @ApiOperation(value = "GetByPFTEAMEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "GetByPFTEAMEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    public ResponseEntity<EMPLANCDTDTO> getByPFTEAMEMEQUIPEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
        EMPLANCDT domain = emplancdtService.get(emplancdt_id);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByPFTEAMEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveByPFTEAMEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/save")
    public ResponseEntity<Boolean> saveByPFTEAMEMEQUIPEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFTEAMEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveBatchByPFTEAMEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFTEAMEMEQUIPEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
             domain.setPlanid(emplan_id);
        }
        emplancdtService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByPFTEAMEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "CreateByPFTEAMEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> createByPFTEAMEMEQUIPEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
		emplancdtService.create(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFTEAMEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "createBatchByPFTEAMEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> createBatchByPFTEAMEMEQUIPEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFTEAMEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "GetDraftByPFTEAMEMEQUIPEMPLAN")
    @RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/getdraft")
    public ResponseEntity<EMPLANCDTDTO> getDraftByPFTEAMEMEQUIPEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLANCDT domain = new EMPLANCDT();
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtMapping.toDto(emplancdtService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByPFTEAMEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateByPFTEAMEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> updateByPFTEAMEMEQUIPEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        domain.setEmplancdtid(emplancdt_id);
		emplancdtService.update(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFTEAMEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateBatchByPFTEAMEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> updateBatchByPFTEAMEMEQUIPEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFTEAMEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "CheckKeyByPFTEAMEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFTEAMEMEQUIPEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplancdtService.checkKey(emplancdtMapping.toDomain(emplancdtdto)));
    }

    @ApiOperation(value = "RemoveByPFTEAMEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveByPFTEAMEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFTEAMEMEQUIPEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.remove(emplancdt_id));
    }

    @ApiOperation(value = "RemoveBatchByPFTEAMEMEQUIPEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveBatchByPFTEAMEMEQUIPEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> removeBatchByPFTEAMEMEQUIPEMPLAN(@RequestBody List<String> ids) {
        emplancdtService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFTEAMEMEQUIPEMPLAN", tags = {"EMPLANCDT" } ,notes = "fetchDEFAULTByPFTEAMEMEQUIPEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/fetchdefault")
	public ResponseEntity<List<EMPLANCDTDTO>> fetchEMPLANCDTDefaultByPFTEAMEMEQUIPEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
        List<EMPLANCDTDTO> list = emplancdtMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFTEAMEMEQUIPEMPLAN", tags = {"EMPLANCDT" } ,notes = "searchDEFAULTByPFTEAMEMEQUIPEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/{emplan_id}/emplancdts/searchdefault")
	public ResponseEntity<Page<EMPLANCDTDTO>> searchEMPLANCDTDefaultByPFTEAMEMEQUIPEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplancdtMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}





    @ApiOperation(value = "GetByEMACCLASSEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "GetByEMACCLASSEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.GET, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    public ResponseEntity<EMPLANCDTDTO> getByEMACCLASSEMPLANTEMPLEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
        EMPLANCDT domain = emplancdtService.get(emplancdt_id);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMACCLASSEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveByEMACCLASSEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/save")
    public ResponseEntity<Boolean> saveByEMACCLASSEMPLANTEMPLEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMACCLASSEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveBatchByEMACCLASSEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMACCLASSEMPLANTEMPLEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
             domain.setPlanid(emplan_id);
        }
        emplancdtService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMACCLASSEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "CreateByEMACCLASSEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> createByEMACCLASSEMPLANTEMPLEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
		emplancdtService.create(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMACCLASSEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "createBatchByEMACCLASSEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> createBatchByEMACCLASSEMPLANTEMPLEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMACCLASSEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "GetDraftByEMACCLASSEMPLANTEMPLEMPLAN")
    @RequestMapping(method = RequestMethod.GET, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/getdraft")
    public ResponseEntity<EMPLANCDTDTO> getDraftByEMACCLASSEMPLANTEMPLEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLANCDT domain = new EMPLANCDT();
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtMapping.toDto(emplancdtService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMACCLASSEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateByEMACCLASSEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> updateByEMACCLASSEMPLANTEMPLEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        domain.setEmplancdtid(emplancdt_id);
		emplancdtService.update(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMACCLASSEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateBatchByEMACCLASSEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> updateBatchByEMACCLASSEMPLANTEMPLEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMACCLASSEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "CheckKeyByEMACCLASSEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMACCLASSEMPLANTEMPLEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplancdtService.checkKey(emplancdtMapping.toDomain(emplancdtdto)));
    }

    @ApiOperation(value = "RemoveByEMACCLASSEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveByEMACCLASSEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMACCLASSEMPLANTEMPLEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.remove(emplancdt_id));
    }

    @ApiOperation(value = "RemoveBatchByEMACCLASSEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveBatchByEMACCLASSEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> removeBatchByEMACCLASSEMPLANTEMPLEMPLAN(@RequestBody List<String> ids) {
        emplancdtService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMACCLASSEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" } ,notes = "fetchDEFAULTByEMACCLASSEMPLANTEMPLEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/fetchdefault")
	public ResponseEntity<List<EMPLANCDTDTO>> fetchEMPLANCDTDefaultByEMACCLASSEMPLANTEMPLEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
        List<EMPLANCDTDTO> list = emplancdtMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMACCLASSEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" } ,notes = "searchDEFAULTByEMACCLASSEMPLANTEMPLEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/searchdefault")
	public ResponseEntity<Page<EMPLANCDTDTO>> searchEMPLANCDTDefaultByEMACCLASSEMPLANTEMPLEMPLAN(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplancdtMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}





    @ApiOperation(value = "GetByEMSERVICEEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "GetByEMSERVICEEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    public ResponseEntity<EMPLANCDTDTO> getByEMSERVICEEMPLANTEMPLEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
        EMPLANCDT domain = emplancdtService.get(emplancdt_id);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByEMSERVICEEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveByEMSERVICEEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/save")
    public ResponseEntity<Boolean> saveByEMSERVICEEMPLANTEMPLEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSERVICEEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveBatchByEMSERVICEEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSERVICEEMPLANTEMPLEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
             domain.setPlanid(emplan_id);
        }
        emplancdtService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMSERVICEEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "CreateByEMSERVICEEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> createByEMSERVICEEMPLANTEMPLEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
		emplancdtService.create(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSERVICEEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "createBatchByEMSERVICEEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> createBatchByEMSERVICEEMPLANTEMPLEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSERVICEEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "GetDraftByEMSERVICEEMPLANTEMPLEMPLAN")
    @RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/getdraft")
    public ResponseEntity<EMPLANCDTDTO> getDraftByEMSERVICEEMPLANTEMPLEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLANCDT domain = new EMPLANCDT();
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtMapping.toDto(emplancdtService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByEMSERVICEEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateByEMSERVICEEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> updateByEMSERVICEEMPLANTEMPLEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        domain.setEmplancdtid(emplancdt_id);
		emplancdtService.update(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSERVICEEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateBatchByEMSERVICEEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> updateBatchByEMSERVICEEMPLANTEMPLEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMSERVICEEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "CheckKeyByEMSERVICEEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSERVICEEMPLANTEMPLEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplancdtService.checkKey(emplancdtMapping.toDomain(emplancdtdto)));
    }

    @ApiOperation(value = "RemoveByEMSERVICEEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveByEMSERVICEEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSERVICEEMPLANTEMPLEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.remove(emplancdt_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSERVICEEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveBatchByEMSERVICEEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> removeBatchByEMSERVICEEMPLANTEMPLEMPLAN(@RequestBody List<String> ids) {
        emplancdtService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMSERVICEEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" } ,notes = "fetchDEFAULTByEMSERVICEEMPLANTEMPLEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/fetchdefault")
	public ResponseEntity<List<EMPLANCDTDTO>> fetchEMPLANCDTDefaultByEMSERVICEEMPLANTEMPLEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
        List<EMPLANCDTDTO> list = emplancdtMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSERVICEEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" } ,notes = "searchDEFAULTByEMSERVICEEMPLANTEMPLEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/searchdefault")
	public ResponseEntity<Page<EMPLANCDTDTO>> searchEMPLANCDTDefaultByEMSERVICEEMPLANTEMPLEMPLAN(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplancdtMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}





    @ApiOperation(value = "GetByPFDEPTEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "GetByPFDEPTEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.GET, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    public ResponseEntity<EMPLANCDTDTO> getByPFDEPTEMPLANTEMPLEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
        EMPLANCDT domain = emplancdtService.get(emplancdt_id);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByPFDEPTEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveByPFDEPTEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/save")
    public ResponseEntity<Boolean> saveByPFDEPTEMPLANTEMPLEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFDEPTEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveBatchByPFDEPTEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFDEPTEMPLANTEMPLEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
             domain.setPlanid(emplan_id);
        }
        emplancdtService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByPFDEPTEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "CreateByPFDEPTEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> createByPFDEPTEMPLANTEMPLEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
		emplancdtService.create(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFDEPTEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "createBatchByPFDEPTEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> createBatchByPFDEPTEMPLANTEMPLEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFDEPTEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "GetDraftByPFDEPTEMPLANTEMPLEMPLAN")
    @RequestMapping(method = RequestMethod.GET, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/getdraft")
    public ResponseEntity<EMPLANCDTDTO> getDraftByPFDEPTEMPLANTEMPLEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLANCDT domain = new EMPLANCDT();
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtMapping.toDto(emplancdtService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByPFDEPTEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateByPFDEPTEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> updateByPFDEPTEMPLANTEMPLEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        domain.setEmplancdtid(emplancdt_id);
		emplancdtService.update(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFDEPTEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateBatchByPFDEPTEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> updateBatchByPFDEPTEMPLANTEMPLEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFDEPTEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "CheckKeyByPFDEPTEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFDEPTEMPLANTEMPLEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplancdtService.checkKey(emplancdtMapping.toDomain(emplancdtdto)));
    }

    @ApiOperation(value = "RemoveByPFDEPTEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveByPFDEPTEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFDEPTEMPLANTEMPLEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.remove(emplancdt_id));
    }

    @ApiOperation(value = "RemoveBatchByPFDEPTEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveBatchByPFDEPTEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> removeBatchByPFDEPTEMPLANTEMPLEMPLAN(@RequestBody List<String> ids) {
        emplancdtService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFDEPTEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" } ,notes = "fetchDEFAULTByPFDEPTEMPLANTEMPLEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/fetchdefault")
	public ResponseEntity<List<EMPLANCDTDTO>> fetchEMPLANCDTDefaultByPFDEPTEMPLANTEMPLEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
        List<EMPLANCDTDTO> list = emplancdtMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFDEPTEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" } ,notes = "searchDEFAULTByPFDEPTEMPLANTEMPLEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/searchdefault")
	public ResponseEntity<Page<EMPLANCDTDTO>> searchEMPLANCDTDefaultByPFDEPTEMPLANTEMPLEMPLAN(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplancdtMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}





    @ApiOperation(value = "GetByPFEMPEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "GetByPFEMPEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    public ResponseEntity<EMPLANCDTDTO> getByPFEMPEMPLANTEMPLEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
        EMPLANCDT domain = emplancdtService.get(emplancdt_id);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByPFEMPEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveByPFEMPEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/save")
    public ResponseEntity<Boolean> saveByPFEMPEMPLANTEMPLEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFEMPEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveBatchByPFEMPEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFEMPEMPLANTEMPLEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
             domain.setPlanid(emplan_id);
        }
        emplancdtService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByPFEMPEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "CreateByPFEMPEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> createByPFEMPEMPLANTEMPLEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
		emplancdtService.create(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFEMPEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "createBatchByPFEMPEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> createBatchByPFEMPEMPLANTEMPLEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFEMPEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "GetDraftByPFEMPEMPLANTEMPLEMPLAN")
    @RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/getdraft")
    public ResponseEntity<EMPLANCDTDTO> getDraftByPFEMPEMPLANTEMPLEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLANCDT domain = new EMPLANCDT();
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtMapping.toDto(emplancdtService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByPFEMPEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateByPFEMPEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> updateByPFEMPEMPLANTEMPLEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        domain.setEmplancdtid(emplancdt_id);
		emplancdtService.update(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFEMPEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateBatchByPFEMPEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> updateBatchByPFEMPEMPLANTEMPLEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFEMPEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "CheckKeyByPFEMPEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFEMPEMPLANTEMPLEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplancdtService.checkKey(emplancdtMapping.toDomain(emplancdtdto)));
    }

    @ApiOperation(value = "RemoveByPFEMPEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveByPFEMPEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFEMPEMPLANTEMPLEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.remove(emplancdt_id));
    }

    @ApiOperation(value = "RemoveBatchByPFEMPEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveBatchByPFEMPEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> removeBatchByPFEMPEMPLANTEMPLEMPLAN(@RequestBody List<String> ids) {
        emplancdtService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFEMPEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" } ,notes = "fetchDEFAULTByPFEMPEMPLANTEMPLEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/fetchdefault")
	public ResponseEntity<List<EMPLANCDTDTO>> fetchEMPLANCDTDefaultByPFEMPEMPLANTEMPLEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
        List<EMPLANCDTDTO> list = emplancdtMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFEMPEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" } ,notes = "searchDEFAULTByPFEMPEMPLANTEMPLEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/searchdefault")
	public ResponseEntity<Page<EMPLANCDTDTO>> searchEMPLANCDTDefaultByPFEMPEMPLANTEMPLEMPLAN(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplancdtMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}





    @ApiOperation(value = "GetByPFTEAMEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "GetByPFTEAMEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    public ResponseEntity<EMPLANCDTDTO> getByPFTEAMEMPLANTEMPLEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
        EMPLANCDT domain = emplancdtService.get(emplancdt_id);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "SaveByPFTEAMEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveByPFTEAMEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/save")
    public ResponseEntity<Boolean> saveByPFTEAMEMPLANTEMPLEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFTEAMEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "SaveBatchByPFTEAMEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFTEAMEMPLANTEMPLEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
             domain.setPlanid(emplan_id);
        }
        emplancdtService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByPFTEAMEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "CreateByPFTEAMEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> createByPFTEAMEMPLANTEMPLEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
		emplancdtService.create(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFTEAMEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "createBatchByPFTEAMEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> createBatchByPFTEAMEMPLANTEMPLEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFTEAMEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "GetDraftByPFTEAMEMPLANTEMPLEMPLAN")
    @RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/getdraft")
    public ResponseEntity<EMPLANCDTDTO> getDraftByPFTEAMEMPLANTEMPLEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLANCDT domain = new EMPLANCDT();
        domain.setPlanid(emplan_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplancdtMapping.toDto(emplancdtService.getDraft(domain)));
    }

    @ApiOperation(value = "UpdateByPFTEAMEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateByPFTEAMEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<EMPLANCDTDTO> updateByPFTEAMEMPLANTEMPLEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        EMPLANCDT domain = emplancdtMapping.toDomain(emplancdtdto);
        domain.setPlanid(emplan_id);
        domain.setEmplancdtid(emplancdt_id);
		emplancdtService.update(domain);
        EMPLANCDTDTO dto = emplancdtMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFTEAMEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "UpdateBatchByPFTEAMEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> updateBatchByPFTEAMEMPLANTEMPLEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody List<EMPLANCDTDTO> emplancdtdtos) {
        List<EMPLANCDT> domainlist=emplancdtMapping.toDomain(emplancdtdtos);
        for(EMPLANCDT domain:domainlist){
            domain.setPlanid(emplan_id);
        }
        emplancdtService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFTEAMEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "CheckKeyByPFTEAMEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFTEAMEMPLANTEMPLEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANCDTDTO emplancdtdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplancdtService.checkKey(emplancdtMapping.toDomain(emplancdtdto)));
    }

    @ApiOperation(value = "RemoveByPFTEAMEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveByPFTEAMEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/{emplancdt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFTEAMEMPLANTEMPLEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @PathVariable("emplancdt_id") String emplancdt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplancdtService.remove(emplancdt_id));
    }

    @ApiOperation(value = "RemoveBatchByPFTEAMEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" },  notes = "RemoveBatchByPFTEAMEMPLANTEMPLEMPLAN")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/batch")
    public ResponseEntity<Boolean> removeBatchByPFTEAMEMPLANTEMPLEMPLAN(@RequestBody List<String> ids) {
        emplancdtService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFTEAMEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" } ,notes = "fetchDEFAULTByPFTEAMEMPLANTEMPLEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/fetchdefault")
	public ResponseEntity<List<EMPLANCDTDTO>> fetchEMPLANCDTDefaultByPFTEAMEMPLANTEMPLEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
        List<EMPLANCDTDTO> list = emplancdtMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFTEAMEMPLANTEMPLEMPLAN", tags = {"EMPLANCDT" } ,notes = "searchDEFAULTByPFTEAMEMPLANTEMPLEMPLAN")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}/emplancdts/searchdefault")
	public ResponseEntity<Page<EMPLANCDTDTO>> searchEMPLANCDTDefaultByPFTEAMEMPLANTEMPLEMPLAN(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id,EMPLANCDTSearchContext context) {
        context.setN_planid_eq(emplan_id);
        Page<EMPLANCDT> domains = emplancdtService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplancdtMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMPLANCDT getEntity(){
        return new EMPLANCDT();
    }

}
