package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMPLAN;
import cn.ibizlab.eam.core.eam_core.service.IEMPLANService;
import cn.ibizlab.eam.core.eam_core.filter.EMPLANSearchContext;




@Slf4j
@Api(tags = {"EMPLAN" })
@RestController("WebApi-emplan")
@RequestMapping("")
public class EMPLANResource {

    @Autowired
    private IEMPLANService emplanService;

    @Autowired
    @Lazy
    private EMPLANMapping emplanMapping;




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMPLAN" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emplans")
    @Transactional
    public ResponseEntity<EMPLANDTO> create(@RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
		emplanService.create(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMPLAN" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emplans/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMPLANDTO> emplandtos) {
        emplanService.createBatch(emplanMapping.toDomain(emplandtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emplan_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMPLAN" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<EMPLANDTO> update(@PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANDTO emplandto) {
		EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setEmplanid(emplan_id);
		emplanService.update(domain);
		EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emplan_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMPLAN" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emplans/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMPLANDTO> emplandtos) {
        emplanService.updateBatch(emplanMapping.toDomain(emplandtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emplan_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMPLAN" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emplans/{emplan_id}")
    public ResponseEntity<EMPLANDTO> get(@PathVariable("emplan_id") String emplan_id) {
        EMPLAN domain = emplanService.get(emplan_id);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @PreAuthorize("hasPermission('Remove',{#emplan_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMPLAN" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emplan_id") String emplan_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emplanService.remove(emplan_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMPLAN" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emplans/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emplanService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMPLAN" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emplans/getdraft")
    public ResponseEntity<EMPLANDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emplanMapping.toDto(emplanService.getDraft(new EMPLAN())));
    }




    @ApiOperation(value = "CheckKey", tags = {"EMPLAN" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emplans/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMPLANDTO emplandto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplanService.checkKey(emplanMapping.toDomain(emplandto)));
    }




    @ApiOperation(value = "Save", tags = {"EMPLAN" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emplans/save")
    public ResponseEntity<Boolean> save(@RequestBody EMPLANDTO emplandto) {
        return ResponseEntity.status(HttpStatus.OK).body(emplanService.save(emplanMapping.toDomain(emplandto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMPLAN" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emplans/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMPLANDTO> emplandtos) {
        emplanService.saveBatch(emplanMapping.toDomain(emplandtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMPLAN" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emplans/fetchdefault")
	public ResponseEntity<List<EMPLANDTO>> fetchDefault(EMPLANSearchContext context) {
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
        List<EMPLANDTO> list = emplanMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMPLAN" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emplans/searchdefault")
	public ResponseEntity<Page<EMPLANDTO>> searchDefault(EMPLANSearchContext context) {
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplanMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "CreateByEMACCLASS", tags = {"EMPLAN" },  notes = "CreateByEMACCLASS")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplans")
    @Transactional
    public ResponseEntity<EMPLANDTO> createByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setAcclassid(emacclass_id);
		emplanService.create(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMACCLASS", tags = {"EMPLAN" },  notes = "createBatchByEMACCLASS")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplans/batch")
    public ResponseEntity<Boolean> createBatchByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setAcclassid(emacclass_id);
        }
        emplanService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMACCLASS", tags = {"EMPLAN" },  notes = "UpdateByEMACCLASS")
	@RequestMapping(method = RequestMethod.PUT, value = "/emacclasses/{emacclass_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<EMPLANDTO> updateByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setAcclassid(emacclass_id);
        domain.setEmplanid(emplan_id);
		emplanService.update(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMACCLASS", tags = {"EMPLAN" },  notes = "UpdateBatchByEMACCLASS")
	@RequestMapping(method = RequestMethod.PUT, value = "/emacclasses/{emacclass_id}/emplans/batch")
    public ResponseEntity<Boolean> updateBatchByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setAcclassid(emacclass_id);
        }
        emplanService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMACCLASS", tags = {"EMPLAN" },  notes = "GetByEMACCLASS")
	@RequestMapping(method = RequestMethod.GET, value = "/emacclasses/{emacclass_id}/emplans/{emplan_id}")
    public ResponseEntity<EMPLANDTO> getByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLAN domain = emplanService.get(emplan_id);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByEMACCLASS", tags = {"EMPLAN" },  notes = "RemoveByEMACCLASS")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emacclasses/{emacclass_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplan_id") String emplan_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplanService.remove(emplan_id));
    }

    @ApiOperation(value = "RemoveBatchByEMACCLASS", tags = {"EMPLAN" },  notes = "RemoveBatchByEMACCLASS")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emacclasses/{emacclass_id}/emplans/batch")
    public ResponseEntity<Boolean> removeBatchByEMACCLASS(@RequestBody List<String> ids) {
        emplanService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMACCLASS", tags = {"EMPLAN" },  notes = "GetDraftByEMACCLASS")
    @RequestMapping(method = RequestMethod.GET, value = "/emacclasses/{emacclass_id}/emplans/getdraft")
    public ResponseEntity<EMPLANDTO> getDraftByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id) {
        EMPLAN domain = new EMPLAN();
        domain.setAcclassid(emacclass_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanMapping.toDto(emplanService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByEMACCLASS", tags = {"EMPLAN" },  notes = "CheckKeyByEMACCLASS")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplans/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @RequestBody EMPLANDTO emplandto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplanService.checkKey(emplanMapping.toDomain(emplandto)));
    }

    @ApiOperation(value = "SaveByEMACCLASS", tags = {"EMPLAN" },  notes = "SaveByEMACCLASS")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplans/save")
    public ResponseEntity<Boolean> saveByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setAcclassid(emacclass_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMACCLASS", tags = {"EMPLAN" },  notes = "SaveBatchByEMACCLASS")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplans/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
             domain.setAcclassid(emacclass_id);
        }
        emplanService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMACCLASS", tags = {"EMPLAN" } ,notes = "fetchDEFAULTByEMACCLASS")
    @RequestMapping(method= RequestMethod.GET , value="/emacclasses/{emacclass_id}/emplans/fetchdefault")
	public ResponseEntity<List<EMPLANDTO>> fetchEMPLANDefaultByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id,EMPLANSearchContext context) {
        context.setN_acclassid_eq(emacclass_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
        List<EMPLANDTO> list = emplanMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMACCLASS", tags = {"EMPLAN" } ,notes = "searchDEFAULTByEMACCLASS")
    @RequestMapping(method= RequestMethod.GET , value="/emacclasses/{emacclass_id}/emplans/searchdefault")
	public ResponseEntity<Page<EMPLANDTO>> searchEMPLANDefaultByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id,EMPLANSearchContext context) {
        context.setN_acclassid_eq(emacclass_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplanMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "CreateByEMEQUIP", tags = {"EMPLAN" },  notes = "CreateByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emplans")
    @Transactional
    public ResponseEntity<EMPLANDTO> createByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setEquipid(emequip_id);
		emplanService.create(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMEQUIP", tags = {"EMPLAN" },  notes = "createBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emplans/batch")
    public ResponseEntity<Boolean> createBatchByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emplanService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMEQUIP", tags = {"EMPLAN" },  notes = "UpdateByEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emequips/{emequip_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<EMPLANDTO> updateByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setEquipid(emequip_id);
        domain.setEmplanid(emplan_id);
		emplanService.update(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMEQUIP", tags = {"EMPLAN" },  notes = "UpdateBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emequips/{emequip_id}/emplans/batch")
    public ResponseEntity<Boolean> updateBatchByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emplanService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMEQUIP", tags = {"EMPLAN" },  notes = "GetByEMEQUIP")
	@RequestMapping(method = RequestMethod.GET, value = "/emequips/{emequip_id}/emplans/{emplan_id}")
    public ResponseEntity<EMPLANDTO> getByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLAN domain = emplanService.get(emplan_id);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByEMEQUIP", tags = {"EMPLAN" },  notes = "RemoveByEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emequips/{emequip_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplanService.remove(emplan_id));
    }

    @ApiOperation(value = "RemoveBatchByEMEQUIP", tags = {"EMPLAN" },  notes = "RemoveBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emequips/{emequip_id}/emplans/batch")
    public ResponseEntity<Boolean> removeBatchByEMEQUIP(@RequestBody List<String> ids) {
        emplanService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMEQUIP", tags = {"EMPLAN" },  notes = "GetDraftByEMEQUIP")
    @RequestMapping(method = RequestMethod.GET, value = "/emequips/{emequip_id}/emplans/getdraft")
    public ResponseEntity<EMPLANDTO> getDraftByEMEQUIP(@PathVariable("emequip_id") String emequip_id) {
        EMPLAN domain = new EMPLAN();
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanMapping.toDto(emplanService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByEMEQUIP", tags = {"EMPLAN" },  notes = "CheckKeyByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emplans/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody EMPLANDTO emplandto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplanService.checkKey(emplanMapping.toDomain(emplandto)));
    }

    @ApiOperation(value = "SaveByEMEQUIP", tags = {"EMPLAN" },  notes = "SaveByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emplans/save")
    public ResponseEntity<Boolean> saveByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMEQUIP", tags = {"EMPLAN" },  notes = "SaveBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emplans/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
             domain.setEquipid(emequip_id);
        }
        emplanService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMEQUIP", tags = {"EMPLAN" } ,notes = "fetchDEFAULTByEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emequips/{emequip_id}/emplans/fetchdefault")
	public ResponseEntity<List<EMPLANDTO>> fetchEMPLANDefaultByEMEQUIP(@PathVariable("emequip_id") String emequip_id,EMPLANSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
        List<EMPLANDTO> list = emplanMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMEQUIP", tags = {"EMPLAN" } ,notes = "searchDEFAULTByEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emequips/{emequip_id}/emplans/searchdefault")
	public ResponseEntity<Page<EMPLANDTO>> searchEMPLANDefaultByEMEQUIP(@PathVariable("emequip_id") String emequip_id,EMPLANSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplanMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "CreateByEMPLANTEMPL", tags = {"EMPLAN" },  notes = "CreateByEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/emplantempls/{emplantempl_id}/emplans")
    @Transactional
    public ResponseEntity<EMPLANDTO> createByEMPLANTEMPL(@PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
		emplanService.create(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMPLANTEMPL", tags = {"EMPLAN" },  notes = "createBatchByEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> createBatchByEMPLANTEMPL(@PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setPlantemplid(emplantempl_id);
        }
        emplanService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMPLANTEMPL", tags = {"EMPLAN" },  notes = "UpdateByEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.PUT, value = "/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<EMPLANDTO> updateByEMPLANTEMPL(@PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
        domain.setEmplanid(emplan_id);
		emplanService.update(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMPLANTEMPL", tags = {"EMPLAN" },  notes = "UpdateBatchByEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.PUT, value = "/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> updateBatchByEMPLANTEMPL(@PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setPlantemplid(emplantempl_id);
        }
        emplanService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMPLANTEMPL", tags = {"EMPLAN" },  notes = "GetByEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.GET, value = "/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    public ResponseEntity<EMPLANDTO> getByEMPLANTEMPL(@PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLAN domain = emplanService.get(emplan_id);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByEMPLANTEMPL", tags = {"EMPLAN" },  notes = "RemoveByEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMPLANTEMPL(@PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplanService.remove(emplan_id));
    }

    @ApiOperation(value = "RemoveBatchByEMPLANTEMPL", tags = {"EMPLAN" },  notes = "RemoveBatchByEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> removeBatchByEMPLANTEMPL(@RequestBody List<String> ids) {
        emplanService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMPLANTEMPL", tags = {"EMPLAN" },  notes = "GetDraftByEMPLANTEMPL")
    @RequestMapping(method = RequestMethod.GET, value = "/emplantempls/{emplantempl_id}/emplans/getdraft")
    public ResponseEntity<EMPLANDTO> getDraftByEMPLANTEMPL(@PathVariable("emplantempl_id") String emplantempl_id) {
        EMPLAN domain = new EMPLAN();
        domain.setPlantemplid(emplantempl_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanMapping.toDto(emplanService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByEMPLANTEMPL", tags = {"EMPLAN" },  notes = "CheckKeyByEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/emplantempls/{emplantempl_id}/emplans/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMPLANTEMPL(@PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplanService.checkKey(emplanMapping.toDomain(emplandto)));
    }

    @ApiOperation(value = "SaveByEMPLANTEMPL", tags = {"EMPLAN" },  notes = "SaveByEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/emplantempls/{emplantempl_id}/emplans/save")
    public ResponseEntity<Boolean> saveByEMPLANTEMPL(@PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMPLANTEMPL", tags = {"EMPLAN" },  notes = "SaveBatchByEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/emplantempls/{emplantempl_id}/emplans/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMPLANTEMPL(@PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
             domain.setPlantemplid(emplantempl_id);
        }
        emplanService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMPLANTEMPL", tags = {"EMPLAN" } ,notes = "fetchDEFAULTByEMPLANTEMPL")
    @RequestMapping(method= RequestMethod.GET , value="/emplantempls/{emplantempl_id}/emplans/fetchdefault")
	public ResponseEntity<List<EMPLANDTO>> fetchEMPLANDefaultByEMPLANTEMPL(@PathVariable("emplantempl_id") String emplantempl_id,EMPLANSearchContext context) {
        context.setN_plantemplid_eq(emplantempl_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
        List<EMPLANDTO> list = emplanMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMPLANTEMPL", tags = {"EMPLAN" } ,notes = "searchDEFAULTByEMPLANTEMPL")
    @RequestMapping(method= RequestMethod.GET , value="/emplantempls/{emplantempl_id}/emplans/searchdefault")
	public ResponseEntity<Page<EMPLANDTO>> searchEMPLANDefaultByEMPLANTEMPL(@PathVariable("emplantempl_id") String emplantempl_id,EMPLANSearchContext context) {
        context.setN_plantemplid_eq(emplantempl_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplanMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "CreateByEMSERVICE", tags = {"EMPLAN" },  notes = "CreateByEMSERVICE")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplans")
    @Transactional
    public ResponseEntity<EMPLANDTO> createByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setRserviceid(emservice_id);
		emplanService.create(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSERVICE", tags = {"EMPLAN" },  notes = "createBatchByEMSERVICE")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplans/batch")
    public ResponseEntity<Boolean> createBatchByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setRserviceid(emservice_id);
        }
        emplanService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMSERVICE", tags = {"EMPLAN" },  notes = "UpdateByEMSERVICE")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<EMPLANDTO> updateByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setRserviceid(emservice_id);
        domain.setEmplanid(emplan_id);
		emplanService.update(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSERVICE", tags = {"EMPLAN" },  notes = "UpdateBatchByEMSERVICE")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emplans/batch")
    public ResponseEntity<Boolean> updateBatchByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setRserviceid(emservice_id);
        }
        emplanService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSERVICE", tags = {"EMPLAN" },  notes = "GetByEMSERVICE")
	@RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emplans/{emplan_id}")
    public ResponseEntity<EMPLANDTO> getByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLAN domain = emplanService.get(emplan_id);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByEMSERVICE", tags = {"EMPLAN" },  notes = "RemoveByEMSERVICE")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplan_id") String emplan_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplanService.remove(emplan_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSERVICE", tags = {"EMPLAN" },  notes = "RemoveBatchByEMSERVICE")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emplans/batch")
    public ResponseEntity<Boolean> removeBatchByEMSERVICE(@RequestBody List<String> ids) {
        emplanService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSERVICE", tags = {"EMPLAN" },  notes = "GetDraftByEMSERVICE")
    @RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emplans/getdraft")
    public ResponseEntity<EMPLANDTO> getDraftByEMSERVICE(@PathVariable("emservice_id") String emservice_id) {
        EMPLAN domain = new EMPLAN();
        domain.setRserviceid(emservice_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanMapping.toDto(emplanService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByEMSERVICE", tags = {"EMPLAN" },  notes = "CheckKeyByEMSERVICE")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplans/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody EMPLANDTO emplandto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplanService.checkKey(emplanMapping.toDomain(emplandto)));
    }

    @ApiOperation(value = "SaveByEMSERVICE", tags = {"EMPLAN" },  notes = "SaveByEMSERVICE")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplans/save")
    public ResponseEntity<Boolean> saveByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setRserviceid(emservice_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSERVICE", tags = {"EMPLAN" },  notes = "SaveBatchByEMSERVICE")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplans/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
             domain.setRserviceid(emservice_id);
        }
        emplanService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMSERVICE", tags = {"EMPLAN" } ,notes = "fetchDEFAULTByEMSERVICE")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emplans/fetchdefault")
	public ResponseEntity<List<EMPLANDTO>> fetchEMPLANDefaultByEMSERVICE(@PathVariable("emservice_id") String emservice_id,EMPLANSearchContext context) {
        context.setN_rserviceid_eq(emservice_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
        List<EMPLANDTO> list = emplanMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSERVICE", tags = {"EMPLAN" } ,notes = "searchDEFAULTByEMSERVICE")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emplans/searchdefault")
	public ResponseEntity<Page<EMPLANDTO>> searchEMPLANDefaultByEMSERVICE(@PathVariable("emservice_id") String emservice_id,EMPLANSearchContext context) {
        context.setN_rserviceid_eq(emservice_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplanMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "CreateByPFDEPT", tags = {"EMPLAN" },  notes = "CreateByPFDEPT")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplans")
    @Transactional
    public ResponseEntity<EMPLANDTO> createByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setRdeptid(pfdept_id);
		emplanService.create(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFDEPT", tags = {"EMPLAN" },  notes = "createBatchByPFDEPT")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplans/batch")
    public ResponseEntity<Boolean> createBatchByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setRdeptid(pfdept_id);
        }
        emplanService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByPFDEPT", tags = {"EMPLAN" },  notes = "UpdateByPFDEPT")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfdepts/{pfdept_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<EMPLANDTO> updateByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setRdeptid(pfdept_id);
        domain.setEmplanid(emplan_id);
		emplanService.update(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFDEPT", tags = {"EMPLAN" },  notes = "UpdateBatchByPFDEPT")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfdepts/{pfdept_id}/emplans/batch")
    public ResponseEntity<Boolean> updateBatchByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setRdeptid(pfdept_id);
        }
        emplanService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFDEPT", tags = {"EMPLAN" },  notes = "GetByPFDEPT")
	@RequestMapping(method = RequestMethod.GET, value = "/pfdepts/{pfdept_id}/emplans/{emplan_id}")
    public ResponseEntity<EMPLANDTO> getByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLAN domain = emplanService.get(emplan_id);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByPFDEPT", tags = {"EMPLAN" },  notes = "RemoveByPFDEPT")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfdepts/{pfdept_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplan_id") String emplan_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplanService.remove(emplan_id));
    }

    @ApiOperation(value = "RemoveBatchByPFDEPT", tags = {"EMPLAN" },  notes = "RemoveBatchByPFDEPT")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfdepts/{pfdept_id}/emplans/batch")
    public ResponseEntity<Boolean> removeBatchByPFDEPT(@RequestBody List<String> ids) {
        emplanService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFDEPT", tags = {"EMPLAN" },  notes = "GetDraftByPFDEPT")
    @RequestMapping(method = RequestMethod.GET, value = "/pfdepts/{pfdept_id}/emplans/getdraft")
    public ResponseEntity<EMPLANDTO> getDraftByPFDEPT(@PathVariable("pfdept_id") String pfdept_id) {
        EMPLAN domain = new EMPLAN();
        domain.setRdeptid(pfdept_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanMapping.toDto(emplanService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByPFDEPT", tags = {"EMPLAN" },  notes = "CheckKeyByPFDEPT")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplans/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @RequestBody EMPLANDTO emplandto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplanService.checkKey(emplanMapping.toDomain(emplandto)));
    }

    @ApiOperation(value = "SaveByPFDEPT", tags = {"EMPLAN" },  notes = "SaveByPFDEPT")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplans/save")
    public ResponseEntity<Boolean> saveByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setRdeptid(pfdept_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFDEPT", tags = {"EMPLAN" },  notes = "SaveBatchByPFDEPT")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplans/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
             domain.setRdeptid(pfdept_id);
        }
        emplanService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFDEPT", tags = {"EMPLAN" } ,notes = "fetchDEFAULTByPFDEPT")
    @RequestMapping(method= RequestMethod.GET , value="/pfdepts/{pfdept_id}/emplans/fetchdefault")
	public ResponseEntity<List<EMPLANDTO>> fetchEMPLANDefaultByPFDEPT(@PathVariable("pfdept_id") String pfdept_id,EMPLANSearchContext context) {
        context.setN_rdeptid_eq(pfdept_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
        List<EMPLANDTO> list = emplanMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFDEPT", tags = {"EMPLAN" } ,notes = "searchDEFAULTByPFDEPT")
    @RequestMapping(method= RequestMethod.GET , value="/pfdepts/{pfdept_id}/emplans/searchdefault")
	public ResponseEntity<Page<EMPLANDTO>> searchEMPLANDefaultByPFDEPT(@PathVariable("pfdept_id") String pfdept_id,EMPLANSearchContext context) {
        context.setN_rdeptid_eq(pfdept_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplanMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "CreateByPFEMP", tags = {"EMPLAN" },  notes = "CreateByPFEMP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplans")
    @Transactional
    public ResponseEntity<EMPLANDTO> createByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setMpersonid(pfemp_id);
		emplanService.create(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFEMP", tags = {"EMPLAN" },  notes = "createBatchByPFEMP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplans/batch")
    public ResponseEntity<Boolean> createBatchByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setMpersonid(pfemp_id);
        }
        emplanService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByPFEMP", tags = {"EMPLAN" },  notes = "UpdateByPFEMP")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<EMPLANDTO> updateByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setMpersonid(pfemp_id);
        domain.setEmplanid(emplan_id);
		emplanService.update(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFEMP", tags = {"EMPLAN" },  notes = "UpdateBatchByPFEMP")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emplans/batch")
    public ResponseEntity<Boolean> updateBatchByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setMpersonid(pfemp_id);
        }
        emplanService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFEMP", tags = {"EMPLAN" },  notes = "GetByPFEMP")
	@RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emplans/{emplan_id}")
    public ResponseEntity<EMPLANDTO> getByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLAN domain = emplanService.get(emplan_id);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByPFEMP", tags = {"EMPLAN" },  notes = "RemoveByPFEMP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplan_id") String emplan_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplanService.remove(emplan_id));
    }

    @ApiOperation(value = "RemoveBatchByPFEMP", tags = {"EMPLAN" },  notes = "RemoveBatchByPFEMP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emplans/batch")
    public ResponseEntity<Boolean> removeBatchByPFEMP(@RequestBody List<String> ids) {
        emplanService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFEMP", tags = {"EMPLAN" },  notes = "GetDraftByPFEMP")
    @RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emplans/getdraft")
    public ResponseEntity<EMPLANDTO> getDraftByPFEMP(@PathVariable("pfemp_id") String pfemp_id) {
        EMPLAN domain = new EMPLAN();
        domain.setMpersonid(pfemp_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanMapping.toDto(emplanService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByPFEMP", tags = {"EMPLAN" },  notes = "CheckKeyByPFEMP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplans/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody EMPLANDTO emplandto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplanService.checkKey(emplanMapping.toDomain(emplandto)));
    }

    @ApiOperation(value = "SaveByPFEMP", tags = {"EMPLAN" },  notes = "SaveByPFEMP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplans/save")
    public ResponseEntity<Boolean> saveByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setMpersonid(pfemp_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFEMP", tags = {"EMPLAN" },  notes = "SaveBatchByPFEMP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplans/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
             domain.setMpersonid(pfemp_id);
        }
        emplanService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFEMP", tags = {"EMPLAN" } ,notes = "fetchDEFAULTByPFEMP")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emplans/fetchdefault")
	public ResponseEntity<List<EMPLANDTO>> fetchEMPLANDefaultByPFEMP(@PathVariable("pfemp_id") String pfemp_id,EMPLANSearchContext context) {
        context.setN_mpersonid_eq(pfemp_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
        List<EMPLANDTO> list = emplanMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFEMP", tags = {"EMPLAN" } ,notes = "searchDEFAULTByPFEMP")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emplans/searchdefault")
	public ResponseEntity<Page<EMPLANDTO>> searchEMPLANDefaultByPFEMP(@PathVariable("pfemp_id") String pfemp_id,EMPLANSearchContext context) {
        context.setN_mpersonid_eq(pfemp_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplanMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "CreateByPFTEAM", tags = {"EMPLAN" },  notes = "CreateByPFTEAM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplans")
    @Transactional
    public ResponseEntity<EMPLANDTO> createByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setRteamid(pfteam_id);
		emplanService.create(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFTEAM", tags = {"EMPLAN" },  notes = "createBatchByPFTEAM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplans/batch")
    public ResponseEntity<Boolean> createBatchByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setRteamid(pfteam_id);
        }
        emplanService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByPFTEAM", tags = {"EMPLAN" },  notes = "UpdateByPFTEAM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<EMPLANDTO> updateByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setRteamid(pfteam_id);
        domain.setEmplanid(emplan_id);
		emplanService.update(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFTEAM", tags = {"EMPLAN" },  notes = "UpdateBatchByPFTEAM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emplans/batch")
    public ResponseEntity<Boolean> updateBatchByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setRteamid(pfteam_id);
        }
        emplanService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFTEAM", tags = {"EMPLAN" },  notes = "GetByPFTEAM")
	@RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emplans/{emplan_id}")
    public ResponseEntity<EMPLANDTO> getByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLAN domain = emplanService.get(emplan_id);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByPFTEAM", tags = {"EMPLAN" },  notes = "RemoveByPFTEAM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplan_id") String emplan_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplanService.remove(emplan_id));
    }

    @ApiOperation(value = "RemoveBatchByPFTEAM", tags = {"EMPLAN" },  notes = "RemoveBatchByPFTEAM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emplans/batch")
    public ResponseEntity<Boolean> removeBatchByPFTEAM(@RequestBody List<String> ids) {
        emplanService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFTEAM", tags = {"EMPLAN" },  notes = "GetDraftByPFTEAM")
    @RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emplans/getdraft")
    public ResponseEntity<EMPLANDTO> getDraftByPFTEAM(@PathVariable("pfteam_id") String pfteam_id) {
        EMPLAN domain = new EMPLAN();
        domain.setRteamid(pfteam_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanMapping.toDto(emplanService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByPFTEAM", tags = {"EMPLAN" },  notes = "CheckKeyByPFTEAM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplans/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody EMPLANDTO emplandto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplanService.checkKey(emplanMapping.toDomain(emplandto)));
    }

    @ApiOperation(value = "SaveByPFTEAM", tags = {"EMPLAN" },  notes = "SaveByPFTEAM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplans/save")
    public ResponseEntity<Boolean> saveByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setRteamid(pfteam_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFTEAM", tags = {"EMPLAN" },  notes = "SaveBatchByPFTEAM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplans/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
             domain.setRteamid(pfteam_id);
        }
        emplanService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFTEAM", tags = {"EMPLAN" } ,notes = "fetchDEFAULTByPFTEAM")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emplans/fetchdefault")
	public ResponseEntity<List<EMPLANDTO>> fetchEMPLANDefaultByPFTEAM(@PathVariable("pfteam_id") String pfteam_id,EMPLANSearchContext context) {
        context.setN_rteamid_eq(pfteam_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
        List<EMPLANDTO> list = emplanMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFTEAM", tags = {"EMPLAN" } ,notes = "searchDEFAULTByPFTEAM")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emplans/searchdefault")
	public ResponseEntity<Page<EMPLANDTO>> searchEMPLANDefaultByPFTEAM(@PathVariable("pfteam_id") String pfteam_id,EMPLANSearchContext context) {
        context.setN_rteamid_eq(pfteam_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplanMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CreateByEMEQTYPEEMEQUIP", tags = {"EMPLAN" },  notes = "CreateByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans")
    @Transactional
    public ResponseEntity<EMPLANDTO> createByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setEquipid(emequip_id);
		emplanService.create(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMEQTYPEEMEQUIP", tags = {"EMPLAN" },  notes = "createBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/batch")
    public ResponseEntity<Boolean> createBatchByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emplanService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMEQTYPEEMEQUIP", tags = {"EMPLAN" },  notes = "UpdateByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<EMPLANDTO> updateByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setEquipid(emequip_id);
        domain.setEmplanid(emplan_id);
		emplanService.update(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMEQTYPEEMEQUIP", tags = {"EMPLAN" },  notes = "UpdateBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/batch")
    public ResponseEntity<Boolean> updateBatchByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emplanService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMEQTYPEEMEQUIP", tags = {"EMPLAN" },  notes = "GetByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.GET, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/{emplan_id}")
    public ResponseEntity<EMPLANDTO> getByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLAN domain = emplanService.get(emplan_id);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByEMEQTYPEEMEQUIP", tags = {"EMPLAN" },  notes = "RemoveByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplanService.remove(emplan_id));
    }

    @ApiOperation(value = "RemoveBatchByEMEQTYPEEMEQUIP", tags = {"EMPLAN" },  notes = "RemoveBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/batch")
    public ResponseEntity<Boolean> removeBatchByEMEQTYPEEMEQUIP(@RequestBody List<String> ids) {
        emplanService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMEQTYPEEMEQUIP", tags = {"EMPLAN" },  notes = "GetDraftByEMEQTYPEEMEQUIP")
    @RequestMapping(method = RequestMethod.GET, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/getdraft")
    public ResponseEntity<EMPLANDTO> getDraftByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id) {
        EMPLAN domain = new EMPLAN();
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanMapping.toDto(emplanService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByEMEQTYPEEMEQUIP", tags = {"EMPLAN" },  notes = "CheckKeyByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMPLANDTO emplandto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplanService.checkKey(emplanMapping.toDomain(emplandto)));
    }

    @ApiOperation(value = "SaveByEMEQTYPEEMEQUIP", tags = {"EMPLAN" },  notes = "SaveByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/save")
    public ResponseEntity<Boolean> saveByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMEQTYPEEMEQUIP", tags = {"EMPLAN" },  notes = "SaveBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
             domain.setEquipid(emequip_id);
        }
        emplanService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMEQTYPEEMEQUIP", tags = {"EMPLAN" } ,notes = "fetchDEFAULTByEMEQTYPEEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/fetchdefault")
	public ResponseEntity<List<EMPLANDTO>> fetchEMPLANDefaultByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id,EMPLANSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
        List<EMPLANDTO> list = emplanMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMEQTYPEEMEQUIP", tags = {"EMPLAN" } ,notes = "searchDEFAULTByEMEQTYPEEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emplans/searchdefault")
	public ResponseEntity<Page<EMPLANDTO>> searchEMPLANDefaultByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id,EMPLANSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplanMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CreateByPFTEAMEMEQUIP", tags = {"EMPLAN" },  notes = "CreateByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans")
    @Transactional
    public ResponseEntity<EMPLANDTO> createByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setEquipid(emequip_id);
		emplanService.create(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFTEAMEMEQUIP", tags = {"EMPLAN" },  notes = "createBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/batch")
    public ResponseEntity<Boolean> createBatchByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emplanService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByPFTEAMEMEQUIP", tags = {"EMPLAN" },  notes = "UpdateByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<EMPLANDTO> updateByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setEquipid(emequip_id);
        domain.setEmplanid(emplan_id);
		emplanService.update(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFTEAMEMEQUIP", tags = {"EMPLAN" },  notes = "UpdateBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/batch")
    public ResponseEntity<Boolean> updateBatchByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emplanService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFTEAMEMEQUIP", tags = {"EMPLAN" },  notes = "GetByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/{emplan_id}")
    public ResponseEntity<EMPLANDTO> getByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLAN domain = emplanService.get(emplan_id);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByPFTEAMEMEQUIP", tags = {"EMPLAN" },  notes = "RemoveByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emplan_id") String emplan_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplanService.remove(emplan_id));
    }

    @ApiOperation(value = "RemoveBatchByPFTEAMEMEQUIP", tags = {"EMPLAN" },  notes = "RemoveBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/batch")
    public ResponseEntity<Boolean> removeBatchByPFTEAMEMEQUIP(@RequestBody List<String> ids) {
        emplanService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFTEAMEMEQUIP", tags = {"EMPLAN" },  notes = "GetDraftByPFTEAMEMEQUIP")
    @RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/getdraft")
    public ResponseEntity<EMPLANDTO> getDraftByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id) {
        EMPLAN domain = new EMPLAN();
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanMapping.toDto(emplanService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByPFTEAMEMEQUIP", tags = {"EMPLAN" },  notes = "CheckKeyByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMPLANDTO emplandto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplanService.checkKey(emplanMapping.toDomain(emplandto)));
    }

    @ApiOperation(value = "SaveByPFTEAMEMEQUIP", tags = {"EMPLAN" },  notes = "SaveByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/save")
    public ResponseEntity<Boolean> saveByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFTEAMEMEQUIP", tags = {"EMPLAN" },  notes = "SaveBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
             domain.setEquipid(emequip_id);
        }
        emplanService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFTEAMEMEQUIP", tags = {"EMPLAN" } ,notes = "fetchDEFAULTByPFTEAMEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/fetchdefault")
	public ResponseEntity<List<EMPLANDTO>> fetchEMPLANDefaultByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id,EMPLANSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
        List<EMPLANDTO> list = emplanMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFTEAMEMEQUIP", tags = {"EMPLAN" } ,notes = "searchDEFAULTByPFTEAMEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emequips/{emequip_id}/emplans/searchdefault")
	public ResponseEntity<Page<EMPLANDTO>> searchEMPLANDefaultByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id,EMPLANSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplanMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CreateByEMACCLASSEMPLANTEMPL", tags = {"EMPLAN" },  notes = "CreateByEMACCLASSEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans")
    @Transactional
    public ResponseEntity<EMPLANDTO> createByEMACCLASSEMPLANTEMPL(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
		emplanService.create(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMACCLASSEMPLANTEMPL", tags = {"EMPLAN" },  notes = "createBatchByEMACCLASSEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> createBatchByEMACCLASSEMPLANTEMPL(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setPlantemplid(emplantempl_id);
        }
        emplanService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMACCLASSEMPLANTEMPL", tags = {"EMPLAN" },  notes = "UpdateByEMACCLASSEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.PUT, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<EMPLANDTO> updateByEMACCLASSEMPLANTEMPL(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
        domain.setEmplanid(emplan_id);
		emplanService.update(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMACCLASSEMPLANTEMPL", tags = {"EMPLAN" },  notes = "UpdateBatchByEMACCLASSEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.PUT, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> updateBatchByEMACCLASSEMPLANTEMPL(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setPlantemplid(emplantempl_id);
        }
        emplanService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMACCLASSEMPLANTEMPL", tags = {"EMPLAN" },  notes = "GetByEMACCLASSEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.GET, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    public ResponseEntity<EMPLANDTO> getByEMACCLASSEMPLANTEMPL(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLAN domain = emplanService.get(emplan_id);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByEMACCLASSEMPLANTEMPL", tags = {"EMPLAN" },  notes = "RemoveByEMACCLASSEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMACCLASSEMPLANTEMPL(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplanService.remove(emplan_id));
    }

    @ApiOperation(value = "RemoveBatchByEMACCLASSEMPLANTEMPL", tags = {"EMPLAN" },  notes = "RemoveBatchByEMACCLASSEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> removeBatchByEMACCLASSEMPLANTEMPL(@RequestBody List<String> ids) {
        emplanService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMACCLASSEMPLANTEMPL", tags = {"EMPLAN" },  notes = "GetDraftByEMACCLASSEMPLANTEMPL")
    @RequestMapping(method = RequestMethod.GET, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/getdraft")
    public ResponseEntity<EMPLANDTO> getDraftByEMACCLASSEMPLANTEMPL(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id) {
        EMPLAN domain = new EMPLAN();
        domain.setPlantemplid(emplantempl_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanMapping.toDto(emplanService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByEMACCLASSEMPLANTEMPL", tags = {"EMPLAN" },  notes = "CheckKeyByEMACCLASSEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMACCLASSEMPLANTEMPL(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplanService.checkKey(emplanMapping.toDomain(emplandto)));
    }

    @ApiOperation(value = "SaveByEMACCLASSEMPLANTEMPL", tags = {"EMPLAN" },  notes = "SaveByEMACCLASSEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/save")
    public ResponseEntity<Boolean> saveByEMACCLASSEMPLANTEMPL(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMACCLASSEMPLANTEMPL", tags = {"EMPLAN" },  notes = "SaveBatchByEMACCLASSEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMACCLASSEMPLANTEMPL(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
             domain.setPlantemplid(emplantempl_id);
        }
        emplanService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMACCLASSEMPLANTEMPL", tags = {"EMPLAN" } ,notes = "fetchDEFAULTByEMACCLASSEMPLANTEMPL")
    @RequestMapping(method= RequestMethod.GET , value="/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/fetchdefault")
	public ResponseEntity<List<EMPLANDTO>> fetchEMPLANDefaultByEMACCLASSEMPLANTEMPL(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id,EMPLANSearchContext context) {
        context.setN_plantemplid_eq(emplantempl_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
        List<EMPLANDTO> list = emplanMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMACCLASSEMPLANTEMPL", tags = {"EMPLAN" } ,notes = "searchDEFAULTByEMACCLASSEMPLANTEMPL")
    @RequestMapping(method= RequestMethod.GET , value="/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}/emplans/searchdefault")
	public ResponseEntity<Page<EMPLANDTO>> searchEMPLANDefaultByEMACCLASSEMPLANTEMPL(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id,EMPLANSearchContext context) {
        context.setN_plantemplid_eq(emplantempl_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplanMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CreateByEMSERVICEEMPLANTEMPL", tags = {"EMPLAN" },  notes = "CreateByEMSERVICEEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans")
    @Transactional
    public ResponseEntity<EMPLANDTO> createByEMSERVICEEMPLANTEMPL(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
		emplanService.create(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSERVICEEMPLANTEMPL", tags = {"EMPLAN" },  notes = "createBatchByEMSERVICEEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> createBatchByEMSERVICEEMPLANTEMPL(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setPlantemplid(emplantempl_id);
        }
        emplanService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMSERVICEEMPLANTEMPL", tags = {"EMPLAN" },  notes = "UpdateByEMSERVICEEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<EMPLANDTO> updateByEMSERVICEEMPLANTEMPL(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
        domain.setEmplanid(emplan_id);
		emplanService.update(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSERVICEEMPLANTEMPL", tags = {"EMPLAN" },  notes = "UpdateBatchByEMSERVICEEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> updateBatchByEMSERVICEEMPLANTEMPL(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setPlantemplid(emplantempl_id);
        }
        emplanService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSERVICEEMPLANTEMPL", tags = {"EMPLAN" },  notes = "GetByEMSERVICEEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    public ResponseEntity<EMPLANDTO> getByEMSERVICEEMPLANTEMPL(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLAN domain = emplanService.get(emplan_id);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByEMSERVICEEMPLANTEMPL", tags = {"EMPLAN" },  notes = "RemoveByEMSERVICEEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSERVICEEMPLANTEMPL(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplanService.remove(emplan_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSERVICEEMPLANTEMPL", tags = {"EMPLAN" },  notes = "RemoveBatchByEMSERVICEEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> removeBatchByEMSERVICEEMPLANTEMPL(@RequestBody List<String> ids) {
        emplanService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSERVICEEMPLANTEMPL", tags = {"EMPLAN" },  notes = "GetDraftByEMSERVICEEMPLANTEMPL")
    @RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/getdraft")
    public ResponseEntity<EMPLANDTO> getDraftByEMSERVICEEMPLANTEMPL(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id) {
        EMPLAN domain = new EMPLAN();
        domain.setPlantemplid(emplantempl_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanMapping.toDto(emplanService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByEMSERVICEEMPLANTEMPL", tags = {"EMPLAN" },  notes = "CheckKeyByEMSERVICEEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSERVICEEMPLANTEMPL(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplanService.checkKey(emplanMapping.toDomain(emplandto)));
    }

    @ApiOperation(value = "SaveByEMSERVICEEMPLANTEMPL", tags = {"EMPLAN" },  notes = "SaveByEMSERVICEEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/save")
    public ResponseEntity<Boolean> saveByEMSERVICEEMPLANTEMPL(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSERVICEEMPLANTEMPL", tags = {"EMPLAN" },  notes = "SaveBatchByEMSERVICEEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSERVICEEMPLANTEMPL(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
             domain.setPlantemplid(emplantempl_id);
        }
        emplanService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMSERVICEEMPLANTEMPL", tags = {"EMPLAN" } ,notes = "fetchDEFAULTByEMSERVICEEMPLANTEMPL")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/fetchdefault")
	public ResponseEntity<List<EMPLANDTO>> fetchEMPLANDefaultByEMSERVICEEMPLANTEMPL(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id,EMPLANSearchContext context) {
        context.setN_plantemplid_eq(emplantempl_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
        List<EMPLANDTO> list = emplanMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSERVICEEMPLANTEMPL", tags = {"EMPLAN" } ,notes = "searchDEFAULTByEMSERVICEEMPLANTEMPL")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emplantempls/{emplantempl_id}/emplans/searchdefault")
	public ResponseEntity<Page<EMPLANDTO>> searchEMPLANDefaultByEMSERVICEEMPLANTEMPL(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id,EMPLANSearchContext context) {
        context.setN_plantemplid_eq(emplantempl_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplanMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CreateByPFDEPTEMPLANTEMPL", tags = {"EMPLAN" },  notes = "CreateByPFDEPTEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans")
    @Transactional
    public ResponseEntity<EMPLANDTO> createByPFDEPTEMPLANTEMPL(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
		emplanService.create(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFDEPTEMPLANTEMPL", tags = {"EMPLAN" },  notes = "createBatchByPFDEPTEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> createBatchByPFDEPTEMPLANTEMPL(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setPlantemplid(emplantempl_id);
        }
        emplanService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByPFDEPTEMPLANTEMPL", tags = {"EMPLAN" },  notes = "UpdateByPFDEPTEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<EMPLANDTO> updateByPFDEPTEMPLANTEMPL(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
        domain.setEmplanid(emplan_id);
		emplanService.update(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFDEPTEMPLANTEMPL", tags = {"EMPLAN" },  notes = "UpdateBatchByPFDEPTEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> updateBatchByPFDEPTEMPLANTEMPL(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setPlantemplid(emplantempl_id);
        }
        emplanService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFDEPTEMPLANTEMPL", tags = {"EMPLAN" },  notes = "GetByPFDEPTEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.GET, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    public ResponseEntity<EMPLANDTO> getByPFDEPTEMPLANTEMPL(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLAN domain = emplanService.get(emplan_id);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByPFDEPTEMPLANTEMPL", tags = {"EMPLAN" },  notes = "RemoveByPFDEPTEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFDEPTEMPLANTEMPL(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplanService.remove(emplan_id));
    }

    @ApiOperation(value = "RemoveBatchByPFDEPTEMPLANTEMPL", tags = {"EMPLAN" },  notes = "RemoveBatchByPFDEPTEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> removeBatchByPFDEPTEMPLANTEMPL(@RequestBody List<String> ids) {
        emplanService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFDEPTEMPLANTEMPL", tags = {"EMPLAN" },  notes = "GetDraftByPFDEPTEMPLANTEMPL")
    @RequestMapping(method = RequestMethod.GET, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/getdraft")
    public ResponseEntity<EMPLANDTO> getDraftByPFDEPTEMPLANTEMPL(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id) {
        EMPLAN domain = new EMPLAN();
        domain.setPlantemplid(emplantempl_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanMapping.toDto(emplanService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByPFDEPTEMPLANTEMPL", tags = {"EMPLAN" },  notes = "CheckKeyByPFDEPTEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFDEPTEMPLANTEMPL(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplanService.checkKey(emplanMapping.toDomain(emplandto)));
    }

    @ApiOperation(value = "SaveByPFDEPTEMPLANTEMPL", tags = {"EMPLAN" },  notes = "SaveByPFDEPTEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/save")
    public ResponseEntity<Boolean> saveByPFDEPTEMPLANTEMPL(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFDEPTEMPLANTEMPL", tags = {"EMPLAN" },  notes = "SaveBatchByPFDEPTEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFDEPTEMPLANTEMPL(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
             domain.setPlantemplid(emplantempl_id);
        }
        emplanService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFDEPTEMPLANTEMPL", tags = {"EMPLAN" } ,notes = "fetchDEFAULTByPFDEPTEMPLANTEMPL")
    @RequestMapping(method= RequestMethod.GET , value="/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/fetchdefault")
	public ResponseEntity<List<EMPLANDTO>> fetchEMPLANDefaultByPFDEPTEMPLANTEMPL(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id,EMPLANSearchContext context) {
        context.setN_plantemplid_eq(emplantempl_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
        List<EMPLANDTO> list = emplanMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFDEPTEMPLANTEMPL", tags = {"EMPLAN" } ,notes = "searchDEFAULTByPFDEPTEMPLANTEMPL")
    @RequestMapping(method= RequestMethod.GET , value="/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}/emplans/searchdefault")
	public ResponseEntity<Page<EMPLANDTO>> searchEMPLANDefaultByPFDEPTEMPLANTEMPL(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id,EMPLANSearchContext context) {
        context.setN_plantemplid_eq(emplantempl_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplanMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CreateByPFEMPEMPLANTEMPL", tags = {"EMPLAN" },  notes = "CreateByPFEMPEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans")
    @Transactional
    public ResponseEntity<EMPLANDTO> createByPFEMPEMPLANTEMPL(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
		emplanService.create(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFEMPEMPLANTEMPL", tags = {"EMPLAN" },  notes = "createBatchByPFEMPEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> createBatchByPFEMPEMPLANTEMPL(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setPlantemplid(emplantempl_id);
        }
        emplanService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByPFEMPEMPLANTEMPL", tags = {"EMPLAN" },  notes = "UpdateByPFEMPEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<EMPLANDTO> updateByPFEMPEMPLANTEMPL(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
        domain.setEmplanid(emplan_id);
		emplanService.update(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFEMPEMPLANTEMPL", tags = {"EMPLAN" },  notes = "UpdateBatchByPFEMPEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> updateBatchByPFEMPEMPLANTEMPL(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setPlantemplid(emplantempl_id);
        }
        emplanService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFEMPEMPLANTEMPL", tags = {"EMPLAN" },  notes = "GetByPFEMPEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    public ResponseEntity<EMPLANDTO> getByPFEMPEMPLANTEMPL(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLAN domain = emplanService.get(emplan_id);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByPFEMPEMPLANTEMPL", tags = {"EMPLAN" },  notes = "RemoveByPFEMPEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFEMPEMPLANTEMPL(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplanService.remove(emplan_id));
    }

    @ApiOperation(value = "RemoveBatchByPFEMPEMPLANTEMPL", tags = {"EMPLAN" },  notes = "RemoveBatchByPFEMPEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> removeBatchByPFEMPEMPLANTEMPL(@RequestBody List<String> ids) {
        emplanService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFEMPEMPLANTEMPL", tags = {"EMPLAN" },  notes = "GetDraftByPFEMPEMPLANTEMPL")
    @RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/getdraft")
    public ResponseEntity<EMPLANDTO> getDraftByPFEMPEMPLANTEMPL(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id) {
        EMPLAN domain = new EMPLAN();
        domain.setPlantemplid(emplantempl_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanMapping.toDto(emplanService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByPFEMPEMPLANTEMPL", tags = {"EMPLAN" },  notes = "CheckKeyByPFEMPEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFEMPEMPLANTEMPL(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplanService.checkKey(emplanMapping.toDomain(emplandto)));
    }

    @ApiOperation(value = "SaveByPFEMPEMPLANTEMPL", tags = {"EMPLAN" },  notes = "SaveByPFEMPEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/save")
    public ResponseEntity<Boolean> saveByPFEMPEMPLANTEMPL(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFEMPEMPLANTEMPL", tags = {"EMPLAN" },  notes = "SaveBatchByPFEMPEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFEMPEMPLANTEMPL(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
             domain.setPlantemplid(emplantempl_id);
        }
        emplanService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFEMPEMPLANTEMPL", tags = {"EMPLAN" } ,notes = "fetchDEFAULTByPFEMPEMPLANTEMPL")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/fetchdefault")
	public ResponseEntity<List<EMPLANDTO>> fetchEMPLANDefaultByPFEMPEMPLANTEMPL(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id,EMPLANSearchContext context) {
        context.setN_plantemplid_eq(emplantempl_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
        List<EMPLANDTO> list = emplanMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFEMPEMPLANTEMPL", tags = {"EMPLAN" } ,notes = "searchDEFAULTByPFEMPEMPLANTEMPL")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}/emplans/searchdefault")
	public ResponseEntity<Page<EMPLANDTO>> searchEMPLANDefaultByPFEMPEMPLANTEMPL(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id,EMPLANSearchContext context) {
        context.setN_plantemplid_eq(emplantempl_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplanMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CreateByPFTEAMEMPLANTEMPL", tags = {"EMPLAN" },  notes = "CreateByPFTEAMEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans")
    @Transactional
    public ResponseEntity<EMPLANDTO> createByPFTEAMEMPLANTEMPL(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
		emplanService.create(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFTEAMEMPLANTEMPL", tags = {"EMPLAN" },  notes = "createBatchByPFTEAMEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> createBatchByPFTEAMEMPLANTEMPL(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setPlantemplid(emplantempl_id);
        }
        emplanService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByPFTEAMEMPLANTEMPL", tags = {"EMPLAN" },  notes = "UpdateByPFTEAMEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<EMPLANDTO> updateByPFTEAMEMPLANTEMPL(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
        domain.setEmplanid(emplan_id);
		emplanService.update(domain);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFTEAMEMPLANTEMPL", tags = {"EMPLAN" },  notes = "UpdateBatchByPFTEAMEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> updateBatchByPFTEAMEMPLANTEMPL(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
            domain.setPlantemplid(emplantempl_id);
        }
        emplanService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFTEAMEMPLANTEMPL", tags = {"EMPLAN" },  notes = "GetByPFTEAMEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    public ResponseEntity<EMPLANDTO> getByPFTEAMEMPLANTEMPL(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
        EMPLAN domain = emplanService.get(emplan_id);
        EMPLANDTO dto = emplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByPFTEAMEMPLANTEMPL", tags = {"EMPLAN" },  notes = "RemoveByPFTEAMEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/{emplan_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFTEAMEMPLANTEMPL(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @PathVariable("emplan_id") String emplan_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplanService.remove(emplan_id));
    }

    @ApiOperation(value = "RemoveBatchByPFTEAMEMPLANTEMPL", tags = {"EMPLAN" },  notes = "RemoveBatchByPFTEAMEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/batch")
    public ResponseEntity<Boolean> removeBatchByPFTEAMEMPLANTEMPL(@RequestBody List<String> ids) {
        emplanService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFTEAMEMPLANTEMPL", tags = {"EMPLAN" },  notes = "GetDraftByPFTEAMEMPLANTEMPL")
    @RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/getdraft")
    public ResponseEntity<EMPLANDTO> getDraftByPFTEAMEMPLANTEMPL(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id) {
        EMPLAN domain = new EMPLAN();
        domain.setPlantemplid(emplantempl_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanMapping.toDto(emplanService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByPFTEAMEMPLANTEMPL", tags = {"EMPLAN" },  notes = "CheckKeyByPFTEAMEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFTEAMEMPLANTEMPL(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplanService.checkKey(emplanMapping.toDomain(emplandto)));
    }

    @ApiOperation(value = "SaveByPFTEAMEMPLANTEMPL", tags = {"EMPLAN" },  notes = "SaveByPFTEAMEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/save")
    public ResponseEntity<Boolean> saveByPFTEAMEMPLANTEMPL(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANDTO emplandto) {
        EMPLAN domain = emplanMapping.toDomain(emplandto);
        domain.setPlantemplid(emplantempl_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplanService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFTEAMEMPLANTEMPL", tags = {"EMPLAN" },  notes = "SaveBatchByPFTEAMEMPLANTEMPL")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFTEAMEMPLANTEMPL(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody List<EMPLANDTO> emplandtos) {
        List<EMPLAN> domainlist=emplanMapping.toDomain(emplandtos);
        for(EMPLAN domain:domainlist){
             domain.setPlantemplid(emplantempl_id);
        }
        emplanService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFTEAMEMPLANTEMPL", tags = {"EMPLAN" } ,notes = "fetchDEFAULTByPFTEAMEMPLANTEMPL")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/fetchdefault")
	public ResponseEntity<List<EMPLANDTO>> fetchEMPLANDefaultByPFTEAMEMPLANTEMPL(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id,EMPLANSearchContext context) {
        context.setN_plantemplid_eq(emplantempl_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
        List<EMPLANDTO> list = emplanMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFTEAMEMPLANTEMPL", tags = {"EMPLAN" } ,notes = "searchDEFAULTByPFTEAMEMPLANTEMPL")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}/emplans/searchdefault")
	public ResponseEntity<Page<EMPLANDTO>> searchEMPLANDefaultByPFTEAMEMPLANTEMPL(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id,EMPLANSearchContext context) {
        context.setN_plantemplid_eq(emplantempl_id);
        Page<EMPLAN> domains = emplanService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplanMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMPLAN getEntity(){
        return new EMPLAN();
    }

}
