package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMPLANTEMPL;
import cn.ibizlab.eam.core.eam_core.service.IEMPLANTEMPLService;
import cn.ibizlab.eam.core.eam_core.filter.EMPLANTEMPLSearchContext;




@Slf4j
@Api(tags = {"EMPLANTEMPL" })
@RestController("WebApi-emplantempl")
@RequestMapping("")
public class EMPLANTEMPLResource {

    @Autowired
    private IEMPLANTEMPLService emplantemplService;

    @Autowired
    @Lazy
    private EMPLANTEMPLMapping emplantemplMapping;




    @PreAuthorize("hasPermission(#emplantempl_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMPLANTEMPL" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emplantempls/{emplantempl_id}")
    public ResponseEntity<EMPLANTEMPLDTO> get(@PathVariable("emplantempl_id") String emplantempl_id) {
        EMPLANTEMPL domain = emplantemplService.get(emplantempl_id);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMPLANTEMPL" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emplantempls/getdraft")
    public ResponseEntity<EMPLANTEMPLDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emplantemplMapping.toDto(emplantemplService.getDraft(new EMPLANTEMPL())));
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMPLANTEMPL" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emplantempls")
    @Transactional
    public ResponseEntity<EMPLANTEMPLDTO> create(@RequestBody EMPLANTEMPLDTO emplantempldto) {
        EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
		emplantemplService.create(domain);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMPLANTEMPL" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emplantempls/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        emplantemplService.createBatch(emplantemplMapping.toDomain(emplantempldtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emplantempl_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMPLANTEMPL" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emplantempls/{emplantempl_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emplantempl_id") String emplantempl_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emplantemplService.remove(emplantempl_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMPLANTEMPL" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emplantempls/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emplantemplService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMPLANTEMPL" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emplantempls/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMPLANTEMPLDTO emplantempldto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplantemplService.checkKey(emplantemplMapping.toDomain(emplantempldto)));
    }




    @PreAuthorize("hasPermission(#emplantempl_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMPLANTEMPL" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emplantempls/{emplantempl_id}")
    @Transactional
    public ResponseEntity<EMPLANTEMPLDTO> update(@PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
		EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
        domain.setEmplantemplid(emplantempl_id);
		emplantemplService.update(domain);
		EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emplantempl_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMPLANTEMPL" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emplantempls/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        emplantemplService.updateBatch(emplantemplMapping.toDomain(emplantempldtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"EMPLANTEMPL" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emplantempls/save")
    public ResponseEntity<Boolean> save(@RequestBody EMPLANTEMPLDTO emplantempldto) {
        return ResponseEntity.status(HttpStatus.OK).body(emplantemplService.save(emplantemplMapping.toDomain(emplantempldto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMPLANTEMPL" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emplantempls/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        emplantemplService.saveBatch(emplantemplMapping.toDomain(emplantempldtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMPLANTEMPL" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emplantempls/fetchdefault")
	public ResponseEntity<List<EMPLANTEMPLDTO>> fetchDefault(EMPLANTEMPLSearchContext context) {
        Page<EMPLANTEMPL> domains = emplantemplService.searchDefault(context) ;
        List<EMPLANTEMPLDTO> list = emplantemplMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMPLANTEMPL" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emplantempls/searchdefault")
	public ResponseEntity<Page<EMPLANTEMPLDTO>> searchDefault(EMPLANTEMPLSearchContext context) {
        Page<EMPLANTEMPL> domains = emplantemplService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplantemplMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "GetByEMACCLASS", tags = {"EMPLANTEMPL" },  notes = "GetByEMACCLASS")
	@RequestMapping(method = RequestMethod.GET, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}")
    public ResponseEntity<EMPLANTEMPLDTO> getByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id) {
        EMPLANTEMPL domain = emplantemplService.get(emplantempl_id);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraftByEMACCLASS", tags = {"EMPLANTEMPL" },  notes = "GetDraftByEMACCLASS")
    @RequestMapping(method = RequestMethod.GET, value = "/emacclasses/{emacclass_id}/emplantempls/getdraft")
    public ResponseEntity<EMPLANTEMPLDTO> getDraftByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id) {
        EMPLANTEMPL domain = new EMPLANTEMPL();
        domain.setAcclassid(emacclass_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplantemplMapping.toDto(emplantemplService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByEMACCLASS", tags = {"EMPLANTEMPL" },  notes = "CreateByEMACCLASS")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplantempls")
    @Transactional
    public ResponseEntity<EMPLANTEMPLDTO> createByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
        domain.setAcclassid(emacclass_id);
		emplantemplService.create(domain);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMACCLASS", tags = {"EMPLANTEMPL" },  notes = "createBatchByEMACCLASS")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplantempls/batch")
    public ResponseEntity<Boolean> createBatchByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        List<EMPLANTEMPL> domainlist=emplantemplMapping.toDomain(emplantempldtos);
        for(EMPLANTEMPL domain:domainlist){
            domain.setAcclassid(emacclass_id);
        }
        emplantemplService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByEMACCLASS", tags = {"EMPLANTEMPL" },  notes = "RemoveByEMACCLASS")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplantemplService.remove(emplantempl_id));
    }

    @ApiOperation(value = "RemoveBatchByEMACCLASS", tags = {"EMPLANTEMPL" },  notes = "RemoveBatchByEMACCLASS")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emacclasses/{emacclass_id}/emplantempls/batch")
    public ResponseEntity<Boolean> removeBatchByEMACCLASS(@RequestBody List<String> ids) {
        emplantemplService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMACCLASS", tags = {"EMPLANTEMPL" },  notes = "CheckKeyByEMACCLASS")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplantempls/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplantemplService.checkKey(emplantemplMapping.toDomain(emplantempldto)));
    }

    @ApiOperation(value = "UpdateByEMACCLASS", tags = {"EMPLANTEMPL" },  notes = "UpdateByEMACCLASS")
	@RequestMapping(method = RequestMethod.PUT, value = "/emacclasses/{emacclass_id}/emplantempls/{emplantempl_id}")
    @Transactional
    public ResponseEntity<EMPLANTEMPLDTO> updateByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
        domain.setAcclassid(emacclass_id);
        domain.setEmplantemplid(emplantempl_id);
		emplantemplService.update(domain);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMACCLASS", tags = {"EMPLANTEMPL" },  notes = "UpdateBatchByEMACCLASS")
	@RequestMapping(method = RequestMethod.PUT, value = "/emacclasses/{emacclass_id}/emplantempls/batch")
    public ResponseEntity<Boolean> updateBatchByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        List<EMPLANTEMPL> domainlist=emplantemplMapping.toDomain(emplantempldtos);
        for(EMPLANTEMPL domain:domainlist){
            domain.setAcclassid(emacclass_id);
        }
        emplantemplService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByEMACCLASS", tags = {"EMPLANTEMPL" },  notes = "SaveByEMACCLASS")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplantempls/save")
    public ResponseEntity<Boolean> saveByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
        domain.setAcclassid(emacclass_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplantemplService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMACCLASS", tags = {"EMPLANTEMPL" },  notes = "SaveBatchByEMACCLASS")
	@RequestMapping(method = RequestMethod.POST, value = "/emacclasses/{emacclass_id}/emplantempls/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id, @RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        List<EMPLANTEMPL> domainlist=emplantemplMapping.toDomain(emplantempldtos);
        for(EMPLANTEMPL domain:domainlist){
             domain.setAcclassid(emacclass_id);
        }
        emplantemplService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMACCLASS", tags = {"EMPLANTEMPL" } ,notes = "fetchDEFAULTByEMACCLASS")
    @RequestMapping(method= RequestMethod.GET , value="/emacclasses/{emacclass_id}/emplantempls/fetchdefault")
	public ResponseEntity<List<EMPLANTEMPLDTO>> fetchEMPLANTEMPLDefaultByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id,EMPLANTEMPLSearchContext context) {
        context.setN_acclassid_eq(emacclass_id);
        Page<EMPLANTEMPL> domains = emplantemplService.searchDefault(context) ;
        List<EMPLANTEMPLDTO> list = emplantemplMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMACCLASS", tags = {"EMPLANTEMPL" } ,notes = "searchDEFAULTByEMACCLASS")
    @RequestMapping(method= RequestMethod.GET , value="/emacclasses/{emacclass_id}/emplantempls/searchdefault")
	public ResponseEntity<Page<EMPLANTEMPLDTO>> searchEMPLANTEMPLDefaultByEMACCLASS(@PathVariable("emacclass_id") String emacclass_id,EMPLANTEMPLSearchContext context) {
        context.setN_acclassid_eq(emacclass_id);
        Page<EMPLANTEMPL> domains = emplantemplService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplantemplMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "GetByEMSERVICE", tags = {"EMPLANTEMPL" },  notes = "GetByEMSERVICE")
	@RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}")
    public ResponseEntity<EMPLANTEMPLDTO> getByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id) {
        EMPLANTEMPL domain = emplantemplService.get(emplantempl_id);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraftByEMSERVICE", tags = {"EMPLANTEMPL" },  notes = "GetDraftByEMSERVICE")
    @RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emplantempls/getdraft")
    public ResponseEntity<EMPLANTEMPLDTO> getDraftByEMSERVICE(@PathVariable("emservice_id") String emservice_id) {
        EMPLANTEMPL domain = new EMPLANTEMPL();
        domain.setRserviceid(emservice_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplantemplMapping.toDto(emplantemplService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByEMSERVICE", tags = {"EMPLANTEMPL" },  notes = "CreateByEMSERVICE")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplantempls")
    @Transactional
    public ResponseEntity<EMPLANTEMPLDTO> createByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
        domain.setRserviceid(emservice_id);
		emplantemplService.create(domain);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSERVICE", tags = {"EMPLANTEMPL" },  notes = "createBatchByEMSERVICE")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplantempls/batch")
    public ResponseEntity<Boolean> createBatchByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        List<EMPLANTEMPL> domainlist=emplantemplMapping.toDomain(emplantempldtos);
        for(EMPLANTEMPL domain:domainlist){
            domain.setRserviceid(emservice_id);
        }
        emplantemplService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByEMSERVICE", tags = {"EMPLANTEMPL" },  notes = "RemoveByEMSERVICE")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplantemplService.remove(emplantempl_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSERVICE", tags = {"EMPLANTEMPL" },  notes = "RemoveBatchByEMSERVICE")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emplantempls/batch")
    public ResponseEntity<Boolean> removeBatchByEMSERVICE(@RequestBody List<String> ids) {
        emplantemplService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMSERVICE", tags = {"EMPLANTEMPL" },  notes = "CheckKeyByEMSERVICE")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplantempls/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplantemplService.checkKey(emplantemplMapping.toDomain(emplantempldto)));
    }

    @ApiOperation(value = "UpdateByEMSERVICE", tags = {"EMPLANTEMPL" },  notes = "UpdateByEMSERVICE")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emplantempls/{emplantempl_id}")
    @Transactional
    public ResponseEntity<EMPLANTEMPLDTO> updateByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
        domain.setRserviceid(emservice_id);
        domain.setEmplantemplid(emplantempl_id);
		emplantemplService.update(domain);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSERVICE", tags = {"EMPLANTEMPL" },  notes = "UpdateBatchByEMSERVICE")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emplantempls/batch")
    public ResponseEntity<Boolean> updateBatchByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        List<EMPLANTEMPL> domainlist=emplantemplMapping.toDomain(emplantempldtos);
        for(EMPLANTEMPL domain:domainlist){
            domain.setRserviceid(emservice_id);
        }
        emplantemplService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByEMSERVICE", tags = {"EMPLANTEMPL" },  notes = "SaveByEMSERVICE")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplantempls/save")
    public ResponseEntity<Boolean> saveByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
        domain.setRserviceid(emservice_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplantemplService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSERVICE", tags = {"EMPLANTEMPL" },  notes = "SaveBatchByEMSERVICE")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emplantempls/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSERVICE(@PathVariable("emservice_id") String emservice_id, @RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        List<EMPLANTEMPL> domainlist=emplantemplMapping.toDomain(emplantempldtos);
        for(EMPLANTEMPL domain:domainlist){
             domain.setRserviceid(emservice_id);
        }
        emplantemplService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByEMSERVICE", tags = {"EMPLANTEMPL" } ,notes = "fetchDEFAULTByEMSERVICE")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emplantempls/fetchdefault")
	public ResponseEntity<List<EMPLANTEMPLDTO>> fetchEMPLANTEMPLDefaultByEMSERVICE(@PathVariable("emservice_id") String emservice_id,EMPLANTEMPLSearchContext context) {
        context.setN_rserviceid_eq(emservice_id);
        Page<EMPLANTEMPL> domains = emplantemplService.searchDefault(context) ;
        List<EMPLANTEMPLDTO> list = emplantemplMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSERVICE", tags = {"EMPLANTEMPL" } ,notes = "searchDEFAULTByEMSERVICE")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emplantempls/searchdefault")
	public ResponseEntity<Page<EMPLANTEMPLDTO>> searchEMPLANTEMPLDefaultByEMSERVICE(@PathVariable("emservice_id") String emservice_id,EMPLANTEMPLSearchContext context) {
        context.setN_rserviceid_eq(emservice_id);
        Page<EMPLANTEMPL> domains = emplantemplService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplantemplMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "GetByPFDEPT", tags = {"EMPLANTEMPL" },  notes = "GetByPFDEPT")
	@RequestMapping(method = RequestMethod.GET, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}")
    public ResponseEntity<EMPLANTEMPLDTO> getByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id) {
        EMPLANTEMPL domain = emplantemplService.get(emplantempl_id);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraftByPFDEPT", tags = {"EMPLANTEMPL" },  notes = "GetDraftByPFDEPT")
    @RequestMapping(method = RequestMethod.GET, value = "/pfdepts/{pfdept_id}/emplantempls/getdraft")
    public ResponseEntity<EMPLANTEMPLDTO> getDraftByPFDEPT(@PathVariable("pfdept_id") String pfdept_id) {
        EMPLANTEMPL domain = new EMPLANTEMPL();
        domain.setRdeptid(pfdept_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplantemplMapping.toDto(emplantemplService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByPFDEPT", tags = {"EMPLANTEMPL" },  notes = "CreateByPFDEPT")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplantempls")
    @Transactional
    public ResponseEntity<EMPLANTEMPLDTO> createByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
        domain.setRdeptid(pfdept_id);
		emplantemplService.create(domain);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFDEPT", tags = {"EMPLANTEMPL" },  notes = "createBatchByPFDEPT")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplantempls/batch")
    public ResponseEntity<Boolean> createBatchByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        List<EMPLANTEMPL> domainlist=emplantemplMapping.toDomain(emplantempldtos);
        for(EMPLANTEMPL domain:domainlist){
            domain.setRdeptid(pfdept_id);
        }
        emplantemplService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByPFDEPT", tags = {"EMPLANTEMPL" },  notes = "RemoveByPFDEPT")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplantemplService.remove(emplantempl_id));
    }

    @ApiOperation(value = "RemoveBatchByPFDEPT", tags = {"EMPLANTEMPL" },  notes = "RemoveBatchByPFDEPT")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfdepts/{pfdept_id}/emplantempls/batch")
    public ResponseEntity<Boolean> removeBatchByPFDEPT(@RequestBody List<String> ids) {
        emplantemplService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFDEPT", tags = {"EMPLANTEMPL" },  notes = "CheckKeyByPFDEPT")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplantempls/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplantemplService.checkKey(emplantemplMapping.toDomain(emplantempldto)));
    }

    @ApiOperation(value = "UpdateByPFDEPT", tags = {"EMPLANTEMPL" },  notes = "UpdateByPFDEPT")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfdepts/{pfdept_id}/emplantempls/{emplantempl_id}")
    @Transactional
    public ResponseEntity<EMPLANTEMPLDTO> updateByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
        domain.setRdeptid(pfdept_id);
        domain.setEmplantemplid(emplantempl_id);
		emplantemplService.update(domain);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFDEPT", tags = {"EMPLANTEMPL" },  notes = "UpdateBatchByPFDEPT")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfdepts/{pfdept_id}/emplantempls/batch")
    public ResponseEntity<Boolean> updateBatchByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        List<EMPLANTEMPL> domainlist=emplantemplMapping.toDomain(emplantempldtos);
        for(EMPLANTEMPL domain:domainlist){
            domain.setRdeptid(pfdept_id);
        }
        emplantemplService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByPFDEPT", tags = {"EMPLANTEMPL" },  notes = "SaveByPFDEPT")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplantempls/save")
    public ResponseEntity<Boolean> saveByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
        domain.setRdeptid(pfdept_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplantemplService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFDEPT", tags = {"EMPLANTEMPL" },  notes = "SaveBatchByPFDEPT")
	@RequestMapping(method = RequestMethod.POST, value = "/pfdepts/{pfdept_id}/emplantempls/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFDEPT(@PathVariable("pfdept_id") String pfdept_id, @RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        List<EMPLANTEMPL> domainlist=emplantemplMapping.toDomain(emplantempldtos);
        for(EMPLANTEMPL domain:domainlist){
             domain.setRdeptid(pfdept_id);
        }
        emplantemplService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFDEPT", tags = {"EMPLANTEMPL" } ,notes = "fetchDEFAULTByPFDEPT")
    @RequestMapping(method= RequestMethod.GET , value="/pfdepts/{pfdept_id}/emplantempls/fetchdefault")
	public ResponseEntity<List<EMPLANTEMPLDTO>> fetchEMPLANTEMPLDefaultByPFDEPT(@PathVariable("pfdept_id") String pfdept_id,EMPLANTEMPLSearchContext context) {
        context.setN_rdeptid_eq(pfdept_id);
        Page<EMPLANTEMPL> domains = emplantemplService.searchDefault(context) ;
        List<EMPLANTEMPLDTO> list = emplantemplMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFDEPT", tags = {"EMPLANTEMPL" } ,notes = "searchDEFAULTByPFDEPT")
    @RequestMapping(method= RequestMethod.GET , value="/pfdepts/{pfdept_id}/emplantempls/searchdefault")
	public ResponseEntity<Page<EMPLANTEMPLDTO>> searchEMPLANTEMPLDefaultByPFDEPT(@PathVariable("pfdept_id") String pfdept_id,EMPLANTEMPLSearchContext context) {
        context.setN_rdeptid_eq(pfdept_id);
        Page<EMPLANTEMPL> domains = emplantemplService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplantemplMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "GetByPFEMP", tags = {"EMPLANTEMPL" },  notes = "GetByPFEMP")
	@RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}")
    public ResponseEntity<EMPLANTEMPLDTO> getByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id) {
        EMPLANTEMPL domain = emplantemplService.get(emplantempl_id);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraftByPFEMP", tags = {"EMPLANTEMPL" },  notes = "GetDraftByPFEMP")
    @RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emplantempls/getdraft")
    public ResponseEntity<EMPLANTEMPLDTO> getDraftByPFEMP(@PathVariable("pfemp_id") String pfemp_id) {
        EMPLANTEMPL domain = new EMPLANTEMPL();
        domain.setMpersonid(pfemp_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplantemplMapping.toDto(emplantemplService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByPFEMP", tags = {"EMPLANTEMPL" },  notes = "CreateByPFEMP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplantempls")
    @Transactional
    public ResponseEntity<EMPLANTEMPLDTO> createByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
        domain.setMpersonid(pfemp_id);
		emplantemplService.create(domain);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFEMP", tags = {"EMPLANTEMPL" },  notes = "createBatchByPFEMP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplantempls/batch")
    public ResponseEntity<Boolean> createBatchByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        List<EMPLANTEMPL> domainlist=emplantemplMapping.toDomain(emplantempldtos);
        for(EMPLANTEMPL domain:domainlist){
            domain.setMpersonid(pfemp_id);
        }
        emplantemplService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByPFEMP", tags = {"EMPLANTEMPL" },  notes = "RemoveByPFEMP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplantemplService.remove(emplantempl_id));
    }

    @ApiOperation(value = "RemoveBatchByPFEMP", tags = {"EMPLANTEMPL" },  notes = "RemoveBatchByPFEMP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emplantempls/batch")
    public ResponseEntity<Boolean> removeBatchByPFEMP(@RequestBody List<String> ids) {
        emplantemplService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFEMP", tags = {"EMPLANTEMPL" },  notes = "CheckKeyByPFEMP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplantempls/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplantemplService.checkKey(emplantemplMapping.toDomain(emplantempldto)));
    }

    @ApiOperation(value = "UpdateByPFEMP", tags = {"EMPLANTEMPL" },  notes = "UpdateByPFEMP")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emplantempls/{emplantempl_id}")
    @Transactional
    public ResponseEntity<EMPLANTEMPLDTO> updateByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
        domain.setMpersonid(pfemp_id);
        domain.setEmplantemplid(emplantempl_id);
		emplantemplService.update(domain);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFEMP", tags = {"EMPLANTEMPL" },  notes = "UpdateBatchByPFEMP")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emplantempls/batch")
    public ResponseEntity<Boolean> updateBatchByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        List<EMPLANTEMPL> domainlist=emplantemplMapping.toDomain(emplantempldtos);
        for(EMPLANTEMPL domain:domainlist){
            domain.setMpersonid(pfemp_id);
        }
        emplantemplService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByPFEMP", tags = {"EMPLANTEMPL" },  notes = "SaveByPFEMP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplantempls/save")
    public ResponseEntity<Boolean> saveByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
        domain.setMpersonid(pfemp_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplantemplService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFEMP", tags = {"EMPLANTEMPL" },  notes = "SaveBatchByPFEMP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emplantempls/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFEMP(@PathVariable("pfemp_id") String pfemp_id, @RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        List<EMPLANTEMPL> domainlist=emplantemplMapping.toDomain(emplantempldtos);
        for(EMPLANTEMPL domain:domainlist){
             domain.setMpersonid(pfemp_id);
        }
        emplantemplService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFEMP", tags = {"EMPLANTEMPL" } ,notes = "fetchDEFAULTByPFEMP")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emplantempls/fetchdefault")
	public ResponseEntity<List<EMPLANTEMPLDTO>> fetchEMPLANTEMPLDefaultByPFEMP(@PathVariable("pfemp_id") String pfemp_id,EMPLANTEMPLSearchContext context) {
        context.setN_mpersonid_eq(pfemp_id);
        Page<EMPLANTEMPL> domains = emplantemplService.searchDefault(context) ;
        List<EMPLANTEMPLDTO> list = emplantemplMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFEMP", tags = {"EMPLANTEMPL" } ,notes = "searchDEFAULTByPFEMP")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emplantempls/searchdefault")
	public ResponseEntity<Page<EMPLANTEMPLDTO>> searchEMPLANTEMPLDefaultByPFEMP(@PathVariable("pfemp_id") String pfemp_id,EMPLANTEMPLSearchContext context) {
        context.setN_mpersonid_eq(pfemp_id);
        Page<EMPLANTEMPL> domains = emplantemplService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplantemplMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "GetByPFTEAM", tags = {"EMPLANTEMPL" },  notes = "GetByPFTEAM")
	@RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}")
    public ResponseEntity<EMPLANTEMPLDTO> getByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id) {
        EMPLANTEMPL domain = emplantemplService.get(emplantempl_id);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraftByPFTEAM", tags = {"EMPLANTEMPL" },  notes = "GetDraftByPFTEAM")
    @RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emplantempls/getdraft")
    public ResponseEntity<EMPLANTEMPLDTO> getDraftByPFTEAM(@PathVariable("pfteam_id") String pfteam_id) {
        EMPLANTEMPL domain = new EMPLANTEMPL();
        domain.setRteamid(pfteam_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplantemplMapping.toDto(emplantemplService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByPFTEAM", tags = {"EMPLANTEMPL" },  notes = "CreateByPFTEAM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplantempls")
    @Transactional
    public ResponseEntity<EMPLANTEMPLDTO> createByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
        domain.setRteamid(pfteam_id);
		emplantemplService.create(domain);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFTEAM", tags = {"EMPLANTEMPL" },  notes = "createBatchByPFTEAM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplantempls/batch")
    public ResponseEntity<Boolean> createBatchByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        List<EMPLANTEMPL> domainlist=emplantemplMapping.toDomain(emplantempldtos);
        for(EMPLANTEMPL domain:domainlist){
            domain.setRteamid(pfteam_id);
        }
        emplantemplService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByPFTEAM", tags = {"EMPLANTEMPL" },  notes = "RemoveByPFTEAM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emplantemplService.remove(emplantempl_id));
    }

    @ApiOperation(value = "RemoveBatchByPFTEAM", tags = {"EMPLANTEMPL" },  notes = "RemoveBatchByPFTEAM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emplantempls/batch")
    public ResponseEntity<Boolean> removeBatchByPFTEAM(@RequestBody List<String> ids) {
        emplantemplService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFTEAM", tags = {"EMPLANTEMPL" },  notes = "CheckKeyByPFTEAM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplantempls/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emplantemplService.checkKey(emplantemplMapping.toDomain(emplantempldto)));
    }

    @ApiOperation(value = "UpdateByPFTEAM", tags = {"EMPLANTEMPL" },  notes = "UpdateByPFTEAM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emplantempls/{emplantempl_id}")
    @Transactional
    public ResponseEntity<EMPLANTEMPLDTO> updateByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emplantempl_id") String emplantempl_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
        domain.setRteamid(pfteam_id);
        domain.setEmplantemplid(emplantempl_id);
		emplantemplService.update(domain);
        EMPLANTEMPLDTO dto = emplantemplMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFTEAM", tags = {"EMPLANTEMPL" },  notes = "UpdateBatchByPFTEAM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emplantempls/batch")
    public ResponseEntity<Boolean> updateBatchByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        List<EMPLANTEMPL> domainlist=emplantemplMapping.toDomain(emplantempldtos);
        for(EMPLANTEMPL domain:domainlist){
            domain.setRteamid(pfteam_id);
        }
        emplantemplService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByPFTEAM", tags = {"EMPLANTEMPL" },  notes = "SaveByPFTEAM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplantempls/save")
    public ResponseEntity<Boolean> saveByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody EMPLANTEMPLDTO emplantempldto) {
        EMPLANTEMPL domain = emplantemplMapping.toDomain(emplantempldto);
        domain.setRteamid(pfteam_id);
        return ResponseEntity.status(HttpStatus.OK).body(emplantemplService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFTEAM", tags = {"EMPLANTEMPL" },  notes = "SaveBatchByPFTEAM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emplantempls/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFTEAM(@PathVariable("pfteam_id") String pfteam_id, @RequestBody List<EMPLANTEMPLDTO> emplantempldtos) {
        List<EMPLANTEMPL> domainlist=emplantemplMapping.toDomain(emplantempldtos);
        for(EMPLANTEMPL domain:domainlist){
             domain.setRteamid(pfteam_id);
        }
        emplantemplService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetchDEFAULTByPFTEAM", tags = {"EMPLANTEMPL" } ,notes = "fetchDEFAULTByPFTEAM")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emplantempls/fetchdefault")
	public ResponseEntity<List<EMPLANTEMPLDTO>> fetchEMPLANTEMPLDefaultByPFTEAM(@PathVariable("pfteam_id") String pfteam_id,EMPLANTEMPLSearchContext context) {
        context.setN_rteamid_eq(pfteam_id);
        Page<EMPLANTEMPL> domains = emplantemplService.searchDefault(context) ;
        List<EMPLANTEMPLDTO> list = emplantemplMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFTEAM", tags = {"EMPLANTEMPL" } ,notes = "searchDEFAULTByPFTEAM")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emplantempls/searchdefault")
	public ResponseEntity<Page<EMPLANTEMPLDTO>> searchEMPLANTEMPLDefaultByPFTEAM(@PathVariable("pfteam_id") String pfteam_id,EMPLANTEMPLSearchContext context) {
        context.setN_rteamid_eq(pfteam_id);
        Page<EMPLANTEMPL> domains = emplantemplService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emplantemplMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMPLANTEMPL getEntity(){
        return new EMPLANTEMPL();
    }

}
