package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMPODETAIL;
import cn.ibizlab.eam.core.eam_core.service.IEMPODETAILService;
import cn.ibizlab.eam.core.eam_core.filter.EMPODETAILSearchContext;




@Slf4j
@Api(tags = {"EMPODETAIL" })
@RestController("WebApi-empodetail")
@RequestMapping("")
public class EMPODETAILResource {

    @Autowired
    private IEMPODETAILService empodetailService;

    @Autowired
    @Lazy
    private EMPODETAILMapping empodetailMapping;




    @PreAuthorize("hasPermission(#empodetail_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMPODETAIL" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> update(@PathVariable("empodetail_id") String empodetail_id, @RequestBody EMPODETAILDTO empodetaildto) {
		EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setEmpodetailid(empodetail_id);
		empodetailService.update(domain);
		EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#empodetail_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMPODETAIL" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/empodetails/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMPODETAILDTO> empodetaildtos) {
        empodetailService.updateBatch(empodetailMapping.toDomain(empodetaildtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#empodetail_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMPODETAIL" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/empodetails/{empodetail_id}")
    public ResponseEntity<EMPODETAILDTO> get(@PathVariable("empodetail_id") String empodetail_id) {
        EMPODETAIL domain = empodetailService.get(empodetail_id);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMPODETAIL" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/empodetails")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> create(@RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
		empodetailService.create(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMPODETAIL" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/empodetails/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMPODETAILDTO> empodetaildtos) {
        empodetailService.createBatch(empodetailMapping.toDomain(empodetaildtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMPODETAIL" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/empodetails/getdraft")
    public ResponseEntity<EMPODETAILDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(empodetailMapping.toDto(empodetailService.getDraft(new EMPODETAIL())));
    }




    @ApiOperation(value = "Save", tags = {"EMPODETAIL" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/empodetails/save")
    public ResponseEntity<Boolean> save(@RequestBody EMPODETAILDTO empodetaildto) {
        return ResponseEntity.status(HttpStatus.OK).body(empodetailService.save(empodetailMapping.toDomain(empodetaildto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMPODETAIL" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/empodetails/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMPODETAILDTO> empodetaildtos) {
        empodetailService.saveBatch(empodetailMapping.toDomain(empodetaildtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMPODETAIL" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/empodetails/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMPODETAILDTO empodetaildto) {
        return  ResponseEntity.status(HttpStatus.OK).body(empodetailService.checkKey(empodetailMapping.toDomain(empodetaildto)));
    }




    @PreAuthorize("hasPermission('Remove',{#empodetail_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMPODETAIL" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("empodetail_id") String empodetail_id) {
         return ResponseEntity.status(HttpStatus.OK).body(empodetailService.remove(empodetail_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMPODETAIL" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/empodetails/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        empodetailService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'LaterYear',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetch近五年采购", tags = {"EMPODETAIL" } ,notes = "fetch近五年采购")
    @RequestMapping(method= RequestMethod.GET , value="/empodetails/fetchlateryear")
	public ResponseEntity<List<HashMap>> fetchLaterYear(EMPODETAILSearchContext context) {
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(domains.getContent());
	}

    @PreAuthorize("hasPermission('Get',{#context,'LaterYear',this.getEntity(),'Sql'})")
	@ApiOperation(value = "search近五年采购", tags = {"EMPODETAIL" } ,notes = "search近五年采购")
    @RequestMapping(method= RequestMethod.GET , value="/empodetails/searchlateryear")
	public ResponseEntity<Page<HashMap>> searchLaterYear(EMPODETAILSearchContext context) {
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(domains.getContent(), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMPODETAIL" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/empodetails/fetchdefault")
	public ResponseEntity<List<EMPODETAILDTO>> fetchDefault(EMPODETAILSearchContext context) {
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
        List<EMPODETAILDTO> list = empodetailMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMPODETAIL" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/empodetails/searchdefault")
	public ResponseEntity<Page<EMPODETAILDTO>> searchDefault(EMPODETAILSearchContext context) {
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(empodetailMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "UpdateByEMITEM", tags = {"EMPODETAIL" },  notes = "UpdateByEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emitems/{emitem_id}/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> updateByEMITEM(@PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
        domain.setEmpodetailid(empodetail_id);
		empodetailService.update(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMITEM", tags = {"EMPODETAIL" },  notes = "UpdateBatchByEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> updateBatchByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
            domain.setItemid(emitem_id);
        }
        empodetailService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMITEM", tags = {"EMPODETAIL" },  notes = "GetByEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emitems/{emitem_id}/empodetails/{empodetail_id}")
    public ResponseEntity<EMPODETAILDTO> getByEMITEM(@PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id) {
        EMPODETAIL domain = empodetailService.get(empodetail_id);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CreateByEMITEM", tags = {"EMPODETAIL" },  notes = "CreateByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/empodetails")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> createByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
		empodetailService.create(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMITEM", tags = {"EMPODETAIL" },  notes = "createBatchByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> createBatchByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
            domain.setItemid(emitem_id);
        }
        empodetailService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMITEM", tags = {"EMPODETAIL" },  notes = "GetDraftByEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emitems/{emitem_id}/empodetails/getdraft")
    public ResponseEntity<EMPODETAILDTO> getDraftByEMITEM(@PathVariable("emitem_id") String emitem_id) {
        EMPODETAIL domain = new EMPODETAIL();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(empodetailMapping.toDto(empodetailService.getDraft(domain)));
    }

    @ApiOperation(value = "SaveByEMITEM", tags = {"EMPODETAIL" },  notes = "SaveByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/empodetails/save")
    public ResponseEntity<Boolean> saveByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(empodetailService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMITEM", tags = {"EMPODETAIL" },  notes = "SaveBatchByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/empodetails/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
             domain.setItemid(emitem_id);
        }
        empodetailService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMITEM", tags = {"EMPODETAIL" },  notes = "CheckKeyByEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emitems/{emitem_id}/empodetails/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMITEM(@PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        return  ResponseEntity.status(HttpStatus.OK).body(empodetailService.checkKey(empodetailMapping.toDomain(empodetaildto)));
    }

    @ApiOperation(value = "RemoveByEMITEM", tags = {"EMPODETAIL" },  notes = "RemoveByEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emitems/{emitem_id}/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMITEM(@PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id) {
		return ResponseEntity.status(HttpStatus.OK).body(empodetailService.remove(empodetail_id));
    }

    @ApiOperation(value = "RemoveBatchByEMITEM", tags = {"EMPODETAIL" },  notes = "RemoveBatchByEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> removeBatchByEMITEM(@RequestBody List<String> ids) {
        empodetailService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetch近五年采购ByEMITEM", tags = {"EMPODETAIL" } ,notes = "fetch近五年采购ByEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emitems/{emitem_id}/empodetails/fetchlateryear")
	public ResponseEntity<List<HashMap>> fetchEMPODETAILLaterYearByEMITEM(@PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(domains.getContent());
	}

	@ApiOperation(value = "search近五年采购ByEMITEM", tags = {"EMPODETAIL" } ,notes = "search近五年采购ByEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emitems/{emitem_id}/empodetails/searchlateryear")
	public ResponseEntity<Page<HashMap>> searchEMPODETAILLaterYearByEMITEM(@PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(domains.getContent(), context.getPageable(), domains.getTotalElements()));
	}

	@ApiOperation(value = "fetchDEFAULTByEMITEM", tags = {"EMPODETAIL" } ,notes = "fetchDEFAULTByEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emitems/{emitem_id}/empodetails/fetchdefault")
	public ResponseEntity<List<EMPODETAILDTO>> fetchEMPODETAILDefaultByEMITEM(@PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
        List<EMPODETAILDTO> list = empodetailMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMITEM", tags = {"EMPODETAIL" } ,notes = "searchDEFAULTByEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emitems/{emitem_id}/empodetails/searchdefault")
	public ResponseEntity<Page<EMPODETAILDTO>> searchEMPODETAILDefaultByEMITEM(@PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(empodetailMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "UpdateByEMPO", tags = {"EMPODETAIL" },  notes = "UpdateByEMPO")
	@RequestMapping(method = RequestMethod.PUT, value = "/empos/{empo_id}/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> updateByEMPO(@PathVariable("empo_id") String empo_id, @PathVariable("empodetail_id") String empodetail_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setPoid(empo_id);
        domain.setEmpodetailid(empodetail_id);
		empodetailService.update(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMPO", tags = {"EMPODETAIL" },  notes = "UpdateBatchByEMPO")
	@RequestMapping(method = RequestMethod.PUT, value = "/empos/{empo_id}/empodetails/batch")
    public ResponseEntity<Boolean> updateBatchByEMPO(@PathVariable("empo_id") String empo_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
            domain.setPoid(empo_id);
        }
        empodetailService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMPO", tags = {"EMPODETAIL" },  notes = "GetByEMPO")
	@RequestMapping(method = RequestMethod.GET, value = "/empos/{empo_id}/empodetails/{empodetail_id}")
    public ResponseEntity<EMPODETAILDTO> getByEMPO(@PathVariable("empo_id") String empo_id, @PathVariable("empodetail_id") String empodetail_id) {
        EMPODETAIL domain = empodetailService.get(empodetail_id);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CreateByEMPO", tags = {"EMPODETAIL" },  notes = "CreateByEMPO")
	@RequestMapping(method = RequestMethod.POST, value = "/empos/{empo_id}/empodetails")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> createByEMPO(@PathVariable("empo_id") String empo_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setPoid(empo_id);
		empodetailService.create(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMPO", tags = {"EMPODETAIL" },  notes = "createBatchByEMPO")
	@RequestMapping(method = RequestMethod.POST, value = "/empos/{empo_id}/empodetails/batch")
    public ResponseEntity<Boolean> createBatchByEMPO(@PathVariable("empo_id") String empo_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
            domain.setPoid(empo_id);
        }
        empodetailService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMPO", tags = {"EMPODETAIL" },  notes = "GetDraftByEMPO")
    @RequestMapping(method = RequestMethod.GET, value = "/empos/{empo_id}/empodetails/getdraft")
    public ResponseEntity<EMPODETAILDTO> getDraftByEMPO(@PathVariable("empo_id") String empo_id) {
        EMPODETAIL domain = new EMPODETAIL();
        domain.setPoid(empo_id);
        return ResponseEntity.status(HttpStatus.OK).body(empodetailMapping.toDto(empodetailService.getDraft(domain)));
    }

    @ApiOperation(value = "SaveByEMPO", tags = {"EMPODETAIL" },  notes = "SaveByEMPO")
	@RequestMapping(method = RequestMethod.POST, value = "/empos/{empo_id}/empodetails/save")
    public ResponseEntity<Boolean> saveByEMPO(@PathVariable("empo_id") String empo_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setPoid(empo_id);
        return ResponseEntity.status(HttpStatus.OK).body(empodetailService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMPO", tags = {"EMPODETAIL" },  notes = "SaveBatchByEMPO")
	@RequestMapping(method = RequestMethod.POST, value = "/empos/{empo_id}/empodetails/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMPO(@PathVariable("empo_id") String empo_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
             domain.setPoid(empo_id);
        }
        empodetailService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMPO", tags = {"EMPODETAIL" },  notes = "CheckKeyByEMPO")
	@RequestMapping(method = RequestMethod.POST, value = "/empos/{empo_id}/empodetails/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMPO(@PathVariable("empo_id") String empo_id, @RequestBody EMPODETAILDTO empodetaildto) {
        return  ResponseEntity.status(HttpStatus.OK).body(empodetailService.checkKey(empodetailMapping.toDomain(empodetaildto)));
    }

    @ApiOperation(value = "RemoveByEMPO", tags = {"EMPODETAIL" },  notes = "RemoveByEMPO")
	@RequestMapping(method = RequestMethod.DELETE, value = "/empos/{empo_id}/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMPO(@PathVariable("empo_id") String empo_id, @PathVariable("empodetail_id") String empodetail_id) {
		return ResponseEntity.status(HttpStatus.OK).body(empodetailService.remove(empodetail_id));
    }

    @ApiOperation(value = "RemoveBatchByEMPO", tags = {"EMPODETAIL" },  notes = "RemoveBatchByEMPO")
	@RequestMapping(method = RequestMethod.DELETE, value = "/empos/{empo_id}/empodetails/batch")
    public ResponseEntity<Boolean> removeBatchByEMPO(@RequestBody List<String> ids) {
        empodetailService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetch近五年采购ByEMPO", tags = {"EMPODETAIL" } ,notes = "fetch近五年采购ByEMPO")
    @RequestMapping(method= RequestMethod.GET , value="/empos/{empo_id}/empodetails/fetchlateryear")
	public ResponseEntity<List<HashMap>> fetchEMPODETAILLaterYearByEMPO(@PathVariable("empo_id") String empo_id,EMPODETAILSearchContext context) {
        context.setN_poid_eq(empo_id);
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(domains.getContent());
	}

	@ApiOperation(value = "search近五年采购ByEMPO", tags = {"EMPODETAIL" } ,notes = "search近五年采购ByEMPO")
    @RequestMapping(method= RequestMethod.GET , value="/empos/{empo_id}/empodetails/searchlateryear")
	public ResponseEntity<Page<HashMap>> searchEMPODETAILLaterYearByEMPO(@PathVariable("empo_id") String empo_id,EMPODETAILSearchContext context) {
        context.setN_poid_eq(empo_id);
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(domains.getContent(), context.getPageable(), domains.getTotalElements()));
	}

	@ApiOperation(value = "fetchDEFAULTByEMPO", tags = {"EMPODETAIL" } ,notes = "fetchDEFAULTByEMPO")
    @RequestMapping(method= RequestMethod.GET , value="/empos/{empo_id}/empodetails/fetchdefault")
	public ResponseEntity<List<EMPODETAILDTO>> fetchEMPODETAILDefaultByEMPO(@PathVariable("empo_id") String empo_id,EMPODETAILSearchContext context) {
        context.setN_poid_eq(empo_id);
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
        List<EMPODETAILDTO> list = empodetailMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMPO", tags = {"EMPODETAIL" } ,notes = "searchDEFAULTByEMPO")
    @RequestMapping(method= RequestMethod.GET , value="/empos/{empo_id}/empodetails/searchdefault")
	public ResponseEntity<Page<EMPODETAILDTO>> searchEMPODETAILDefaultByEMPO(@PathVariable("empo_id") String empo_id,EMPODETAILSearchContext context) {
        context.setN_poid_eq(empo_id);
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(empodetailMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "UpdateByEMSERVICEEMITEM", tags = {"EMPODETAIL" },  notes = "UpdateByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> updateByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
        domain.setEmpodetailid(empodetail_id);
		empodetailService.update(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSERVICEEMITEM", tags = {"EMPODETAIL" },  notes = "UpdateBatchByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emservices/{emservice_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> updateBatchByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
            domain.setItemid(emitem_id);
        }
        empodetailService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSERVICEEMITEM", tags = {"EMPODETAIL" },  notes = "GetByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    public ResponseEntity<EMPODETAILDTO> getByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id) {
        EMPODETAIL domain = empodetailService.get(empodetail_id);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CreateByEMSERVICEEMITEM", tags = {"EMPODETAIL" },  notes = "CreateByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/empodetails")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> createByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
		empodetailService.create(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSERVICEEMITEM", tags = {"EMPODETAIL" },  notes = "createBatchByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> createBatchByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
            domain.setItemid(emitem_id);
        }
        empodetailService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSERVICEEMITEM", tags = {"EMPODETAIL" },  notes = "GetDraftByEMSERVICEEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emservices/{emservice_id}/emitems/{emitem_id}/empodetails/getdraft")
    public ResponseEntity<EMPODETAILDTO> getDraftByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id) {
        EMPODETAIL domain = new EMPODETAIL();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(empodetailMapping.toDto(empodetailService.getDraft(domain)));
    }

    @ApiOperation(value = "SaveByEMSERVICEEMITEM", tags = {"EMPODETAIL" },  notes = "SaveByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/empodetails/save")
    public ResponseEntity<Boolean> saveByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(empodetailService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSERVICEEMITEM", tags = {"EMPODETAIL" },  notes = "SaveBatchByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/empodetails/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
             domain.setItemid(emitem_id);
        }
        empodetailService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMSERVICEEMITEM", tags = {"EMPODETAIL" },  notes = "CheckKeyByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emservices/{emservice_id}/emitems/{emitem_id}/empodetails/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        return  ResponseEntity.status(HttpStatus.OK).body(empodetailService.checkKey(empodetailMapping.toDomain(empodetaildto)));
    }

    @ApiOperation(value = "RemoveByEMSERVICEEMITEM", tags = {"EMPODETAIL" },  notes = "RemoveByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id) {
		return ResponseEntity.status(HttpStatus.OK).body(empodetailService.remove(empodetail_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSERVICEEMITEM", tags = {"EMPODETAIL" },  notes = "RemoveBatchByEMSERVICEEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emservices/{emservice_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> removeBatchByEMSERVICEEMITEM(@RequestBody List<String> ids) {
        empodetailService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetch近五年采购ByEMSERVICEEMITEM", tags = {"EMPODETAIL" } ,notes = "fetch近五年采购ByEMSERVICEEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emitems/{emitem_id}/empodetails/fetchlateryear")
	public ResponseEntity<List<HashMap>> fetchEMPODETAILLaterYearByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(domains.getContent());
	}

	@ApiOperation(value = "search近五年采购ByEMSERVICEEMITEM", tags = {"EMPODETAIL" } ,notes = "search近五年采购ByEMSERVICEEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emitems/{emitem_id}/empodetails/searchlateryear")
	public ResponseEntity<Page<HashMap>> searchEMPODETAILLaterYearByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(domains.getContent(), context.getPageable(), domains.getTotalElements()));
	}

	@ApiOperation(value = "fetchDEFAULTByEMSERVICEEMITEM", tags = {"EMPODETAIL" } ,notes = "fetchDEFAULTByEMSERVICEEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emitems/{emitem_id}/empodetails/fetchdefault")
	public ResponseEntity<List<EMPODETAILDTO>> fetchEMPODETAILDefaultByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
        List<EMPODETAILDTO> list = empodetailMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSERVICEEMITEM", tags = {"EMPODETAIL" } ,notes = "searchDEFAULTByEMSERVICEEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emservices/{emservice_id}/emitems/{emitem_id}/empodetails/searchdefault")
	public ResponseEntity<Page<EMPODETAILDTO>> searchEMPODETAILDefaultByEMSERVICEEMITEM(@PathVariable("emservice_id") String emservice_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(empodetailMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "UpdateByEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "UpdateByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> updateByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
        domain.setEmpodetailid(empodetail_id);
		empodetailService.update(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "UpdateBatchByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> updateBatchByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
            domain.setItemid(emitem_id);
        }
        empodetailService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "GetByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    public ResponseEntity<EMPODETAILDTO> getByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id) {
        EMPODETAIL domain = empodetailService.get(empodetail_id);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CreateByEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "CreateByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> createByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
		empodetailService.create(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "createBatchByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> createBatchByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
            domain.setItemid(emitem_id);
        }
        empodetailService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "GetDraftByEMSTOREPARTEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/getdraft")
    public ResponseEntity<EMPODETAILDTO> getDraftByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id) {
        EMPODETAIL domain = new EMPODETAIL();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(empodetailMapping.toDto(empodetailService.getDraft(domain)));
    }

    @ApiOperation(value = "SaveByEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "SaveByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/save")
    public ResponseEntity<Boolean> saveByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(empodetailService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "SaveBatchByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
             domain.setItemid(emitem_id);
        }
        empodetailService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "CheckKeyByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        return  ResponseEntity.status(HttpStatus.OK).body(empodetailService.checkKey(empodetailMapping.toDomain(empodetaildto)));
    }

    @ApiOperation(value = "RemoveByEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "RemoveByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id) {
		return ResponseEntity.status(HttpStatus.OK).body(empodetailService.remove(empodetail_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "RemoveBatchByEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> removeBatchByEMSTOREPARTEMITEM(@RequestBody List<String> ids) {
        empodetailService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetch近五年采购ByEMSTOREPARTEMITEM", tags = {"EMPODETAIL" } ,notes = "fetch近五年采购ByEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/fetchlateryear")
	public ResponseEntity<List<HashMap>> fetchEMPODETAILLaterYearByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(domains.getContent());
	}

	@ApiOperation(value = "search近五年采购ByEMSTOREPARTEMITEM", tags = {"EMPODETAIL" } ,notes = "search近五年采购ByEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/searchlateryear")
	public ResponseEntity<Page<HashMap>> searchEMPODETAILLaterYearByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(domains.getContent(), context.getPageable(), domains.getTotalElements()));
	}

	@ApiOperation(value = "fetchDEFAULTByEMSTOREPARTEMITEM", tags = {"EMPODETAIL" } ,notes = "fetchDEFAULTByEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/fetchdefault")
	public ResponseEntity<List<EMPODETAILDTO>> fetchEMPODETAILDefaultByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
        List<EMPODETAILDTO> list = empodetailMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSTOREPARTEMITEM", tags = {"EMPODETAIL" } ,notes = "searchDEFAULTByEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/searchdefault")
	public ResponseEntity<Page<EMPODETAILDTO>> searchEMPODETAILDefaultByEMSTOREPARTEMITEM(@PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(empodetailMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "UpdateByEMSTOREEMITEM", tags = {"EMPODETAIL" },  notes = "UpdateByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> updateByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
        domain.setEmpodetailid(empodetail_id);
		empodetailService.update(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSTOREEMITEM", tags = {"EMPODETAIL" },  notes = "UpdateBatchByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> updateBatchByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
            domain.setItemid(emitem_id);
        }
        empodetailService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSTOREEMITEM", tags = {"EMPODETAIL" },  notes = "GetByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    public ResponseEntity<EMPODETAILDTO> getByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id) {
        EMPODETAIL domain = empodetailService.get(empodetail_id);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CreateByEMSTOREEMITEM", tags = {"EMPODETAIL" },  notes = "CreateByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/empodetails")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> createByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
		empodetailService.create(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSTOREEMITEM", tags = {"EMPODETAIL" },  notes = "createBatchByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> createBatchByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
            domain.setItemid(emitem_id);
        }
        empodetailService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSTOREEMITEM", tags = {"EMPODETAIL" },  notes = "GetDraftByEMSTOREEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emitems/{emitem_id}/empodetails/getdraft")
    public ResponseEntity<EMPODETAILDTO> getDraftByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id) {
        EMPODETAIL domain = new EMPODETAIL();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(empodetailMapping.toDto(empodetailService.getDraft(domain)));
    }

    @ApiOperation(value = "SaveByEMSTOREEMITEM", tags = {"EMPODETAIL" },  notes = "SaveByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/empodetails/save")
    public ResponseEntity<Boolean> saveByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(empodetailService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSTOREEMITEM", tags = {"EMPODETAIL" },  notes = "SaveBatchByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/empodetails/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
             domain.setItemid(emitem_id);
        }
        empodetailService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMSTOREEMITEM", tags = {"EMPODETAIL" },  notes = "CheckKeyByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emitems/{emitem_id}/empodetails/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        return  ResponseEntity.status(HttpStatus.OK).body(empodetailService.checkKey(empodetailMapping.toDomain(empodetaildto)));
    }

    @ApiOperation(value = "RemoveByEMSTOREEMITEM", tags = {"EMPODETAIL" },  notes = "RemoveByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id) {
		return ResponseEntity.status(HttpStatus.OK).body(empodetailService.remove(empodetail_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSTOREEMITEM", tags = {"EMPODETAIL" },  notes = "RemoveBatchByEMSTOREEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> removeBatchByEMSTOREEMITEM(@RequestBody List<String> ids) {
        empodetailService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetch近五年采购ByEMSTOREEMITEM", tags = {"EMPODETAIL" } ,notes = "fetch近五年采购ByEMSTOREEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emitems/{emitem_id}/empodetails/fetchlateryear")
	public ResponseEntity<List<HashMap>> fetchEMPODETAILLaterYearByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(domains.getContent());
	}

	@ApiOperation(value = "search近五年采购ByEMSTOREEMITEM", tags = {"EMPODETAIL" } ,notes = "search近五年采购ByEMSTOREEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emitems/{emitem_id}/empodetails/searchlateryear")
	public ResponseEntity<Page<HashMap>> searchEMPODETAILLaterYearByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(domains.getContent(), context.getPageable(), domains.getTotalElements()));
	}

	@ApiOperation(value = "fetchDEFAULTByEMSTOREEMITEM", tags = {"EMPODETAIL" } ,notes = "fetchDEFAULTByEMSTOREEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emitems/{emitem_id}/empodetails/fetchdefault")
	public ResponseEntity<List<EMPODETAILDTO>> fetchEMPODETAILDefaultByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
        List<EMPODETAILDTO> list = empodetailMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSTOREEMITEM", tags = {"EMPODETAIL" } ,notes = "searchDEFAULTByEMSTOREEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emitems/{emitem_id}/empodetails/searchdefault")
	public ResponseEntity<Page<EMPODETAILDTO>> searchEMPODETAILDefaultByEMSTOREEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(empodetailMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "UpdateByPFEMPEMITEM", tags = {"EMPODETAIL" },  notes = "UpdateByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> updateByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
        domain.setEmpodetailid(empodetail_id);
		empodetailService.update(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFEMPEMITEM", tags = {"EMPODETAIL" },  notes = "UpdateBatchByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> updateBatchByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
            domain.setItemid(emitem_id);
        }
        empodetailService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFEMPEMITEM", tags = {"EMPODETAIL" },  notes = "GetByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    public ResponseEntity<EMPODETAILDTO> getByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id) {
        EMPODETAIL domain = empodetailService.get(empodetail_id);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CreateByPFEMPEMITEM", tags = {"EMPODETAIL" },  notes = "CreateByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/empodetails")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> createByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
		empodetailService.create(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFEMPEMITEM", tags = {"EMPODETAIL" },  notes = "createBatchByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> createBatchByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
            domain.setItemid(emitem_id);
        }
        empodetailService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFEMPEMITEM", tags = {"EMPODETAIL" },  notes = "GetDraftByPFEMPEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/empodetails/getdraft")
    public ResponseEntity<EMPODETAILDTO> getDraftByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id) {
        EMPODETAIL domain = new EMPODETAIL();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(empodetailMapping.toDto(empodetailService.getDraft(domain)));
    }

    @ApiOperation(value = "SaveByPFEMPEMITEM", tags = {"EMPODETAIL" },  notes = "SaveByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/empodetails/save")
    public ResponseEntity<Boolean> saveByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(empodetailService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFEMPEMITEM", tags = {"EMPODETAIL" },  notes = "SaveBatchByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/empodetails/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
             domain.setItemid(emitem_id);
        }
        empodetailService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFEMPEMITEM", tags = {"EMPODETAIL" },  notes = "CheckKeyByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/empodetails/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        return  ResponseEntity.status(HttpStatus.OK).body(empodetailService.checkKey(empodetailMapping.toDomain(empodetaildto)));
    }

    @ApiOperation(value = "RemoveByPFEMPEMITEM", tags = {"EMPODETAIL" },  notes = "RemoveByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id) {
		return ResponseEntity.status(HttpStatus.OK).body(empodetailService.remove(empodetail_id));
    }

    @ApiOperation(value = "RemoveBatchByPFEMPEMITEM", tags = {"EMPODETAIL" },  notes = "RemoveBatchByPFEMPEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemps/{pfemp_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> removeBatchByPFEMPEMITEM(@RequestBody List<String> ids) {
        empodetailService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetch近五年采购ByPFEMPEMITEM", tags = {"EMPODETAIL" } ,notes = "fetch近五年采购ByPFEMPEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emitems/{emitem_id}/empodetails/fetchlateryear")
	public ResponseEntity<List<HashMap>> fetchEMPODETAILLaterYearByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(domains.getContent());
	}

	@ApiOperation(value = "search近五年采购ByPFEMPEMITEM", tags = {"EMPODETAIL" } ,notes = "search近五年采购ByPFEMPEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emitems/{emitem_id}/empodetails/searchlateryear")
	public ResponseEntity<Page<HashMap>> searchEMPODETAILLaterYearByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(domains.getContent(), context.getPageable(), domains.getTotalElements()));
	}

	@ApiOperation(value = "fetchDEFAULTByPFEMPEMITEM", tags = {"EMPODETAIL" } ,notes = "fetchDEFAULTByPFEMPEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emitems/{emitem_id}/empodetails/fetchdefault")
	public ResponseEntity<List<EMPODETAILDTO>> fetchEMPODETAILDefaultByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
        List<EMPODETAILDTO> list = empodetailMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFEMPEMITEM", tags = {"EMPODETAIL" } ,notes = "searchDEFAULTByPFEMPEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfemps/{pfemp_id}/emitems/{emitem_id}/empodetails/searchdefault")
	public ResponseEntity<Page<EMPODETAILDTO>> searchEMPODETAILDefaultByPFEMPEMITEM(@PathVariable("pfemp_id") String pfemp_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(empodetailMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "UpdateByPFUNITEMITEM", tags = {"EMPODETAIL" },  notes = "UpdateByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> updateByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
        domain.setEmpodetailid(empodetail_id);
		empodetailService.update(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFUNITEMITEM", tags = {"EMPODETAIL" },  notes = "UpdateBatchByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> updateBatchByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
            domain.setItemid(emitem_id);
        }
        empodetailService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFUNITEMITEM", tags = {"EMPODETAIL" },  notes = "GetByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    public ResponseEntity<EMPODETAILDTO> getByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id) {
        EMPODETAIL domain = empodetailService.get(empodetail_id);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CreateByPFUNITEMITEM", tags = {"EMPODETAIL" },  notes = "CreateByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/empodetails")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> createByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
		empodetailService.create(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFUNITEMITEM", tags = {"EMPODETAIL" },  notes = "createBatchByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> createBatchByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
            domain.setItemid(emitem_id);
        }
        empodetailService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFUNITEMITEM", tags = {"EMPODETAIL" },  notes = "GetDraftByPFUNITEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/empodetails/getdraft")
    public ResponseEntity<EMPODETAILDTO> getDraftByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id) {
        EMPODETAIL domain = new EMPODETAIL();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(empodetailMapping.toDto(empodetailService.getDraft(domain)));
    }

    @ApiOperation(value = "SaveByPFUNITEMITEM", tags = {"EMPODETAIL" },  notes = "SaveByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/empodetails/save")
    public ResponseEntity<Boolean> saveByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(empodetailService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFUNITEMITEM", tags = {"EMPODETAIL" },  notes = "SaveBatchByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/empodetails/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
             domain.setItemid(emitem_id);
        }
        empodetailService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByPFUNITEMITEM", tags = {"EMPODETAIL" },  notes = "CheckKeyByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/empodetails/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        return  ResponseEntity.status(HttpStatus.OK).body(empodetailService.checkKey(empodetailMapping.toDomain(empodetaildto)));
    }

    @ApiOperation(value = "RemoveByPFUNITEMITEM", tags = {"EMPODETAIL" },  notes = "RemoveByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id) {
		return ResponseEntity.status(HttpStatus.OK).body(empodetailService.remove(empodetail_id));
    }

    @ApiOperation(value = "RemoveBatchByPFUNITEMITEM", tags = {"EMPODETAIL" },  notes = "RemoveBatchByPFUNITEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfunits/{pfunit_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> removeBatchByPFUNITEMITEM(@RequestBody List<String> ids) {
        empodetailService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetch近五年采购ByPFUNITEMITEM", tags = {"EMPODETAIL" } ,notes = "fetch近五年采购ByPFUNITEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfunits/{pfunit_id}/emitems/{emitem_id}/empodetails/fetchlateryear")
	public ResponseEntity<List<HashMap>> fetchEMPODETAILLaterYearByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(domains.getContent());
	}

	@ApiOperation(value = "search近五年采购ByPFUNITEMITEM", tags = {"EMPODETAIL" } ,notes = "search近五年采购ByPFUNITEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfunits/{pfunit_id}/emitems/{emitem_id}/empodetails/searchlateryear")
	public ResponseEntity<Page<HashMap>> searchEMPODETAILLaterYearByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(domains.getContent(), context.getPageable(), domains.getTotalElements()));
	}

	@ApiOperation(value = "fetchDEFAULTByPFUNITEMITEM", tags = {"EMPODETAIL" } ,notes = "fetchDEFAULTByPFUNITEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfunits/{pfunit_id}/emitems/{emitem_id}/empodetails/fetchdefault")
	public ResponseEntity<List<EMPODETAILDTO>> fetchEMPODETAILDefaultByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
        List<EMPODETAILDTO> list = empodetailMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFUNITEMITEM", tags = {"EMPODETAIL" } ,notes = "searchDEFAULTByPFUNITEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/pfunits/{pfunit_id}/emitems/{emitem_id}/empodetails/searchdefault")
	public ResponseEntity<Page<EMPODETAILDTO>> searchEMPODETAILDefaultByPFUNITEMITEM(@PathVariable("pfunit_id") String pfunit_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(empodetailMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}





    @ApiOperation(value = "UpdateByEMSTOREEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "UpdateByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> updateByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
        domain.setEmpodetailid(empodetail_id);
		empodetailService.update(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSTOREEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "UpdateBatchByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> updateBatchByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
            domain.setItemid(emitem_id);
        }
        empodetailService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSTOREEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "GetByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    public ResponseEntity<EMPODETAILDTO> getByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id) {
        EMPODETAIL domain = empodetailService.get(empodetail_id);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CreateByEMSTOREEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "CreateByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails")
    @Transactional
    public ResponseEntity<EMPODETAILDTO> createByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
		empodetailService.create(domain);
        EMPODETAILDTO dto = empodetailMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSTOREEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "createBatchByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> createBatchByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
            domain.setItemid(emitem_id);
        }
        empodetailService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSTOREEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "GetDraftByEMSTOREEMSTOREPARTEMITEM")
    @RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/getdraft")
    public ResponseEntity<EMPODETAILDTO> getDraftByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id) {
        EMPODETAIL domain = new EMPODETAIL();
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(empodetailMapping.toDto(empodetailService.getDraft(domain)));
    }

    @ApiOperation(value = "SaveByEMSTOREEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "SaveByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/save")
    public ResponseEntity<Boolean> saveByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        EMPODETAIL domain = empodetailMapping.toDomain(empodetaildto);
        domain.setItemid(emitem_id);
        return ResponseEntity.status(HttpStatus.OK).body(empodetailService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSTOREEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "SaveBatchByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody List<EMPODETAILDTO> empodetaildtos) {
        List<EMPODETAIL> domainlist=empodetailMapping.toDomain(empodetaildtos);
        for(EMPODETAIL domain:domainlist){
             domain.setItemid(emitem_id);
        }
        empodetailService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMSTOREEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "CheckKeyByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @RequestBody EMPODETAILDTO empodetaildto) {
        return  ResponseEntity.status(HttpStatus.OK).body(empodetailService.checkKey(empodetailMapping.toDomain(empodetaildto)));
    }

    @ApiOperation(value = "RemoveByEMSTOREEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "RemoveByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/{empodetail_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id, @PathVariable("empodetail_id") String empodetail_id) {
		return ResponseEntity.status(HttpStatus.OK).body(empodetailService.remove(empodetail_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSTOREEMSTOREPARTEMITEM", tags = {"EMPODETAIL" },  notes = "RemoveBatchByEMSTOREEMSTOREPARTEMITEM")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/batch")
    public ResponseEntity<Boolean> removeBatchByEMSTOREEMSTOREPARTEMITEM(@RequestBody List<String> ids) {
        empodetailService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "fetch近五年采购ByEMSTOREEMSTOREPARTEMITEM", tags = {"EMPODETAIL" } ,notes = "fetch近五年采购ByEMSTOREEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/fetchlateryear")
	public ResponseEntity<List<HashMap>> fetchEMPODETAILLaterYearByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(domains.getContent());
	}

	@ApiOperation(value = "search近五年采购ByEMSTOREEMSTOREPARTEMITEM", tags = {"EMPODETAIL" } ,notes = "search近五年采购ByEMSTOREEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/searchlateryear")
	public ResponseEntity<Page<HashMap>> searchEMPODETAILLaterYearByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<HashMap> domains = empodetailService.searchLaterYear(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(domains.getContent(), context.getPageable(), domains.getTotalElements()));
	}

	@ApiOperation(value = "fetchDEFAULTByEMSTOREEMSTOREPARTEMITEM", tags = {"EMPODETAIL" } ,notes = "fetchDEFAULTByEMSTOREEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/fetchdefault")
	public ResponseEntity<List<EMPODETAILDTO>> fetchEMPODETAILDefaultByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
        List<EMPODETAILDTO> list = empodetailMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSTOREEMSTOREPARTEMITEM", tags = {"EMPODETAIL" } ,notes = "searchDEFAULTByEMSTOREEMSTOREPARTEMITEM")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emstoreparts/{emstorepart_id}/emitems/{emitem_id}/empodetails/searchdefault")
	public ResponseEntity<Page<EMPODETAILDTO>> searchEMPODETAILDefaultByEMSTOREEMSTOREPARTEMITEM(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @PathVariable("emitem_id") String emitem_id,EMPODETAILSearchContext context) {
        context.setN_itemid_eq(emitem_id);
        Page<EMPODETAIL> domains = empodetailService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(empodetailMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMPODETAIL getEntity(){
        return new EMPODETAIL();
    }

}
