package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMPRODUCT;
import cn.ibizlab.eam.core.eam_core.service.IEMPRODUCTService;
import cn.ibizlab.eam.core.eam_core.filter.EMPRODUCTSearchContext;




@Slf4j
@Api(tags = {"EMPRODUCT" })
@RestController("WebApi-emproduct")
@RequestMapping("")
public class EMPRODUCTResource {

    @Autowired
    private IEMPRODUCTService emproductService;

    @Autowired
    @Lazy
    private EMPRODUCTMapping emproductMapping;




    @ApiOperation(value = "GetDraft", tags = {"EMPRODUCT" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emproducts/getdraft")
    public ResponseEntity<EMPRODUCTDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emproductMapping.toDto(emproductService.getDraft(new EMPRODUCT())));
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMPRODUCT" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emproducts")
    @Transactional
    public ResponseEntity<EMPRODUCTDTO> create(@RequestBody EMPRODUCTDTO emproductdto) {
        EMPRODUCT domain = emproductMapping.toDomain(emproductdto);
		emproductService.create(domain);
        EMPRODUCTDTO dto = emproductMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMPRODUCT" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emproducts/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMPRODUCTDTO> emproductdtos) {
        emproductService.createBatch(emproductMapping.toDomain(emproductdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"EMPRODUCT" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emproducts/save")
    public ResponseEntity<Boolean> save(@RequestBody EMPRODUCTDTO emproductdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emproductService.save(emproductMapping.toDomain(emproductdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMPRODUCT" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emproducts/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMPRODUCTDTO> emproductdtos) {
        emproductService.saveBatch(emproductMapping.toDomain(emproductdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMPRODUCT" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emproducts/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMPRODUCTDTO emproductdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emproductService.checkKey(emproductMapping.toDomain(emproductdto)));
    }




    @PreAuthorize("hasPermission('Remove',{#emproduct_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMPRODUCT" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emproducts/{emproduct_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emproduct_id") String emproduct_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emproductService.remove(emproduct_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMPRODUCT" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emproducts/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emproductService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emproduct_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMPRODUCT" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emproducts/{emproduct_id}")
    @Transactional
    public ResponseEntity<EMPRODUCTDTO> update(@PathVariable("emproduct_id") String emproduct_id, @RequestBody EMPRODUCTDTO emproductdto) {
		EMPRODUCT domain = emproductMapping.toDomain(emproductdto);
        domain.setEmproductid(emproduct_id);
		emproductService.update(domain);
		EMPRODUCTDTO dto = emproductMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emproduct_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMPRODUCT" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emproducts/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMPRODUCTDTO> emproductdtos) {
        emproductService.updateBatch(emproductMapping.toDomain(emproductdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emproduct_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMPRODUCT" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emproducts/{emproduct_id}")
    public ResponseEntity<EMPRODUCTDTO> get(@PathVariable("emproduct_id") String emproduct_id) {
        EMPRODUCT domain = emproductService.get(emproduct_id);
        EMPRODUCTDTO dto = emproductMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMPRODUCT" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emproducts/fetchdefault")
	public ResponseEntity<List<EMPRODUCTDTO>> fetchDefault(EMPRODUCTSearchContext context) {
        Page<EMPRODUCT> domains = emproductService.searchDefault(context) ;
        List<EMPRODUCTDTO> list = emproductMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMPRODUCT" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emproducts/searchdefault")
	public ResponseEntity<Page<EMPRODUCTDTO>> searchDefault(EMPRODUCTSearchContext context) {
        Page<EMPRODUCT> domains = emproductService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emproductMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMPRODUCT getEntity(){
        return new EMPRODUCT();
    }

}
