package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMREPAIRCOST;
import cn.ibizlab.eam.core.eam_core.service.IEMREPAIRCOSTService;
import cn.ibizlab.eam.core.eam_core.filter.EMREPAIRCOSTSearchContext;




@Slf4j
@Api(tags = {"EMREPAIRCOST" })
@RestController("WebApi-emrepaircost")
@RequestMapping("")
public class EMREPAIRCOSTResource {

    @Autowired
    private IEMREPAIRCOSTService emrepaircostService;

    @Autowired
    @Lazy
    private EMREPAIRCOSTMapping emrepaircostMapping;




    @ApiOperation(value = "CheckKey", tags = {"EMREPAIRCOST" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emrepaircosts/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMREPAIRCOSTDTO emrepaircostdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emrepaircostService.checkKey(emrepaircostMapping.toDomain(emrepaircostdto)));
    }




    @PreAuthorize("hasPermission(#emrepaircost_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMREPAIRCOST" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emrepaircosts/{emrepaircost_id}")
    @Transactional
    public ResponseEntity<EMREPAIRCOSTDTO> update(@PathVariable("emrepaircost_id") String emrepaircost_id, @RequestBody EMREPAIRCOSTDTO emrepaircostdto) {
		EMREPAIRCOST domain = emrepaircostMapping.toDomain(emrepaircostdto);
        domain.setEmrepaircostid(emrepaircost_id);
		emrepaircostService.update(domain);
		EMREPAIRCOSTDTO dto = emrepaircostMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emrepaircost_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMREPAIRCOST" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emrepaircosts/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMREPAIRCOSTDTO> emrepaircostdtos) {
        emrepaircostService.updateBatch(emrepaircostMapping.toDomain(emrepaircostdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMREPAIRCOST" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emrepaircosts")
    @Transactional
    public ResponseEntity<EMREPAIRCOSTDTO> create(@RequestBody EMREPAIRCOSTDTO emrepaircostdto) {
        EMREPAIRCOST domain = emrepaircostMapping.toDomain(emrepaircostdto);
		emrepaircostService.create(domain);
        EMREPAIRCOSTDTO dto = emrepaircostMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMREPAIRCOST" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emrepaircosts/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMREPAIRCOSTDTO> emrepaircostdtos) {
        emrepaircostService.createBatch(emrepaircostMapping.toDomain(emrepaircostdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"EMREPAIRCOST" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emrepaircosts/save")
    public ResponseEntity<Boolean> save(@RequestBody EMREPAIRCOSTDTO emrepaircostdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emrepaircostService.save(emrepaircostMapping.toDomain(emrepaircostdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMREPAIRCOST" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emrepaircosts/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMREPAIRCOSTDTO> emrepaircostdtos) {
        emrepaircostService.saveBatch(emrepaircostMapping.toDomain(emrepaircostdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMREPAIRCOST" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emrepaircosts/getdraft")
    public ResponseEntity<EMREPAIRCOSTDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emrepaircostMapping.toDto(emrepaircostService.getDraft(new EMREPAIRCOST())));
    }




    @PreAuthorize("hasPermission('Remove',{#emrepaircost_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMREPAIRCOST" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emrepaircosts/{emrepaircost_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emrepaircost_id") String emrepaircost_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emrepaircostService.remove(emrepaircost_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMREPAIRCOST" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emrepaircosts/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emrepaircostService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emrepaircost_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMREPAIRCOST" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emrepaircosts/{emrepaircost_id}")
    public ResponseEntity<EMREPAIRCOSTDTO> get(@PathVariable("emrepaircost_id") String emrepaircost_id) {
        EMREPAIRCOST domain = emrepaircostService.get(emrepaircost_id);
        EMREPAIRCOSTDTO dto = emrepaircostMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMREPAIRCOST" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emrepaircosts/fetchdefault")
	public ResponseEntity<List<EMREPAIRCOSTDTO>> fetchDefault(EMREPAIRCOSTSearchContext context) {
        Page<EMREPAIRCOST> domains = emrepaircostService.searchDefault(context) ;
        List<EMREPAIRCOSTDTO> list = emrepaircostMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMREPAIRCOST" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emrepaircosts/searchdefault")
	public ResponseEntity<Page<EMREPAIRCOSTDTO>> searchDefault(EMREPAIRCOSTSearchContext context) {
        Page<EMREPAIRCOST> domains = emrepaircostService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emrepaircostMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMREPAIRCOST getEntity(){
        return new EMREPAIRCOST();
    }

}
