package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMRESSERVICE;
import cn.ibizlab.eam.core.eam_core.service.IEMRESSERVICEService;
import cn.ibizlab.eam.core.eam_core.filter.EMRESSERVICESearchContext;




@Slf4j
@Api(tags = {"EMRESSERVICE" })
@RestController("WebApi-emresservice")
@RequestMapping("")
public class EMRESSERVICEResource {

    @Autowired
    private IEMRESSERVICEService emresserviceService;

    @Autowired
    @Lazy
    private EMRESSERVICEMapping emresserviceMapping;




    @ApiOperation(value = "CheckKey", tags = {"EMRESSERVICE" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emresservices/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMRESSERVICEDTO emresservicedto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emresserviceService.checkKey(emresserviceMapping.toDomain(emresservicedto)));
    }




    @PreAuthorize("hasPermission(#emresservice_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMRESSERVICE" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emresservices/{emresservice_id}")
    public ResponseEntity<EMRESSERVICEDTO> get(@PathVariable("emresservice_id") String emresservice_id) {
        EMRESSERVICE domain = emresserviceService.get(emresservice_id);
        EMRESSERVICEDTO dto = emresserviceMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "Save", tags = {"EMRESSERVICE" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emresservices/save")
    public ResponseEntity<Boolean> save(@RequestBody EMRESSERVICEDTO emresservicedto) {
        return ResponseEntity.status(HttpStatus.OK).body(emresserviceService.save(emresserviceMapping.toDomain(emresservicedto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMRESSERVICE" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emresservices/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMRESSERVICEDTO> emresservicedtos) {
        emresserviceService.saveBatch(emresserviceMapping.toDomain(emresservicedtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMRESSERVICE" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emresservices")
    @Transactional
    public ResponseEntity<EMRESSERVICEDTO> create(@RequestBody EMRESSERVICEDTO emresservicedto) {
        EMRESSERVICE domain = emresserviceMapping.toDomain(emresservicedto);
		emresserviceService.create(domain);
        EMRESSERVICEDTO dto = emresserviceMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMRESSERVICE" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emresservices/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMRESSERVICEDTO> emresservicedtos) {
        emresserviceService.createBatch(emresserviceMapping.toDomain(emresservicedtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emresservice_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMRESSERVICE" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emresservices/{emresservice_id}")
    @Transactional
    public ResponseEntity<EMRESSERVICEDTO> update(@PathVariable("emresservice_id") String emresservice_id, @RequestBody EMRESSERVICEDTO emresservicedto) {
		EMRESSERVICE domain = emresserviceMapping.toDomain(emresservicedto);
        domain.setEmresserviceid(emresservice_id);
		emresserviceService.update(domain);
		EMRESSERVICEDTO dto = emresserviceMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emresservice_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMRESSERVICE" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emresservices/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMRESSERVICEDTO> emresservicedtos) {
        emresserviceService.updateBatch(emresserviceMapping.toDomain(emresservicedtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emresservice_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMRESSERVICE" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emresservices/{emresservice_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emresservice_id") String emresservice_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emresserviceService.remove(emresservice_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMRESSERVICE" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emresservices/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emresserviceService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMRESSERVICE" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emresservices/getdraft")
    public ResponseEntity<EMRESSERVICEDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emresserviceMapping.toDto(emresserviceService.getDraft(new EMRESSERVICE())));
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMRESSERVICE" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emresservices/fetchdefault")
	public ResponseEntity<List<EMRESSERVICEDTO>> fetchDefault(EMRESSERVICESearchContext context) {
        Page<EMRESSERVICE> domains = emresserviceService.searchDefault(context) ;
        List<EMRESSERVICEDTO> list = emresserviceMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMRESSERVICE" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emresservices/searchdefault")
	public ResponseEntity<Page<EMRESSERVICEDTO>> searchDefault(EMRESSERVICESearchContext context) {
        Page<EMRESSERVICE> domains = emresserviceService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emresserviceMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMRESSERVICE getEntity(){
        return new EMRESSERVICE();
    }

}
