package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMSTOREPART;
import cn.ibizlab.eam.core.eam_core.service.IEMSTOREPARTService;
import cn.ibizlab.eam.core.eam_core.filter.EMSTOREPARTSearchContext;




@Slf4j
@Api(tags = {"EMSTOREPART" })
@RestController("WebApi-emstorepart")
@RequestMapping("")
public class EMSTOREPARTResource {

    @Autowired
    private IEMSTOREPARTService emstorepartService;

    @Autowired
    @Lazy
    private EMSTOREPARTMapping emstorepartMapping;




    @PreAuthorize("hasPermission(#emstorepart_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMSTOREPART" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstoreparts/{emstorepart_id}")
    @Transactional
    public ResponseEntity<EMSTOREPARTDTO> update(@PathVariable("emstorepart_id") String emstorepart_id, @RequestBody EMSTOREPARTDTO emstorepartdto) {
		EMSTOREPART domain = emstorepartMapping.toDomain(emstorepartdto);
        domain.setEmstorepartid(emstorepart_id);
		emstorepartService.update(domain);
		EMSTOREPARTDTO dto = emstorepartMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emstorepart_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMSTOREPART" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstoreparts/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMSTOREPARTDTO> emstorepartdtos) {
        emstorepartService.updateBatch(emstorepartMapping.toDomain(emstorepartdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMSTOREPART" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emstoreparts/getdraft")
    public ResponseEntity<EMSTOREPARTDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emstorepartMapping.toDto(emstorepartService.getDraft(new EMSTOREPART())));
    }




    @ApiOperation(value = "Save", tags = {"EMSTOREPART" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/save")
    public ResponseEntity<Boolean> save(@RequestBody EMSTOREPARTDTO emstorepartdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emstorepartService.save(emstorepartMapping.toDomain(emstorepartdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMSTOREPART" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMSTOREPARTDTO> emstorepartdtos) {
        emstorepartService.saveBatch(emstorepartMapping.toDomain(emstorepartdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMSTOREPART" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts")
    @Transactional
    public ResponseEntity<EMSTOREPARTDTO> create(@RequestBody EMSTOREPARTDTO emstorepartdto) {
        EMSTOREPART domain = emstorepartMapping.toDomain(emstorepartdto);
		emstorepartService.create(domain);
        EMSTOREPARTDTO dto = emstorepartMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMSTOREPART" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMSTOREPARTDTO> emstorepartdtos) {
        emstorepartService.createBatch(emstorepartMapping.toDomain(emstorepartdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emstorepart_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMSTOREPART" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emstoreparts/{emstorepart_id}")
    public ResponseEntity<EMSTOREPARTDTO> get(@PathVariable("emstorepart_id") String emstorepart_id) {
        EMSTOREPART domain = emstorepartService.get(emstorepart_id);
        EMSTOREPARTDTO dto = emstorepartMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @PreAuthorize("hasPermission('Remove',{#emstorepart_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMSTOREPART" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstoreparts/{emstorepart_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emstorepart_id") String emstorepart_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emstorepartService.remove(emstorepart_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMSTOREPART" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstoreparts/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emstorepartService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMSTOREPART" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emstoreparts/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMSTOREPARTDTO emstorepartdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emstorepartService.checkKey(emstorepartMapping.toDomain(emstorepartdto)));
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMSTOREPART" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emstoreparts/fetchdefault")
	public ResponseEntity<List<EMSTOREPARTDTO>> fetchDefault(EMSTOREPARTSearchContext context) {
        Page<EMSTOREPART> domains = emstorepartService.searchDefault(context) ;
        List<EMSTOREPARTDTO> list = emstorepartMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMSTOREPART" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emstoreparts/searchdefault")
	public ResponseEntity<Page<EMSTOREPARTDTO>> searchDefault(EMSTOREPARTSearchContext context) {
        Page<EMSTOREPART> domains = emstorepartService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emstorepartMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "UpdateByEMSTORE", tags = {"EMSTOREPART" },  notes = "UpdateByEMSTORE")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}")
    @Transactional
    public ResponseEntity<EMSTOREPARTDTO> updateByEMSTORE(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id, @RequestBody EMSTOREPARTDTO emstorepartdto) {
        EMSTOREPART domain = emstorepartMapping.toDomain(emstorepartdto);
        domain.setStoreid(emstore_id);
        domain.setEmstorepartid(emstorepart_id);
		emstorepartService.update(domain);
        EMSTOREPARTDTO dto = emstorepartMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMSTORE", tags = {"EMSTOREPART" },  notes = "UpdateBatchByEMSTORE")
	@RequestMapping(method = RequestMethod.PUT, value = "/emstores/{emstore_id}/emstoreparts/batch")
    public ResponseEntity<Boolean> updateBatchByEMSTORE(@PathVariable("emstore_id") String emstore_id, @RequestBody List<EMSTOREPARTDTO> emstorepartdtos) {
        List<EMSTOREPART> domainlist=emstorepartMapping.toDomain(emstorepartdtos);
        for(EMSTOREPART domain:domainlist){
            domain.setStoreid(emstore_id);
        }
        emstorepartService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMSTORE", tags = {"EMSTOREPART" },  notes = "GetDraftByEMSTORE")
    @RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emstoreparts/getdraft")
    public ResponseEntity<EMSTOREPARTDTO> getDraftByEMSTORE(@PathVariable("emstore_id") String emstore_id) {
        EMSTOREPART domain = new EMSTOREPART();
        domain.setStoreid(emstore_id);
        return ResponseEntity.status(HttpStatus.OK).body(emstorepartMapping.toDto(emstorepartService.getDraft(domain)));
    }

    @ApiOperation(value = "SaveByEMSTORE", tags = {"EMSTOREPART" },  notes = "SaveByEMSTORE")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/save")
    public ResponseEntity<Boolean> saveByEMSTORE(@PathVariable("emstore_id") String emstore_id, @RequestBody EMSTOREPARTDTO emstorepartdto) {
        EMSTOREPART domain = emstorepartMapping.toDomain(emstorepartdto);
        domain.setStoreid(emstore_id);
        return ResponseEntity.status(HttpStatus.OK).body(emstorepartService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMSTORE", tags = {"EMSTOREPART" },  notes = "SaveBatchByEMSTORE")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMSTORE(@PathVariable("emstore_id") String emstore_id, @RequestBody List<EMSTOREPARTDTO> emstorepartdtos) {
        List<EMSTOREPART> domainlist=emstorepartMapping.toDomain(emstorepartdtos);
        for(EMSTOREPART domain:domainlist){
             domain.setStoreid(emstore_id);
        }
        emstorepartService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CreateByEMSTORE", tags = {"EMSTOREPART" },  notes = "CreateByEMSTORE")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts")
    @Transactional
    public ResponseEntity<EMSTOREPARTDTO> createByEMSTORE(@PathVariable("emstore_id") String emstore_id, @RequestBody EMSTOREPARTDTO emstorepartdto) {
        EMSTOREPART domain = emstorepartMapping.toDomain(emstorepartdto);
        domain.setStoreid(emstore_id);
		emstorepartService.create(domain);
        EMSTOREPARTDTO dto = emstorepartMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMSTORE", tags = {"EMSTOREPART" },  notes = "createBatchByEMSTORE")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/batch")
    public ResponseEntity<Boolean> createBatchByEMSTORE(@PathVariable("emstore_id") String emstore_id, @RequestBody List<EMSTOREPARTDTO> emstorepartdtos) {
        List<EMSTOREPART> domainlist=emstorepartMapping.toDomain(emstorepartdtos);
        for(EMSTOREPART domain:domainlist){
            domain.setStoreid(emstore_id);
        }
        emstorepartService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMSTORE", tags = {"EMSTOREPART" },  notes = "GetByEMSTORE")
	@RequestMapping(method = RequestMethod.GET, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}")
    public ResponseEntity<EMSTOREPARTDTO> getByEMSTORE(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id) {
        EMSTOREPART domain = emstorepartService.get(emstorepart_id);
        EMSTOREPARTDTO dto = emstorepartMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "RemoveByEMSTORE", tags = {"EMSTOREPART" },  notes = "RemoveByEMSTORE")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emstoreparts/{emstorepart_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMSTORE(@PathVariable("emstore_id") String emstore_id, @PathVariable("emstorepart_id") String emstorepart_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emstorepartService.remove(emstorepart_id));
    }

    @ApiOperation(value = "RemoveBatchByEMSTORE", tags = {"EMSTOREPART" },  notes = "RemoveBatchByEMSTORE")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emstores/{emstore_id}/emstoreparts/batch")
    public ResponseEntity<Boolean> removeBatchByEMSTORE(@RequestBody List<String> ids) {
        emstorepartService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "CheckKeyByEMSTORE", tags = {"EMSTOREPART" },  notes = "CheckKeyByEMSTORE")
	@RequestMapping(method = RequestMethod.POST, value = "/emstores/{emstore_id}/emstoreparts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMSTORE(@PathVariable("emstore_id") String emstore_id, @RequestBody EMSTOREPARTDTO emstorepartdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emstorepartService.checkKey(emstorepartMapping.toDomain(emstorepartdto)));
    }

	@ApiOperation(value = "fetchDEFAULTByEMSTORE", tags = {"EMSTOREPART" } ,notes = "fetchDEFAULTByEMSTORE")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emstoreparts/fetchdefault")
	public ResponseEntity<List<EMSTOREPARTDTO>> fetchEMSTOREPARTDefaultByEMSTORE(@PathVariable("emstore_id") String emstore_id,EMSTOREPARTSearchContext context) {
        context.setN_storeid_eq(emstore_id);
        Page<EMSTOREPART> domains = emstorepartService.searchDefault(context) ;
        List<EMSTOREPARTDTO> list = emstorepartMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMSTORE", tags = {"EMSTOREPART" } ,notes = "searchDEFAULTByEMSTORE")
    @RequestMapping(method= RequestMethod.GET , value="/emstores/{emstore_id}/emstoreparts/searchdefault")
	public ResponseEntity<Page<EMSTOREPARTDTO>> searchEMSTOREPARTDefaultByEMSTORE(@PathVariable("emstore_id") String emstore_id,EMSTOREPARTSearchContext context) {
        context.setN_storeid_eq(emstore_id);
        Page<EMSTOREPART> domains = emstorepartService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emstorepartMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMSTOREPART getEntity(){
        return new EMSTOREPART();
    }

}
