package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMSUBLIST;
import cn.ibizlab.eam.core.eam_core.service.IEMSUBLISTService;
import cn.ibizlab.eam.core.eam_core.filter.EMSUBLISTSearchContext;




@Slf4j
@Api(tags = {"EMSUBLIST" })
@RestController("WebApi-emsublist")
@RequestMapping("")
public class EMSUBLISTResource {

    @Autowired
    private IEMSUBLISTService emsublistService;

    @Autowired
    @Lazy
    private EMSUBLISTMapping emsublistMapping;




    @ApiOperation(value = "CheckKey", tags = {"EMSUBLIST" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emsublists/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMSUBLISTDTO emsublistdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emsublistService.checkKey(emsublistMapping.toDomain(emsublistdto)));
    }




    @PreAuthorize("hasPermission(#emsublist_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMSUBLIST" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emsublists/{emsublist_id}")
    public ResponseEntity<EMSUBLISTDTO> get(@PathVariable("emsublist_id") String emsublist_id) {
        EMSUBLIST domain = emsublistService.get(emsublist_id);
        EMSUBLISTDTO dto = emsublistMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "Save", tags = {"EMSUBLIST" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emsublists/save")
    public ResponseEntity<Boolean> save(@RequestBody EMSUBLISTDTO emsublistdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emsublistService.save(emsublistMapping.toDomain(emsublistdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMSUBLIST" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emsublists/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMSUBLISTDTO> emsublistdtos) {
        emsublistService.saveBatch(emsublistMapping.toDomain(emsublistdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMSUBLIST" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emsublists")
    @Transactional
    public ResponseEntity<EMSUBLISTDTO> create(@RequestBody EMSUBLISTDTO emsublistdto) {
        EMSUBLIST domain = emsublistMapping.toDomain(emsublistdto);
		emsublistService.create(domain);
        EMSUBLISTDTO dto = emsublistMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMSUBLIST" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emsublists/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMSUBLISTDTO> emsublistdtos) {
        emsublistService.createBatch(emsublistMapping.toDomain(emsublistdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMSUBLIST" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emsublists/getdraft")
    public ResponseEntity<EMSUBLISTDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emsublistMapping.toDto(emsublistService.getDraft(new EMSUBLIST())));
    }




    @PreAuthorize("hasPermission('Remove',{#emsublist_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMSUBLIST" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emsublists/{emsublist_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emsublist_id") String emsublist_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emsublistService.remove(emsublist_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMSUBLIST" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emsublists/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emsublistService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emsublist_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMSUBLIST" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emsublists/{emsublist_id}")
    @Transactional
    public ResponseEntity<EMSUBLISTDTO> update(@PathVariable("emsublist_id") String emsublist_id, @RequestBody EMSUBLISTDTO emsublistdto) {
		EMSUBLIST domain = emsublistMapping.toDomain(emsublistdto);
        domain.setEmsublistid(emsublist_id);
		emsublistService.update(domain);
		EMSUBLISTDTO dto = emsublistMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emsublist_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMSUBLIST" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emsublists/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMSUBLISTDTO> emsublistdtos) {
        emsublistService.updateBatch(emsublistMapping.toDomain(emsublistdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMSUBLIST" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emsublists/fetchdefault")
	public ResponseEntity<List<EMSUBLISTDTO>> fetchDefault(EMSUBLISTSearchContext context) {
        Page<EMSUBLIST> domains = emsublistService.searchDefault(context) ;
        List<EMSUBLISTDTO> list = emsublistMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMSUBLIST" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emsublists/searchdefault")
	public ResponseEntity<Page<EMSUBLISTDTO>> searchDefault(EMSUBLISTSearchContext context) {
        Page<EMSUBLIST> domains = emsublistService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emsublistMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMSUBLIST getEntity(){
        return new EMSUBLIST();
    }

}
