package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMWEEKLYPLAN;
import cn.ibizlab.eam.core.eam_core.service.IEMWEEKLYPLANService;
import cn.ibizlab.eam.core.eam_core.filter.EMWEEKLYPLANSearchContext;




@Slf4j
@Api(tags = {"EMWEEKLYPLAN" })
@RestController("WebApi-emweeklyplan")
@RequestMapping("")
public class EMWEEKLYPLANResource {

    @Autowired
    private IEMWEEKLYPLANService emweeklyplanService;

    @Autowired
    @Lazy
    private EMWEEKLYPLANMapping emweeklyplanMapping;




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMWEEKLYPLAN" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emweeklyplans")
    @Transactional
    public ResponseEntity<EMWEEKLYPLANDTO> create(@RequestBody EMWEEKLYPLANDTO emweeklyplandto) {
        EMWEEKLYPLAN domain = emweeklyplanMapping.toDomain(emweeklyplandto);
		emweeklyplanService.create(domain);
        EMWEEKLYPLANDTO dto = emweeklyplanMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMWEEKLYPLAN" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emweeklyplans/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMWEEKLYPLANDTO> emweeklyplandtos) {
        emweeklyplanService.createBatch(emweeklyplanMapping.toDomain(emweeklyplandtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emweeklyplan_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMWEEKLYPLAN" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emweeklyplans/{emweeklyplan_id}")
    public ResponseEntity<EMWEEKLYPLANDTO> get(@PathVariable("emweeklyplan_id") String emweeklyplan_id) {
        EMWEEKLYPLAN domain = emweeklyplanService.get(emweeklyplan_id);
        EMWEEKLYPLANDTO dto = emweeklyplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "Save", tags = {"EMWEEKLYPLAN" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emweeklyplans/save")
    public ResponseEntity<Boolean> save(@RequestBody EMWEEKLYPLANDTO emweeklyplandto) {
        return ResponseEntity.status(HttpStatus.OK).body(emweeklyplanService.save(emweeklyplanMapping.toDomain(emweeklyplandto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMWEEKLYPLAN" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emweeklyplans/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMWEEKLYPLANDTO> emweeklyplandtos) {
        emweeklyplanService.saveBatch(emweeklyplanMapping.toDomain(emweeklyplandtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emweeklyplan_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMWEEKLYPLAN" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emweeklyplans/{emweeklyplan_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emweeklyplan_id") String emweeklyplan_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emweeklyplanService.remove(emweeklyplan_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMWEEKLYPLAN" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emweeklyplans/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emweeklyplanService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emweeklyplan_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMWEEKLYPLAN" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emweeklyplans/{emweeklyplan_id}")
    @Transactional
    public ResponseEntity<EMWEEKLYPLANDTO> update(@PathVariable("emweeklyplan_id") String emweeklyplan_id, @RequestBody EMWEEKLYPLANDTO emweeklyplandto) {
		EMWEEKLYPLAN domain = emweeklyplanMapping.toDomain(emweeklyplandto);
        domain.setEmweeklyplanid(emweeklyplan_id);
		emweeklyplanService.update(domain);
		EMWEEKLYPLANDTO dto = emweeklyplanMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emweeklyplan_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMWEEKLYPLAN" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emweeklyplans/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMWEEKLYPLANDTO> emweeklyplandtos) {
        emweeklyplanService.updateBatch(emweeklyplanMapping.toDomain(emweeklyplandtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMWEEKLYPLAN" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emweeklyplans/getdraft")
    public ResponseEntity<EMWEEKLYPLANDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emweeklyplanMapping.toDto(emweeklyplanService.getDraft(new EMWEEKLYPLAN())));
    }




    @ApiOperation(value = "CheckKey", tags = {"EMWEEKLYPLAN" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emweeklyplans/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMWEEKLYPLANDTO emweeklyplandto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emweeklyplanService.checkKey(emweeklyplanMapping.toDomain(emweeklyplandto)));
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMWEEKLYPLAN" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emweeklyplans/fetchdefault")
	public ResponseEntity<List<EMWEEKLYPLANDTO>> fetchDefault(EMWEEKLYPLANSearchContext context) {
        Page<EMWEEKLYPLAN> domains = emweeklyplanService.searchDefault(context) ;
        List<EMWEEKLYPLANDTO> list = emweeklyplanMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMWEEKLYPLAN" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emweeklyplans/searchdefault")
	public ResponseEntity<Page<EMWEEKLYPLANDTO>> searchDefault(EMWEEKLYPLANSearchContext context) {
        Page<EMWEEKLYPLAN> domains = emweeklyplanService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emweeklyplanMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMWEEKLYPLAN getEntity(){
        return new EMWEEKLYPLAN();
    }

}
