package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMWORK;
import cn.ibizlab.eam.core.eam_core.service.IEMWORKService;
import cn.ibizlab.eam.core.eam_core.filter.EMWORKSearchContext;




@Slf4j
@Api(tags = {"EMWORK" })
@RestController("WebApi-emwork")
@RequestMapping("")
public class EMWORKResource {

    @Autowired
    private IEMWORKService emworkService;

    @Autowired
    @Lazy
    private EMWORKMapping emworkMapping;




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMWORK" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emworks")
    @Transactional
    public ResponseEntity<EMWORKDTO> create(@RequestBody EMWORKDTO emworkdto) {
        EMWORK domain = emworkMapping.toDomain(emworkdto);
		emworkService.create(domain);
        EMWORKDTO dto = emworkMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMWORK" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emworks/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMWORKDTO> emworkdtos) {
        emworkService.createBatch(emworkMapping.toDomain(emworkdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"EMWORK" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emworks/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMWORKDTO emworkdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emworkService.checkKey(emworkMapping.toDomain(emworkdto)));
    }




    @PreAuthorize("hasPermission(#emwork_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMWORK" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emworks/{emwork_id}")
    public ResponseEntity<EMWORKDTO> get(@PathVariable("emwork_id") String emwork_id) {
        EMWORK domain = emworkService.get(emwork_id);
        EMWORKDTO dto = emworkMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMWORK" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emworks/getdraft")
    public ResponseEntity<EMWORKDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emworkMapping.toDto(emworkService.getDraft(new EMWORK())));
    }




    @PreAuthorize("hasPermission(#emwork_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMWORK" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emworks/{emwork_id}")
    @Transactional
    public ResponseEntity<EMWORKDTO> update(@PathVariable("emwork_id") String emwork_id, @RequestBody EMWORKDTO emworkdto) {
		EMWORK domain = emworkMapping.toDomain(emworkdto);
        domain.setEmworkid(emwork_id);
		emworkService.update(domain);
		EMWORKDTO dto = emworkMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emwork_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMWORK" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emworks/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMWORKDTO> emworkdtos) {
        emworkService.updateBatch(emworkMapping.toDomain(emworkdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"EMWORK" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emworks/save")
    public ResponseEntity<Boolean> save(@RequestBody EMWORKDTO emworkdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emworkService.save(emworkMapping.toDomain(emworkdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMWORK" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emworks/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMWORKDTO> emworkdtos) {
        emworkService.saveBatch(emworkMapping.toDomain(emworkdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emwork_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMWORK" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emworks/{emwork_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emwork_id") String emwork_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emworkService.remove(emwork_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMWORK" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emworks/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emworkService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMWORK" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emworks/fetchdefault")
	public ResponseEntity<List<EMWORKDTO>> fetchDefault(EMWORKSearchContext context) {
        Page<EMWORK> domains = emworkService.searchDefault(context) ;
        List<EMWORKDTO> list = emworkMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMWORK" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emworks/searchdefault")
	public ResponseEntity<Page<EMWORKDTO>> searchDefault(EMWORKSearchContext context) {
        Page<EMWORK> domains = emworkService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emworkMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMWORK getEntity(){
        return new EMWORK();
    }

}
