package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_core.domain.EMWO_PT;
import cn.ibizlab.eam.core.eam_core.service.IEMWO_PTService;
import cn.ibizlab.eam.core.eam_core.filter.EMWO_PTSearchContext;




@Slf4j
@Api(tags = {"EMWO_PT" })
@RestController("WebApi-emwo_pt")
@RequestMapping("")
public class EMWO_PTResource {

    @Autowired
    private IEMWO_PTService emwo_ptService;

    @Autowired
    @Lazy
    private EMWO_PTMapping emwo_ptMapping;




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"EMWO_PT" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/emwo_pts")
    @Transactional
    public ResponseEntity<EMWO_PTDTO> create(@RequestBody EMWO_PTDTO emwo_ptdto) {
        EMWO_PT domain = emwo_ptMapping.toDomain(emwo_ptdto);
		emwo_ptService.create(domain);
        EMWO_PTDTO dto = emwo_ptMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"EMWO_PT" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emwo_pts/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<EMWO_PTDTO> emwo_ptdtos) {
        emwo_ptService.createBatch(emwo_ptMapping.toDomain(emwo_ptdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#emwo_pt_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"EMWO_PT" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emwo_pts/{emwo_pt_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("emwo_pt_id") String emwo_pt_id) {
         return ResponseEntity.status(HttpStatus.OK).body(emwo_ptService.remove(emwo_pt_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"EMWO_PT" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emwo_pts/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        emwo_ptService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"EMWO_PT" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/emwo_pts/getdraft")
    public ResponseEntity<EMWO_PTDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(emwo_ptMapping.toDto(emwo_ptService.getDraft(new EMWO_PT())));
    }




    @ApiOperation(value = "CheckKey", tags = {"EMWO_PT" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/emwo_pts/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EMWO_PTDTO emwo_ptdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emwo_ptService.checkKey(emwo_ptMapping.toDomain(emwo_ptdto)));
    }




    @ApiOperation(value = "Save", tags = {"EMWO_PT" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/emwo_pts/save")
    public ResponseEntity<Boolean> save(@RequestBody EMWO_PTDTO emwo_ptdto) {
        return ResponseEntity.status(HttpStatus.OK).body(emwo_ptService.save(emwo_ptMapping.toDomain(emwo_ptdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"EMWO_PT" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/emwo_pts/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<EMWO_PTDTO> emwo_ptdtos) {
        emwo_ptService.saveBatch(emwo_ptMapping.toDomain(emwo_ptdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emwo_pt_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"EMWO_PT" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/emwo_pts/{emwo_pt_id}")
    @Transactional
    public ResponseEntity<EMWO_PTDTO> update(@PathVariable("emwo_pt_id") String emwo_pt_id, @RequestBody EMWO_PTDTO emwo_ptdto) {
		EMWO_PT domain = emwo_ptMapping.toDomain(emwo_ptdto);
        domain.setEmwoPtid(emwo_pt_id);
		emwo_ptService.update(domain);
		EMWO_PTDTO dto = emwo_ptMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#emwo_pt_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"EMWO_PT" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/emwo_pts/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<EMWO_PTDTO> emwo_ptdtos) {
        emwo_ptService.updateBatch(emwo_ptMapping.toDomain(emwo_ptdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#emwo_pt_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"EMWO_PT" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/emwo_pts/{emwo_pt_id}")
    public ResponseEntity<EMWO_PTDTO> get(@PathVariable("emwo_pt_id") String emwo_pt_id) {
        EMWO_PT domain = emwo_ptService.get(emwo_pt_id);
        EMWO_PTDTO dto = emwo_ptMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"EMWO_PT" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emwo_pts/fetchdefault")
	public ResponseEntity<List<EMWO_PTDTO>> fetchDefault(EMWO_PTSearchContext context) {
        Page<EMWO_PT> domains = emwo_ptService.searchDefault(context) ;
        List<EMWO_PTDTO> list = emwo_ptMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"EMWO_PT" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/emwo_pts/searchdefault")
	public ResponseEntity<Page<EMWO_PTDTO>> searchDefault(EMWO_PTSearchContext context) {
        Page<EMWO_PT> domains = emwo_ptService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emwo_ptMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "CreateByEMEQUIP", tags = {"EMWO_PT" },  notes = "CreateByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emwo_pts")
    @Transactional
    public ResponseEntity<EMWO_PTDTO> createByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody EMWO_PTDTO emwo_ptdto) {
        EMWO_PT domain = emwo_ptMapping.toDomain(emwo_ptdto);
        domain.setEquipid(emequip_id);
		emwo_ptService.create(domain);
        EMWO_PTDTO dto = emwo_ptMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMEQUIP", tags = {"EMWO_PT" },  notes = "createBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emwo_pts/batch")
    public ResponseEntity<Boolean> createBatchByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody List<EMWO_PTDTO> emwo_ptdtos) {
        List<EMWO_PT> domainlist=emwo_ptMapping.toDomain(emwo_ptdtos);
        for(EMWO_PT domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emwo_ptService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByEMEQUIP", tags = {"EMWO_PT" },  notes = "RemoveByEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emequips/{emequip_id}/emwo_pts/{emwo_pt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @PathVariable("emwo_pt_id") String emwo_pt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emwo_ptService.remove(emwo_pt_id));
    }

    @ApiOperation(value = "RemoveBatchByEMEQUIP", tags = {"EMWO_PT" },  notes = "RemoveBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emequips/{emequip_id}/emwo_pts/batch")
    public ResponseEntity<Boolean> removeBatchByEMEQUIP(@RequestBody List<String> ids) {
        emwo_ptService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMEQUIP", tags = {"EMWO_PT" },  notes = "GetDraftByEMEQUIP")
    @RequestMapping(method = RequestMethod.GET, value = "/emequips/{emequip_id}/emwo_pts/getdraft")
    public ResponseEntity<EMWO_PTDTO> getDraftByEMEQUIP(@PathVariable("emequip_id") String emequip_id) {
        EMWO_PT domain = new EMWO_PT();
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emwo_ptMapping.toDto(emwo_ptService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByEMEQUIP", tags = {"EMWO_PT" },  notes = "CheckKeyByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emwo_pts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody EMWO_PTDTO emwo_ptdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emwo_ptService.checkKey(emwo_ptMapping.toDomain(emwo_ptdto)));
    }

    @ApiOperation(value = "SaveByEMEQUIP", tags = {"EMWO_PT" },  notes = "SaveByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emwo_pts/save")
    public ResponseEntity<Boolean> saveByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody EMWO_PTDTO emwo_ptdto) {
        EMWO_PT domain = emwo_ptMapping.toDomain(emwo_ptdto);
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emwo_ptService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMEQUIP", tags = {"EMWO_PT" },  notes = "SaveBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emequips/{emequip_id}/emwo_pts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody List<EMWO_PTDTO> emwo_ptdtos) {
        List<EMWO_PT> domainlist=emwo_ptMapping.toDomain(emwo_ptdtos);
        for(EMWO_PT domain:domainlist){
             domain.setEquipid(emequip_id);
        }
        emwo_ptService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMEQUIP", tags = {"EMWO_PT" },  notes = "UpdateByEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emequips/{emequip_id}/emwo_pts/{emwo_pt_id}")
    @Transactional
    public ResponseEntity<EMWO_PTDTO> updateByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @PathVariable("emwo_pt_id") String emwo_pt_id, @RequestBody EMWO_PTDTO emwo_ptdto) {
        EMWO_PT domain = emwo_ptMapping.toDomain(emwo_ptdto);
        domain.setEquipid(emequip_id);
        domain.setEmwoPtid(emwo_pt_id);
		emwo_ptService.update(domain);
        EMWO_PTDTO dto = emwo_ptMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMEQUIP", tags = {"EMWO_PT" },  notes = "UpdateBatchByEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emequips/{emequip_id}/emwo_pts/batch")
    public ResponseEntity<Boolean> updateBatchByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @RequestBody List<EMWO_PTDTO> emwo_ptdtos) {
        List<EMWO_PT> domainlist=emwo_ptMapping.toDomain(emwo_ptdtos);
        for(EMWO_PT domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emwo_ptService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMEQUIP", tags = {"EMWO_PT" },  notes = "GetByEMEQUIP")
	@RequestMapping(method = RequestMethod.GET, value = "/emequips/{emequip_id}/emwo_pts/{emwo_pt_id}")
    public ResponseEntity<EMWO_PTDTO> getByEMEQUIP(@PathVariable("emequip_id") String emequip_id, @PathVariable("emwo_pt_id") String emwo_pt_id) {
        EMWO_PT domain = emwo_ptService.get(emwo_pt_id);
        EMWO_PTDTO dto = emwo_ptMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "fetchDEFAULTByEMEQUIP", tags = {"EMWO_PT" } ,notes = "fetchDEFAULTByEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emequips/{emequip_id}/emwo_pts/fetchdefault")
	public ResponseEntity<List<EMWO_PTDTO>> fetchEMWO_PTDefaultByEMEQUIP(@PathVariable("emequip_id") String emequip_id,EMWO_PTSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMWO_PT> domains = emwo_ptService.searchDefault(context) ;
        List<EMWO_PTDTO> list = emwo_ptMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMEQUIP", tags = {"EMWO_PT" } ,notes = "searchDEFAULTByEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emequips/{emequip_id}/emwo_pts/searchdefault")
	public ResponseEntity<Page<EMWO_PTDTO>> searchEMWO_PTDefaultByEMEQUIP(@PathVariable("emequip_id") String emequip_id,EMWO_PTSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMWO_PT> domains = emwo_ptService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emwo_ptMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CreateByEMEQTYPEEMEQUIP", tags = {"EMWO_PT" },  notes = "CreateByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emwo_pts")
    @Transactional
    public ResponseEntity<EMWO_PTDTO> createByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMWO_PTDTO emwo_ptdto) {
        EMWO_PT domain = emwo_ptMapping.toDomain(emwo_ptdto);
        domain.setEquipid(emequip_id);
		emwo_ptService.create(domain);
        EMWO_PTDTO dto = emwo_ptMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByEMEQTYPEEMEQUIP", tags = {"EMWO_PT" },  notes = "createBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emwo_pts/batch")
    public ResponseEntity<Boolean> createBatchByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMWO_PTDTO> emwo_ptdtos) {
        List<EMWO_PT> domainlist=emwo_ptMapping.toDomain(emwo_ptdtos);
        for(EMWO_PT domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emwo_ptService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByEMEQTYPEEMEQUIP", tags = {"EMWO_PT" },  notes = "RemoveByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emwo_pts/{emwo_pt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emwo_pt_id") String emwo_pt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emwo_ptService.remove(emwo_pt_id));
    }

    @ApiOperation(value = "RemoveBatchByEMEQTYPEEMEQUIP", tags = {"EMWO_PT" },  notes = "RemoveBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emwo_pts/batch")
    public ResponseEntity<Boolean> removeBatchByEMEQTYPEEMEQUIP(@RequestBody List<String> ids) {
        emwo_ptService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByEMEQTYPEEMEQUIP", tags = {"EMWO_PT" },  notes = "GetDraftByEMEQTYPEEMEQUIP")
    @RequestMapping(method = RequestMethod.GET, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emwo_pts/getdraft")
    public ResponseEntity<EMWO_PTDTO> getDraftByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id) {
        EMWO_PT domain = new EMWO_PT();
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emwo_ptMapping.toDto(emwo_ptService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByEMEQTYPEEMEQUIP", tags = {"EMWO_PT" },  notes = "CheckKeyByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emwo_pts/checkkey")
    public ResponseEntity<Boolean> checkKeyByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMWO_PTDTO emwo_ptdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emwo_ptService.checkKey(emwo_ptMapping.toDomain(emwo_ptdto)));
    }

    @ApiOperation(value = "SaveByEMEQTYPEEMEQUIP", tags = {"EMWO_PT" },  notes = "SaveByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emwo_pts/save")
    public ResponseEntity<Boolean> saveByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMWO_PTDTO emwo_ptdto) {
        EMWO_PT domain = emwo_ptMapping.toDomain(emwo_ptdto);
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emwo_ptService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByEMEQTYPEEMEQUIP", tags = {"EMWO_PT" },  notes = "SaveBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emwo_pts/savebatch")
    public ResponseEntity<Boolean> saveBatchByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMWO_PTDTO> emwo_ptdtos) {
        List<EMWO_PT> domainlist=emwo_ptMapping.toDomain(emwo_ptdtos);
        for(EMWO_PT domain:domainlist){
             domain.setEquipid(emequip_id);
        }
        emwo_ptService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByEMEQTYPEEMEQUIP", tags = {"EMWO_PT" },  notes = "UpdateByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emwo_pts/{emwo_pt_id}")
    @Transactional
    public ResponseEntity<EMWO_PTDTO> updateByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emwo_pt_id") String emwo_pt_id, @RequestBody EMWO_PTDTO emwo_ptdto) {
        EMWO_PT domain = emwo_ptMapping.toDomain(emwo_ptdto);
        domain.setEquipid(emequip_id);
        domain.setEmwoPtid(emwo_pt_id);
		emwo_ptService.update(domain);
        EMWO_PTDTO dto = emwo_ptMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByEMEQTYPEEMEQUIP", tags = {"EMWO_PT" },  notes = "UpdateBatchByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emwo_pts/batch")
    public ResponseEntity<Boolean> updateBatchByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMWO_PTDTO> emwo_ptdtos) {
        List<EMWO_PT> domainlist=emwo_ptMapping.toDomain(emwo_ptdtos);
        for(EMWO_PT domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emwo_ptService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByEMEQTYPEEMEQUIP", tags = {"EMWO_PT" },  notes = "GetByEMEQTYPEEMEQUIP")
	@RequestMapping(method = RequestMethod.GET, value = "/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emwo_pts/{emwo_pt_id}")
    public ResponseEntity<EMWO_PTDTO> getByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emwo_pt_id") String emwo_pt_id) {
        EMWO_PT domain = emwo_ptService.get(emwo_pt_id);
        EMWO_PTDTO dto = emwo_ptMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "fetchDEFAULTByEMEQTYPEEMEQUIP", tags = {"EMWO_PT" } ,notes = "fetchDEFAULTByEMEQTYPEEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emwo_pts/fetchdefault")
	public ResponseEntity<List<EMWO_PTDTO>> fetchEMWO_PTDefaultByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id,EMWO_PTSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMWO_PT> domains = emwo_ptService.searchDefault(context) ;
        List<EMWO_PTDTO> list = emwo_ptMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByEMEQTYPEEMEQUIP", tags = {"EMWO_PT" } ,notes = "searchDEFAULTByEMEQTYPEEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/emeqtypes/{emeqtype_id}/emequips/{emequip_id}/emwo_pts/searchdefault")
	public ResponseEntity<Page<EMWO_PTDTO>> searchEMWO_PTDefaultByEMEQTYPEEMEQUIP(@PathVariable("emeqtype_id") String emeqtype_id, @PathVariable("emequip_id") String emequip_id,EMWO_PTSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMWO_PT> domains = emwo_ptService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emwo_ptMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}




    @ApiOperation(value = "CreateByPFTEAMEMEQUIP", tags = {"EMWO_PT" },  notes = "CreateByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emwo_pts")
    @Transactional
    public ResponseEntity<EMWO_PTDTO> createByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMWO_PTDTO emwo_ptdto) {
        EMWO_PT domain = emwo_ptMapping.toDomain(emwo_ptdto);
        domain.setEquipid(emequip_id);
		emwo_ptService.create(domain);
        EMWO_PTDTO dto = emwo_ptMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByPFTEAMEMEQUIP", tags = {"EMWO_PT" },  notes = "createBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emwo_pts/batch")
    public ResponseEntity<Boolean> createBatchByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMWO_PTDTO> emwo_ptdtos) {
        List<EMWO_PT> domainlist=emwo_ptMapping.toDomain(emwo_ptdtos);
        for(EMWO_PT domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emwo_ptService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByPFTEAMEMEQUIP", tags = {"EMWO_PT" },  notes = "RemoveByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emwo_pts/{emwo_pt_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emwo_pt_id") String emwo_pt_id) {
		return ResponseEntity.status(HttpStatus.OK).body(emwo_ptService.remove(emwo_pt_id));
    }

    @ApiOperation(value = "RemoveBatchByPFTEAMEMEQUIP", tags = {"EMWO_PT" },  notes = "RemoveBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emwo_pts/batch")
    public ResponseEntity<Boolean> removeBatchByPFTEAMEMEQUIP(@RequestBody List<String> ids) {
        emwo_ptService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraftByPFTEAMEMEQUIP", tags = {"EMWO_PT" },  notes = "GetDraftByPFTEAMEMEQUIP")
    @RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emwo_pts/getdraft")
    public ResponseEntity<EMWO_PTDTO> getDraftByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id) {
        EMWO_PT domain = new EMWO_PT();
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emwo_ptMapping.toDto(emwo_ptService.getDraft(domain)));
    }

    @ApiOperation(value = "CheckKeyByPFTEAMEMEQUIP", tags = {"EMWO_PT" },  notes = "CheckKeyByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emwo_pts/checkkey")
    public ResponseEntity<Boolean> checkKeyByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMWO_PTDTO emwo_ptdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(emwo_ptService.checkKey(emwo_ptMapping.toDomain(emwo_ptdto)));
    }

    @ApiOperation(value = "SaveByPFTEAMEMEQUIP", tags = {"EMWO_PT" },  notes = "SaveByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emwo_pts/save")
    public ResponseEntity<Boolean> saveByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody EMWO_PTDTO emwo_ptdto) {
        EMWO_PT domain = emwo_ptMapping.toDomain(emwo_ptdto);
        domain.setEquipid(emequip_id);
        return ResponseEntity.status(HttpStatus.OK).body(emwo_ptService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByPFTEAMEMEQUIP", tags = {"EMWO_PT" },  notes = "SaveBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.POST, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emwo_pts/savebatch")
    public ResponseEntity<Boolean> saveBatchByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMWO_PTDTO> emwo_ptdtos) {
        List<EMWO_PT> domainlist=emwo_ptMapping.toDomain(emwo_ptdtos);
        for(EMWO_PT domain:domainlist){
             domain.setEquipid(emequip_id);
        }
        emwo_ptService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByPFTEAMEMEQUIP", tags = {"EMWO_PT" },  notes = "UpdateByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emwo_pts/{emwo_pt_id}")
    @Transactional
    public ResponseEntity<EMWO_PTDTO> updateByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emwo_pt_id") String emwo_pt_id, @RequestBody EMWO_PTDTO emwo_ptdto) {
        EMWO_PT domain = emwo_ptMapping.toDomain(emwo_ptdto);
        domain.setEquipid(emequip_id);
        domain.setEmwoPtid(emwo_pt_id);
		emwo_ptService.update(domain);
        EMWO_PTDTO dto = emwo_ptMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByPFTEAMEMEQUIP", tags = {"EMWO_PT" },  notes = "UpdateBatchByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emwo_pts/batch")
    public ResponseEntity<Boolean> updateBatchByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @RequestBody List<EMWO_PTDTO> emwo_ptdtos) {
        List<EMWO_PT> domainlist=emwo_ptMapping.toDomain(emwo_ptdtos);
        for(EMWO_PT domain:domainlist){
            domain.setEquipid(emequip_id);
        }
        emwo_ptService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByPFTEAMEMEQUIP", tags = {"EMWO_PT" },  notes = "GetByPFTEAMEMEQUIP")
	@RequestMapping(method = RequestMethod.GET, value = "/pfteams/{pfteam_id}/emequips/{emequip_id}/emwo_pts/{emwo_pt_id}")
    public ResponseEntity<EMWO_PTDTO> getByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id, @PathVariable("emwo_pt_id") String emwo_pt_id) {
        EMWO_PT domain = emwo_ptService.get(emwo_pt_id);
        EMWO_PTDTO dto = emwo_ptMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "fetchDEFAULTByPFTEAMEMEQUIP", tags = {"EMWO_PT" } ,notes = "fetchDEFAULTByPFTEAMEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emequips/{emequip_id}/emwo_pts/fetchdefault")
	public ResponseEntity<List<EMWO_PTDTO>> fetchEMWO_PTDefaultByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id,EMWO_PTSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMWO_PT> domains = emwo_ptService.searchDefault(context) ;
        List<EMWO_PTDTO> list = emwo_ptMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByPFTEAMEMEQUIP", tags = {"EMWO_PT" } ,notes = "searchDEFAULTByPFTEAMEMEQUIP")
    @RequestMapping(method= RequestMethod.GET , value="/pfteams/{pfteam_id}/emequips/{emequip_id}/emwo_pts/searchdefault")
	public ResponseEntity<Page<EMWO_PTDTO>> searchEMWO_PTDefaultByPFTEAMEMEQUIP(@PathVariable("pfteam_id") String pfteam_id, @PathVariable("emequip_id") String emequip_id,EMWO_PTSearchContext context) {
        context.setN_equipid_eq(emequip_id);
        Page<EMWO_PT> domains = emwo_ptService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(emwo_ptMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public EMWO_PT getEntity(){
        return new EMWO_PT();
    }

}
