package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_pf.domain.PFCONTRACT;
import cn.ibizlab.eam.core.eam_pf.service.IPFCONTRACTService;
import cn.ibizlab.eam.core.eam_pf.filter.PFCONTRACTSearchContext;




@Slf4j
@Api(tags = {"PFCONTRACT" })
@RestController("WebApi-pfcontract")
@RequestMapping("")
public class PFCONTRACTResource {

    @Autowired
    private IPFCONTRACTService pfcontractService;

    @Autowired
    @Lazy
    private PFCONTRACTMapping pfcontractMapping;




    @PreAuthorize("hasPermission('Remove',{#pfcontract_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"PFCONTRACT" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfcontracts/{pfcontract_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("pfcontract_id") String pfcontract_id) {
         return ResponseEntity.status(HttpStatus.OK).body(pfcontractService.remove(pfcontract_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"PFCONTRACT" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfcontracts/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        pfcontractService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#pfcontract_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"PFCONTRACT" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/pfcontracts/{pfcontract_id}")
    public ResponseEntity<PFCONTRACTDTO> get(@PathVariable("pfcontract_id") String pfcontract_id) {
        PFCONTRACT domain = pfcontractService.get(pfcontract_id);
        PFCONTRACTDTO dto = pfcontractMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @ApiOperation(value = "GetDraft", tags = {"PFCONTRACT" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/pfcontracts/getdraft")
    public ResponseEntity<PFCONTRACTDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(pfcontractMapping.toDto(pfcontractService.getDraft(new PFCONTRACT())));
    }




    @ApiOperation(value = "Save", tags = {"PFCONTRACT" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/pfcontracts/save")
    public ResponseEntity<Boolean> save(@RequestBody PFCONTRACTDTO pfcontractdto) {
        return ResponseEntity.status(HttpStatus.OK).body(pfcontractService.save(pfcontractMapping.toDomain(pfcontractdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"PFCONTRACT" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/pfcontracts/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<PFCONTRACTDTO> pfcontractdtos) {
        pfcontractService.saveBatch(pfcontractMapping.toDomain(pfcontractdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"PFCONTRACT" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/pfcontracts/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody PFCONTRACTDTO pfcontractdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(pfcontractService.checkKey(pfcontractMapping.toDomain(pfcontractdto)));
    }




    @PreAuthorize("hasPermission(#pfcontract_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"PFCONTRACT" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfcontracts/{pfcontract_id}")
    @Transactional
    public ResponseEntity<PFCONTRACTDTO> update(@PathVariable("pfcontract_id") String pfcontract_id, @RequestBody PFCONTRACTDTO pfcontractdto) {
		PFCONTRACT domain = pfcontractMapping.toDomain(pfcontractdto);
        domain.setPfcontractid(pfcontract_id);
		pfcontractService.update(domain);
		PFCONTRACTDTO dto = pfcontractMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#pfcontract_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"PFCONTRACT" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfcontracts/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<PFCONTRACTDTO> pfcontractdtos) {
        pfcontractService.updateBatch(pfcontractMapping.toDomain(pfcontractdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"PFCONTRACT" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/pfcontracts")
    @Transactional
    public ResponseEntity<PFCONTRACTDTO> create(@RequestBody PFCONTRACTDTO pfcontractdto) {
        PFCONTRACT domain = pfcontractMapping.toDomain(pfcontractdto);
		pfcontractService.create(domain);
        PFCONTRACTDTO dto = pfcontractMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"PFCONTRACT" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/pfcontracts/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<PFCONTRACTDTO> pfcontractdtos) {
        pfcontractService.createBatch(pfcontractMapping.toDomain(pfcontractdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"PFCONTRACT" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/pfcontracts/fetchdefault")
	public ResponseEntity<List<PFCONTRACTDTO>> fetchDefault(PFCONTRACTSearchContext context) {
        Page<PFCONTRACT> domains = pfcontractService.searchDefault(context) ;
        List<PFCONTRACTDTO> list = pfcontractMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"PFCONTRACT" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/pfcontracts/searchdefault")
	public ResponseEntity<Page<PFCONTRACTDTO>> searchDefault(PFCONTRACTSearchContext context) {
        Page<PFCONTRACT> domains = pfcontractService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(pfcontractMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public PFCONTRACT getEntity(){
        return new PFCONTRACT();
    }

}
