package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_pf.domain.PFEMPPOSTMAP;
import cn.ibizlab.eam.core.eam_pf.service.IPFEMPPOSTMAPService;
import cn.ibizlab.eam.core.eam_pf.filter.PFEMPPOSTMAPSearchContext;




@Slf4j
@Api(tags = {"PFEMPPOSTMAP" })
@RestController("WebApi-pfemppostmap")
@RequestMapping("")
public class PFEMPPOSTMAPResource {

    @Autowired
    private IPFEMPPOSTMAPService pfemppostmapService;

    @Autowired
    @Lazy
    private PFEMPPOSTMAPMapping pfemppostmapMapping;




    @PreAuthorize("hasPermission(#pfemppostmap_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"PFEMPPOSTMAP" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/pfemppostmaps/{pfemppostmap_id}")
    public ResponseEntity<PFEMPPOSTMAPDTO> get(@PathVariable("pfemppostmap_id") String pfemppostmap_id) {
        PFEMPPOSTMAP domain = pfemppostmapService.get(pfemppostmap_id);
        PFEMPPOSTMAPDTO dto = pfemppostmapMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"PFEMPPOSTMAP" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemppostmaps")
    @Transactional
    public ResponseEntity<PFEMPPOSTMAPDTO> create(@RequestBody PFEMPPOSTMAPDTO pfemppostmapdto) {
        PFEMPPOSTMAP domain = pfemppostmapMapping.toDomain(pfemppostmapdto);
		pfemppostmapService.create(domain);
        PFEMPPOSTMAPDTO dto = pfemppostmapMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"PFEMPPOSTMAP" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemppostmaps/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<PFEMPPOSTMAPDTO> pfemppostmapdtos) {
        pfemppostmapService.createBatch(pfemppostmapMapping.toDomain(pfemppostmapdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission('Remove',{#pfemppostmap_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"PFEMPPOSTMAP" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemppostmaps/{pfemppostmap_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("pfemppostmap_id") String pfemppostmap_id) {
         return ResponseEntity.status(HttpStatus.OK).body(pfemppostmapService.remove(pfemppostmap_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"PFEMPPOSTMAP" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pfemppostmaps/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        pfemppostmapService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "GetDraft", tags = {"PFEMPPOSTMAP" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/pfemppostmaps/getdraft")
    public ResponseEntity<PFEMPPOSTMAPDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(pfemppostmapMapping.toDto(pfemppostmapService.getDraft(new PFEMPPOSTMAP())));
    }




    @ApiOperation(value = "Save", tags = {"PFEMPPOSTMAP" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemppostmaps/save")
    public ResponseEntity<Boolean> save(@RequestBody PFEMPPOSTMAPDTO pfemppostmapdto) {
        return ResponseEntity.status(HttpStatus.OK).body(pfemppostmapService.save(pfemppostmapMapping.toDomain(pfemppostmapdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"PFEMPPOSTMAP" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemppostmaps/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<PFEMPPOSTMAPDTO> pfemppostmapdtos) {
        pfemppostmapService.saveBatch(pfemppostmapMapping.toDomain(pfemppostmapdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "CheckKey", tags = {"PFEMPPOSTMAP" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/pfemppostmaps/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody PFEMPPOSTMAPDTO pfemppostmapdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(pfemppostmapService.checkKey(pfemppostmapMapping.toDomain(pfemppostmapdto)));
    }




    @PreAuthorize("hasPermission(#pfemppostmap_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"PFEMPPOSTMAP" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemppostmaps/{pfemppostmap_id}")
    @Transactional
    public ResponseEntity<PFEMPPOSTMAPDTO> update(@PathVariable("pfemppostmap_id") String pfemppostmap_id, @RequestBody PFEMPPOSTMAPDTO pfemppostmapdto) {
		PFEMPPOSTMAP domain = pfemppostmapMapping.toDomain(pfemppostmapdto);
        domain.setPfemppostmapid(pfemppostmap_id);
		pfemppostmapService.update(domain);
		PFEMPPOSTMAPDTO dto = pfemppostmapMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#pfemppostmap_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"PFEMPPOSTMAP" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/pfemppostmaps/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<PFEMPPOSTMAPDTO> pfemppostmapdtos) {
        pfemppostmapService.updateBatch(pfemppostmapMapping.toDomain(pfemppostmapdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"PFEMPPOSTMAP" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/pfemppostmaps/fetchdefault")
	public ResponseEntity<List<PFEMPPOSTMAPDTO>> fetchDefault(PFEMPPOSTMAPSearchContext context) {
        Page<PFEMPPOSTMAP> domains = pfemppostmapService.searchDefault(context) ;
        List<PFEMPPOSTMAPDTO> list = pfemppostmapMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"PFEMPPOSTMAP" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/pfemppostmaps/searchdefault")
	public ResponseEntity<Page<PFEMPPOSTMAPDTO>> searchDefault(PFEMPPOSTMAPSearchContext context) {
        Page<PFEMPPOSTMAP> domains = pfemppostmapService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(pfemppostmapMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public PFEMPPOSTMAP getEntity(){
        return new PFEMPPOSTMAP();
    }

}
