package cn.ibizlab.eam.webapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.eam.webapi.dto.*;
import cn.ibizlab.eam.webapi.mapping.*;
import cn.ibizlab.eam.core.eam_pf.domain.PFORG;
import cn.ibizlab.eam.core.eam_pf.service.IPFORGService;
import cn.ibizlab.eam.core.eam_pf.filter.PFORGSearchContext;




@Slf4j
@Api(tags = {"PFORG" })
@RestController("WebApi-pforg")
@RequestMapping("")
public class PFORGResource {

    @Autowired
    private IPFORGService pforgService;

    @Autowired
    @Lazy
    private PFORGMapping pforgMapping;




    @ApiOperation(value = "GetDraft", tags = {"PFORG" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/pforgs/getdraft")
    public ResponseEntity<PFORGDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(pforgMapping.toDto(pforgService.getDraft(new PFORG())));
    }




    @ApiOperation(value = "CheckKey", tags = {"PFORG" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/pforgs/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody PFORGDTO pforgdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(pforgService.checkKey(pforgMapping.toDomain(pforgdto)));
    }




    @PreAuthorize("hasPermission('Remove',{#pforg_id,{this.getEntity(),'Sql'}})")
    @ApiOperation(value = "Remove", tags = {"PFORG" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pforgs/{pforg_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("pforg_id") String pforg_id) {
         return ResponseEntity.status(HttpStatus.OK).body(pforgService.remove(pforg_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"PFORG" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/pforgs/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        pforgService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#pforg_id,'Get',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Get", tags = {"PFORG" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/pforgs/{pforg_id}")
    public ResponseEntity<PFORGDTO> get(@PathVariable("pforg_id") String pforg_id) {
        PFORG domain = pforgService.get(pforg_id);
        PFORGDTO dto = pforgMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }




    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Create", tags = {"PFORG" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/pforgs")
    @Transactional
    public ResponseEntity<PFORGDTO> create(@RequestBody PFORGDTO pforgdto) {
        PFORG domain = pforgMapping.toDomain(pforgdto);
		pforgService.create(domain);
        PFORGDTO dto = pforgMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission('','Create',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "createBatch", tags = {"PFORG" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/pforgs/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<PFORGDTO> pforgdtos) {
        pforgService.createBatch(pforgMapping.toDomain(pforgdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasPermission(#pforg_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "Update", tags = {"PFORG" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/pforgs/{pforg_id}")
    @Transactional
    public ResponseEntity<PFORGDTO> update(@PathVariable("pforg_id") String pforg_id, @RequestBody PFORGDTO pforgdto) {
		PFORG domain = pforgMapping.toDomain(pforgdto);
        domain.setPforgid(pforg_id);
		pforgService.update(domain);
		PFORGDTO dto = pforgMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(#pforg_id,'Update',{this.getEntity(),'Sql'})")
    @ApiOperation(value = "UpdateBatch", tags = {"PFORG" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/pforgs/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<PFORGDTO> pforgdtos) {
        pforgService.updateBatch(pforgMapping.toDomain(pforgdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"PFORG" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/pforgs/save")
    public ResponseEntity<Boolean> save(@RequestBody PFORGDTO pforgdto) {
        return ResponseEntity.status(HttpStatus.OK).body(pforgService.save(pforgMapping.toDomain(pforgdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"PFORG" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/pforgs/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<PFORGDTO> pforgdtos) {
        pforgService.saveBatch(pforgMapping.toDomain(pforgdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "fetchDEFAULT", tags = {"PFORG" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/pforgs/fetchdefault")
	public ResponseEntity<List<PFORGDTO>> fetchDefault(PFORGSearchContext context) {
        Page<PFORG> domains = pforgService.searchDefault(context) ;
        List<PFORGDTO> list = pforgMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasPermission('Get',{#context,'Default',this.getEntity(),'Sql'})")
	@ApiOperation(value = "searchDEFAULT", tags = {"PFORG" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/pforgs/searchdefault")
	public ResponseEntity<Page<PFORGDTO>> searchDefault(PFORGSearchContext context) {
        Page<PFORG> domains = pforgService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(pforgMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public PFORG getEntity(){
        return new PFORG();
    }

}
